#!/usr/bin/env python
# encoding: utf-8

name = "H_Abstraction/NIST"
shortDesc = u""
longDesc = u"""

"""
entry(
    index = 1,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.006864, 'm^3/(mol*s)', '*|/', 2),
        n = 2.74,
        Ea = (39.411, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:109",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 2.0
""",
)

entry(
    index = 2,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0399, 'm^3/(mol*s)'),
        n = (2.24, '', '+|-', 0.18),
        Ea = (26.773, 'kJ/mol', '+|-', 1.073),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (1800, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Rabinowitz, M.J.", "Sutherland, J.W.", "Patterson, P.M.", "Klemm, R.B."],
        title = u'Direct rate constant measurements for H + CH4 \u2192\x92 CH3 + H2, 897-1729 K, using the flash photolysis-shock tube technique',
        journal = "J. Phys. Chem.",
        volume = "95",
        pages = """674-681""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991RAB/SUT674-681:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
""",
)

entry(
    index = 3,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.00029, 'm^3/(mol*s)', '*|/', 3),
        n = 3.12,
        Ea = (36.417, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:94",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 3.0
""",
)

entry(
    index = 4,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000661, 'm^3/(mol*s)', '*|/', 1.58),
        n = 3,
        Ea = (32.426, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:108",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 1.58
""",
)

entry(
    index = 5,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (537000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.485, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (350, 'K'),
        Tmax = (600, 'K'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Bell, T.N."],
        title = u'An evaluation of the kinetic data for hydrogen abstraction from silanes in the gas phase',
        journal = "Rev. Chem. Intermed.",
        volume = "2",
        pages = """37-74""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978ART/BEL37-74:19",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 6,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.3e+06, 'm^3/(mol*s)', '+|-', 500000),
        n = 0,
        Ea = (51.051, 'kJ/mol', '+|-', 3.575),
        T0 = (1, 'K'),
        Tmin = (372, 'K'),
        Tmax = (1790, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Activation energies of the reversible raction between hydrogen atoms and methane to give hydrogen and methyl radicals',
        journal = "J. Chem. Soc. A",
        pages = """2391""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968WAL2391:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 7,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(A=(1.14e+08, 'm^3/(mol*s)'), n=0, Ea=(89.913, 'kJ/mol'), T0=(1, 'K')),
    reference = Article(
        authors = ["Sutherland, J.W.", "Su, M.-C.", "Michael, J.V."],
        title = u'Rate Constants for H + CH4, CH3 + H2, and CH4 Dissociation at High Temperature',
        journal = "Int J. Chem. Kinet.",
        volume = "33",
        pages = """669-684""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001SUT/SU669-684:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Experimental procedure: Shock tube
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Vis-UV absorption

Excimer laser photolysis-shock tube technique coupled with H-atom atomic resonance absorption spectromtry has been used. The real time H atom profiles were fit with a complex mechanism to derive the best fit rate constants for the reactions, H+CH4-> CH3+H2, CH3+H2->H+CH4, as well as the reaction CH4+Kr->CH3+H+Kr

Results of this study and seven previous experimental studies have been evaluated. Results from theory are also discussed.
""",
)

entry(
    index = 8,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.73e+06, 'm^3/(mol*s)', '+|-', 1e+06),
        n = 0,
        Ea = (56.622, 'kJ/mol', '+|-', 0.566),
        T0 = (1, 'K'),
        Tmin = (646, 'K'),
        Tmax = (1100, 'K'),
        Pmin = (253, 'Pa'),
        Pmax = (1013, 'Pa'),
    ),
    reference = Article(
        authors = ["Knyazev, V.D.", "Bencsura, A.", "Stoliarov, S.I.", "Slagle, I.R."],
        title = u'Kinetics of the C2H3 + H2 = H + C2H4 and CH3 + H2 = H + CH4 reactions',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """11346-11354""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996KNY/BEN11346-11354:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 9,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (61.278, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1310, 'K'),
        Tmax = (1820, 'K'),
        Pmin = (3280, 'Pa'),
        Pmax = (3280, 'Pa'),
    ),
    reference = Article(
        authors = ["Baeck, H.J.", "Shin, K.S.", "Yang, H.", "Lissianski, V.", "Gardiner, W.C., Jr."],
        title = u'Reaction between CH3 and H2 at combustion temperatures',
        journal = "Bull. Korean Chem. Soc.",
        volume = "16",
        pages = """543-546""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995BAE/SHI543-546:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 10,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (64.687, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1250, 'K'),
        Tmax = (1950, 'K'),
    ),
    reference = Article(
        authors = ["Baeck, H.J.", "Shin, K.S.", "Yang, H.", "Qin, Z.", "Lissianski, V.", "Gardiner, W.C., Jr."],
        title = u'Shock tube study of the reaction between CH3 and H2',
        journal = "J. Phys. Chem.",
        volume = "99",
        pages = """15925-15929""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995BAE/SHI15925-15929:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 11,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (59.864, 'kJ/mol', '+|-', 3.592),
        T0 = (1, 'K'),
        Tmin = (1070, 'K'),
        Tmax = (2320, 'K'),
        Pmin = (22700, 'Pa'),
        Pmax = (90700, 'Pa'),
    ),
    reference = Article(
        authors = ["Moller, W.", "Mozzhukhin, E.", "Wagner, H.Gg."],
        title = u'High temperature reactions of CH3. 1. The reactions CH3 + H2 \u2192\x92 CH4 + H',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "90",
        pages = """854""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986MOL/MOZ854:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 12,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (501000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.984, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (584, 'K'),
        Tmax = (671, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (3466, 'Pa'),
    ),
    reference = Article(
        authors = ["Marshall, R.M.", "Shahkar, G."],
        title = u'Rate Parameters for CH3 + H2 \u2192\x92 CH4 + H in the Temperature Range 584-671 K',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "77",
        pages = """2271""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981MAR/SHA2271:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: (E)-CH3N=NCH3
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 13,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.794, 'm^3/(mol*s)'),
        n = 2,
        Ea = (39.993, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (372, 'K'),
        Tmax = (1370, 'K'),
        Pmin = (3600, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Kobrinsky, P.C.", "Pacey, P.D."],
        title = u'The Reaction of Methyl Radicals with Molecular Hydrogen',
        journal = "Can. J. Chem.",
        volume = "52",
        pages = """3665""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974KOB/PAC3665:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 14,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.9e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.822, 'kJ/mol', '+|-', 2.095),
        T0 = (1, 'K'),
        Tmin = (375, 'K'),
        Tmax = (447, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (12000, 'Pa'),
    ),
    reference = Article(
        authors = ["Ayscough, P.B.", "Polanyi, J.C."],
        title = u'The reactions of trifluoromethyl radicals with hydrogen isotopes',
        journal = "Trans. Faraday Soc.",
        volume = "52",
        pages = """961""",
        year = "1956",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1956AYS/POL961:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: H2
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 15,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.006383, 'm^3/(mol*s)'),
        n = 2.7,
        Ea = (37.008, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Methane and Chlorinated Methanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """3107-3122""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA3107-3122:22",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00002017

Derived from fits of a transition state theory model, the Marcus expression for correlation between reaction barriers and energetics, and analysis of experimental data reported in this reference. Transition state geometry and barriers were computed at the UMP2/6-31G(d,p) level. Eckart-level tunneling contributions are applied.
""",
)

entry(
    index = 16,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (151000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (35.004, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Maity, D.K.", "Duncan, W.T.", "Truong, T.N."],
        title = u'Direct ab initio dynamics studies of the hydrogen abstraction reactions of hydrogen atom with fluoromethanes',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """2152-2159""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999MAI/DUN2152-2159:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 17,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (638000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (40.491, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Espinosa-Garcia, J.", "Corchado, J.C."],
        title = u'Recalibration of two earlier potential energy surfaces for the CH4 + H \u2192\x92 CH3 + H2 reaction. Application of variational transition-state theory and analysis of the kinetic isotope effects using rectilinear and curvilinear coordinates',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """16561-16567""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996ESP/COR16561-16567:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 18,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.51e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.485, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (872, 'K'),
        Tmax = (1080, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Manion, J.A.", "Louw, R."],
        title = u'Gas-phase hydrogenolysis of chloroethene: Rates, products, and computer modelling',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1547-1555""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988MAN/LOU1547-1555:9",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: N2
""",
)

entry(
    index = 19,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.27e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (50.801, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (490, 'K'),
        Tmax = (1140, 'K'),
    ),
    reference = Article(
        authors = ["Leroy, G.", "Sana, M.", "Tinant, A."],
        title = u"Etude theorique des reactions d'abstraction d'hydrogene RH + X = R + HX, avec R, X\u2261H, CH3, NH2, OH et F",
        journal = "Can. J. Chem.",
        volume = "63",
        pages = """1447-1456""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985LER/SAN1447-1456:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 20,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (275000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (36.916, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (350, 'K'),
        Tmax = (600, 'K'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Donchi, K.F.", "McDonell, J.A."],
        title = u'BEBO calculations. Part 4. - Arrhenius parameters and kinetic isotope effects for the reactions of CH3 and CF3 radicals with H2 and D2',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "71",
        pages = """2431""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975ART/DON2431:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 21,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.55e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (64.853, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Clark, T.C.", "Dove, J.E."],
        title = u'The Rate Coefficient for CH3 + H2 \u2192\x92 CH4 + H Measured in Reflected Shock Waves; a Non-Arrhenius Reaction',
        journal = "Can. J. Chem.",
        volume = "51",
        pages = """2155""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973CLA/DOV2155:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 2.0
""",
)

entry(
    index = 22,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (316000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.822, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (750, 'K'),
        Tmax = (820, 'K'),
        Pmin = (4666, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Benson, S.W.", "Jain, D.V.S."],
        title = u'Further studies of the pyrolysis of dimethyl ether',
        journal = "J. Chem. Phys.",
        volume = "31",
        pages = """1008""",
        year = "1959",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1959BEN/JAI1008:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: (CH3)2O
""",
)

entry(
    index = 23,
    label = "H2 + CH3 <=> CH4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.86e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (37.332, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (693, 'K'),
    ),
    reference = Article(
        authors = ["Polanyi, J.C."],
        title = u'Rates of isotopic reactions between methyl and hydrogen',
        journal = "J. Chem. Phys.",
        volume = "23",
        pages = """1505""",
        year = "1955",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1955POL1505:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 24,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.004083, 'm^3/(mol*s)'),
        n = 3.16,
        Ea = (36.634, 'kJ/mol'),
        T0 = (1, 'K'),
    ),
    reference = Article(
        authors = ["Sutherland, J.W.", "Su, M.-C.", "Michael, J.V."],
        title = u'Rate Constants for H + CH4, CH3 + H2, and CH4 Dissociation at High Temperature',
        journal = "Int J. Chem. Kinet.",
        volume = "33",
        pages = """669-684""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001SUT/SU669-684:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Experimental procedure: Shock tube
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Vis-UV absorption

Excimer laser photolysis-shock tube technique coupled with H-atom atomic resonance absorption spectromtry has been used. The real time H atom profiles were fit with a complex mechanism to derive the best fit rate constants for the reactions, H+CH4-> CH3+H2, CH3+H2->H+CH4, as well as the reaction CH4+Kr->CH3+H+Kr

Results of this study and seven previous experimental studies have been evaluated. Results from theory are also discussed.
""",
)

entry(
    index = 25,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0133, 'm^3/(mol*s)', '*|/', 1.58),
        n = 3,
        Ea = (33.59, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:30",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 1.58
""",
)

entry(
    index = 26,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.86, 'm^3/(mol*s)'),
        n = (2.11, '', '+|-', 0.19),
        Ea = (32.426, 'kJ/mol', '+|-', 1.297),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (1800, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Rabinowitz, M.J.", "Sutherland, J.W.", "Patterson, P.M.", "Klemm, R.B."],
        title = u'Direct rate constant measurements for H + CH4 \u2192\x92 CH3 + H2, 897-1729 K, using the flash photolysis-shock tube technique',
        journal = "J. Phys. Chem.",
        volume = "95",
        pages = """674-681""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991RAB/SUT674-681:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
""",
)

entry(
    index = 27,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0224, 'm^3/(mol*s)', '*|/', 3),
        n = 3,
        Ea = (36.667, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:24",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 3.0
""",
)

entry(
    index = 28,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.022, 'm^3/(mol*s)', '*|/', 1.41),
        n = 3,
        Ea = (36.584, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:14",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 1.41
""",
)

entry(
    index = 29,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.59e+07, 'm^3/(mol*s)', '*|/', 1.15),
        n = 0,
        Ea = (49.887, 'kJ/mol', '+|-', 0.998),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (1800, 'K'),
        Pmin = (693, 'Pa'),
        Pmax = (1973, 'Pa'),
    ),
    reference = Article(
        authors = ["Sepehrad, A.", "Marshall, R.M.", "Purnell, H."],
        title = u'Reaction between Hydrogen Atoms and Methane',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """835""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979SEP/MAR835:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 1.15
Bath gas: Ar
""",
)

entry(
    index = 30,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.26e+08, 'm^3/(mol*s)', '+|-', 2.5e+07),
        n = 0,
        Ea = (49.804, 'kJ/mol', '+|-', 1.497),
        T0 = (1, 'K'),
        Tmin = (372, 'K'),
        Tmax = (1790, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Activation energies of the reversible raction between hydrogen atoms and methane to give hydrogen and methyl radicals',
        journal = "J. Chem. Soc. A",
        pages = """2391""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968WAL2391:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 31,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.31e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (52.714, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (350, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Dixon-Lewis, G.", "Williams, A."],
        title = u'Some observations on the combustion of methane in premixed flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "11",
        pages = """951-958""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967DIX/WIL951-958:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 2.0
Bath gas: N2
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 32,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(A=(1.77e+08, 'm^3/(mol*s)'), n=0, Ea=(57.653, 'kJ/mol'), T0=(1, 'K')),
    reference = Article(
        authors = ["Sutherland, J.W.", "Su, M.-C.", "Michael, J.V."],
        title = u'Rate Constants for H + CH4, CH3 + H2, and CH4 Dissociation at High Temperature',
        journal = "Int J. Chem. Kinet.",
        volume = "33",
        pages = """669-684""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001SUT/SU669-684:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Experimental procedure: Shock tube
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Vis-UV absorption

Excimer laser photolysis-shock tube technique coupled with H-atom atomic resonance absorption spectromtry has been used. The real time H atom profiles were fit with a complex mechanism to derive the best fit rate constants for the reactions, H+CH4-> CH3+H2, CH3+H2->H+CH4, as well as the reaction CH4+Kr->CH3+H+Kr

Results of this study and seven previous experimental studies have been evaluated. Results from theory are also discussed.
""",
)

entry(
    index = 33,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.54e+08, 'm^3/(mol*s)', '+|-', 5.36e+07),
        n = 0,
        Ea = (57.154, 'kJ/mol', '+|-', 2.22),
        T0 = (1, 'K'),
        Tmin = (748, 'K'),
        Tmax = (1054, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (859, 'Pa'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Methane and Chlorinated Methanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """3107-3122""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA3107-3122:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Pressure dependence: None reported
Experimental procedure: Flow tube - Data taken vs distance
Excitation technique: Discharge
Analytical technique: Resonance fluorescence

Error limits are 2 sigma and reflect only statistical contributions.
""",
)

entry(
    index = 34,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.1e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (63.19, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1310, 'K'),
        Tmax = (1820, 'K'),
        Pmin = (3280, 'Pa'),
        Pmax = (3280, 'Pa'),
    ),
    reference = Article(
        authors = ["Baeck, H.J.", "Shin, K.S.", "Yang, H.", "Lissianski, V.", "Gardiner, W.C., Jr."],
        title = u'Reaction between CH3 and H2 at combustion temperatures',
        journal = "Bull. Korean Chem. Soc.",
        volume = "16",
        pages = """543-546""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995BAE/SHI543-546:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
""",
)

entry(
    index = 35,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.4e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (65.185, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1250, 'K'),
        Tmax = (1950, 'K'),
    ),
    reference = Article(
        authors = ["Baeck, H.J.", "Shin, K.S.", "Yang, H.", "Qin, Z.", "Lissianski, V.", "Gardiner, W.C., Jr."],
        title = u'Shock tube study of the reaction between CH3 and H2',
        journal = "J. Phys. Chem.",
        volume = "99",
        pages = """15925-15929""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995BAE/SHI15925-15929:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
""",
)

entry(
    index = 36,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (321000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.923, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (348, 'K'),
        Tmax = (421, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Marquaire, P-M.", "Dastidar, A.G.", "Manthorne, K.C.", "Pacey, P.D."],
        title = u'Electron spin resonance study of the reaction of hydrogen atoms with methane',
        journal = "Can. J. Chem.",
        volume = "72",
        pages = """600-605""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994MAR/DAS600-605:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 37,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.07e+08, 'm^3/(mol*s)', '+|-', 5.4e+07),
        n = 0,
        Ea = (53.545, 'kJ/mol', '+|-', 0.535),
        T0 = (1, 'K'),
        Tmin = (897, 'K'),
        Tmax = (1730, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Rabinowitz, M.J.", "Sutherland, J.W.", "Patterson, P.M.", "Klemm, R.B."],
        title = u'Direct rate constant measurements for H + CH4 \u2192\x92 CH3 + H2, 897-1729 K, using the flash photolysis-shock tube technique',
        journal = "J. Phys. Chem.",
        volume = "95",
        pages = """674-681""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991RAB/SUT674-681:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 38,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.23e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (63.19, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1800, 'K'),
        Tmax = (2300, 'K'),
        Pmin = (600, 'Pa'),
        Pmax = (600, 'Pa'),
    ),
    reference = Article(
        authors = ["Roth, P."],
        title = u'ARAS-Messungen an einigen Hochtemperatur-Kohlenwasserstoff-Reaktionen',
        journal = "Forsch. Ingenieurwes.",
        volume = "46",
        pages = """93""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980ROT93:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 39,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.82e+08, 'm^3/(mol*s)', '*|/', 1.82),
        n = 0,
        Ea = (55.125, 'kJ/mol', '+|-', 3.309),
        T0 = (1, 'K'),
        Tmin = (640, 'K'),
        Tmax = (818, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (2000, 'Pa'),
    ),
    reference = Article(
        authors = ["Sepehrad, A.", "Marshall, R.M.", "Purnell, H."],
        title = u'Reaction between Hydrogen Atoms and Methane',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """835""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979SEP/MAR835:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 1.8200001
Bath gas: Ar
Excitation technique: Electron beam
Analytical technique: Gas chromatography
""",
)

entry(
    index = 40,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.23e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (63.024, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1700, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (175000, 'Pa'),
        Pmax = (185000, 'Pa'),
    ),
    reference = Article(
        authors = ["Roth, P.", "Just, T.H."],
        title = u'Measurements of Some Elementary Hydrocarbon Reactions at High Temperatures',
        journal = "NBS Spec. Publ. (U.S.)",
        volume = "10",
        pages = """1339""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979ROT/JUS1339:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 41,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.64e+10, 'm^3/(mol*s)'),
        n = 0,
        Ea = (112.245, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1320, 'K'),
        Tmax = (1700, 'K'),
    ),
    reference = Article(
        authors = ["Biordi, J.C.", "Lazzara, C.P.", "Papp, J.F."],
        title = u'Molecular beam mass spectrometry applied to determining the kinetics of reactions in flames. II. A critique of rate coefficient determinations',
        journal = "Combust. Flame",
        volume = "26",
        pages = """57""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976BIO/LAZ57:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 42,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.23e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (63.024, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1700, 'K'),
        Tmax = (2300, 'K'),
        Pmin = (160000, 'Pa'),
        Pmax = (160000, 'Pa'),
    ),
    reference = Article(
        authors = ["Roth, P.", "Just, Th."],
        title = u'Atom-Resonanzabsorptionsmessungen beim thermischen Zerfall von Methan hinter Stosswellen',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "79",
        pages = """682""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975ROT/JUS682:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 43,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.24e+08, 'm^3/(mol*s)', '*|/', 1.38),
        n = 0,
        Ea = (49.804, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'The Use of the H2 + O2 Reaction in Determining the Velocity Constants of Elementary Reactions in Hydrocarbon Oxidation',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """291""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAK/BAL291:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 1.38
""",
)

entry(
    index = 44,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.25e+07, 'm^3/(mol*s)', '+|-', 2e+07),
        n = 0,
        Ea = (48.557, 'kJ/mol', '+|-', 0.486),
        T0 = (1, 'K'),
        Tmin = (474, 'K'),
        Tmax = (732, 'K'),
        Pmin = (213, 'Pa'),
        Pmax = (680, 'Pa'),
    ),
    reference = Article(
        authors = ["Kurylo, M.J.", "Hollinden, G.A.", "Timmons, R.B."],
        title = u'ESR study of the kinetic isotope effect in the reaction of H and D atoms with CH4',
        journal = "J. Chem. Phys.",
        volume = "52",
        pages = """1773""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970KUR/HOL1773:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 45,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.9e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (49.388, 'kJ/mol', '+|-', 0.989),
        T0 = (1, 'K'),
        Tmin = (426, 'K'),
        Tmax = (752, 'K'),
        Pmin = (227, 'Pa'),
        Pmax = (827, 'Pa'),
    ),
    reference = Article(
        authors = ["Kurylo, M.J.", "Timmons, R.B."],
        title = u'ESR study of the kinetics of the reaction of H atoms with methane',
        journal = "J. Chem. Phys.",
        volume = "50",
        pages = """5076""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969KUR/TIM5076:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 46,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.21e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (44.316, 'kJ/mol', '+|-', 3.991),
        T0 = (1, 'K'),
        Tmin = (843, 'K'),
        Tmax = (933, 'K'),
        Pmin = (116, 'Pa'),
        Pmax = (208, 'Pa'),
    ),
    reference = Article(
        authors = ["Azatyan, V.V."],
        title = u'Combustion limitation method in the heterogeneous termination of chains in diffusion range',
        journal = "Arm. Khim. Zh.",
        volume = "20",
        pages = """577-584""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967AZA577-584:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 47,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.44e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (35.586, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (398, 'K'),
    ),
    reference = Article(
        authors = ["Lawrence, R.H., Jr.", "Firestone, R.F."],
        title = u'Kinetics of thermal deuterium atom reactions with methane and ethane',
        journal = "J. Am. Chem. Soc.",
        volume = "88",
        pages = """4564""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966LAW/FIR4564:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: N2
Excitation technique: Ultrasonics
Analytical technique: Gas chromatography
""",
)

entry(
    index = 48,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (603000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (30.93, 'kJ/mol', '+|-', 4.639),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (787, 'K'),
    ),
    reference = Article(
        authors = ["Jamieson, J.W.S.", "Brown, G.R."],
        title = u'The kinetics of the reaction of atomic hydrogen with methane',
        journal = "Can. J. Chem.",
        volume = "42",
        pages = """1638""",
        year = "1964",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1964JAM/BRO1638:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Gas chromatography
""",
)

entry(
    index = 49,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.31e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (63.19, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (753, 'K'),
        Pmin = (33300, 'Pa'),
        Pmax = (33300, 'Pa'),
    ),
    reference = Article(
        authors = ["Gorban, N.I.", "Nalbandyan, A.B."],
        title = u'Rate constants for the reactions of atomic hydrogen with simple saturated hydrocarbons',
        journal = "Russ. J. Phys. Chem. (Engl. Transl.)",
        volume = "36",
        pages = """946""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962GOR/NAL946:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 50,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (48.141, 'kJ/mol', '+|-', 6.252),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1800, 'K'),
    ),
    reference = Article(
        authors = ["Fenimore, C.P.", "Jones, G.W."],
        title = u'Rate of reaction of methane with H atoms and OH radicals in flames',
        journal = "J. Phys. Chem.",
        volume = "65",
        pages = """2200-2203""",
        year = "1961",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1961FEN/JON2200-2203:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 51,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (10000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (18.624, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (372, 'K'),
        Tmax = (436, 'K'),
        Pmin = (627, 'Pa'),
        Pmax = (733, 'Pa'),
    ),
    reference = Article(
        authors = ["Berlie, M.R.", "Le Roy, D.J."],
        title = u'Kinetics of the reaction H + CH4 = CH3 + H2',
        journal = "Can. J. Chem.",
        volume = "32",
        pages = """650""",
        year = "1954",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1954BER/LER650:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002017/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 52,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.69, 'm^3/(mol*s)'),
        n = 2.19,
        Ea = (32.618, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Pu, J.", "Truhlar, D.G."],
        title = u'Validation of Variational Transition State Theory with Multidimensional Tunneling Contributions Against Accurate Quantum Mechanical Dynamics for H + CH4 -&gt; H2 + CH3 in an Extended Temperature Interval',
        journal = "J. Chem. Phys.",
        volume = "117",
        pages = """1479-1481""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002PU/TRU1479-1481:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Pressure dependence: Rate constant is high pressure limit

Variational transition state theory (VTST) with microcanonically optimized multidimensional tunneling corrections used to validate theory to accurate quantum dynamics (QD) calculations. Ratio of VTST to QD calculations varies from 0.86 to 0.99 over stated temperature range. Rate constants fit to modified Arrhenius expression by abstracter.
""",
)

entry(
    index = 53,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.449, 'm^3/(mol*s)'),
        n = 2.59,
        Ea = (42.046, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Methane and Chlorinated Methanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """3107-3122""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA3107-3122:21",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00002017

Derived from fits of a transition state theory model, the Marcus expression for correlation between reaction barriers and energetics, and analysis of experimental data reported in this reference. Transition state geometry and barriers were computed at the UMP2/6-31G(d,p) level. Eckart-level tunneling contributions are applied.
""",
)

entry(
    index = 54,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.42e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (36.667, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Maity, D.K.", "Duncan, W.T.", "Truong, T.N."],
        title = u'Direct ab initio dynamics studies of the hydrogen abstraction reactions of hydrogen atom with fluoromethanes',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """2152-2159""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999MAI/DUN2152-2159:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 55,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (77.1, 'm^3/(mol*s)'),
        n = 1.97,
        Ea = (55.541, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Berry, R.J.", "Ehlers, C.J.", "Burgess, D.R., Jr.", "Zachariah, M.R.", "Marshall, P."],
        title = u'A computational study of the reactions of atomic hydrogen with fluoromethanes: kinetics and product channels',
        journal = "Chem. Phys. Lett.",
        volume = "269",
        pages = """107-116""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997BER/EHL107-116:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 56,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.11e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (48.723, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Espinosa-Garcia, J.", "Corchado, J.C."],
        title = u'Recalibration of two earlier potential energy surfaces for the CH4 + H \u2192\x92 CH3 + H2 reaction. Application of variational transition-state theory and analysis of the kinetic isotope effects using rectilinear and curvilinear coordinates',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """16561-16567""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996ESP/COR16561-16567:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 57,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (43, 'm^3/(mol*s)'),
        n = 1.89,
        Ea = (45.231, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Gonzalez, C.", "McDouall, J.J.W.", "Schlegel, H.B."],
        title = u'Ab initio study of the reactions between methane and OH, H, and 3O',
        journal = "J. Phys. Chem.",
        volume = "94",
        pages = """7467-7471""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990GON/MCD7467-7471:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 58,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.58e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (56.123, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (548, 'K'),
        Tmax = (1410, 'K'),
    ),
    reference = Article(
        authors = ["Leroy, G.", "Sana, M.", "Tinant, A."],
        title = u"Etude theorique des reactions d'abstraction d'hydrogene RH + X = R + HX, avec R, X\u2261H, CH3, NH2, OH et F",
        journal = "Can. J. Chem.",
        volume = "63",
        pages = """1447-1456""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985LER/SAN1447-1456:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 59,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (14.1, 'm^3/(mol*s)'),
        n = 2,
        Ea = (36.999, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Shaw, R."],
        title = u'Semi-Empirical Extrapolation and Estimation of Rate Constants for Abstraction of H From Methane by H, O, HO, and O2',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "7",
        pages = """1179""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978SHA1179:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 60,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0224, 'm^3/(mol*s)', '*|/', 1.05),
        n = 3,
        Ea = (36.584, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1800, 'K'),
    ),
    reference = Article(
        authors = ["Clark, T.C.", "Dove, J.E."],
        title = u'Examination of Possible Non-Arrhenius Behavior in the Reactions',
        journal = "Can. J. Chem.",
        volume = "51",
        pages = """2147""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973CLA/DOV2147:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Uncertainty: 1.05
""",
)

entry(
    index = 61,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7950, 'm^3/(mol*s)'),
        n = 1,
        Ea = (37.665, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1300, 'K'),
        Tmax = (1600, 'K'),
    ),
    reference = Article(
        authors = ["Skinner, G.B.", "Ruehrwein, R.A."],
        title = u'Shock tube studies on the pyrolysis and oxidation of methane',
        journal = "J. Phys. Chem.",
        volume = "63",
        pages = """1736""",
        year = "1959",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1959SKI/RUE1736:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
""",
)

entry(
    index = 62,
    label = "CH4 + H <=> H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.98e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.424, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (750, 'K'),
        Tmax = (820, 'K'),
        Pmin = (4666, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Benson, S.W.", "Jain, D.V.S."],
        title = u'Further studies of the pyrolysis of dimethyl ether',
        journal = "J. Chem. Phys.",
        volume = "31",
        pages = """1008""",
        year = "1959",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1959BEN/JAI1008:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002017
Bath gas: (CH3)2O
""",
)

entry(
    index = 63,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (452, 'm^3/(mol*s)', '*|/', 1.58),
        n = 1.6,
        Ea = (80.817, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:201",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 1.58
""",
)

entry(
    index = 64,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (61.9, 'm^3/(mol*s)', '*|/', 2.5),
        n = 1.9,
        Ea = (76.992, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:242",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 2.5
""",
)

entry(
    index = 65,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (460, 'm^3/(mol*s)', '*|/', 1.58),
        n = 1.6,
        Ea = (77.657, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:181",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 1.58
""",
)

entry(
    index = 66,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (61.9, 'm^3/(mol*s)', '*|/', 2.51),
        n = 1.9,
        Ea = (76.992, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (2400, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:33",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 2.51
""",
)

entry(
    index = 67,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (10200, 'm^3/(mol*s)'),
        n = 1.2,
        Ea = (79.902, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K."],
        title = u'Evaluation and Compilation of Chemical Kinetic Data',
        journal = "J. Phys. Chem.",
        volume = "83",
        pages = """46""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979COH/WES46:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 68,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.02e+08, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (88.133, 'kJ/mol', '+|-', 6.178),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Kaufman, F.", "Del Greco, F.P."],
        title = u'Fast reactions of OH radicals',
        journal = "Symp. Int. Combust. Proc.",
        volume = "9",
        pages = """659""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963KAU/DEL659:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013781/rk00000001.xml
Uncertainty: 10.0
Bath gas: He
""",
)

entry(
    index = 69,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.4e+08, 'm^3/(mol*s)', '+|-', 2.4e+07),
        n = 0,
        Ea = (89.796, 'kJ/mol', '+|-', 4.473),
        T0 = (1, 'K'),
        Tmin = (1600, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (152000, 'Pa'),
    ),
    reference = Article(
        authors = ["Davidson, D.F.", "Chang, A.Y.", "Hanson, R.K."],
        title = u'Laser photolysis shock tube for combustion kinetics studies',
        journal = "Symp. Int. Combust. Proc.",
        volume = "22",
        pages = """1877-1885""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989DAV/CHA1877-1885:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 70,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.76e+08, 'm^3/(mol*s)', '+|-', 3.6e+07),
        n = 0,
        Ea = (96.448, 'kJ/mol', '+|-', 1.929),
        T0 = (1, 'K'),
        Tmin = (1250, 'K'),
        Tmax = (2300, 'K'),
        Pmin = (1400, 'Pa'),
        Pmax = (4066, 'Pa'),
    ),
    reference = Article(
        authors = ["Michael, J.V.", "Sutherland, J.W."],
        title = u'Rate constant for the reaction of H with H2O and OH with H2 by the flash photolysis-shock tube technique over the temperature range 1246-2297 K',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """3853""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988MIC/SUT3853:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 71,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.13e+08, 'm^3/(mol*s)', '+|-', 2.7e+08),
        n = 0,
        Ea = (92.291, 'kJ/mol', '+|-', 9.229),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Felder, W.", "Madronich, S."],
        title = u'High temperature photochemistry (HTP): kinetics and mechanism studies of elementary combustion reactions over 300-1700 K',
        journal = "Combust. Sci. Technol.",
        volume = "50",
        pages = """135-150""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986FEL/MAD135-150:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: N2
Excitation technique: Direct photolysis
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 72,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.13e+08, 'm^3/(mol*s)', '+|-', 2.7e+08),
        n = 0,
        Ea = (92.291, 'kJ/mol', '+|-', 9.229),
        T0 = (1, 'K'),
        Tmin = (1160, 'K'),
        Tmax = (1390, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Madronich, S.", "Felder, W."],
        title = u'High-temperature photochemistry. Measurements of the rate coefficient for H + H2O \u2192\x92 OH + H2 from 1160 to 1390 K',
        journal = "J. Phys. Chem.",
        volume = "88",
        pages = """1857""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984MAD/FEL1857:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 73,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.2e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (83.062, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (613, 'K'),
        Tmax = (1650, 'K'),
    ),
    reference = Article(
        authors = ["Leroy, G.", "Sana, M.", "Tinant, A."],
        title = u"Etude theorique des reactions d'abstraction d'hydrogene RH + X = R + HX, avec R, X\u2261H, CH3, NH2, OH et F",
        journal = "Can. J. Chem.",
        volume = "63",
        pages = """1447-1456""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985LER/SAN1447-1456:21",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 74,
    label = "H2O + H <=> H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (85.639, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (310, 'K'),
        Tmax = (915, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Dixon-Lewis, G.", "Sutton, M.M.", "Williams, A."],
        title = u'Some reactions of hydrogen atoms and simple radicals at high temperatures',
        journal = "Symp. Int. Combust. Proc.",
        volume = "10",
        pages = """495""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965DIX/SUT495:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: N2
""",
)

entry(
    index = 75,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.64e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.46, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (450, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F.", "Hynes, R.G.", "Jenkin, M.E.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic and photochemical data for atmospheric chemistry: Volume I - gas phase reactions of Ox, HOx, NOx and SOx species',
        journal = "Atmos. Chem. Phys.",
        volume = "4",
        pages = """1461-1738""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004ATK/BAU1461-1738:47",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 76,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.64e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.46, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (450, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:17",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Pressure dependence: None reported
""",
)

entry(
    index = 77,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.31e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (16.629, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:245",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 78,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.63e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.46, 'kJ/mol', '+|-', 1.746),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (450, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic and photochemical data for atmospheric chemistry: supplement VI. IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """1329-1499""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU1329-1499:45",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 79,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.31e+06, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (16.629, 'kJ/mol', '+|-', 3.326),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.J.", "Molina, M.J."],
        title = u'Chemical Kinetic and Photochemical Data for Use in Stratospheric Modeling: Evaluation No. 11 of the NASA Panel for Data Evaluation',
        journal = "JPL Publication 94-26",
        pages = """1-2""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DEM/SAN:227",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 1.2
""",
)

entry(
    index = 80,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (215, 'm^3/(mol*s)'),
        n = 1.52,
        Ea = (14.467, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (2580, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Oldenborg, R.C.", "Loge, G.W.", "Harradine, D.M.", "Winn, K.R."],
        title = u'Kinetic study of the OH + H2 reaction from 800 to 1550 K',
        journal = "J. Phys. Chem.",
        volume = "96",
        pages = """8426-8430""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992OLD/LOG8426-8430:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
""",
)

entry(
    index = 81,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (102, 'm^3/(mol*s)', '*|/', 2),
        n = 1.6,
        Ea = (13.802, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:111",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 2.0
""",
)

entry(
    index = 82,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.63e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.46, 'kJ/mol', '+|-', 1.746),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (450, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:162",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 83,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.63e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (17.46, 'kJ/mol', '+|-', 1.746),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (450, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:89",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 1.26
""",
)

entry(
    index = 84,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (217, 'm^3/(mol*s)'),
        n = 1.51,
        Ea = (14.384, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (2580, 'K'),
        Pmin = (1400, 'Pa'),
        Pmax = (4066, 'Pa'),
    ),
    reference = Article(
        authors = ["Michael, J.V.", "Sutherland, J.W."],
        title = u'Rate constant for the reaction of H with H2O and OH with H2 by the flash photolysis-shock tube technique over the temperature range 1246-2297 K',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """3853""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988MIC/SUT3853:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
""",
)

entry(
    index = 85,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.37, 'm^3/(mol*s)', '*|/', 3),
        n = 2,
        Ea = (12.389, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (2400, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:99",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 3.0
""",
)

entry(
    index = 86,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (100, 'm^3/(mol*s)', '*|/', 1.41),
        n = 1.6,
        Ea = (13.802, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:110",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 1.41
""",
)

entry(
    index = 87,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.28, 'm^3/(mol*s)', '*|/', 2.51),
        n = 2,
        Ea = (12.389, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (2400, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:21",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 2.51
""",
)

entry(
    index = 88,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (100, 'm^3/(mol*s)'),
        n = 1.6,
        Ea = (13.802, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Zellner, R."],
        title = u'Non-Arrhenius Behavior in Bimolecular Reactions of the OH Radical',
        journal = "J. Phys. Chem.",
        volume = "83",
        pages = """18""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979ZEL18:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 89,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1100, 'm^3/(mol*s)'),
        n = 1.3,
        Ea = (15.299, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K."],
        title = u'Evaluation and Compilation of Chemical Kinetic Data',
        journal = "J. Phys. Chem.",
        volume = "83",
        pages = """46""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979COH/WES46:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 90,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (31.6, 'm^3/(mol*s)'),
        n = 1.77,
        Ea = (12.721, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1800, 'K'),
        Pmin = (2706, 'Pa'),
        Pmax = (2706, 'Pa'),
    ),
    reference = Article(
        authors = ["Gardiner, W.C., Jr.", "Mallard, W.G.", "Owen, J.H."],
        title = u'Rate Constant of OH + H2 = H2O + H from 1350 to 1600K',
        journal = "J. Chem. Phys.",
        volume = "60",
        pages = """2290""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974GAR/MAL2290:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
""",
)

entry(
    index = 91,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.2e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.534, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Drysdale, D.D.", "Horne, D.G."],
        title = u'An assessment of rate data for high-temperature systems',
        journal = "Symp. Int. Combust. Proc.",
        volume = "14",
        pages = """107-118""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973BAU/DRY107-118:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 92,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.3e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (21.618, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Wilson, W.E., Jr."],
        title = u'A critical review of the gas-phase reaction kinetics of the hydroxyl radical',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "1",
        pages = """535-573""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972WIL535-573:11",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 2.0
""",
)

entry(
    index = 93,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.72e+07, 'm^3/(mol*s)', '*|/', 1.41),
        n = 0,
        Ea = (23.031, 'kJ/mol', '+|-', 0.923),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1330, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Dixon-Lewis, G."],
        title = u'Flames Structure and Flame Reaction Kinetics VII. Reactions of Traces of Heavy Water, Deuterium and Carbon Dioxide added to rich Hydrogen + Nitrogen + Oxygen Flames',
        journal = "Proc. R. Soc. London A",
        volume = "330",
        pages = """219""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972DIX219:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 1.41
Bath gas: N2
""",
)

entry(
    index = 94,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.3e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.784, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Dixon-Lewis, G.", "Wilson, W.E.", "Westenberg, A.A."],
        title = u'Studies of hydroxyl radical kinetics by quantitative ESR',
        journal = "J. Chem. Phys.",
        volume = "44",
        pages = """2877""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966DIX/WIL2877:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
""",
)

entry(
    index = 95,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.91e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.784, 'kJ/mol', '+|-', 2.611),
        T0 = (1, 'K'),
        Tmin = (310, 'K'),
        Tmax = (915, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Dixon-Lewis, G.", "Sutton, M.M.", "Williams, A."],
        title = u'Some reactions of hydrogen atoms and simple radicals at high temperatures',
        journal = "Symp. Int. Combust. Proc.",
        volume = "10",
        pages = """495""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965DIX/SUT495:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: N2
""",
)

entry(
    index = 96,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.31e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (24.694, 'kJ/mol', '+|-', 4.199),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Kaufman, F.", "Del Greco, F.P."],
        title = u'Fast reactions of OH radicals',
        journal = "Symp. Int. Combust. Proc.",
        volume = "9",
        pages = """659""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963KAU/DEL659:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013781/rk00000001.xml
Uncertainty: 10.0
Bath gas: He
""",
)

entry(
    index = 97,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (543000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (12.688, 'kJ/mol', '+|-', 0.582),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (250, 'K'),
        Pmin = (2200, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Orkin, V.L.", "Kozlov, S.N.", "Poskrebyshev, G.A.", "Kurylo, M.J."],
        title = u'Rate constant for the reaction of OH with H-2 between 200 and 480 K',
        journal = "J. Phys. Chem. A",
        volume = "110",
        pages = """6978-6985""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006ORK/KOZ6978-6985:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Resonance fluorescence

The overall uncertainty factor is given by the expression f(T) = 1.04*exp(50*(1/T-1/298)) (95% confidence limits).
""",
)

entry(
    index = 98,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.287, 'm^3/(mol*s)'),
        n = 2.41,
        Ea = (10.31, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (479, 'K'),
        Pmin = (2200, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Orkin, V.L.", "Kozlov, S.N.", "Poskrebyshev, G.A.", "Kurylo, M.J."],
        title = u'Rate constant for the reaction of OH with H-2 between 200 and 480 K',
        journal = "J. Phys. Chem. A",
        volume = "110",
        pages = """6978-6985""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006ORK/KOZ6978-6985:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Resonance fluorescence

The overall uncertainty factor is given by the expression f(T) = 1.04*exp(50*(1/T-1/298)) (95% confidence limits).
""",
)

entry(
    index = 99,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.28e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (26.773, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (832, 'K'),
        Tmax = (1359, 'K'),
        Pmin = (1455, 'Pa'),
        Pmax = (2790, 'Pa'),
    ),
    reference = Article(
        authors = ["Krasnoperov, L.N.", "Michael, J.V."],
        title = u'Shock tube studies using a novel multipass absorption cell: Rate constant results for OH + H2 and OH + C2H6',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """5643-5648""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004KRA/MIC5643-5648:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 100,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0433, 'm^3/(mol*s)'),
        n = 2.69,
        Ea = (9.562, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (238, 'K'),
        Tmax = (400, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Talukdar, R.K.", "Gierczak, T.", "Goldfarb, L.", "Rudich, Y.", "Rao, B.S.M.", "Ravishankara, A.R."],
        title = u'Kinetics of hydroxyl radical reactions with isotopically labeled hydrogen',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """3037-3043""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996TAL/GIE3037-3043:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 101,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.21e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.534, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1900, 'K'),
        Tmax = (2800, 'K'),
        Pmin = (180000, 'Pa'),
        Pmax = (180000, 'Pa'),
    ),
    reference = Article(
        authors = ["Roth, P.", "Just, Th."],
        title = u'Kinetics of the high temperature, low concentration CH4 oxidation verified by H and O atom measurements',
        journal = "Symp. Int. Combust. Proc.",
        volume = "20",
        pages = """807""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985ROT/JUS807:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 102,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.74e+07, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (25.525, 'kJ/mol', '+|-', 2.295),
        T0 = (1, 'K'),
        Tmin = (1700, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (203000, 'Pa'),
    ),
    reference = Article(
        authors = ["Frank, P.", "Just, Th."],
        title = u'High temperature reaction rate for H + O2 = OH + O and OH + H2 = H2O + H',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "89",
        pages = """181""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985FRA/JUS181:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 2.51
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 103,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.248, 'm^3/(mol*s)'),
        n = 2.44,
        Ea = (10.643, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1050, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Ravishankara, A.R.", "Nicovich, J.M.", "Thompson, R.L.", "Tully, F.P."],
        title = u'Kinetic Study of the Reaction of OH with H2 and D2 from 250 to 1050 K',
        journal = "J. Phys. Chem.",
        volume = "85",
        pages = """2498""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981RAV/NIC2498:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 104,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.95e+06, 'm^3/(mol*s)', '+|-', 300000),
        n = 0,
        Ea = (16.546, 'kJ/mol', '+|-', 2.81),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (400, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Ravishankara, A.R.", "Nicovich, J.M.", "Thompson, R.L.", "Tully, F.P."],
        title = u'Kinetic Study of the Reaction of OH with H2 and D2 from 250 to 1050 K',
        journal = "J. Phys. Chem.",
        volume = "85",
        pages = """2498""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981RAV/NIC2498:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 1.05
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 105,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.248, 'm^3/(mol*s)'),
        n = 2.44,
        Ea = (10.643, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (992, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Tully, F.P.", "Ravishankara, A.R."],
        title = u'Flash Photolysis-Resonance Fluorescence Kinetic Study of the Reactions OH + H2 \u2192\x92 H2O + H and OH + CH4 \u2192\x92 H2O + CH3 from 298 to 1020 K',
        journal = "J. Phys. Chem.",
        volume = "84",
        pages = """3126""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980TUL/RAV3126:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 106,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (18.375, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (1300, 'K'),
        Pmin = (5333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Vandooren, J.", "Peeters, J.", "Van Tiggelen, P.J."],
        title = u'Rate Constant of the Elementary Reaction of Carbon Monoxide with Hydroxyl Radical',
        journal = "Symp. Int. Combust. Proc.",
        volume = "15",
        pages = """745""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975VAN/PEE745:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 107,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.56e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (16.712, 'kJ/mol', '+|-', 1.339),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (434, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (3333, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Hansen, D.A.", "Pitts, J.N., Jr."],
        title = u'Rate Constants for the Reaction of OH Radicals with CHF2Cl, CF2Cl2, CFCl3, and H2 over the Temperature Range 297-434oK',
        journal = "J. Chem. Phys.",
        volume = "63",
        pages = """1703""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975ATK/HAN1703:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 108,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.08e+07, 'm^3/(mol*s)', '+|-', 5.4e+06),
        n = 0,
        Ea = (19.373, 'kJ/mol', '+|-', 0.973),
        T0 = (1, 'K'),
        Tmin = (210, 'K'),
        Tmax = (460, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Smith, I.W.M.", "Zellner, R."],
        title = u'Rate Measurements of Reactions of OH by Resonance Absorption. Part 3. Reactions of OH with H2, D2 and Hydrogenand Deuterium Halides',
        journal = "J. Chem. Soc. Faraday Trans. 2",
        volume = "70",
        pages = """1045""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974SMI/ZEL1045:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 109,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.2e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (27.022, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1350, 'K'),
        Tmax = (1600, 'K'),
        Pmin = (2706, 'Pa'),
        Pmax = (2706, 'Pa'),
    ),
    reference = Article(
        authors = ["Gardiner, W.C., Jr.", "Mallard, W.G.", "Owen, J.H."],
        title = u'Rate Constant of OH + H2 = H2O + H from 1350 to 1600K',
        journal = "J. Chem. Phys.",
        volume = "60",
        pages = """2290""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974GAR/MAL2290:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 110,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.86e-06, 'm^3/(mol*s)'),
        n = 4.05,
        Ea = (3.692, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (745, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (400, 'Pa'),
    ),
    reference = Article(
        authors = ["Westenberg, A.A.", "DeHaas, N."],
        title = u'Rates of CO + OH and H2 + OH over an Extended Temperature',
        journal = "J. Chem. Phys.",
        volume = "58",
        pages = """4061""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973WES/DEH4061:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 111,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.4e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.121, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (210, 'K'),
        Tmax = (460, 'K'),
    ),
    reference = Book(
        authors = ["Smith, I.W.M.", "Zellner, R."],
        title = u'Rate Measurements of Reactions of the OH Radical with H2, CO, C2H4, and C2H2 between 210oK and 460oK',
        publisher = "ed. F. J. Weinberg, pub. Academic Press, London,",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973SMI/ZEL24C:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: H2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 112,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.2e+07, 'm^3/(mol*s)', '*|/', 3.2),
        n = 0,
        Ea = (27.188, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Gardiner, W.C., Jr.", "Mallard, W.G.", "McFarland, M.", "Morinaga, K.", "Owen, J.H.", "Rawlins, W.T.", "Takeyama, T.", "Walker, B.G."],
        title = u'Elementary Reaction Rates from Post-Induction-Period Profiles in Shock-Initiated Combustion',
        journal = "Symp. Int. Combust. Proc.",
        volume = "14",
        pages = """61""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973GAR/MAL61:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 3.2
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 113,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.121, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (1500, 'K'),
        Pmin = (1027, 'Pa'),
        Pmax = (1413, 'Pa'),
    ),
    reference = Article(
        authors = ["Eberius, K.H.", "Hoyermann, K.", "Wagner, H.GG."],
        title = u'Experimental and Mathematical Study of a Hydrogen-Oxygen Flame',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """713""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971EBE/HOY713:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 114,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.368, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1100, 'K'),
        Tmax = (1600, 'K'),
        Pmin = (91200, 'Pa'),
        Pmax = (156000, 'Pa'),
    ),
    reference = Article(
        authors = ["Brabbs, T.A.", "Belles, F.E.", "Brokaw, R.S."],
        title = u'Shock-Tube Measurements of Specific Reaction Rates in the Branched- Chain H2-CO-O2 System',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """129""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BRA/BEL129:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV emission
""",
)

entry(
    index = 115,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.07e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (16.795, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (500, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. V. Reactions with H2 and CO in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "51",
        pages = """5049""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969GRE5049:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Uncertainty: 1.26
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 116,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.21e+08, 'm^3/(mol*s)', '+|-', 4.8e+07),
        n = 0,
        Ea = (36.002, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (900, 'K'),
        Tmax = (1050, 'K'),
        Pmin = (381, 'Pa'),
        Pmax = (381, 'Pa'),
    ),
    reference = Article(
        authors = ["Balakhnin, V.P.", "Gershenzon, Yu.M."],
        title = u'A quantitative study of the mechanism of hydrogen combustion close to the lower explosion limit',
        journal = "Dokl. Chem. (Engl. Transl.)",
        volume = "170",
        pages = """659-662""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967BAL/GER659-662:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 117,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.55e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (22.782, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (813, 'K'),
        Tmax = (843, 'K'),
    ),
    reference = Article(
        authors = ["Azatyan, V.V.", "Romanovich, L.B.", "Sysoeva, S.G."],
        title = u'Determination of the reaction rate constant of the hydroxyl radical and hydrogen',
        journal = "Fiz. Goreniya Vzryva",
        volume = "3",
        pages = """77-85""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967AZA/ROM77-85:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 118,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.98e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.863, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1400, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (20300, 'Pa'),
        Pmax = (50700, 'Pa'),
    ),
    reference = Article(
        authors = ["Ripley, D.L.", "Gardner, W.C., Jr."],
        title = u'Shock-tube study of the hydrogen-oxygen reaction. II. Role of exchange initiation',
        journal = "J. Chem. Phys.",
        volume = "44",
        pages = """2285""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966RIP/GAR2285:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 119,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.21e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (36.002, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (900, 'K'),
        Tmax = (1050, 'K'),
        Pmin = (381, 'Pa'),
        Pmax = (381, 'Pa'),
    ),
    reference = Article(
        authors = ["Balakhnin, V.P.", "Gershenzon, Yu.M.", "Kondrat'ev, V.N.", "Nalbandyan, A.B."],
        title = u'A quantitative study of the mechanism of hydrogen combustion close to the lower explosion limit',
        journal = "Dokl. Phys. Chem. (Engl. Transl.)",
        volume = "170",
        pages = """659""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966BAL/GER659:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 120,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.14e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.422, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Haworth, N.L.", "Bacskay, G.B.", "Mackie, J.C."],
        title = u'The Role of Phosphorus Dioxide in the H + OH Recombination Reaction:  Ab Initio Quantum Chemical Computation of Thermochemical and Rate Parameters',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """1533-1541""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002HAW/BAC1533-1541:10",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Pressure dependence: Rate constant is high pressure limit
""",
)

entry(
    index = 121,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.832, 'm^3/(mol*s)'),
        n = 2.34,
        Ea = (14.644, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Haworth, N.L.", "Bacskay, G.B.", "Mackie, J.C."],
        title = u'The Role of Phosphorus Dioxide in the H + OH Recombination Reaction:  Ab Initio Quantum Chemical Computation of Thermochemical and Rate Parameters',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """1533-1541""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002HAW/BAC1533-1541:9",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Pressure dependence: Rate constant is high pressure limit
""",
)

entry(
    index = 122,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (506000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.647, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (360, 'K'),
    ),
    reference = Article(
        authors = ["Matzkies, F.", "Manthe, U."],
        title = u'Accurate quantum calculations of thermal rate constants employing MCTDH: H2 + OH \u2192\x92 H + H2O and D2 + OH \u2192\x92 D + DOH',
        journal = "J. Chem. Phys.",
        volume = "108",
        pages = """4828-4836""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998MAT/MAN4828-4836:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 123,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1820, 'm^3/(mol*s)'),
        n = 1.21,
        Ea = (19.705, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (2400, 'K'),
    ),
    reference = Article(
        authors = ["Isaacson, A.D."],
        title = u'Harmonic and anharmonic rate constants and transmission coefficients obtained from ab initio data',
        journal = "J. Chem. Phys.",
        volume = "107",
        pages = """3832-3839""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ISA3832-3839:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 124,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.71e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (19.788, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, M.J.", "Willetts, A.", "Handy, N.C."],
        title = u'Cumulative reaction probabilities for OH+H2\u2192\x92H2O+H and CIH+Cl\u2192\x92Cl+HCI from a knowledge of the anharmonic force field',
        journal = "J. Chem. Phys.",
        volume = "99",
        pages = """5885-5897""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993COH/WIL5885-5897:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 125,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.46e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (19.539, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (600, 'K'),
    ),
    reference = Article(
        authors = ["Fisher, J.R.", "Michael, J.V."],
        title = u'Rate constants for the reaction D + D2O \u2192\x92 D2 + OD by the flash photolysis-shock tube technique over the temperature range 1285-2261 K: Results for the back-reaction and a comparison to the protonated case',
        journal = "J. Chem. Phys.",
        volume = "94",
        pages = """2465-2471""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990FIS/MIC2465-2471:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 126,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (106, 'm^3/(mol*s)'),
        n = 1.63,
        Ea = (14.55, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Fisher, J.R.", "Michael, J.V."],
        title = u'Rate constants for the reaction D + D2O \u2192\x92 D2 + OD by the flash photolysis-shock tube technique over the temperature range 1285-2261 K: Results for the back-reaction and a comparison to the protonated case',
        journal = "J. Chem. Phys.",
        volume = "94",
        pages = """2465-2471""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990FIS/MIC2465-2471:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 127,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.32e+07, 'm^3/(mol*s)', '+|-', 4.2e+07),
        n = 0,
        Ea = (33.59, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1250, 'K'),
        Tmax = (2300, 'K'),
        Pmin = (1400, 'Pa'),
        Pmax = (4066, 'Pa'),
    ),
    reference = Article(
        authors = ["Michael, J.V.", "Sutherland, J.W."],
        title = u'Rate constant for the reaction of H with H2O and OH with H2 by the flash photolysis-shock tube technique over the temperature range 1246-2297 K',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """3853""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988MIC/SUT3853:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: Ar
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 128,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.74e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (32.26, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1020, 'K'),
        Tmax = (2050, 'K'),
    ),
    reference = Article(
        authors = ["Leroy, G.", "Sana, M.", "Tinant, A."],
        title = u"Etude theorique des reactions d'abstraction d'hydrogene RH + X = R + HX, avec R, X\u2261H, CH3, NH2, OH et F",
        journal = "Can. J. Chem.",
        volume = "63",
        pages = """1447-1456""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985LER/SAN1447-1456:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 129,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (18700, 'm^3/(mol*s)'),
        n = 0.75,
        Ea = (13.137, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Shaw, R."],
        title = u'Estimation of Rate Constants as a Function of Temperature for the Reactions W + XYZ = WX + YZ, Where W, X, Y, and Z are H or O Atoms',
        journal = "Int. J. Chem. Kinet.",
        volume = "9",
        pages = """929""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977SHA929:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
""",
)

entry(
    index = 130,
    label = "H2 + OH <=> H2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.35e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.952, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (310, 'K'),
        Tmax = (1070, 'K'),
    ),
    reference = Article(
        authors = ["Dixon-Lewis, G.", "Sutton, M.M.", "Williams, A."],
        title = u'Reactions contributing to the establishment of the water gas equilibrium when carbon dioxide is added to a hydrogen-oxygen flame',
        journal = "Trans. Faraday Soc.",
        volume = "61",
        pages = """255""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965DIX/SUT255:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00013781
Bath gas: N2
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 131,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.03e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (116.403, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:58",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Uncertainty: 10.0
""",
)

entry(
    index = 132,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.03e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (93.122, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:73",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Uncertainty: 5.0
""",
)

entry(
    index = 133,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.03e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (98.942, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1800, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Gardiner, W.", "Tanzawa, T.", "Koike, T.", "Morinaga, K."],
        title = u'Rate coefficient for H + C2H2 = C2H + H2',
        journal = "Bull. Chem. Soc. Jpn.",
        volume = "58",
        pages = """1851""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985GAR/TAN1851:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: Ar
""",
)

entry(
    index = 134,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6e+07, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (98.942, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:35",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Uncertainty: 3.1600001
""",
)

entry(
    index = 135,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (90500, 'm^3/(mol*s)'),
        n = 1.32,
        Ea = (128.043, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (440, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Peeters, J.", "Van Look, H.", "Ceursters, B."],
        title = u'Absolute rate coefficients of the reactions of C2H with NO and H2 between 295 and 440 K',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """15124-15129""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996PEE/VAN15124-15129:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: He
""",
)

entry(
    index = 136,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.42e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (99.774, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (4860, 'K'),
        Tmax = (6920, 'K'),
        Pmin = (933, 'Pa'),
        Pmax = (2933, 'Pa'),
    ),
    reference = Article(
        authors = ["Beck, W.H.", "Mackie, J.C."],
        title = u'Formation and Dissociation of C2 from High Temperature Pyrolysis of Acetylene',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "71",
        pages = """1363""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975BEC/MAC1363:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV emission
""",
)

entry(
    index = 137,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.79e+07, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (68.594, 'kJ/mol', '+|-', 16.463),
        T0 = (1, 'K'),
        Tmin = (1060, 'K'),
        Tmax = (1270, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Yampol'skii, Yu.P.", "Lavrovskii, K.P.", "Maksimov, Yu.V.", "Rybin, V.M."],
        title = u'Determination of the Rate Constant for the Reaction H + C2H2 \u2192\x92 H2+ C2H',
        journal = "Kinet. Catal.",
        volume = "15",
        pages = """17""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974YAM/LAV17:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Uncertainty: 2.51
Bath gas: C2H2
""",
)

entry(
    index = 138,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.81e-06, 'm^3/(mol*s)'),
        n = 3.2,
        Ea = (1.995, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1700, 'K'),
        Tmax = (3400, 'K'),
        Pmin = (30000, 'Pa'),
        Pmax = (75100, 'Pa'),
    ),
    reference = Article(
        authors = ["Tanzawa, T.", "Gardiner, W.C., Jr."],
        title = u'Thermal decomposition of acetylene',
        journal = "Symp. Int. Combust. Proc.",
        volume = "17",
        pages = """563-572""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978TAN/GAR563-572:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: Ar
""",
)

entry(
    index = 139,
    label = "C2H2 + H <=> H2 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (79.486, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1700, 'K'),
    ),
    reference = Article(
        authors = ["Browne, W.G.", "Porter, R.P.", "Verlin, J.D.", "Clark, A.H."],
        title = u'A study of acetylene-oxygen flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "12",
        pages = """1035""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969BRO/POR1035:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002499/rk00000001.xml
Bath gas: Ar
""",
)

entry(
    index = 140,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.236, 'm^3/(mol*s)'),
        n = (2.57, '', '+|-', 0.3),
        Ea = (1.081, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (220, 'K'),
        Tmax = (2200, 'K'),
    ),
    reference = Article(
        authors = ["Laufer, A.H.", "Fahr, A."],
        title = u'Reactions and kinetics of unsaturated C2 hydrocarbon radicals',
        journal = "Chem. Rev.",
        volume = "104",
        pages = """2813-2832""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004LAU/FAH2813-2832:7",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499

A factor and sign on Ea given in table in paper are incorrect
Note: Invalid activation energy uncertainty (1.164) found and ignored
""",
)

entry(
    index = 141,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.45, 'm^3/(mol*s)'),
        n = 2.22,
        Ea = (3.833, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Eiteneer, B.", "Frenklach, M."],
        title = u'Experimental and Modeling Study of Shock-Tube Oxidation of Acetylene',
        journal = "Int J. Chem. Kinet.",
        volume = "35",
        pages = """391-414""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003EIT/FRE391-414:8",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499

No direct measurements of rate constants. Rate constants reported are either from estimates or optimization fits. Enthalpies of formation were also allowed to be varied in fits. This paper is combined experimental and modeling. These measurements consist of shock tube oxidation of C2H2 at temperatures of 1150-2130 K, pressures of 0.9-1.9 atm in Argon, with lean to rich conditions (Phi = 0.06 to 1.7). CO produced was detected using CO laser absorption at 2077.1 cm-1

Rate expressions for C2H + H2 -> C2H2 + H and C2H + C2H2 -> C4H2 + H were reported based on fits to data in the literature.
""",
)

entry(
    index = 142,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.56, 'm^3/(mol*s)'),
        n = (2.17, '', '+|-', 0.5),
        Ea = (3.974, 'kJ/mol', '+|-', 1.389),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (854, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (11100, 'Pa'),
    ),
    reference = Article(
        authors = ["Opansky, B.J.", "Leone, S.R."],
        title = u'Rate coefficients of C2H with C2H4, C2H6, and H2 from 150 to 359 K',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """19904-19910""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996OPA/LEO19904-19910:4",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: He
""",
)

entry(
    index = 143,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.08e+07, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (9.063, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Frank, P.", "Hayman, G.", "Just, Th.", "Kerr, J.A.", "Murrells, T.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combusion modelling. Supplement I',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "23",
        pages = """847-1033""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994BAU/COB847-1033:59",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Uncertainty: 3.1600001
""",
)

entry(
    index = 144,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.51e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (12.971, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:108",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Uncertainty: 10.0
""",
)

entry(
    index = 145,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.15e+07, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (12.056, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:92",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Uncertainty: 3.0
""",
)

entry(
    index = 146,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.12e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (11.973, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2800, 'K'),
    ),
    reference = Article(
        authors = ["Gardiner, W.", "Tanzawa, T.", "Koike, T.", "Morinaga, K."],
        title = u'Rate coefficient for H + C2H2 = C2H + H2',
        journal = "Bull. Chem. Soc. Jpn.",
        volume = "58",
        pages = """1851""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985GAR/TAN1851:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: Ar
""",
)

entry(
    index = 147,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.5e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (12.971, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:107",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Uncertainty: 5.0
""",
)

entry(
    index = 148,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.4e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (28.269, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (2580, 'K'),
        Tmax = (4650, 'K'),
        Pmin = (152000, 'Pa'),
        Pmax = (273000, 'Pa'),
    ),
    reference = Article(
        authors = ["Kruse, T.", "Roth, P."],
        title = u'Kinetics of C2 reactions during high-temperature pyrolysis of acetylene',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """2138-2146""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997KRU/ROT2138-2146:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 149,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.19e+06, 'm^3/(mol*s)', '+|-', 260000),
        n = 0,
        Ea = (4.972, 'kJ/mol', '+|-', 0.348),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (440, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Peeters, J.", "Van Look, H.", "Ceursters, B."],
        title = u'Absolute rate coefficients of the reactions of C2H with NO and H2 between 295 and 440 K',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """15124-15129""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996PEE/VAN15124-15129:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Chemiluminescence
""",
)

entry(
    index = 150,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.23e+06, 'm^3/(mol*s)', '+|-', 1.8e+06),
        n = 0,
        Ea = (8.298, 'kJ/mol', '+|-', 0.498),
        T0 = (1, 'K'),
        Tmin = (178, 'K'),
        Tmax = (359, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (11100, 'Pa'),
    ),
    reference = Article(
        authors = ["Opansky, B.J.", "Leone, S.R."],
        title = u'Rate coefficients of C2H with C2H4, C2H6, and H2 from 150 to 359 K',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """19904-19910""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996OPA/LEO19904-19910:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: IR absorption
""",
)

entry(
    index = 151,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (56700, 'm^3/(mol*s)', '+|-', 1720),
        n = 0.9,
        Ea = (8.314, 'kJ/mol', '+|-', 0.167),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (854, 'K'),
        Pmin = (2533, 'Pa'),
        Pmax = (2533, 'Pa'),
    ),
    reference = Article(
        authors = ["Farhat, S.K.", "Morter, C.L.", "Glass, G.P."],
        title = u'Temperature dependence of the rate of reaction of C2H with H2',
        journal = "J. Phys. Chem.",
        volume = "97",
        pages = """12789-12792""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993FAR/MOR12789-12792:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: IR absorption
""",
)

entry(
    index = 152,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.08e+07, 'm^3/(mol*s)', '+|-', 6.1e+06),
        n = 0,
        Ea = (9.063, 'kJ/mol', '+|-', 2.444),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (438, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (667, 'Pa'),
    ),
    reference = Article(
        authors = ["Koshi, M.", "Fukuda, K.", "Kamiya, K.", "Matsui, H."],
        title = u'Temperature dependence of the rate constants for the reactions of C2H with C2H2, H2 and D2',
        journal = "J. Phys. Chem.",
        volume = "96",
        pages = """9839-9843""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992KOS/FUK9839-9843:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 153,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.789, 'm^3/(mol*s)'),
        n = 2.39,
        Ea = (1.447, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (440, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Peeters, J.", "Van Look, H.", "Ceursters, B."],
        title = u'Absolute rate coefficients of the reactions of C2H with NO and H2 between 295 and 440 K',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """15124-15129""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996PEE/VAN15124-15129:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
Bath gas: He
""",
)

entry(
    index = 154,
    label = "H2 + C2H <=> C2H2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.41, 'm^3/(mol*s)'),
        n = 2.39,
        Ea = (3.617, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (625, 'K'),
        Tmax = (1530, 'K'),
    ),
    reference = Article(
        authors = ["Harding, L.B.", "Schatz, G.C.", "Chiles, R.A."],
        title = u'An ab initio determination of the rate constant for H2 + C2H\u2192\x92H + C2H2',
        journal = "J. Chem. Phys.",
        volume = "76",
        pages = """5172-5173""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982HAR/SCH5172-5173:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00002499
""",
)

entry(
    index = 155,
    label = "H2 + C2H5 <=> C2H6 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.07e-06, 'm^3/(mol*s)', '*|/', 5),
        n = 3.6,
        Ea = (35.337, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:101",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 5.0
""",
)

entry(
    index = 156,
    label = "H2 + C2H5 <=> C2H6 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.46e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (59.033, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (363, 'K'),
        Tmax = (713, 'K'),
        Pmin = (23500, 'Pa'),
        Pmax = (68900, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Walker, R.W.", "Langford, D.H."],
        title = u'Reaction of ethyl radicals with hydrogen and deuterium',
        journal = "Trans. Faraday Soc.",
        volume = "65",
        pages = """2116-2122""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969BAL/WAL2116-2122:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: N2
""",
)

entry(
    index = 157,
    label = "H2 + C2H5 <=> C2H6 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.98e+07, 'm^3/(mol*s)', '*|/', 1.1),
        n = 0,
        Ea = (96.448, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1110, 'K'),
        Tmax = (1200, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (40000, 'Pa'),
    ),
    reference = Article(
        authors = ["Cao, J.-R.", "Back, M.H."],
        title = u'Kinetics of the Reaction C2H5 + H2 \u2192\x92 C2H6 + H from 1111-1200 K',
        journal = "Can. J. Chem.",
        volume = "60",
        pages = """3039""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982CAO/BAC3039:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 1.1
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 158,
    label = "H2 + C2H5 <=> C2H6 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.72e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (57.453, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (513, 'K'),
        Tmax = (593, 'K'),
        Pmin = (12300, 'Pa'),
        Pmax = (12300, 'Pa'),
    ),
    reference = Article(
        authors = ["Reid, L.E.", "Le Roy, D.J."],
        title = u'The mercury (63P1) photosensitized hydrogenation of ethylene. Kinetics of the reaction C2H5 + H2 = C2H6 + H',
        journal = "Can. J. Chem.",
        volume = "46",
        pages = """3275""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968REI/LER3275:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009460/rk00000003.xml
Bath gas: H2
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 159,
    label = "H2 + C2H5 <=> C2H6 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0137, 'm^3/(mol*s)'),
        n = 2.43,
        Ea = (36.95, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Ethane and Chlorinated Ethanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """6900-6909""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA6900-6909:8",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00009460

Derived from fits of a transition state theory model, the Marcus expression for correlation between reaction barriers and energetics, and analysis of experimental data reported in this reference. Transition state geometry and barriers were computed at several levels and Eckart-level tunneling contributions were applied.
""",
)

entry(
    index = 160,
    label = "H2 + C2H5 <=> C2H6 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.17e-22, 'm^3/(mol*s)'),
        n = 8.94,
        Ea = (18.849, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (400, 'K'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Ethane and Chlorinated Ethanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """6900-6909""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA6900-6909:9",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00009460

Derived from fits of a transition state theory model, the Marcus expression for correlation between reaction barriers and energetics, and analysis of experimental data reported in this reference. Transition state geometry and barriers were computed at several levels and Eckart-level tunneling contributions were applied.
""",
)

entry(
    index = 161,
    label = "H2 + C2H5 <=> C2H6 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.41e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (54.792, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (872, 'K'),
        Tmax = (1080, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Manion, J.A.", "Louw, R."],
        title = u'Gas-phase hydrogenolysis of chloroethene: Rates, products, and computer modelling',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1547-1555""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988MAN/LOU1547-1555:11",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: N2
""",
)

entry(
    index = 162,
    label = "H2 + C2H5 <=> C2H6 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.5e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (59.033, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (713, 'K'),
        Tmax = (813, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Langford, D.H.", "Matchan, M.J.", "Walker, R.W.", "Yorke, D.A."],
        title = u'The High-Temperature Oxidation of Aldehydes',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """251""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAL/LAN251:13",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
""",
)

entry(
    index = 163,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.26e+07, 'm^3/(mol*s)', '+|-', 2.41e+07),
        n = 0,
        Ea = (36.226, 'kJ/mol', '+|-', 1.588),
        T0 = (1, 'K'),
        Tmin = (357, 'K'),
        Tmax = (826, 'K'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Ethane and Chlorinated Ethanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """6900-6909""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA6900-6909:10",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460

Fit of the combined data of 2001BRY/SLA6900-6909 and 1977JON/MOR1311. Conditions under which this expression is valid are not specified but were assumed to encompass the temperature ranges of the two studies.
""",
)

entry(
    index = 164,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1440, 'm^3/(mol*s)', '*|/', 2),
        n = 1.5,
        Ea = (31.013, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:40",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 2.0
""",
)

entry(
    index = 165,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000554, 'm^3/(mol*s)', '*|/', 3),
        n = 3.5,
        Ea = (21.618, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:39",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 3.0
""",
)

entry(
    index = 166,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000541, 'm^3/(mol*s)', '*|/', 2),
        n = 3.5,
        Ea = (21.784, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:21",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 2.0
""",
)

entry(
    index = 167,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+08, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (40.159, 'kJ/mol', '+|-', 0.803),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cao, J.R.", "Back, M.H."],
        title = u'The heat of formation of the ethyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "16",
        pages = """961-966""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984CAO/BAC961-966:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 1.26
""",
)

entry(
    index = 168,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol', '+|-', 0.784),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (1290, 'K'),
        Pmin = (533, 'Pa'),
        Pmax = (2133, 'Pa'),
    ),
    reference = Article(
        authors = ["Camilleri, P.", "Marshall, R.M.", "Purnell, J.H."],
        title = u'Reaction of Hydrogen Atoms with Ethane',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "70",
        pages = """1434""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974CAM/MAR1434:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: Ar
""",
)

entry(
    index = 169,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.31e+08, 'm^3/(mol*s)', '*|/', 1.78),
        n = 0,
        Ea = (40.658, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (813, 'K'),
        Tmax = (1100, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Melvin, A."],
        title = u'The reaction of hydrogen atoms with oxygen and with ethane',
        journal = "J. Chem. Soc.",
        pages = """1785""",
        year = "1964",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1964BAL/MEL1785:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 1.78
Bath gas: O2
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 170,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.72e+07, 'm^3/(mol*s)', '+|-', 2.23e+07),
        n = 0,
        Ea = (35.885, 'kJ/mol', '+|-', 1.763),
        T0 = (1, 'K'),
        Tmin = (467, 'K'),
        Tmax = (826, 'K'),
        Pmin = (253, 'Pa'),
        Pmax = (1071, 'Pa'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Ethane and Chlorinated Ethanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """6900-6909""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA6900-6909:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Pressure dependence: None reported
Experimental procedure: Flow tube - Data taken vs distance
Excitation technique: Discharge
Analytical technique: Resonance fluorescence

Error limits (2?igma? reflect only statistical contributions.
""",
)

entry(
    index = 171,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.25e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (53.545, 'kJ/mol', '+|-', 1.073),
        T0 = (1, 'K'),
        Tmin = (876, 'K'),
        Tmax = (1020, 'K'),
        Pmin = (4866, 'Pa'),
        Pmax = (23300, 'Pa'),
    ),
    reference = Article(
        authors = ["Cao, J.-R.", "Back, M.H."],
        title = u'Kinetics of the reaction H + C2H6 \u2192\x92 H2 + C2H5 in the temperature retion of 1000 K',
        journal = "Can. J. Chem.",
        volume = "62",
        pages = """86""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984CAO/BAC86:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 172,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.31e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
""",
)

entry(
    index = 173,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.01e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (38.08, 'kJ/mol', '+|-', 2.669),
        T0 = (1, 'K'),
        Tmin = (281, 'K'),
        Tmax = (1480, 'K'),
        Pmin = (12000, 'Pa'),
        Pmax = (53700, 'Pa'),
    ),
    reference = Article(
        authors = ["Lede, J.", "Villermaux, J."],
        title = u"Measure de la Constante de Vitesse de Reaction des Atomes d'Hydrogene sur l'Ethane et le Propane en Reacteurs Tubulaire et Parfaitement Agite Ouverts",
        journal = "Can. J. Chem.",
        volume = "56",
        pages = """392""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978LED/VIL392:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 5.0
Bath gas: C2H6
Excitation technique: Electron beam
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 174,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.07e+08, 'm^3/(mol*s)', '*|/', 1.86),
        n = 0,
        Ea = (38.579, 'kJ/mol', '+|-', 2.702),
        T0 = (1, 'K'),
        Tmin = (357, 'K'),
        Tmax = (544, 'K'),
        Pmin = (533, 'Pa'),
        Pmax = (533, 'Pa'),
    ),
    reference = Article(
        authors = ["Jones, D.", "Morgan, P.A.", "Purnell, J.H."],
        title = u'Mass Spectrometric Study of the Reaction of Hydrogen Atoms with Ethane',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "73",
        pages = """1311""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977JON/MOR1311:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 1.86
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 175,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.86e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (40.907, 'kJ/mol', '+|-', 1.638),
        T0 = (1, 'K'),
        Tmin = (503, 'K'),
        Tmax = (753, 'K'),
        Pmin = (1067, 'Pa'),
        Pmax = (2133, 'Pa'),
    ),
    reference = Article(
        authors = ["Camilleri, P.", "Marshall, R.M.", "Purnell, J.H."],
        title = u'Reaction of Hydrogen Atoms with Ethane',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "70",
        pages = """1434""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974CAM/MAR1434:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: Ar
Excitation technique: Electron beam
Analytical technique: Gas chromatography
""",
)

entry(
    index = 176,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)', '*|/', 1.38),
        n = 0,
        Ea = (40.575, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'The Use of the H2 + O2 Reaction in Determining the Velocity Constants of Elementary Reactions in Hydrocarbon Oxidation',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """291""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAK/BAL291:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 1.38
""",
)

entry(
    index = 177,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.11e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (38.912, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (579, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (653, 'Pa'),
    ),
    reference = Article(
        authors = ["Azatyan, V.V.", "Filippov, S.B."],
        title = u'A study of the reaction of atomic hydrogen and deuterium with ethane',
        journal = "Dokl. Phys. Chem. (Engl. Transl.)",
        volume = "184",
        pages = """49""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969AZA/FIL49:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 178,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.83e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (38.08, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (509, 'K'),
    ),
    reference = Article(
        authors = ["Azatyan, V.V.", "Filippov, S.B.", "Nalbandyan, A.B.", "Romanovich, L.B."],
        title = u'Rate constant determination for the reaction of atomic hydrogen with ethane using an E.S.R. method',
        journal = "Arm. Khim. Zh.",
        volume = "22",
        pages = """193-196""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969AZA/FIL193-196:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 179,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.46e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (47.725, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (853, 'K'),
        Tmax = (953, 'K'),
    ),
    reference = Article(
        authors = ["Parsamyan, N.I.", "Arakelyan, E.A.", "Azatyan, V.V.", "Nalbandyan, A.B."],
        title = u'Study of the reaction of atomic hydrogen with ethane',
        journal = "Bull. Acad. Sci. USSR Div. Chem. Sci. (Engl. Transl.)",
        pages = """486""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968PAR/ARA486:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 180,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.23e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.743, 'kJ/mol', '+|-', 8.314),
        T0 = (1, 'K'),
        Tmin = (843, 'K'),
        Tmax = (933, 'K'),
        Pmin = (116, 'Pa'),
        Pmax = (208, 'Pa'),
    ),
    reference = Article(
        authors = ["Azatyan, V.V."],
        title = u'Combustion limitation method in the heterogeneous termination of chains in diffusion range',
        journal = "Arm. Khim. Zh.",
        volume = "20",
        pages = """577-584""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967AZA577-584:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 181,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)', '*|/', 1.6),
        n = 0,
        Ea = (40.575, 'kJ/mol', '+|-', 2.029),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (873, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Jackson, D.", "Walker, R.W.", "Webster, S.J."],
        title = u'The use of the hydrogen-oxygen reaction in evaluating velocity constants',
        journal = "Symp. Int. Combust. Proc.",
        volume = "10",
        pages = """423-433""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965BAL/JAC423-433:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 1.6
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 182,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (36.002, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Yang, K."],
        title = u'Free radical reactions initiated by ionizing radiations. III. Paraffin reactivities in hydrogen atom abstraction reactions',
        journal = "J. Phys. Chem.",
        volume = "67",
        pages = """562""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963YAN562:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: Ar
Excitation technique: Ultrasonics
Analytical technique: Gas chromatography
""",
)

entry(
    index = 183,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.38e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (40.575, 'kJ/mol', '+|-', 8.564),
        T0 = (1, 'K'),
        Tmin = (900, 'K'),
        Tmax = (1430, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Fenimore, C.P.", "Jones, G.W."],
        title = u'The decomposition of ethylene and ethane in premixed hydrocarbon-oxygen-hydrogen flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "9",
        pages = """597""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963FEN/JON597:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Other
""",
)

entry(
    index = 184,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.37e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (51.051, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (823, 'K'),
        Pmin = (15100, 'Pa'),
        Pmax = (15100, 'Pa'),
    ),
    reference = Article(
        authors = ["Gorban, N.I.", "Nalbandyan, A.B."],
        title = u'Rate constants for the reactions of atomic hydrogen with simple saturated hydrocarbons',
        journal = "Russ. J. Phys. Chem. (Engl. Transl.)",
        volume = "36",
        pages = """946""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962GOR/NAL946:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 185,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.4e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (28.435, 'kJ/mol', '+|-', 1.704),
        T0 = (1, 'K'),
        Tmin = (353, 'K'),
        Tmax = (436, 'K'),
        Pmin = (8533, 'Pa'),
        Pmax = (20500, 'Pa'),
    ),
    reference = Article(
        authors = ["Berlie, M.R.", "Le Roy, D.J."],
        title = u'The reaction of atomic hydrogen with ethane',
        journal = "Discuss. Faraday Soc.",
        pages = """50""",
        year = "1953",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1953BER/LER50:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Bath gas: C2H6
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 186,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.24e-22, 'm^3/(mol*s)'),
        n = 9.72,
        Ea = (3.883, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (400, 'K'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Ethane and Chlorinated Ethanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """6900-6909""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA6900-6909:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00009460

Derived from fits of a transition state theory model, the Marcus expression for correlation between reaction barriers and energetics, and analysis of experimental data reported in this reference. Transition state geometry and barriers were computed at several levels and Eckart-level tunneling contributions were applied.
""",
)

entry(
    index = 187,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (26.8, 'm^3/(mol*s)'),
        n = 1.98,
        Ea = (26.465, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Slagle, I.R.", "Knyazev, V.D."],
        title = u'Kinetics of Reactions of H Atoms with Ethane and Chlorinated Ethanes',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """6900-6909""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BRY/SLA6900-6909:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00009460

Derived from fits of a transition state theory model, the Marcus expression for correlation between reaction barriers and energetics, and analysis of experimental data reported in this reference. Transition state geometry and barriers were computed at several levels and Eckart-level tunneling contributions were applied.
""",
)

entry(
    index = 188,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000536, 'm^3/(mol*s)', '*|/', 1.07),
        n = 3.5,
        Ea = (21.784, 'kJ/mol', '+|-', 0.218),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1800, 'K'),
    ),
    reference = Article(
        authors = ["Clark, T.C.", "Dove, J.E."],
        title = u'Examination of Possible Non-Arrhenius Behavior in the Reactions',
        journal = "Can. J. Chem.",
        volume = "51",
        pages = """2147""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973CLA/DOV2147:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 1.0700001
""",
)

entry(
    index = 189,
    label = "C2H6 + H <=> H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (40.575, 'kJ/mol', '+|-', 2.029),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (813, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Jackson, D.", "Walker, R.W.", "Webster, S.J."],
        title = u'The use of the hydrogen-oxygen reaction in evaluating velocity constants',
        journal = "Symp. Int. Combust. Proc.",
        volume = "10",
        pages = """423-433""",
        year = "1964",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1964BAL/JAC423-433:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009460
Uncertainty: 1.58
""",
)

entry(
    index = 190,
    label = "H2 + CH3O <=> CH4O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.3e-07, 'm^3/(mol*s)'),
        n = 4,
        Ea = (20.537, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00009467
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009467/rk00000001.xml

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 191,
    label = "CH4O + H <=> H2 + CH3O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (25.525, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009467
Uncertainty: 2.0
""",
)

entry(
    index = 192,
    label = "CH4O + H <=> H2 + CH3O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.834e-05, 'm^3/(mol*s)'),
        n = 3.4,
        Ea = (30.265, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00009467
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009467/rk00000001.xml

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 193,
    label = "H2 + CH3O-2 <=> CH4O-2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.676, 'm^3/(mol*s)', '*|/', 5),
        n = 2,
        Ea = (55.873, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:27",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009476
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009476/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 194,
    label = "H2 + CH3O-2 <=> CH4O-2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.133e-05, 'm^3/(mol*s)'),
        n = 3.5,
        Ea = (43.817, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00009476

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 195,
    label = "CH4O-2 + H <=> H2 + CH3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (16.4, 'm^3/(mol*s)'),
        n = 2,
        Ea = (18.874, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Li, S.C.", "Williams, F.A."],
        title = u'Experimental and numerical studies of two-stage methanol flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "26",
        pages = """1017-1024""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996LI/WIL1017-1024:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009476
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 196,
    label = "CH4O-2 + H <=> H2 + CH3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (59.199, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1900, 'K'),
        Tmax = (2700, 'K'),
        Pmin = (800, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Cribb, P.H.", "Dove, J.E.", "Yamazaki, S."],
        title = u'A kinetic study of the pyrolysis of methanol using shock tube and computer simulation techniques',
        journal = "Combust. Flame",
        volume = "88",
        pages = """169-185""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992CRI/DOV169-185:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009476
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Laser schlieren
""",
)

entry(
    index = 197,
    label = "CH4O-2 + H <=> H2 + CH3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.4e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (10.892, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (5333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Vandooren, J.", "Van Tiggelen, P.J."],
        title = u'Experimental Investigation of Methanol Oxidation in Flames: Mechanism and Rate Constants of Elementary Steps',
        journal = "Symp. Int. Combust. Proc.",
        volume = "18",
        pages = """473""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981VAN/VAN473:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009476
Uncertainty: 2.0
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 198,
    label = "CH4O-2 + H <=> H2 + CH3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.031, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (680, 'K'),
        Pmin = (200, 'Pa'),
        Pmax = (800, 'Pa'),
    ),
    reference = Article(
        authors = ["Hoyermann, K.", "Sievert, R.", "Wagner, H.Gg."],
        title = u'Mechanism of the Reaction of H Atoms with Methanol',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "85",
        pages = """149""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981HOY/SIE149:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009476
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 199,
    label = "CH4O-2 + H <=> H2 + CH3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.16e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (29.267, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2180, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (507000, 'Pa'),
    ),
    reference = Article(
        authors = ["Westbrook, C.K.", "Dryer, F.L."],
        title = u'A comprehensive mechanism for methanol oxidation',
        journal = "Combust. Sci. Technol.",
        volume = "20",
        pages = """125""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979WES/DRY125:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009476
Bath gas: N2
""",
)

entry(
    index = 200,
    label = "CH4O-2 + H <=> H2 + CH3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.001354, 'm^3/(mol*s)'),
        n = 3.2,
        Ea = (14.592, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00009476

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 201,
    label = "H2 + CHO <=> CH2O + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.8, 'm^3/(mol*s)', '*|/', 5),
        n = 2,
        Ea = (74.581, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:95",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009477/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 202,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (127, 'm^3/(mol*s)', '*|/', 2),
        n = 1.62,
        Ea = (9.063, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1700, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Frank, P.", "Hayman, G.", "Just, Th.", "Kerr, J.A.", "Murrells, T.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combusion modelling. Supplement I',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "23",
        pages = """847-1033""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994BAU/COB847-1033:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Uncertainty: 2.0
""",
)

entry(
    index = 203,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (22900, 'm^3/(mol*s)', '*|/', 3.16),
        n = 1.05,
        Ea = (13.719, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2200, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:8",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Uncertainty: 3.1600001
""",
)

entry(
    index = 204,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (127, 'm^3/(mol*s)'),
        n = 1.62,
        Ea = (9.063, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (260, 'K'),
        Tmax = (1700, 'K'),
        Pmin = (56800, 'Pa'),
        Pmax = (94300, 'Pa'),
    ),
    reference = Article(
        authors = ["Choudhury, T.K.", "Lin, M.C."],
        title = u'Pyrolysis of methyl nitrite and 1,3,5-trioxane mixtures in shock waves: kinetic modeling of the H + CH2O reaction rate',
        journal = "Combust. Sci. Technol.",
        volume = "64",
        pages = """19-28""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989CHO/LIN19-28:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: Ar
""",
)

entry(
    index = 205,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (219, 'm^3/(mol*s)', '*|/', 3),
        n = 1.77,
        Ea = (12.555, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:10",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009477/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 206,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.5e+07, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (16.712, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Uncertainty: 1.58
""",
)

entry(
    index = 207,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.6e+08, 'm^3/(mol*s)', '*|/', 1.66),
        n = 0,
        Ea = (40.6, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1510, 'K'),
        Tmax = (1960, 'K'),
        Pmin = (122000, 'Pa'),
        Pmax = (145000, 'Pa'),
    ),
    reference = Article(
        authors = ["Friedrichs, G.", "Davidson, D.F.", "Hanson, R.K."],
        title = u'Direct Measurements of the Reaction H + CH2O -&gt; H2 + HCO Behind Shock Waves by Means of Vis-UV Detection of Formaldehyde',
        journal = "Int J. Chem. Kinet.",
        volume = "34",
        pages = """374-386""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002FRI/DAV374-386:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Uncertainty: 1.66
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 208,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.7e+06, 'm^3/(mol*s)', '+|-', 1.9e+06),
        n = 0,
        Ea = (14.5, 'kJ/mol', '+|-', 0.7),
        T0 = (1, 'K'),
        Tmin = (296, 'K'),
        Tmax = (780, 'K'),
        Pmin = (185, 'Pa'),
        Pmax = (701, 'Pa'),
    ),
    reference = Article(
        authors = ["Oehlers, C.", "Wagner, H. Gg.", "Ziemer, H.", "Temps, F.", "Dobe, S."],
        title = u'An Investigation of the D/H Addition-elimination and H Atom Abstraction Channels in the Reaction D + H2CO in the Temperature Range 296&lt;=T&lt;=780 K',
        journal = "J. Phys. Chem. A",
        volume = "104",
        pages = """10500-10510""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000OEH/WAG10500-10510:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Discharge
Time resolution: In real time
Analytical technique: Electron spin resonance (ESR or EPR)

At pressures of a few millibars using the discharge flow method with electron paramagnetic resonance (EPR) for the detection of H and D atoms and laser-induced fluorescence (LIF) for the
measurement of HCO.
""",
)

entry(
    index = 209,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (57.3, 'm^3/(mol*s)'),
        n = 1.9,
        Ea = (11.474, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (5000, 'K'),
    ),
    reference = Article(
        authors = ["Irdam, E.A.", "Kiefer, J.H.", "Harding, L.B.", "Wagner, A.F."],
        title = u'The formaldehyde decomposition chain mechanism',
        journal = "Int. J. Chem. Kinet.",
        volume = "25",
        pages = """285-303""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993IRD/KIE285-303:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""RRK(M) extrapolation""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
""",
)

entry(
    index = 210,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (16.712, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1900, 'K'),
        Tmax = (2700, 'K'),
        Pmin = (800, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Cribb, P.H.", "Dove, J.E.", "Yamazaki, S."],
        title = u'A kinetic study of the pyrolysis of methanol using shock tube and computer simulation techniques',
        journal = "Combust. Flame",
        volume = "88",
        pages = """169-185""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992CRI/DOV169-185:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Laser schlieren
""",
)

entry(
    index = 211,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.88e+07, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (15.631, 'kJ/mol', '+|-', 2.503),
        T0 = (1, 'K'),
        Tmin = (1180, 'K'),
        Tmax = (1690, 'K'),
        Pmin = (56800, 'Pa'),
        Pmax = (94300, 'Pa'),
    ),
    reference = Article(
        authors = ["Choudhury, T.K.", "Lin, M.C."],
        title = u'Pyrolysis of methyl nitrite and 1,3,5-trioxane mixtures in shock waves: kinetic modeling of the H + CH2O reaction rate',
        journal = "Combust. Sci. Technol.",
        volume = "64",
        pages = """19-28""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989CHO/LIN19-28:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Uncertainty: 1.2
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 212,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.62, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1600, 'K'),
        Pmin = (293, 'Pa'),
        Pmax = (293, 'Pa'),
    ),
    reference = Article(
        authors = ["Vandooren, J.", "Oldenhove de Guertechin, L.", "van Tiggelen, P.J."],
        title = u'Kinetics in a lean formaldehyde flame',
        journal = "Combust. Flame",
        volume = "64",
        pages = """127""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986VAN/OLD127:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 213,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (2200, 'K'),
        Pmin = (183000, 'Pa'),
        Pmax = (273000, 'Pa'),
    ),
    reference = Article(
        authors = ["Kline, J.M.", "Penner, S.S."],
        title = u'Rates and Mechanisms of Formaldehyde Pyrolysis and Oxidation',
        journal = "Proc. Int. Symp. Shock Tubes Waves",
        volume = "13",
        pages = """869""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982KLI/PEN869:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: IR absorption
""",
)

entry(
    index = 214,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.31e+08, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (43.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1700, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (16800, 'Pa'),
        Pmax = (23300, 'Pa'),
    ),
    reference = Article(
        authors = ["Dean, A.M.", "Johnson, R.L.", "Steiner, D.C."],
        title = u'Shock-Tube Studies of Formaldehyde Oxidation',
        journal = "Combust. Flame",
        volume = "37",
        pages = """41""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980DEA/JOH41:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Uncertainty: 2.0
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Other (IR)
""",
)

entry(
    index = 215,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.97e+07, 'm^3/(mol*s)', '+|-', 9.6e+06),
        n = 0,
        Ea = (15.382, 'kJ/mol', '+|-', 1.538),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (500, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (60000, 'Pa'),
    ),
    reference = Article(
        authors = ["Klemm, R.B."],
        title = u'Absolute Rate Parameters for the Reactions of Formaldehyde with O Atoms and H Atoms Over the Temperature Range 250-500 K',
        journal = "J. Chem. Phys.",
        volume = "71",
        pages = """1987""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979KLE1987:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 216,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.35e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (15.714, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (652, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (267, 'Pa'),
    ),
    reference = Article(
        authors = ["Westenberg, A.A.", "DeHaas, N."],
        title = u'Measurement of the Rate Constant for H + H2CO \u2192\x92 H2 + HCO at 297-652oK',
        journal = "J. Phys. Chem.",
        volume = "76",
        pages = """2213""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972WES/DEH2213:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 217,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (16.712, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1370, 'K'),
        Tmax = (1840, 'K'),
        Pmin = (40000, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Hidaka, Y.", "Oki, T.", "Kawano, H."],
        title = u'Thermal decomposition of methanol in shock waves',
        journal = "J. Phys. Chem.",
        volume = "93",
        pages = """7134-7139""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989HID/OKI7134-7139:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: Ar
""",
)

entry(
    index = 218,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.12e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.092, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (2200, 'K'),
        Tmax = (2650, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Saito, K.", "Kakumoto, T.", "Nakanishi, Y.", "Imamura, A."],
        title = u'Thermal decomposition of formaldehyde at high temperatures',
        journal = "J. Phys. Chem.",
        volume = "89",
        pages = """3109""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985SAI/KAK3109:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: Ar
""",
)

entry(
    index = 219,
    label = "CH2O + H <=> H2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.18e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.863, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (600, 'K'),
        Pmin = (18700, 'Pa'),
        Pmax = (18700, 'Pa'),
    ),
    reference = Article(
        authors = ["Klein, R.", "Scheer, M.D.", "Schoen, L.J."],
        title = u'The pyrolysis of formaldehyde',
        journal = "J. Am. Chem. Soc.",
        volume = "78",
        pages = """50""",
        year = "1956",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1956KLE/SCH50:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009477
Bath gas: CH2O
""",
)

entry(
    index = 220,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0302, 'm^3/(mol*s)', '*|/', 5),
        n = 2.63,
        Ea = (35.752, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:96",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Uncertainty: 5.0
""",
)

entry(
    index = 221,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.06e+06, 'm^3/(mol*s)', '+|-', 210000),
        n = 0,
        Ea = (34.754, 'kJ/mol', '+|-', 0.695),
        T0 = (1, 'K'),
        Tmin = (499, 'K'),
        Tmax = (947, 'K'),
        Pmin = (253, 'Pa'),
        Pmax = (747, 'Pa'),
    ),
    reference = Article(
        authors = ["Knyazev, V.D.", "Bencsura, A.", "Stoliarov, S.I.", "Slagle, I.R."],
        title = u'Kinetics of the C2H3 + H2 = H + C2H4 and CH3 + H2 = H + CH4 reactions',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """11346-11354""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996KNY/BEN11346-11354:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 222,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (55600, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.031, 'kJ/mol', '+|-', 0.46),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (500, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (80000, 'Pa'),
    ),
    reference = Article(
        authors = ["Callear, A.B.", "Smith, G.B."],
        title = u'Addition of atomic hydrogen to acetylene. Chain reactions of the vinyl radical',
        journal = "Chem. Phys. Lett.",
        volume = "105",
        pages = """119""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984CAL/SMI119:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: H2
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 223,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.009454, 'm^3/(mol*s)'),
        n = 2.56,
        Ea = (21.036, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Knyazev, V.D.", "Bencsura, A.", "Stoliarov, S.I.", "Slagle, I.R."],
        title = u'Kinetics of the C2H3 + H2 = H + C2H4 and CH3 + H2 = H + CH4 reactions',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """11346-11354""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996KNY/BEN11346-11354:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
""",
)

entry(
    index = 224,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0222, 'm^3/(mol*s)'),
        n = 2.48,
        Ea = (29.849, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3500, 'K'),
    ),
    reference = Article(
        authors = ["Mebel, A.M.", "Morokuma, K.", "Lin, M.C."],
        title = u'Ab initio molecular orbital study of potential energy surface for the reaction of C2H3 with H2 and related reactions',
        journal = "J. Chem. Phys.",
        volume = "103",
        pages = """3440-3449""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995MEB/MOR3440-3449:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
""",
)

entry(
    index = 225,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3150, 'm^3/(mol*s)'),
        n = 0.7,
        Ea = (21.368, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Weissman, M.A.", "Benson, S.W."],
        title = u'Rate parameters for the reactions of C2H3 and C4H5 with H2 and C2H2',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """4080""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988WEI/BEN4080:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
""",
)

entry(
    index = 226,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.98e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.507, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (872, 'K'),
        Tmax = (1080, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Manion, J.A.", "Louw, R."],
        title = u'Gas-phase hydrogenolysis of chloroethene: Rates, products, and computer modelling',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1547-1555""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988MAN/LOU1547-1555:10",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: N2
""",
)

entry(
    index = 227,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.05e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.008, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    reference = Article(
        authors = ["Scherzer, K.", "Loser, U.", "Stiller, W."],
        title = u'BSBL-Rechnungen zu wasserstoffabspaltungsreaktionen durch alkenylradikale; Vinylradikale',
        journal = "Z. Chem.",
        volume = "27",
        pages = """300""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987SCH/LOS300:8",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
""",
)

entry(
    index = 229,
    label = "H2 + C2H3 <=> C2H4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.94e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (30.93, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1170, 'K'),
        Tmax = (1430, 'K'),
    ),
    reference = Article(
        authors = ["Benson, S.W.", "Haugen, G.R."],
        title = u'Mechanisms for some high-temperature gas-phase reactions of ethylene, acetylene, and butadiene',
        journal = "J. Phys. Chem.",
        volume = "71",
        pages = """1735""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967BEN/HAU1735:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009480/rk00000001.xml
Bath gas: H2
""",
)

entry(
    index = 230,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.42e+08, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (62.359, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:47",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Uncertainty: 3.1600001
""",
)

entry(
    index = 231,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.33, 'm^3/(mol*s)', '*|/', 3),
        n = 2.53,
        Ea = (51.217, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:56",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Uncertainty: 3.0
Bath gas: N2
""",
)

entry(
    index = 232,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.5e+08, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (42.736, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:27",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Uncertainty: 3.1600001
""",
)

entry(
    index = 233,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.55e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (60.03, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1110, 'K'),
        Tmax = (1240, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hautman, D.J.", "Santoro, R.J.", "Dryer, F.L.", "Glassman, I."],
        title = u'An Overall and Detailed Kinetic Study of the Pyrolysis of Propane',
        journal = "Int. J. Chem. Kinet.",
        volume = "13",
        pages = """149""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981HAU/SAN149:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 234,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2e+09, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.398, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1300, 'K'),
        Tmax = (1800, 'K'),
    ),
    reference = Article(
        authors = ["Peeters, J."],
        title = u'Production of hydrogen atoms',
        journal = "Symp. Int. Combust. Proc.",
        volume = "16",
        pages = """969""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977PEE969:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 235,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.9e+07, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (43.069, 'kJ/mol', '+|-', 8.19),
        T0 = (1, 'K'),
        Tmin = (1090, 'K'),
        Tmax = (1270, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Yampol'skii, Yu.P."],
        title = u'Rate Constant of the Reaction H + C2H4 \u2192\x92 H2 + C2H3',
        journal = "Kinet. Catal.",
        volume = "15",
        pages = """938""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974YAM938:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Uncertainty: 2.51
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 236,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.9e+07, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (43.069, 'kJ/mol', '+|-', 8.19),
        T0 = (1, 'K'),
        Tmin = (1020, 'K'),
        Tmax = (1270, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Yampol'skii, Yu.P."],
        title = u'Investigation of the dehydrogenation of ethylene with the aid of deuterated compounds',
        journal = "Bull. Acad. Sci. USSR Div. Chem. Sci. (Engl. Transl.)",
        volume = "23",
        pages = """532""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974YAM532:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Uncertainty: 2.51
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 237,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.04e+06, 'm^3/(mol*s)', '+|-', 3e+06),
        n = 0,
        Ea = (30.098, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (843, 'K'),
        Tmax = (933, 'K'),
        Pmin = (26.66, 'Pa'),
        Pmax = (200, 'Pa'),
    ),
    reference = Article(
        authors = ["Azatyan, V.V.", "Nalbandyan, A.B.", "Ts'ui, M.-Y."],
        title = u'Determination of rate constants of the reactions of atomic hydrogen and atomic oxygen with ethylene',
        journal = "Dokl. Akad. Nauk SSR",
        volume = "149",
        pages = """1095-1098""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963AZA/NAL1095-1098:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Other (direct)
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 238,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.127, 'm^3/(mol*s)'),
        n = 2.75,
        Ea = (48.739, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Huynh, L.K.", "Panasewicz, S.", "Ratkiewicz, A.", "Truong, T.N."],
        title = u'Ab initio study on the kinetics of hydrogen abstraction for the H +  alkene  &rarr; H2 +  alkenyl reaction class',
        journal = "J. Phys. Chem. A",
        volume = "111",
        pages = """2156-2165""",
        year = "2007",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2007HUY/PAN2156-2165:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Pressure dependence: None reported

Ab initio study, using canonical variationaltransition state theory (CVT) with small curvature tunneling (SCT)

CCSD(T)/cc-pVTZ//BH&HLYP;/cc-pVDZ energies.

H + C2H4 -> H2 + C2H3
Ea = 5.54kcal/mol
DrH = 7.6kcal/mol
no uncertainties reported.
""",
)

entry(
    index = 239,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (44.9, 'm^3/(mol*s)'),
        n = 2.12,
        Ea = (55.923, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1850, 'K'),
        Tmax = (2150, 'K'),
    ),
    reference = Article(
        authors = ["Bhargava, A.", "Westmoreland, P.R."],
        title = u'Measured flame structure and kinetics in a fuel-rich ethylene flame',
        journal = "Combust. Flame",
        volume = "113",
        pages = """333-347""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998BHA/WES333-347:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
""",
)

entry(
    index = 240,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (50.7, 'm^3/(mol*s)'),
        n = 1.93,
        Ea = (54.21, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Knyazev, V.D.", "Bencsura, A.", "Stoliarov, S.I.", "Slagle, I.R."],
        title = u'Kinetics of the C2H3 + H2 = H + C2H4 and CH3 + H2 = H + CH4 reactions',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """11346-11354""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996KNY/BEN11346-11354:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
""",
)

entry(
    index = 241,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (317000, 'm^3/(mol*s)'),
        n = 0.7,
        Ea = (33.507, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Weissman, M.A.", "Benson, S.W."],
        title = u'Rate parameters for the reactions of C2H3 and C4H5 with H2 and C2H2',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """4080""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988WEI/BEN4080:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
""",
)

entry(
    index = 242,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (62.774, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (872, 'K'),
        Tmax = (1080, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Manion, J.A.", "Louw, R."],
        title = u'Gas-phase hydrogenolysis of chloroethene: Rates, products, and computer modelling',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1547-1555""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988MAN/LOU1547-1555:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: N2
""",
)

entry(
    index = 243,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5e+09, 'm^3/(mol*s)'),
        n = 0,
        Ea = (95.616, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1700, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (24700, 'Pa'),
        Pmax = (65900, 'Pa'),
    ),
    reference = Article(
        authors = ["Just, Th.", "Roth, P.", "Damm, R."],
        title = u'Production of Hydrogen Atoms during the Thermal Dissociation of Ethylene between 1700 and 2200o K',
        journal = "Symp. Int. Combust. Proc.",
        volume = "16",
        pages = """961""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977JUS/ROT961:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: Ar
""",
)

entry(
    index = 244,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.47e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (37.665, 'kJ/mol', '+|-', 1.505),
        T0 = (1, 'K'),
        Tmin = (1070, 'K'),
        Tmax = (1170, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Nametkin, N.S.", "Shevel'kova, L.V.", "Kalinenko, R.A."],
        title = u'Rate Constants of the Reactions of Hydrogen Atoms with Ethylene and Butadiene at High Temperatures',
        journal = "Dokl. Chem. (Engl. Transl.)",
        volume = "221",
        pages = """851""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975NAM/SHE851:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: C2H4
""",
)

entry(
    index = 245,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.1e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (35.586, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1700, 'K'),
        Pmin = (5333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Book(
        authors = ["Peeters, J.", "Mahnen, G."],
        title = u'Structure of Ethylene-Oxygen Flames. Reaction Mechanism and Rate Constants of Elementary Reactions',
        publisher = "ed. F. J. Weinberg, pub. Academic Press, London,",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973PEE/MAH53C:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
Bath gas: Ar
""",
)

entry(
    index = 246,
    label = "C2H4 + H <=> H2 + C2H3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.31e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (25.11, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1170, 'K'),
        Tmax = (1430, 'K'),
    ),
    reference = Article(
        authors = ["Benson, S.W.", "Haugen, G.R."],
        title = u'Mechanisms for some high-temperature gas-phase reactions of ethylene, acetylene, and butadiene',
        journal = "J. Phys. Chem.",
        volume = "71",
        pages = """1735""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967BEN/HAU1735:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009480
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009480/rk00000001.xml
Bath gas: H2
""",
)

entry(
    index = 247,
    label = "H2 + HO2 <=> H2O2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.01e+07, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (108.92, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:98",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
Uncertainty: 3.0
""",
)

entry(
    index = 248,
    label = "H2 + HO2 <=> H2O2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (729000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (78.073, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (800, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:109",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
Uncertainty: 2.0
""",
)

entry(
    index = 249,
    label = "H2 + HO2 <=> H2O2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (729000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (78.239, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
Uncertainty: 2.0
""",
)

entry(
    index = 250,
    label = "H2 + HO2 <=> H2O2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.66e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (104.762, 'kJ/mol', '+|-', 7.325),
        T0 = (1, 'K'),
        Tmin = (733, 'K'),
        Tmax = (803, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Jackson, D.", "Walker, R.W.", "Webster, S.J."],
        title = u'Interpretation of the slow reaction and second limit of hydrogen oxygen mixtures by computer methods',
        journal = "Trans. Faraday Soc.",
        volume = "63",
        pages = """1676-1686""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967BAL/JAC1676-1686:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009484/rk00000002.xml
Bath gas: H2
""",
)

entry(
    index = 251,
    label = "H2 + HO2 <=> H2O2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.97e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (89.796, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (370, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:31",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
""",
)

entry(
    index = 252,
    label = "H2O2 + H <=> H2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.69e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (15.714, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:197",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
Uncertainty: 2.0
""",
)

entry(
    index = 253,
    label = "H2O2 + H <=> H2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.82e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (33.258, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:235",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
Uncertainty: 5.0
""",
)

entry(
    index = 254,
    label = "H2O2 + H <=> H2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.16e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (49.388, 'kJ/mol', '+|-', 8.398),
        T0 = (1, 'K'),
        Tmin = (733, 'K'),
        Tmax = (803, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Jackson, D.", "Walker, R.W.", "Webster, S.J."],
        title = u'Interpretation of the slow reaction and second limit of hydrogen oxygen mixtures by computer methods',
        journal = "Trans. Faraday Soc.",
        volume = "63",
        pages = """1676-1686""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967BAL/JAC1676-1686:6",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009484/rk00000002.xml
Bath gas: H2
""",
)

entry(
    index = 255,
    label = "H2O2 + H <=> H2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.3e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.258, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (950, 'K'),
        Tmax = (1050, 'K'),
    ),
    reference = Article(
        authors = ["Lee, D.", "Hochgreb, S."],
        title = u'Hydrogen autoignition at pressures above the second explosion limit (0.6 - 4.0 MPa)',
        journal = "Int. J. Chem. Kinet.",
        volume = "30",
        pages = """385-406""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998LEE/HOC385-406:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
""",
)

entry(
    index = 256,
    label = "H2O2 + H <=> H2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.3e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.62, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (713, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:36",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009484
""",
)

entry(
    index = 257,
    label = "H2 + O2 <=> HO2-2 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.45e+08, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (236.962, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:100",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Uncertainty: 5.0
""",
)

entry(
    index = 258,
    label = "H2 + O2 <=> HO2-2 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (9.03e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (190.443, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1662, 'K'),
        Tmax = (2097, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (76000, 'Pa'),
    ),
    reference = Article(
        authors = ["Michael, J.V.", "Sutherland, J.W.", "Harding, L.B.", "Wagner, A.F."],
        title = u'Initiation in H2/O2: Rate constants for H2+O2 -&gt; H+HO2 at high temperature',
        journal = "Proc. Combust. Inst.",
        volume = "28",
        pages = """1471-1478""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000MIC/SUT1471-1478:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Experimental procedure: Shock tube
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 259,
    label = "H2 + O2 <=> HO2-2 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (4.1e+10, 'm^3/(mol*s)'),
        n = 0,
        Ea = (285.186, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1400, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Koike, T."],
        title = u'Shock tube studies of the H2-O2 reaction by atomic resonance absorption spectroscopy',
        journal = "Bull. Chem. Soc. Jpn.",
        volume = "62",
        pages = """2480-2484""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989KOI2480-2484:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 260,
    label = "H2 + O2 <=> HO2-2 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (0.74, 'm^3/(mol*s)'),
        n = 2.43,
        Ea = (223.875, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (2300, 'K'),
    ),
    reference = Article(
        authors = ["Michael, J.V.", "Sutherland, J.W.", "Harding, L.B.", "Wagner, A.F."],
        title = u'Initiation in H2/O2: Rate constants for H2+O2 -&gt; H+HO2 at high temperature',
        journal = "Proc. Combust. Inst.",
        volume = "28",
        pages = """1471-1478""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000MIC/SUT1471-1478:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
""",
)

entry(
    index = 261,
    label = "H2 + O2 <=> HO2-2 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.44e+07, 'm^3/(mol*s)'),
        n = 0.17,
        Ea = (232.556, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Karach, S.P.", "Osherov, V.I."],
        title = u'Ab Initio Analysis of the Transition States on the Lowest Triplet H2O2 Potential Surface',
        journal = "J. Chem. Phys.",
        volume = "110",
        pages = """11918-11927""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999KAR/OSH11918-11927:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
""",
)

entry(
    index = 262,
    label = "H2 + O2 <=> HO2-2 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (263.569, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (1.01e+06, 'Pa'),
        Pmax = (1.01e+06, 'Pa'),
    ),
    reference = Article(
        authors = ["Skinner, G.B.", "Lifshitz, A.", "Scheller, K.", "Burcat, A."],
        title = u'Kinetics of Methane Oxidation',
        journal = "J. Chem. Phys.",
        volume = "56",
        pages = """3853""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972SKI/LIF3853:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Bath gas: CH4
""",
)

entry(
    index = 263,
    label = "H2 + O2 <=> HO2-2 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.91e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (245.277, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Mayer, S.W.", "Schieler, L."],
        title = u'Activation energies and rate constants computed for reactions of oxygen with hydrocarbons',
        journal = "J. Phys. Chem.",
        volume = "72",
        pages = """2628-2631""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968MAY/SCH2628-2631:10",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009509/rk00000001.xml
""",
)

entry(
    index = 264,
    label = "HO2-2 + H <=> H2 + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (4.28e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (5.903, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:171",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Uncertainty: 2.0
""",
)

entry(
    index = 265,
    label = "HO2-2 + H <=> H2 + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.62e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (8.896, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:217",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Uncertainty: 2.0
""",
)

entry(
    index = 266,
    label = "HO2-2 + H <=> H2 + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.5e+07, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (2.902, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:165",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Uncertainty: 1.58
""",
)

entry(
    index = 267,
    label = "HO2-2 + H <=> H2 + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.02e+06, 'm^3/(mol*s)', '*|/', 3.39),
        n = 0,
        Ea = (-1.663, 'kJ/mol', '+|-', 0.998),
        T0 = (1, 'K'),
        Tmin = (231, 'K'),
        Tmax = (464, 'K'),
        Pmin = (267, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Pratt, G.L.", "Wood, S.W."],
        title = u'Stoichiometry and rate of reaction of hydrogen atoms with oxygen',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "79",
        pages = """2597""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983PRA/WOO2597:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Uncertainty: 3.3900001
Bath gas: Ar
""",
)

entry(
    index = 268,
    label = "HO2-2 + H <=> H2 + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.5e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (2.927, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:17",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Uncertainty: 2.0
""",
)

entry(
    index = 269,
    label = "HO2-2 + H <=> H2 + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (67, 'm^3/(mol*s)'),
        n = 1.77,
        Ea = (-2.38, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Mousavipour, S.H.", "Saheb, V."],
        title = u'Theoretical study on the kinetic and mechanism of H+HO2 reaction',
        journal = "Bull. Chem. Soc. Jpn.",
        volume = "80",
        pages = """1901-1913""",
        year = "2007",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2007MOU/SAH1901-1913:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Pressure dependence: Rate constant is pressure independent

Reaction potential energy surface was studied using quantum chemistry and rate constants were calculated using transition state theory.
""",
)

entry(
    index = 270,
    label = "HO2-2 + H <=> H2 + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (186, 'm^3/(mol*s)'),
        n = 1.72,
        Ea = (-4.84, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Mousavipour, S.H.", "Saheb, V."],
        title = u'Theoretical study on the kinetic and mechanism of H+HO2 reaction',
        journal = "Bull. Chem. Soc. Jpn.",
        volume = "80",
        pages = """1901-1913""",
        year = "2007",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2007MOU/SAH1901-1913:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
Pressure dependence: Rate constant is pressure independent

Reaction potential energy surface was studied using quantum chemistry and rate constants were calculated using transition state theory.
""",
)

entry(
    index = 271,
    label = "HO2-2 + H <=> H2 + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (618000, 'm^3/(mol*s)'),
        n = 0.47,
        Ea = (1.912, 'kJ/mol', '+|-', 0.499),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Karach, S.P.", "Osherov, V.I."],
        title = u'Ab Initio Analysis of the Transition States on the Lowest Triplet H2O2 Potential Surface',
        journal = "J. Chem. Phys.",
        volume = "110",
        pages = """11918-11927""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999KAR/OSH11918-11927:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00009509
""",
)

entry(
    index = 274,
    label = "CH3 + H2O <=> CH4 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000483, 'm^3/(mol*s)', '*|/', 1.6),
        n = 2.9,
        Ea = (62.192, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:166",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.6
""",
)

entry(
    index = 275,
    label = "CH3 + H2O <=> CH4 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.00048, 'm^3/(mol*s)', '*|/', 2),
        n = 2.9,
        Ea = (62.192, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:24",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010849/rk00000001.xml
Uncertainty: 2.0
""",
)

entry(
    index = 276,
    label = "CH3 + H2O <=> CH4 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.39e-06, 'm^3/(mol*s)'),
        n = 3.31,
        Ea = (52.547, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Ma, S.", "Liu, R."],
        title = u'Theoretical studies on the reaction path and dynamics of the reaction CH3+H2O \u2192\x92 CH4+OH',
        journal = "Sci. China Ser. B",
        volume = "39",
        pages = """37-44""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996MA/LIU37-44:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 277,
    label = "CH3 + H2O <=> CH4 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.57e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (110.582, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1510, 'K'),
        Tmax = (1530, 'K'),
    ),
    reference = Article(
        authors = ["Leroy, G.", "Sana, M.", "Tinant, A."],
        title = u"Etude theorique des reactions d'abstraction d'hydrogene RH + X = R + HX, avec R, X\u2261H, CH3, NH2, OH et F",
        journal = "Can. J. Chem.",
        volume = "63",
        pages = """1447-1456""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985LER/SAN1447-1456:13",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 278,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1, 'm^3/(mol*s)', '*|/', 1.2),
        n = 2.18,
        Ea = (10.235, 'kJ/mol', '+|-', 1.846),
        T0 = (1, 'K'),
        Tmin = (195, 'K'),
        Tmax = (2025, 'K'),
        Pmin = (1443.9, 'Pa'),
        Pmax = (2133.2, 'Pa'),
    ),
    reference = Article(
        authors = ["Srinivasan, N.K.", "Su, M.C.", "Sutherland, J.W.", "Michael, J.V."],
        title = u'Reflected shock tube studies of high-temperature rate constants for OH+CH4 -&gt; CH3+H2O and CH3+NO2 -&gt; CH3O+NO',
        journal = "J. Phys. Chem. A",
        volume = "109",
        pages = """1857-1863""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005SRI/SU1857-1863:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.2
Pressure dependence: Rate constant is pressure independent

The reflected shock tube technique with multipass absorption spectrometric detection of OH radicals at 308 nm was used to study the CH4+ OH reaction. OH was generated from thermal decomposition of t-butyl hydroperoxide at temperatures less than 1300 K and from HNO3at higher temperatures.

The temperature dependent cross section for OH was measured and is reported as
sigma(OH ) = (4.516 - 0.00118 T) x 10-17cm2molecule-1;
where T is in Kelvin.

Literature results are discussed and compared and a rate expression covering the temperature range of 195-2025 K is given.
""",
)

entry(
    index = 279,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.002463, 'm^3/(mol*s)', '+|-', 0.000108),
        n = 3.04,
        Ea = (7.649, 'kJ/mol', '+|-', 0.108),
        T0 = (1, 'K'),
        Tmin = (195, 'K'),
        Tmax = (1234, 'K'),
    ),
    reference = Article(
        authors = ["Bonard, A.", "Daele, V.", "Delfau, J.-L", "Vovelle, C."],
        title = u'Kinetics of OH Radical Reactions with Methane in the Temperature Range 295-660 K and with Dimethyl Ether and Methyl-tert-butyl Ether in the Temperature Range 295-618 K',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """4384-4389""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002BON/DAE4384-4389:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 280,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.48e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (14.8, 'kJ/mol', '+|-', 0.89),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:88",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 281,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.39e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (14.633, 'kJ/mol', '+|-', 0.881),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:58",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 282,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.6e+06, 'm^3/(mol*s)', '*|/', 1.1),
        n = 0,
        Ea = (14.966, 'kJ/mol', '+|-', 1.197),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.J.", "Molina, M.J."],
        title = u'Chemical Kinetic and Photochemical Data for Use in Stratospheric Modeling: Evaluation No. 11 of the NASA Panel for Data Evaluation',
        journal = "JPL Publication 94-26",
        pages = """1-2""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DEM/SAN:88",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.1
""",
)

entry(
    index = 283,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (15.7, 'm^3/(mol*s)', '*|/', 1.41),
        n = 1.83,
        Ea = (11.64, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:28",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.41
""",
)

entry(
    index = 284,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.35e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (15.631, 'kJ/mol', '+|-', 0.784),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:59",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 285,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.23e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (15.132, 'kJ/mol', '+|-', 0.757),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:22",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.26
""",
)

entry(
    index = 286,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.193, 'm^3/(mol*s)', '*|/', 1.4),
        n = 2.4,
        Ea = (8.813, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:22",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.4
""",
)

entry(
    index = 287,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.73, 'm^3/(mol*s)'),
        n = 1.96,
        Ea = (11.058, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (268, 'K'),
        Tmax = (1510, 'K'),
        Pmin = (5000, 'Pa'),
        Pmax = (20000, 'Pa'),
    ),
    reference = Article(
        authors = ["Felder, W.", "Madronich, S."],
        title = u'High temperature photochemistry (HTP): kinetics and mechanism studies of elementary combustion reactions over 300-1700 K',
        journal = "Combust. Sci. Technol.",
        volume = "50",
        pages = """135-150""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986FEL/MAD135-150:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
""",
)

entry(
    index = 288,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.5, 'm^3/(mol*s)', '*|/', 2),
        n = 2.13,
        Ea = (10.227, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Bowers, D.G.", "Malcolm, D.G.", "Tuckersman, R.T."],
        title = u'Evaluated kinetic data for high-temperature reactions. Volume 5. Part 1. Homogeneous gas phase reactions of the hydroxyl radical with alkanes',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """465""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986BAU/BOW465:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 2.0
""",
)

entry(
    index = 289,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.19, 'm^3/(mol*s)', '*|/', 1.2),
        n = 2,
        Ea = (10.643, 'kJ/mol', '+|-', 0.319),
        T0 = (1, 'K'),
        Tmin = (238, 'K'),
        Tmax = (1250, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics and mechanisms of the gas-phase reactions of the hydroxyl radical with organic compounds under atmospheric conditions',
        journal = "Chem. Rev.",
        volume = "86",
        pages = """69""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK69:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.2
""",
)

entry(
    index = 290,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.6, 'm^3/(mol*s)', '*|/', 1.58),
        n = 2.1,
        Ea = (10.31, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2200, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:13",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.58
""",
)

entry(
    index = 291,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.19, 'm^3/(mol*s)', '*|/', 2),
        n = 2.4,
        Ea = (8.813, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010849/rk00000001.xml
Uncertainty: 2.0
""",
)

entry(
    index = 292,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.55, 'm^3/(mol*s)'),
        n = 2.13,
        Ea = (10.227, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Zellner, R."],
        title = u'Non-Arrhenius Behavior in Bimolecular Reactions of the OH Radical',
        journal = "J. Phys. Chem.",
        volume = "83",
        pages = """18""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979ZEL18:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 293,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.55, 'm^3/(mol*s)'),
        n = 2.13,
        Ea = (10.227, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Ernst, J.", "Wagner, H.Gg.", "Zellner, R."],
        title = u'A Combined Flash Photolysis/Shock-Tube Study of the Absolute Rate Constants for Reactions of the Hydroxyl Radical with CH4 and CF3H around 1300 K',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "82",
        pages = """409""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978ERN/WAG409:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
""",
)

entry(
    index = 294,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.85e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (20.786, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Wilson, W.E., Jr."],
        title = u'A critical review of the gas-phase reaction kinetics of the hydroxyl radical',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "1",
        pages = """535-573""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972WIL535-573:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 10.0
""",
)

entry(
    index = 295,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.9e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.952, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (133, 'Pa'),
    ),
    reference = Article(
        authors = ["Wilson, W.E.", "Westenberg, A.A."],
        title = u'Study of the reaction of hydroxyl radical with methane by quantitative ESR',
        journal = "Symp. Int. Combust. Proc.",
        volume = "11",
        pages = """1143-1150""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967WIL/WES1143-1150:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
""",
)

entry(
    index = 296,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.6e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.368, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Dixon-Lewis, G.", "Williams, A."],
        title = u'Some observations on the combustion of methane in premixed flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "11",
        pages = """951-958""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967DIX/WIL951-958:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: N2
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 297,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.73e+07, 'm^3/(mol*s)', '+|-', 9.76e+06),
        n = 0,
        Ea = (34.372, 'kJ/mol', '+|-', 1.846),
        T0 = (1, 'K'),
        Tmin = (840, 'K'),
        Tmax = (2025, 'K'),
        Pmin = (1443.9, 'Pa'),
        Pmax = (2133.2, 'Pa'),
    ),
    reference = Article(
        authors = ["Srinivasan, N.K.", "Su, M.C.", "Sutherland, J.W.", "Michael, J.V."],
        title = u'Reflected shock tube studies of high-temperature rate constants for OH+CH4 -&gt; CH3+H2O and CH3+NO2 -&gt; CH3O+NO',
        journal = "J. Phys. Chem. A",
        volume = "109",
        pages = """1857-1863""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005SRI/SU1857-1863:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption

The reflected shock tube technique with multipass absorption spectrometric detection of OH radicals at 308 nm was used to study the CH4+ OH reaction. OH was generated from thermal decomposition of t-butyl hydroperoxide at temperatures less than 1300 K and from HNO3at higher temperatures.

The temperature dependent cross section for OH was measured and is reported as
sigma(OH ) = (4.516 - 0.00118 T) x 10-17cm2molecule-1;
where T is in Kelvin.

Literature results are discussed and compared and a rate expression covering the temperature range of 195-2025 K is given.
""",
)

entry(
    index = 298,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.23, 'm^3/(mol*s)'),
        n = 2.38,
        Ea = (9.445, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1009, 'K'),
        Pmin = (6710, 'Pa'),
        Pmax = (24100, 'Pa'),
    ),
    reference = Article(
        authors = ["Bryukov, M.G.", "Knyazev, V.D.", "Lomnicki, S.M.", "McFerrin, C.A.", "Dellinger, B."],
        title = u'Temperature-dependent kinetics of the gas-phase reactions of OH with Cl2, CH4, and C3H8',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """10464-10472""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004BRY/KNY10464-10472:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Laser induced fluorescence

OH produced through 193 nm photolysis of N2O -> N2 + O(1D), then O(1D) + H2O -> 2OH. OH detected using LIF at 282 nm excitation monitoring fluor. at 308-316 nm. Typical conc. CH4 1-4E16, C3H8 1-3E15, Cl2 1-5E15 molecules/cm3.
""",
)

entry(
    index = 299,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.003403, 'm^3/(mol*s)', '+|-', 0.000295),
        n = 3.01,
        Ea = (7.974, 'kJ/mol', '+|-', 0.299),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (668, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Bonard, A.", "Daele, V.", "Delfau, J.-L", "Vovelle, C."],
        title = u'Kinetics of OH Radical Reactions with Methane in the Temperature Range 295-660 K and with Dimethyl Ether and Methyl-tert-butyl Ether in the Temperature Range 295-618 K',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """4384-4389""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002BON/DAE4384-4389:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 300,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0112, 'm^3/(mol*s)'),
        n = 2.82,
        Ea = (8.206, 'kJ/mol', '+|-', 0.08206),
        T0 = (1, 'K'),
        Tmin = (196, 'K'),
        Tmax = (420, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Gierczak, T.", "Talukdar, R.K.", "Herndon, S.C.", "Vaghjiani, G.L.", "Ravishankara, A.R."],
        title = u'Rate coefficients for the reactions of hydroxyl radicals with methane and deuterated methanes',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """3125-3134""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997GIE/TAL3125-3134:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 301,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.54e+06, 'm^3/(mol*s)', '+|-', 990000),
        n = 0,
        Ea = (14.633, 'kJ/mol', '+|-', 1.172),
        T0 = (1, 'K'),
        Tmin = (233, 'K'),
        Tmax = (343, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (14700, 'Pa'),
    ),
    reference = Article(
        authors = ["Mellouki, A.", "Teton, S.", "Laverdet, G.", "Quilgars, A.", "Le Bras, G."],
        title = u'Kinetic studies of OH reactions with H2O, C3H8 and CH4 using the pulsed laser photolysis - laser induced fluorescence method',
        journal = "J. Chim. Phys.",
        volume = "91",
        pages = """473-487""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994MEL/TET473-487:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 302,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (581000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (11.807, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (178, 'K'),
        Tmax = (298, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Sharkey, P.", "Smith, I.W.M."],
        title = u'Kinetics of elementary reactions at low temperatures: rate constants for the reactions of OH with HCl (298 \xe2\x89\xa5 T/K \xe2\x89\xa5 138), CH4 (298 \xe2\x89\xa5 T/K \xe2\x89\xa5 178) and C2H6 (298 \xe2\x89\xa5 T/K \xe2\x89\xa5 138)',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "89",
        pages = """631-638""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993SHA/SMI631-638:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 303,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0583, 'm^3/(mol*s)'),
        n = 2.58,
        Ea = (8.98, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (293, 'K'),
        Tmax = (800, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (100000, 'Pa'),
    ),
    reference = Article(
        authors = ["Dunlop, J.R.", "Tully, F.P."],
        title = u'A kinetic study of OH radical reactions with methane and perdeuterated methane',
        journal = "J. Phys. Chem.",
        volume = "97",
        pages = """11148-11150""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993DUN/TUL11148-11150:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 304,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.71e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (14.717, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (378, 'K'),
        Tmax = (422, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (333, 'Pa'),
    ),
    reference = Article(
        authors = ["Lancar, I.T.", "LeBras, G.", "Poulet, G."],
        title = u'Redetermination de la constante de vitesse de la reaction CH4 + OH et son implication atmospherique',
        journal = "C.R. Acad. Sc. Paris",
        volume = "315",
        pages = """1487-1492""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992LAN/LEB1487-1492:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 305,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.41e+06, 'm^3/(mol*s)', '+|-', 960000),
        n = 0,
        Ea = (16.13, 'kJ/mol', '+|-', 0.973),
        T0 = (1, 'K'),
        Tmin = (278, 'K'),
        Tmax = (378, 'K'),
        Pmin = (140, 'Pa'),
        Pmax = (140, 'Pa'),
    ),
    reference = Article(
        authors = ["Finlayson-Pitts, B.J.", "Ezell, M.J.", "Jayaweera, T.M.", "Berko, H.N.", "Lai, C.C."],
        title = u'Kinetics of the reactions of OH with methyl chloroform and methane: implications for global tropospheric OH and the methane budget',
        journal = "Geophys. Res. Lett.",
        volume = "19",
        pages = """1371-1374""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992FIN/EZE1371-1374:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 306,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.00959, 'm^3/(mol*s)'),
        n = 2.84,
        Ea = (8.132, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (223, 'K'),
        Tmax = (420, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (40000, 'Pa'),
    ),
    reference = Article(
        authors = ["Vaghjiani, G.L.", "Ravishankara, A.R."],
        title = u'New measurement of the rate coefficient for the reaction of OH with methane',
        journal = "Nature (London)",
        volume = "350",
        pages = """406-409""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991VAG/RAV406-409:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 307,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (15.5, 'm^3/(mol*s)'),
        n = (1.83, '', '+|-', 0.16),
        Ea = (11.64, 'kJ/mol', '+|-', 1.164),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1510, 'K'),
        Pmin = (5000, 'Pa'),
        Pmax = (20000, 'Pa'),
    ),
    reference = Article(
        authors = ["Felder, W.", "Madronich, S."],
        title = u'High temperature photochemistry (HTP): kinetics and mechanism studies of elementary combustion reactions over 300-1700 K',
        journal = "Combust. Sci. Technol.",
        volume = "50",
        pages = """135-150""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986FEL/MAD135-150:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
Excitation technique: Direct photolysis
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 308,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (15.5, 'm^3/(mol*s)'),
        n = (1.83, '', '+|-', 0.16),
        Ea = (11.64, 'kJ/mol', '+|-', 1.164),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1510, 'K'),
        Pmin = (10700, 'Pa'),
        Pmax = (48000, 'Pa'),
    ),
    reference = Article(
        authors = ["Madronich, S.", "Felder, W."],
        title = u'Direct measurements of the rate coefficient for the reaction OH + CH4 \u2192\x92 CH3 + H2O over 300-1500 K',
        journal = "Symp. Int. Combust. Proc.",
        volume = "20",
        pages = """703""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985MAD/FEL703:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 309,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.23e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.202, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (340, 'K'),
        Tmax = (1250, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Jonah, C.D.", "Mulac, W.A.", "Zeglinski, P."],
        title = u'Rate constants for the reaction of OH + CO, OD + CO, and OH + Methane as a function of temperature',
        journal = "J. Phys. Chem.",
        volume = "88",
        pages = """4100""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984JON/MUL4100:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 310,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.55, 'm^3/(mol*s)'),
        n = 2.13,
        Ea = (10.227, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (403, 'K'),
        Tmax = (696, 'K'),
        Pmin = (2853, 'Pa'),
        Pmax = (12600, 'Pa'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Craven, R.J.B.", "Din, M.", "Drysdale, D.D.", "Grant, S.", "Richardson, D.J.", "Walker, A.", "Watling, G."],
        title = u'Rates of hydroxy radical reactions with methane, ethane and propane over the temperature range 403-696 K',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "79",
        pages = """689""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983BAU/CRA689:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 311,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.37e+06, 'm^3/(mol*s)', '+|-', 910000),
        n = 0,
        Ea = (16.38, 'kJ/mol', '+|-', 0.821),
        T0 = (1, 'K'),
        Tmin = (278, 'K'),
        Tmax = (473, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (400, 'Pa'),
    ),
    reference = Article(
        authors = ["Jeong, K-M.", "Kaufman, F."],
        title = u'Kinetics of the Reaction of Hydroxyl Radical with Methane and with Nine Cl- and F-Substituted Methanes. 1. Experimental Results, Comparisons, and Applications',
        journal = "J. Phys. Chem.",
        volume = "86",
        pages = """1808""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982JEO/KAU1808:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 312,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.32e+07, 'm^3/(mol*s)', '+|-', 4.8e+06),
        n = 0,
        Ea = (21.119, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (830, 'K'),
        Tmax = (1400, 'K'),
        Pmin = (5333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Fairchild, P.W.", "Smith, G.P.", "Crosley, D.R."],
        title = u'A Laser Pyrolysis/Laser Fluorescence Technique for Combustion Chemical Kinetics',
        journal = "Symp. Int. Combust. Proc.",
        volume = "19",
        pages = """107""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982FAI/SMI107:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 313,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.96, 'm^3/(mol*s)'),
        n = 1.92,
        Ea = (11.308, 'kJ/mol', '+|-', 0.676),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1020, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Tully, F.P.", "Ravishankara, A.R."],
        title = u'Flash Photolysis-Resonance Fluorescence Kinetic Study of the Reactions OH + H2 \u2192\x92 H2O + H and OH + CH4 \u2192\x92 H2O + CH3 from 298 to 1020 K',
        journal = "J. Phys. Chem.",
        volume = "84",
        pages = """3126""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980TUL/RAV3126:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 314,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.003474, 'm^3/(mol*s)', '+|-', 3.35e-05),
        n = 3.08,
        Ea = (8.398, 'kJ/mol', '+|-', 0.672),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (900, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Zellner, R.", "Steinert, W."],
        title = u'A Flash Photolysis Study of the Rate of the Reaction OH + CH4 \u2192\x92 CH3 + H2O over an Extended Temperature Range',
        journal = "Int. J. Chem. Kinet.",
        volume = "8",
        pages = """397""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976ZEL/STE397:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 315,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.003474, 'm^3/(mol*s)'),
        n = 3.08,
        Ea = (8.398, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (900, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Zellner, R."],
        title = u'Rate Measurements of Some Bimolecular Reactions of the Hydroxyl Radical over an Extended Temperature Range',
        journal = "Mol. Rate Processes, Pap. Symp.",
        volume = "7",
        pages = """1""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975ZEL1:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: H2O
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 316,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.8e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (15.465, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (700, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (3333, 'Pa'),
    ),
    reference = Article(
        authors = ["Steinert, W.", "Zellner, R."],
        title = u'Rates of Reaction of OH with CO and CH4 over an Extended Temperature Range',
        journal = "Deuxiene Symp. European sur la Combust.",
        volume = "2",
        pages = """31""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975STE/ZEL31:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 317,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.07e+08, 'm^3/(mol*s)', '+|-', 1.1e+07),
        n = 0,
        Ea = (27.937, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (381, 'K'),
        Tmax = (416, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Gordon, S.", "Mulac, W.A."],
        title = u'Reaction of the OH(X2\u03c0) Radical Produced by the Pulse Radiolysis of Water Vapor',
        journal = "Proc. Symp. Chem. Kinet. Data Upper Lower Atmos. 1974",
        pages = """289""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975GOR/MUL289:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 2.51
Bath gas: H2O
Excitation technique: Ultrasonics
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 318,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.31e+06, 'm^3/(mol*s)', '+|-', 120000),
        n = 0,
        Ea = (15.299, 'kJ/mol', '+|-', 0.153),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (440, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Margitan, J.J.", "Kaufman, F.", "Anderson, J.G."],
        title = u'The Reaction of OH with CH4',
        journal = "Geophys. Res. Lett.",
        volume = "1",
        pages = """80""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974MAR/KAU80:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 319,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.42e+06, 'm^3/(mol*s)', '+|-', 130000),
        n = 0,
        Ea = (14.218, 'kJ/mol', '+|-', 0.712),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (373, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Davis, D.D.", "Fischer, S.", "Schiff, R."],
        title = u'Flash Photolysis-Resonance Fluorescence Kinetics Study: Temperature Dependence of the Reactions OH + CO \u2192\x92 CO2 + H and OH + CH4 \u2192\x92 H2O + CH3',
        journal = "J. Chem. Phys.",
        volume = "61",
        pages = """2213""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974DAV/FIS2213:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 320,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (25.11, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1100, 'K'),
        Tmax = (1900, 'K'),
        Pmin = (5333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Peeters, J.", "Mahnen, G."],
        title = u'Reaction Mechanisms and Rate Constants of Elementary Steps in Methane-Oxygen Flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "14",
        pages = """133""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973PEE/MAH133:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 321,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.52e+07, 'm^3/(mol*s)', '*|/', 1.38),
        n = 0,
        Ea = (20.952, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'The Use of the H2 + O2 Reaction in Determining the Velocity Constants of Elementary Reactions in Hydrocarbon Oxidation',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """291""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAK/BAL291:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.38
""",
)

entry(
    index = 322,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.31e+06, 'm^3/(mol*s)', '*|/', 1.25),
        n = 0,
        Ea = (15.797, 'kJ/mol', '+|-', 0.473),
        T0 = (1, 'K'),
        Tmin = (301, 'K'),
        Tmax = (492, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 1.25
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 323,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.01e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.952, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (423, 'K'),
        Pmin = (41200, 'Pa'),
        Pmax = (41200, 'Pa'),
    ),
    reference = Article(
        authors = ["Horne, D.G.", "Norrish, R.G.W."],
        title = u'Rate of H-abstraction by OH from hydrocarbons',
        journal = "Nature (London)",
        volume = "215",
        pages = """1373""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967HOR/NOR1373:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 324,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.43e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (27.188, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (372, 'K'),
        Tmax = (1340, 'K'),
        Pmin = (5066, 'Pa'),
        Pmax = (5066, 'Pa'),
    ),
    reference = Article(
        authors = ["Fristrom, R.M."],
        title = u'Radical concentrations and reactions in a methane-oxygen flame',
        journal = "Symp. Int. Combust. Proc.",
        volume = "9",
        pages = """560""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963FRI560:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 325,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.5e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (37.665, 'kJ/mol', '+|-', 6.402),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1800, 'K'),
    ),
    reference = Article(
        authors = ["Fenimore, C.P.", "Jones, G.W."],
        title = u'Rate of reaction of methane with H atoms and OH radicals in flames',
        journal = "J. Phys. Chem.",
        volume = "65",
        pages = """2200-2203""",
        year = "1961",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1961FEN/JON2200-2203:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 326,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (313000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (13.64, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (380, 'K'),
    ),
    reference = Article(
        authors = ["Bravo-Perez, G.", "Alvarez-Idaboy, J.R.", "Jimenez, A.G.", "Cruz-Torres, A."],
        title = u'Quantum chemical and conventional TST calculations of rate constants for the OH plus alkane reaction',
        journal = "Chem. Phys.",
        volume = "310",
        pages = """213-223""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005BRA/ALV213-223:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

1) The rate coefficent is the result of BHandHLYP/6-311G(d,p) calculations. The paper also lists rate coeffients computed at the MP2/6-311G(d,p) level.

The title reaction was modeled using ab initio MP2 and a hybrid density functional method (BHandHLYP) methods, and the 6-311G(d,p) basis set. Single-point calculations at the CCSD(T) level were carried out at the optimized geometries. Hindered Internal Rotation partition functions calculations were explicitly carried out and included in the total partition functions. The explicit participation of the tunnel effect was taken into account.
""",
)

entry(
    index = 327,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.464, 'm^3/(mol*s)'),
        n = 2.3,
        Ea = (11.474, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Masgrau, L.", "Gonzalez-Lafont, A.", "Lluch, J.M."],
        title = u'The Reactions CHnD4-n + OH -&gt; P and CH4 + HOD -&gt; CH3 + HOD as a Test of Current Direct Dynamics Multicoefficient Methods to Determine Variational Transition State Rate constants. II',
        journal = "J. Chem. Phys.",
        volume = "115",
        pages = """4515-4526""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001MAS/GON4515-4526:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

Rate constants calculated at several temperatures using the VTST-ISPE mapped interpolation scheme at the multicoefficient correlation method (MMCM) at the CCSD(T) level of theory. Parameters are from a fit by the abstractor to these data.

Calculations at several other levels of theory also presented.
""",
)

entry(
    index = 328,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.361, 'm^3/(mol*s)'),
        n = 2.33,
        Ea = (11.474, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Masgrau, L.", "Gonzalez-Lafont, A.", "Lluch, J.M."],
        title = u'The Reactions CHnD4-n + OH -&gt; P and CH4 + OD -&gt; CH3 + HOD as a Test of Current Direct Dynamics Computational Methods to Determine Variational Transition-State Rate Constants. I.',
        journal = "J. Chem. Phys.",
        volume = "114",
        pages = """2154-2165""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001MAS/GON2154-2165:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

Rate constants calculated at several temperatures using the VTST-ISPE mapped interpolation scheme at the CCSD(T)-SAC//MP2cc-pVTZ level of theory. Parameters are from a fit by the abstractor to these data.
Rate constants were also calculated at other levels of theory and at this level of theory but with a single-point energy approach.
""",
)

entry(
    index = 329,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000837, 'm^3/(mol*s)'),
        n = 3.21,
        Ea = (6.593, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Schwartz, M.", "Marshall, P.", "Berry, R.J.", "Ehlers, C.J.", "Petersson, G.A."],
        title = u'Computational study of the kinetics of hydrogen abstraction from fluoromethanes by the hydroxyl radical',
        journal = "J. Phys. Chem. A",
        volume = "102",
        pages = """10074-10081""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998SCH/MAR10074-10081:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 330,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.54e-06, 'm^3/(mol*s)'),
        n = 3.95,
        Ea = (2.286, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (223, 'K'),
        Tmax = (2400, 'K'),
    ),
    reference = Article(
        authors = ["Melissas, V.S.", "Truhlar, D.G."],
        title = u'Interpolated variational transition state theory and tunneling calculations of the rate constant of the reaction OH+CH4 at 223-2400 K',
        journal = "J. Chem. Phys.",
        volume = "99",
        pages = """1013-1027""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993MEL/TRU1013-1027:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 331,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.05e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.263, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Dobbs, K.D.", "Dixon, D.A.", "Komornicki, A."],
        title = u'Ab initio prediction of the barrier height for abstraction of H from CH4 by OH',
        journal = "J. Chem. Phys.",
        volume = "98",
        pages = """8852-8858""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993DOB/DIX8852-8858:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

Rate constants in this work were computed using transition state theory employing transition states from ab initio calculations. A range of levels of theory and different basis sets were used. A Wigner correction was used to account for tunneling. Both the free rotor and harmonic oscillator approximation were used to treat the CH3 rotor. The highest level calculations were QCISD(T)/CC (Dunnings correlation consistent basis sets). Use of TZ+2P+f basis sets gave barriers that were about 0.50 kcal/mol lower than the QCISD(T)/CC values. Use of PUMP4 theory gave barriers that were about 0.24 kcal/mol lower than the QCISD(T)/CC values. The best agreement of the calculated values with experimental data was found using the free rotor approximation where the calculated values were about a factor of two higher at 400 K and about a factor of three higher at 1500 K than the experimental data.

Extended Arrhenius expression fit by NIST to authors reported calculated data when they employed a free rotor approximation for the torsional mode.
""",
)

entry(
    index = 332,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.11e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (19.205, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (420, 'K'),
    ),
    reference = Article(
        authors = ["Dobbs, K.D.", "Dixon, D.A.", "Komornicki, A."],
        title = u'Ab initio prediction of the barrier height for abstraction of H from CH4 by OH',
        journal = "J. Chem. Phys.",
        volume = "98",
        pages = """8852-8858""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993DOB/DIX8852-8858:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

Rate constants in this work were computed using transition state theory employing transition states from ab initio calculations. A range of levels of theory and different basis sets were used. A Wigner correction was used to account for tunneling. Both the free rotor and harmonic oscillator approximation were used to treat the CH3 rotor. The highest level calculations were QCISD(T)/CC (Dunnings correlation consistent basis sets). Use of TZ+2P+f basis sets gave barriers that were about 0.50 kcal/mol lower than the QCISD(T)/CC values. Use of PUMP4 theory gave barriers that were about 0.24 kcal/mol lower than the QCISD(T)/CC values. The best agreement of the calculated values with experimental data was found using the free rotor approximation where the calculated values were about a factor of two higher at 400 K and about a factor of three higher at 1500 K than the experimental data.

Extended Arrhenius expression fit by NIST to authors reported calculated data when they employed a harmonic oscillator approximation for the torsional mode.
""",
)

entry(
    index = 333,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.07e+09, 'm^3/(mol*s)'),
        n = 0,
        Ea = (25.606, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Dobbs, K.D.", "Dixon, D.A.", "Komornicki, A."],
        title = u'Ab initio prediction of the barrier height for abstraction of H from CH4 by OH',
        journal = "J. Chem. Phys.",
        volume = "98",
        pages = """8852-8858""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993DOB/DIX8852-8858:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

Rate constants in this work were computed using transition state theory employing transition states from ab initio calculations. A range of levels of theory and different basis sets were used. A Wigner correction was used to account for tunneling. Both the free rotor and harmonic oscillator approximation were used to treat the CH3 rotor. The highest level calculations were QCISD(T)/CC (Dunnings correlation consistent basis sets). Use of TZ+2P+f basis sets gave barriers that were about 0.50 kcal/mol lower than the QCISD(T)/CC values. Use of PUMP4 theory gave barriers that were about 0.24 kcal/mol lower than the QCISD(T)/CC values. The best agreement of the calculated values with experimental data was found using the free rotor approximation where the calculated values were about a factor of two higher at 400 K and about a factor of three higher at 1500 K than the experimental data.

Extended Arrhenius expression fit by NIST to authors reported calculated data when they employed a harmonic oscillator approximation for the torsional mode.
""",
)

entry(
    index = 334,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.35, 'm^3/(mol*s)'),
        n = 2.32,
        Ea = (12.175, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Dobbs, K.D.", "Dixon, D.A.", "Komornicki, A."],
        title = u'Ab initio prediction of the barrier height for abstraction of H from CH4 by OH',
        journal = "J. Chem. Phys.",
        volume = "98",
        pages = """8852-8858""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993DOB/DIX8852-8858:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

Rate constants in this work were computed using transition state theory employing transition states from ab initio calculations. A range of levels of theory and different basis sets were used. A Wigner correction was used to account for tunneling. Both the free rotor and harmonic oscillator approximation were used to treat the CH3 rotor. The highest level calculations were QCISD(T)/CC (Dunnings correlation consistent basis sets). Use of TZ+2P+f basis sets gave barriers that were about 0.50 kcal/mol lower than the QCISD(T)/CC values. Use of PUMP4 theory gave barriers that were about 0.24 kcal/mol lower than the QCISD(T)/CC values. The best agreement of the calculated values with experimental data was found using the free rotor approximation where the calculated values were about a factor of two higher at 400 K and about a factor of three higher at 1500 K than the experimental data.

Extended Arrhenius expression fit by NIST to authors reported calculated data when they employed a free rotor approximation for the torsional mode.
""",
)

entry(
    index = 335,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.135, 'm^3/(mol*s)'),
        n = 2.85,
        Ea = (11.966, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Dobbs, K.D.", "Dixon, D.A.", "Komornicki, A."],
        title = u'Ab initio prediction of the barrier height for abstraction of H from CH4 by OH',
        journal = "J. Chem. Phys.",
        volume = "98",
        pages = """8852-8858""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993DOB/DIX8852-8858:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

Rate constants in this work were computed using transition state theory employing transition states from ab initio calculations. A range of levels of theory and different basis sets were used. A Wigner correction was used to account for tunneling. Both the free rotor and harmonic oscillator approximation were used to treat the CH3 rotor. The highest level calculations were QCISD(T)/CC (Dunnings correlation consistent basis sets). Use of TZ+2P+f basis sets gave barriers that were about 0.50 kcal/mol lower than the QCISD(T)/CC values. Use of PUMP4 theory gave barriers that were about 0.24 kcal/mol lower than the QCISD(T)/CC values. The best agreement of the calculated values with experimental data was found using the free rotor approximation where the calculated values were about a factor of two higher at 400 K and about a factor of three higher at 1500 K than the experimental data.

Extended Arrhenius expression fit by NIST to authors reported calculated data when they employed a harmonic oscillator approximation for the torsional mode.
""",
)

entry(
    index = 336,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.85e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (18.075, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (420, 'K'),
    ),
    reference = Article(
        authors = ["Dobbs, K.D.", "Dixon, D.A.", "Komornicki, A."],
        title = u'Ab initio prediction of the barrier height for abstraction of H from CH4 by OH',
        journal = "J. Chem. Phys.",
        volume = "98",
        pages = """8852-8858""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993DOB/DIX8852-8858:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010849

Rate constants in this work were computed using transition state theory employing transition states from ab initio calculations. A range of levels of theory and different basis sets were used. A Wigner correction was used to account for tunneling. Both the free rotor and harmonic oscillator approximation were used to treat the CH3 rotor. The highest level calculations were QCISD(T)/CC (Dunnings correlation consistent basis sets). Use of TZ+2P+f basis sets gave barriers that were about 0.50 kcal/mol lower than the QCISD(T)/CC values. Use of PUMP4 theory gave barriers that were about 0.24 kcal/mol lower than the QCISD(T)/CC values. The best agreement of the calculated values with experimental data was found using the free rotor approximation where the calculated values were about a factor of two higher at 400 K and about a factor of three higher at 1500 K than the experimental data.

Extended Arrhenius expression fit by NIST to authors reported calculated data when they employed a free rotor approximation for the torsional mode.
""",
)

entry(
    index = 337,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (102, 'm^3/(mol*s)'),
        n = 1.6,
        Ea = (13.054, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1510, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 338,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e-08, 'm^3/(mol*s)'),
        n = 4.75,
        Ea = (3.683, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Truong, T.N.", "Truhlar, D.G."],
        title = u'Ab initio transition state theory calculations of the reaction rate for OH+CH4\u2192\x92H2O+CH3',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "93",
        pages = """1761""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TRU/TRU1761:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 339,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.124, 'm^3/(mol*s)'),
        n = 2.51,
        Ea = (12.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Gonzalez, C.", "McDouall, J.J.W.", "Schlegel, H.B."],
        title = u'Ab initio study of the reactions between methane and OH, H, and 3O',
        journal = "J. Phys. Chem.",
        volume = "94",
        pages = """7467-7471""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990GON/MCD7467-7471:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 340,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (512, 'm^3/(mol*s)'),
        n = 1.4,
        Ea = (14.218, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Benson, S.W."],
        title = u'Transition-state-theory calculations for reactions of OH with haloalkanes',
        journal = "J. Phys. Chem.",
        volume = "91",
        pages = """162-170""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987COH/BEN162-170:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 341,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.61e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (50.885, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1500, 'K'),
        Tmax = (1550, 'K'),
    ),
    reference = Article(
        authors = ["Leroy, G.", "Sana, M.", "Tinant, A."],
        title = u"Etude theorique des reactions d'abstraction d'hydrogene RH + X = R + HX, avec R, X\u2261H, CH3, NH2, OH et F",
        journal = "Can. J. Chem.",
        volume = "63",
        pages = """1447-1456""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985LER/SAN1447-1456:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 342,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.911, 'm^3/(mol*s)'),
        n = 2.3,
        Ea = (11.391, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'The use of transition-state theory to extrapolate rate coefficients for reactions of OH with alkanes',
        journal = "Int. J. Chem. Kinet.",
        volume = "14",
        pages = """1339""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982COH1339:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
""",
)

entry(
    index = 343,
    label = "CH4 + OH <=> CH3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.52, 'm^3/(mol*s)', '*|/', 2),
        n = 2,
        Ea = (12.305, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Shaw, R."],
        title = u'Semi-Empirical Extrapolation and Estimation of Rate Constants for Abstraction of H From Methane by H, O, HO, and O2',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "7",
        pages = """1179""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978SHA1179:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00010849
Uncertainty: 2.0
""",
)

entry(
    index = 344,
    label = "C2H6O + H <=> H2 + C2H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.33e-29, 'm^3/(mol*s)'),
        n = 10.58,
        Ea = (-18.649, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Park, J.", "Xu, Z.F.", "Lin, M.C."],
        title = u'Thermal decomposition of ethanol. II. A computational study of the kinetics and mechanism for the H+C2H5OH reaction',
        journal = "J. Chem. Phys.",
        volume = "118",
        pages = """9990-9996""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003PAR/XU9990-9996:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001618
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001618/rk00000001.xml

Ab initio study of Ethanol + H reaction channels. Rate constants based on ab initio transition states. Ab initio energies calculated using G2M method with B3LYP/6-311+G(d,p). Rate expressions calculated using Truhlars Polyrate program using SCT/CVT method (small curvature tunnelling correction/canonical variational transition state theory).

Found barriers of
7.2 kcal/mol for CH3CH(OH)* + H2 channel
13.3 kcal/mol for CH2OHCH2* + H2 channel
15.0 kcal/mol for CH3CH2O* + H2 channel
27.2 kcal/mol for CH3CH2* + H2O channel
The first channel dominates at all temperatures, the second channel begins to contribute at about 1000 K and is roughly equal at 3000 K, the third channel is <5% even at 3000 K. The fourth channel is kinetically insignificant.

NOTE The rate expression given for the CH3CH2O+H2 channel (k3) in Table II of the paper appears to be incorrect. The correct rate expressions can be found in the text.
""",
)

entry(
    index = 345,
    label = "C2H6O + H <=> H2 + C2H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.0536, 'm^3/(mol*s)'),
        n = 2.53,
        Ea = (36.625, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Park, J.", "Xu, Z.F.", "Lin, M.C."],
        title = u'Thermal decomposition of ethanol. II. A computational study of the kinetics and mechanism for the H+C2H5OH reaction',
        journal = "J. Chem. Phys.",
        volume = "118",
        pages = """9990-9996""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003PAR/XU9990-9996:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001618
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001618/rk00000001.xml

Ab initio study of Ethanol + H reaction channels. Rate constants based on ab initio transition states. Ab initio energies calculated using G2M method with B3LYP/6-311+G(d,p). Rate expressions calculated using Truhlars Polyrate program using SCT/CVT method (small curvature tunnelling correction/canonical variational transition state theory).

Found barriers of
7.2 kcal/mol for CH3CH(OH)* + H2 channel
13.3 kcal/mol for CH2OHCH2* + H2 channel
15.0 kcal/mol for CH3CH2O* + H2 channel
27.2 kcal/mol for CH3CH2* + H2O channel
The first channel dominates at all temperatures, the second channel begins to contribute at about 1000 K and is roughly equal at 3000 K, the third channel is <5% even at 3000 K. The fourth channel is kinetically insignificant.

NOTE The rate expression given for the CH3CH2O+H2 channel (k3) in Table II of the paper appears to be incorrect. The correct rate expressions can be found in the text.
""",
)

entry(
    index = 346,
    label = "C2H6O-2 + H <=> H2 + C2H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.4e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (19.123, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (700, 'K'),
        Pmin = (267, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Aders, W.K.", "Wagner, H.G."],
        title = u'Untersuchungen zur Reaktion von Wasserstoffatomen mit Aethanol und tert. Butanol',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "77",
        pages = """712""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973ADE/WAG712:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001619
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001619/rk00000004.xml
Bath gas: He
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 347,
    label = "C2H6O-2 + H <=> H2 + C2H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.179, 'm^3/(mol*s)'),
        n = 2.53,
        Ea = (14.309, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Park, J.", "Xu, Z.F.", "Lin, M.C."],
        title = u'Thermal decomposition of ethanol. II. A computational study of the kinetics and mechanism for the H+C2H5OH reaction',
        journal = "J. Chem. Phys.",
        volume = "118",
        pages = """9990-9996""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003PAR/XU9990-9996:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001619

Ab initio study of Ethanol + H reaction channels. Rate constants based on ab initio transition states. Ab initio energies calculated using G2M method with B3LYP/6-311+G(d,p). Rate expressions calculated using Truhlars Polyrate program using SCT/CVT method (small curvature tunnelling correction/canonical variational transition state theory).

Found barriers of
7.2 kcal/mol for CH3CH(OH)* + H2 channel
13.3 kcal/mol for CH2OHCH2* + H2 channel
15.0 kcal/mol for CH3CH2O* + H2 channel
27.2 kcal/mol for CH3CH2* + H2O channel
The first channel dominates at all temperatures, the second channel begins to contribute at about 1000 K and is roughly equal at 3000 K, the third channel is <5% even at 3000 K. The fourth channel is kinetically insignificant.

There is a disagreement between the calculated value for the total rate with experimental measurements by Adler and Wagner Ber. Buns. Phys. Chem. 77, 712 (1973), the calc values being 2-3 times lower. The current authors attribute the difference to incorrect assumptions regarding secondary reactions in the experimental measurements, and they employing modeling to demonstrate such.
""",
)

entry(
    index = 348,
    label = "C2H6O-3 + H <=> H2 + C2H5O-3",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.00188, 'm^3/(mol*s)'),
        n = 3.2,
        Ea = (29.924, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Park, J.", "Xu, Z.F.", "Lin, M.C."],
        title = u'Thermal decomposition of ethanol. II. A computational study of the kinetics and mechanism for the H+C2H5OH reaction',
        journal = "J. Chem. Phys.",
        volume = "118",
        pages = """9990-9996""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003PAR/XU9990-9996:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001620
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001620/rk00000001.xml

Ab initio study of Ethanol + H reaction channels. Rate constants based on ab initio transition states. Ab initio energies calculated using G2M method with B3LYP/6-311+G(d,p). Rate expressions calculated using Truhlars Polyrate program using SCT/CVT method (small curvature tunnelling correction/canonical variational transition state theory).

Found barriers of
7.2 kcal/mol for CH3CH(OH)* + H2 channel
13.3 kcal/mol for CH2OHCH2* + H2 channel
15.0 kcal/mol for CH3CH2O* + H2 channel
27.2 kcal/mol for CH3CH2* + H2O channel
The first channel dominates at all temperatures, the second channel begins to contribute at about 1000 K and is roughly equal at 3000 K, the third channel is <5% even at 3000 K. The fourth channel is kinetically insignificant.
""",
)

entry(
    index = 349,
    label = "CH4 + C2H5 <=> C2H6 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (9e-08, 'm^3/(mol*s)', '*|/', 2),
        n = 4.14,
        Ea = (52.547, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:25",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001950/rk00000002.xml
Uncertainty: 2.0
""",
)

entry(
    index = 350,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.5e-13, 'm^3/(mol*s)', '*|/', 1.58),
        n = 6,
        Ea = (25.276, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:35",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Uncertainty: 1.58
""",
)

entry(
    index = 351,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.5e-07, 'm^3/(mol*s)', '*|/', 3),
        n = 4,
        Ea = (34.671, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:32",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001950/rk00000002.xml
Uncertainty: 3.0
""",
)

entry(
    index = 352,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.5e-07, 'm^3/(mol*s)', '*|/', 2),
        n = 4,
        Ea = (34.671, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:18",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Uncertainty: 2.0
""",
)

entry(
    index = 353,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (550000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (48.473, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (350, 'K'),
        Tmax = (600, 'K'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Bell, T.N."],
        title = u'An evaluation of the kinetic data for hydrogen abstraction from silanes in the gas phase',
        journal = "Rev. Chem. Intermed.",
        volume = "2",
        pages = """37-74""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978ART/BEL37-74:5",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
""",
)

entry(
    index = 354,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2e+07, 'm^3/(mol*s)', '*|/', 2.5),
        n = 0,
        Ea = (56.538, 'kJ/mol', '+|-', 8.481),
        T0 = (1, 'K'),
        Tmin = (1100, 'K'),
        Tmax = (1400, 'K'),
        Pmin = (40000, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Moller, W.", "Mozzhukhin, E.", "Wagner, H.Gg."],
        title = u'High temperature reactions of CH3. 2. H-abstraction from alkanes',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "91",
        pages = """660""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987MOL/MOZ660:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Uncertainty: 2.5
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 355,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (81.482, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1460, 'K'),
        Tmax = (1600, 'K'),
        Pmin = (205000, 'Pa'),
        Pmax = (220000, 'Pa'),
    ),
    reference = Article(
        authors = ["Roth, P.", "Just, Th."],
        title = u'Messungen zur Hochtemperaturpyroyse von Aethan',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "83",
        pages = """577""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979ROT/JUS577:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 356,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (81.482, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1450, 'K'),
        Tmax = (2100, 'K'),
        Pmin = (175000, 'Pa'),
        Pmax = (185000, 'Pa'),
    ),
    reference = Article(
        authors = ["Roth, P.", "Just, T.H."],
        title = u'Measurements of Some Elementary Hydrocarbon Reactions at High Temperatures',
        journal = "NBS Spec. Publ. (U.S.)",
        volume = "10",
        pages = """1339""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979ROT/JUS1339:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 357,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3.24e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (75.329, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1060, 'K'),
        Tmax = (1320, 'K'),
        Pmin = (292000, 'Pa'),
        Pmax = (400000, 'Pa'),
    ),
    reference = Article(
        authors = ["Bradley, J.N.", "West, K.O."],
        title = u'Single-pulse Shock Tube Studies of Hydrocarbon Pyrolysis. Part 6. The Pyrolysis of Isobutene',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "72",
        pages = """558""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976BRA/WES558:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 358,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3.02e+06, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (56.871, 'kJ/mol', '+|-', 9.146),
        T0 = (1, 'K'),
        Tmin = (980, 'K'),
        Tmax = (1130, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Yampolskii, Yu.P.", "Rybin, V.M."],
        title = u'Arrhenius Parameters of the Reaction CH3 + C2H6 \u2192\x92 CH4 + C2H5',
        journal = "React. Kinet. Catal. Lett.",
        volume = "1",
        pages = """321""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974YAM/RYB321:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Uncertainty: 3.1600001
Bath gas: C2H6
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 359,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.01e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (89.796, 'kJ/mol', '+|-', 19.788),
        T0 = (1, 'K'),
        Tmin = (920, 'K'),
        Tmax = (1040, 'K'),
        Pmin = (13.33, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Pacey, P.D.", "Purnell, J.H."],
        title = u'Arrhenius Parameters of the Reaction CH3. + C2H6 \u2192\x92 CH4 + C2H5.',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "68",
        pages = """1462""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972PAC/PUR1462:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Bath gas: C2H6
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 360,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.8e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (89.796, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1010, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (10700, 'Pa'),
    ),
    reference = Article(
        authors = ["Held, A.M.", "Manthorne, K.C.", "Pacey, P.D.", "Reinholdt, H.P."],
        title = u'Individual Rate Constants of Methyl Radical Reactions in the Pyrolysis of Dimethyl Ether',
        journal = "Can. J. Chem.",
        volume = "55",
        pages = """4128""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977HEL/MAN4128:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Bath gas: (CH3)2O
""",
)

entry(
    index = 361,
    label = "C2H6 + CH3 <=> CH4 + C2H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.5e-07, 'm^3/(mol*s)', '*|/', 1.02),
        n = 4,
        Ea = (34.671, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1800, 'K'),
    ),
    reference = Article(
        authors = ["Clark, T.C.", "Dove, J.E."],
        title = u'Examination of Possible Non-Arrhenius Behavior in the Reactions',
        journal = "Can. J. Chem.",
        volume = "51",
        pages = """2147""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973CLA/DOV2147:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00001950
Uncertainty: 1.02
""",
)

entry(
    index = 362,
    label = "CH4 + CH3O <=> CH4O + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (157000, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (36.999, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:17",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001957
Uncertainty: 3.0
""",
)

entry(
    index = 363,
    label = "CH4 + CH3O <=> CH4O + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)', '+|-', 1.2e+08),
        n = 0,
        Ea = (63.024, 'kJ/mol', '+|-', 3.783),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (973, 'K'),
        Pmin = (3333, 'Pa'),
        Pmax = (3333, 'Pa'),
    ),
    reference = Article(
        authors = ["Wantuck, P.J.", "Oldenborg, R.C.", "Baughcum, S.L.", "Winn, K.R."],
        title = u'Direct measurements of methoxy removal rate constants for collisions with CH4, Ar, N2, Xe, and CF4 in the temperature range 673-973 K',
        journal = "Symp. Int. Combust. Proc.",
        volume = "22",
        pages = """973-981""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989WAN/OLD973-981:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""RRK(M) extrapolation""",
    longDesc = 
u"""
PrIMe Reaction: r00001957
Bath gas: Ar
""",
)

entry(
    index = 364,
    label = "CH4 + CH3O <=> CH4O + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.2e-10, 'm^3/(mol*s)'),
        n = 5,
        Ea = (23.364, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001957

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 365,
    label = "CH4 + CH3O <=> CH4O + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (631000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (46.062, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (403, 'K'),
        Tmax = (523, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Shaw, R.", "Thynne, J.C.J."],
        title = u'Hydrogen and deuterium atom abstraction from methanol and trideuteromethanol. Reaction of methoxy radicals with methane',
        journal = "Trans. Faraday Soc.",
        volume = "62",
        pages = """104""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966SHA/THY104:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00001957
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001957/rk00000001.xml
Bath gas: (CD3)2CO
""",
)

entry(
    index = 366,
    label = "CH4O + CH3 <=> CH4 + CH3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.443e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.1,
        Ea = (29.018, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:7",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001957
Uncertainty: 3.0
""",
)

entry(
    index = 367,
    label = "CH4O + CH3 <=> CH4 + CH3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1780, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (26.773, 'kJ/mol', '+|-', 2.943),
        T0 = (1, 'K'),
        Tmin = (406, 'K'),
        Tmax = (472, 'K'),
    ),
    reference = Article(
        authors = ["Shannon, T.W.", "Harrison, A.G."],
        title = u'The reaction of methyl radicals with methyl alcohol',
        journal = "Can. J. Chem.",
        volume = "41",
        pages = """2455-2461""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963SHA/HAR2455-2461:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001957
Uncertainty: 2.0
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 368,
    label = "CH4O + CH3 <=> CH4 + CH3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3.7e-10, 'm^3/(mol*s)'),
        n = 4.7,
        Ea = (24.195, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001957

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 369,
    label = "CH4 + CH3O-2 <=> CH4O-2 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.159e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.1,
        Ea = (67.929, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:23",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001965
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001965/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 370,
    label = "CH4 + CH3O-2 <=> CH4O-2 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.29e-09, 'm^3/(mol*s)'),
        n = 5,
        Ea = (62.151, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:8",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001965

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 371,
    label = "CH4O-2 + CH3 <=> CH4 + CH3O-2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3.192e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.2,
        Ea = (30.015, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:8",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001965
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001965/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 372,
    label = "CH4O-2 + CH3 <=> CH4 + CH3O-2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (240000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.485, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (406, 'K'),
        Tmax = (472, 'K'),
    ),
    reference = Article(
        authors = ["Shannon, T.W.", "Harrison, A.G."],
        title = u'The reaction of methyl radicals with methyl alcohol',
        journal = "Can. J. Chem.",
        volume = "41",
        pages = """2455-2461""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963SHA/HAR2455-2461:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001965
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 373,
    label = "CH4O-2 + CH3 <=> CH4 + CH3O-2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.14e-10, 'm^3/(mol*s)'),
        n = 4.9,
        Ea = (28.103, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001965

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 374,
    label = "CH4 + CHO <=> CH2O + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (0.007265, 'm^3/(mol*s)', '*|/', 5),
        n = 2.85,
        Ea = (93.954, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:18",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001966/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 375,
    label = "CH4 + CHO <=> CH2O + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.4e-07, 'm^3/(mol*s)', '*|/', 5),
        n = 3.78,
        Ea = (89.331, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Huynh, L.K.", "Truong, T.N."],
        title = u'Kinetics of the hydrogen abstraction CHO plus Alkane -&gt; HCHO plus Alkyl reaction class: an application of the reaction class transition state theory',
        journal = "Theor. Chem. Acct.",
        volume = "120",
        pages = """107-118""",
        year = "2008",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2008HUY/TRU107-118:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Uncertainty: 5.0
""",
)

entry(
    index = 376,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (7.77e-14, 'm^3/(mol*s)', '*|/', 1.58),
        n = 6.1,
        Ea = (8.231, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Frank, P.", "Hayman, G.", "Just, Th.", "Kerr, J.A.", "Murrells, T.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combusion modelling. Supplement I',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "23",
        pages = """847-1033""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994BAU/COB847-1033:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Uncertainty: 1.58
""",
)

entry(
    index = 377,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (4.09e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (36.999, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Uncertainty: 2.0
""",
)

entry(
    index = 378,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (0.005544, 'm^3/(mol*s)', '*|/', 3),
        n = 2.81,
        Ea = (24.528, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001966/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 379,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (7.83e-44, 'm^3/(mol*s)'),
        n = 15.4,
        Ea = (-35.919, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (350, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Hsu, D.S.Y.", "Lin, M.C."],
        title = u'Laser probing and kinetic modeling of NO and CO production in shock-wave decomposition of nitromethane under highly diluted conditions',
        journal = "J. Energ. Mater.",
        volume = "3",
        pages = """95""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985HSU/LIN95:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
""",
)

entry(
    index = 380,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (100000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (25.525, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Uncertainty: 2.0
""",
)

entry(
    index = 381,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (26800, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.128, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (603, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (22300, 'Pa'),
    ),
    reference = Article(
        authors = ["Choudhury, T.K.", "Sanders, W.A."],
        title = u'Kinetic modelling of methyl radical reactions with formaldehyde and isobutane',
        journal = "J. Chem. Soc. Faraday Trans. 2",
        volume = "85",
        pages = """801-808""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989CHO/SAN801-808:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Bath gas: CH2O
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 382,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1e+09, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (96.448, 'kJ/mol', '+|-', 10.643),
        T0 = (1, 'K'),
        Tmin = (1170, 'K'),
        Tmax = (1630, 'K'),
        Pmin = (60800, 'Pa'),
        Pmax = (106000, 'Pa'),
    ),
    reference = Article(
        authors = ["Choudhury, T.K.", "Sanders, W.A.", "Lin, M.C."],
        title = u'A shock tube and modeling study of the CH3 + CH2O reaction at high temperatures',
        journal = "J. Phys. Chem.",
        volume = "93",
        pages = """5143-5147""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989CHO/SAN5143-5147:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Uncertainty: 2.51
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Other
""",
)

entry(
    index = 383,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (843000, 'm^3/(mol*s)', '+|-', 59000),
        n = 0,
        Ea = (29.101, 'kJ/mol', '+|-', 0.291),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (603, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (22300, 'Pa'),
    ),
    reference = Article(
        authors = ["Anastasi, C."],
        title = u'Reaction of methyl radicals with formaldehyde in the range 500\xe2\x89\xa4T/K\xe2\x89\xa4603',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "79",
        pages = """749""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983ANA749:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Bath gas: CH2O
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 384,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.26e+07, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (44.981, 'kJ/mol', '+|-', 3.151),
        T0 = (1, 'K'),
        Tmin = (786, 'K'),
        Tmax = (935, 'K'),
        Pmin = (5066, 'Pa'),
        Pmax = (53500, 'Pa'),
    ),
    reference = Article(
        authors = ["Manthorne, K.C.", "Pacey, P.D."],
        title = u'The reaction of methylradicals with formaldehyde in dimethyl ether pyrolysis',
        journal = "Can. J. Chem.",
        volume = "56",
        pages = """1307""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978MAN/PAC1307:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Uncertainty: 1.58
Bath gas: (CH3)2O
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 385,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (4e-08, 'm^3/(mol*s)'),
        n = 4.4,
        Ea = (20.37, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Liu, J.Y.", "Li, Z.S.", "Wu, J.Y.", "Wei, Z.G.", "Zhang, G.", "Sun, C.C."],
        title = u'Theoretical study and rate constant calculation of the CH2O+CH3 reaction',
        journal = "J. Chem. Phys.",
        volume = "119",
        pages = """7214-7221""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003LIU/LI7214-7221:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Pressure dependence: None reported

The authors have calculated the potential energy surface of the CH2O1CH3 reaction at the MP2/6-31111G(d,p), MP4SDQ/6-311G(d,p), and QCISD(T)/6-3111G(3d f ,2p) single point levels oftheory. The calculations suggest that the major product channel is hydrogen abstraction with addition of CH3 being negligibly small. Energies were refined with the interpolated single-point energies method at the QCISD(T)//MP2 level. Rate constants were evaluated by canonical variational transition-state theory including the small-curvature tunneling correction. Tunneling is shown to play a significant role in the results below about 700 K.

Energies, frequencies, and bond length information for the intermediates and transition states are presented.
""",
)

entry(
    index = 386,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.35e-09, 'm^3/(mol*s)'),
        n = 4.95,
        Ea = (14.979, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (333, 'K'),
        Tmax = (1333, 'K'),
    ),
    reference = Article(
        authors = ["Che, C.-b.", "Zhang, H.", "Zhang, X.", "Liu, Y.", "Liu, B."],
        title = u'Ab Initio and Kinetic Study on CH3 Radical Reaction with H2CO',
        journal = "J. Phys. Chem. A",
        volume = "107",
        pages = """2929-2933""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003CHE/ZHA2929-2933:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001966

Quantum calculations of reaction of CH3 with CH2O. Calculated geometries at B3LYP/6-311+G(d,p) and energies at CCSD(T)/6-311G(2df,p). Also calculated energetics at B3LYP and G2 levels. Use Truhlars Polyrate program to calculate rate expressions using CVT/SCT tunneling corrections.

Considered abstraction, carbon addition, and oxygen addition channels. Abstraction dominates over addition channels by factor of 10 over carbon addition and many orders of magnitude over oxygen addition channel.  Found carbon addition channel can contribute at lower temperatures. Agreement with experimental measurements is good (factor of 2 higher) with some and only fair with others (factor of 5-10 higher). Depends on temperature range and the specific measurement.

Calculated barriers are 40 kcal/mol for abstraction, 34 kcal/mol for C addition, and 69 kcal/mol for O addition channels. Although abstraction has higher barrier than C addition, it also has larger prefactor.

Fits given here in database are NIST fits to curves in Figure 3 in paper.  Rate expressions NOT given in paper.
""",
)

entry(
    index = 387,
    label = "CH2O + CH3 <=> CH4 + CHO",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (8.93e-19, 'm^3/(mol*s)'),
        n = 7.4,
        Ea = (-4.016, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (60800, 'Pa'),
        Pmax = (106000, 'Pa'),
    ),
    reference = Article(
        authors = ["Choudhury, T.K.", "Sanders, W.A.", "Lin, M.C."],
        title = u'A shock tube and modeling study of the CH3 + CH2O reaction at high temperatures',
        journal = "J. Phys. Chem.",
        volume = "93",
        pages = """5143-5147""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989CHO/SAN5143-5147:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001966
Bath gas: Ar
""",
)

entry(
    index = 388,
    label = "CH4 + C2H3 <=> C2H4 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.45e-06, 'm^3/(mol*s)', '*|/', 5),
        n = 4.02,
        Ea = (22.865, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:19",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001968/rk00000002.xml
Uncertainty: 5.0
""",
)

entry(
    index = 389,
    label = "CH4 + C2H3 <=> C2H4 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (89100, 'm^3/(mol*s)'),
        n = 0,
        Ea = (25.941, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    reference = Article(
        authors = ["Scherzer, K.", "Loser, U.", "Stiller, W."],
        title = u'BSBL-Rechnungen zu wasserstoffabspaltungsreaktionen durch alkenylradikale; Vinylradikale',
        journal = "Z. Chem.",
        volume = "27",
        pages = """300""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987SCH/LOS300:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
""",
)

entry(
    index = 390,
    label = "C2H4 + CH3 <=> CH4 + C2H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (4.16e+06, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (46.561, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:42",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
Uncertainty: 3.1600001
""",
)

entry(
    index = 391,
    label = "C2H4 + CH3 <=> CH4 + C2H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.63e-06, 'm^3/(mol*s)', '*|/', 2),
        n = 3.7,
        Ea = (39.743, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:49",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001968/rk00000002.xml
Uncertainty: 2.0
""",
)

entry(
    index = 392,
    label = "C2H4 + CH3 <=> CH4 + C2H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (420000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (46.478, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:25",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
Uncertainty: 2.0
""",
)

entry(
    index = 393,
    label = "C2H4 + CH3 <=> CH4 + C2H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (501000, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (63.024, 'kJ/mol', '+|-', 3.151),
        T0 = (1, 'K'),
        Tmin = (650, 'K'),
        Tmax = (770, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Zhang, H-X.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from ethylene by methyl and ethyl radicals over the temperature range 650-770K',
        journal = "Int. J. Chem. Kinet.",
        volume = "22",
        pages = """21-35""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990ZHA/BAC21-35:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
Uncertainty: 1.58
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 394,
    label = "C2H4 + CH3 <=> CH4 + C2H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (794000, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (71.504, 'kJ/mol', '+|-', 4.29),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (766, 'K'),
        Pmin = (10400, 'Pa'),
        Pmax = (50900, 'Pa'),
    ),
    reference = Article(
        authors = ["Ahonkhai, S.I.", "Lin, X-H.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from ethylene by methyl and ethyl radicals relative to abstraction from propane and isobutane',
        journal = "Int. J. Chem. Kinet.",
        volume = "21",
        pages = """1-20""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989AHO/LIN1-20:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
Uncertainty: 2.51
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 395,
    label = "C2H4 + CH3 <=> CH4 + C2H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (631000, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (66.931, 'kJ/mol', '+|-', 4.016),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (766, 'K'),
        Pmin = (10400, 'Pa'),
        Pmax = (50900, 'Pa'),
    ),
    reference = Article(
        authors = ["Ahonkhai, S.I.", "Lin, X-H.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from ethylene by methyl and ethyl radicals relative to abstraction from propane and isobutane',
        journal = "Int. J. Chem. Kinet.",
        volume = "21",
        pages = """1-20""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989AHO/LIN1-20:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
Uncertainty: 2.51
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 396,
    label = "C2H4 + CH3 <=> CH4 + C2H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (631000, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (64.853, 'kJ/mol', '+|-', 1.946),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (733, 'K'),
        Pmin = (24800, 'Pa'),
        Pmax = (40400, 'Pa'),
    ),
    reference = Article(
        authors = ["Ahonkhai, S.I.", "Back, M.H."],
        title = u'Relative rate constants for abstraction of hydrogen by methyl radicals from ethane and from ethylene',
        journal = "Can. J. Chem.",
        volume = "66",
        pages = """578""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988AHO/BAC578:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
Uncertainty: 1.26
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 397,
    label = "C2H4 + CH3 <=> CH4 + C2H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (54.377, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1950, 'K'),
        Tmax = (2770, 'K'),
        Pmin = (1200, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tabayashi, K.", "Bauer, S.H."],
        title = u'The Early Stages of Pyrolysis and Oxidation of Methane',
        journal = "Combust. Flame",
        volume = "34",
        pages = """63""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979TAB/BAU63:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001968
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Laser schlieren
""",
)

entry(
    index = 398,
    label = "CH4 + HO2 <=> H2O2 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (9.04e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (103.099, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:26",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001973
Uncertainty: 2.0
""",
)

entry(
    index = 399,
    label = "CH4 + HO2 <=> H2O2 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (181000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (77.74, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:21",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001973
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001973/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 400,
    label = "CH4 + HO2 <=> H2O2 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.13e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (103.099, 'kJ/mol', '+|-', 3.093),
        T0 = (1, 'K'),
        Tmin = (623, 'K'),
        Tmax = (1270, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Jones, P.N.", "Walker, R.W."],
        title = u'Determination of the rate constant for HO2 + CH4 \u2192\x92 H2O2 \u2192\x92 H2O2 + CH3 at 443\xb0C',
        journal = "J. Chem. Soc. Faraday Trans. 2",
        volume = "84",
        pages = """199-207""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988BAL/JON199-207:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001973
Uncertainty: 2.0
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 401,
    label = "H2O2 + CH3 <=> CH4 + HO2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (12100, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (-2.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:165",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001973
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001973/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 402,
    label = "CH4 + O2 <=> HO2-2 + CH3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (3.97e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (237.794, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:29",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002003
Uncertainty: 10.0
""",
)

entry(
    index = 403,
    label = "CH4 + O2 <=> HO2-2 + CH3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (4.04e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (237.794, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:23",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002003
Uncertainty: 5.0
""",
)

entry(
    index = 404,
    label = "CH4 + O2 <=> HO2-2 + CH3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (8.52, 'm^3/(mol*s)'),
        n = 2,
        Ea = (217.839, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Shaw, R."],
        title = u'Semi-Empirical Extrapolation and Estimation of Rate Constants for Abstraction of H From Methane by H, O, HO, and O2',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "7",
        pages = """1179""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978SHA1179:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002003
""",
)

entry(
    index = 405,
    label = "CH4 + O2 <=> HO2-2 + CH3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (8e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (234.468, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (1.01e+06, 'Pa'),
        Pmax = (1.01e+06, 'Pa'),
    ),
    reference = Article(
        authors = ["Skinner, G.B.", "Lifshitz, A.", "Scheller, K.", "Burcat, A."],
        title = u'Kinetics of Methane Oxidation',
        journal = "J. Chem. Phys.",
        volume = "56",
        pages = """3853""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972SKI/LIF3853:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002003
Bath gas: CH4
""",
)

entry(
    index = 406,
    label = "CH4 + O2 <=> HO2-2 + CH3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (4.32e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (246.108, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Mayer, S.W.", "Schieler, L."],
        title = u'Activation energies and rate constants computed for reactions of oxygen with hydrocarbons',
        journal = "J. Phys. Chem.",
        volume = "72",
        pages = """2628-2631""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968MAY/SCH2628-2631:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00002003
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002003/rk00000002.xml
""",
)

entry(
    index = 407,
    label = "C2H2 + CH3 <=> CH4 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (181000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (72.336, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:68",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002425
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002425/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 408,
    label = "CH4 + C2H <=> C2H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.81e+06, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (2.079, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:15",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002425
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002425/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 409,
    label = "CH4 + C2H <=> C2H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.837, 'm^3/(mol*s)'),
        n = (2.34, '', '+|-', 0.4),
        Ea = (-3.159, 'kJ/mol', '+|-', 1.497),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (779, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Ceursters, B.", "Nguyen, H.M.T.", "Peeters, J.", "Nguyen, M.T."],
        title = u'Experimental and Theoretical Study of the Gas Phase Reaction of Ethynyl Radical with Methane (HCC+CH4)',
        journal = "Chem. Phys. Lett.",
        volume = "329",
        pages = """412-420""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000CEU/NGU412-420:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002425
Bath gas: He
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Chemiluminescence

Chemiluminescence from CCH + O2-> CH + CO2used to monitor CCH.
""",
)

entry(
    index = 410,
    label = "CH4 + C2H <=> C2H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.23e+06, 'm^3/(mol*s)', '+|-', 580000),
        n = 0,
        Ea = (4.082, 'kJ/mol', '+|-', 0.08165),
        T0 = (1, 'K'),
        Tmin = (154, 'K'),
        Tmax = (359, 'K'),
        Pmin = (1600, 'Pa'),
        Pmax = (9866, 'Pa'),
    ),
    reference = Article(
        authors = ["Opansky, B.J.", "Leone, S.R."],
        title = u'Low-temperature rate coefficients of C2H with CH4 and CD4 from 154 to 359 K',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """4888-4892""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996OPA/LEO4888-4892:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002425
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: IR absorption
""",
)

entry(
    index = 411,
    label = "CH4 + C2H <=> C2H2 + CH3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.23e+06, 'm^3/(mol*s)', '+|-', 580000),
        n = 0,
        Ea = (4.082, 'kJ/mol', '+|-', 0.08165),
        T0 = (1, 'K'),
        Tmin = (154, 'K'),
        Tmax = (359, 'K'),
        Pmin = (1600, 'Pa'),
        Pmax = (9866, 'Pa'),
    ),
    reference = Article(
        authors = ["Opansky, B.J.", "Leone, S.R."],
        title = u'Low-temperature rate coefficients of C2H with CH4 and CD4 from 154 to 359 K',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """4888-4892""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996OPA/LEO4888-4892:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002425
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: IR absorption
""",
)

entry(
    index = 412,
    label = "C3H8 + H <=> H2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.32, 'm^3/(mol*s)', '*|/', 3),
        n = 2.54,
        Ea = (28.269, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:40",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002782
Uncertainty: 3.0
""",
)

entry(
    index = 413,
    label = "C3H8 + H <=> H2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00002782
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002782/rk00000003.xml
""",
)

entry(
    index = 414,
    label = "C3H8 + H <=> H2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (9.29e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.507, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1100, 'K'),
        Tmax = (1450, 'K'),
        Pmin = (152000, 'Pa'),
        Pmax = (264000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hidaka, Y.", "Oki, T.", "Kawano, H."],
        title = u'Thermal decomposition of propane in shock waves',
        journal = "Int. J. Chem. Kinet.",
        volume = "21",
        pages = """689-701""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989HID/OKI689-701:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002782
Bath gas: Ar
""",
)

entry(
    index = 415,
    label = "H2 + C3H7 <=> C3H8 + H",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.001805, 'm^3/(mol*s)', '*|/', 1.5),
        n = 2.84,
        Ea = (38.247, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:48",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002782
Uncertainty: 1.5
""",
)

entry(
    index = 416,
    label = "H2 + C3H7 <=> C3H8 + H",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.6e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (61.943, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (718, 'K'),
        Tmax = (728, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (52800, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Walker, R.W.", "Yorke, D.A."],
        title = u'Reaction of n-Propyl Radicals with Oxygen, Hydrogen and Deuterium',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "69",
        pages = """826""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973BAL/WAL826:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002782
Bath gas: N2
""",
)

entry(
    index = 417,
    label = "C3H6 + H <=> H2 + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.62e+08, 'm^3/(mol*s)', '*|/', 1.35),
        n = 0,
        Ea = (48.972, 'kJ/mol', '+|-', 0.981),
        T0 = (1, 'K'),
        Tmin = (358, 'K'),
        Tmax = (550, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (667, 'Pa'),
    ),
    reference = Article(
        authors = ["Marshall, R.M.", "Purnell, H.", "Sheppard, A."],
        title = u'Reaction of hydrogen atoms with cyclopropane in the temperature range 358-550 K',
        journal = "J. Chem. Soc. Faraday Trans. 2",
        volume = "82",
        pages = """929""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986MAR/PUR929:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003213
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003213/rk00000001.xml
Uncertainty: 1.35
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 418,
    label = "C2H4O + H <=> H2 + C2H3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (8e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (40.491, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (753, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Keen, A.", "Walker, R.W."],
        title = u'Studies of the decomposition of oxirane and of its addition to slowly reacting mixtures of hydrogen and oxygen at 480 C',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "80",
        pages = """435""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984BAL/KEE435:6",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00003234
Bath gas: N2
""",
)

entry(
    index = 419,
    label = "C2H4O + H <=> H2 + C2H3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (34.754, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (830, 'K'),
        Tmax = (1200, 'K'),
        Pmin = (152000, 'Pa'),
        Pmax = (1.01e+06, 'Pa'),
    ),
    reference = Article(
        authors = ["Lifshitz, A.", "Ben-Hamou, H."],
        title = u'Thermal reactions of cyclic ethers at high temperatures. 1. Pyrolysis of ethylene oxide behind reflected shocks',
        journal = "J. Phys. Chem.",
        volume = "87",
        pages = """1782""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983LIF/BEN1782:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003234
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003234/rk00000001.xml
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 420,
    label = "C3H6-2 + H <=> H2 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.17, 'm^3/(mol*s)'),
        n = 2.5,
        Ea = (10.393, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for hydrocarbon pyrolysis',
        journal = "Ind. Eng. Chem.",
        volume = "31",
        pages = """3-8""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992TSA3-8:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00005745
""",
)

entry(
    index = 421,
    label = "C3H6-2 + H <=> H2 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.173, 'm^3/(mol*s)', '*|/', 2),
        n = 2.5,
        Ea = (10.393, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:59",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005745
Uncertainty: 2.0
""",
)

entry(
    index = 422,
    label = "C3H6-2 + H <=> H2 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (646000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (18.624, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (490, 'K'),
        Tmax = (510, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:11",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005745
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005745/rk00000007.xml
""",
)

entry(
    index = 423,
    label = "H2 + C3H5-2 <=> C3H6-2 + H",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.108, 'm^3/(mol*s)', '*|/', 5),
        n = 2.38,
        Ea = (79.486, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:73",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005745
Uncertainty: 5.0
""",
)

entry(
    index = 424,
    label = "H2 + C3H5-2 <=> C3H6-2 + H",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1.02e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (105.594, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (790, 'K'),
        Tmax = (810, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:13",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005745
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005745/rk00000007.xml
""",
)

entry(
    index = 425,
    label = "C2H6O-4 + H <=> H2 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (4.26e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (37, 'kJ/mol', '+|-', 10),
        T0 = (1, 'K'),
        Tmin = (1038, 'K'),
        Tmax = (1208, 'K'),
        Pmin = (5106, 'Pa'),
        Pmax = (5653, 'Pa'),
    ),
    reference = Article(
        authors = ["Takahashi, K.", "Yamamoto, O.", "Inomata, T.", "Kogoma, M."],
        title = u'Shock-tube studies on the reactions of dimethyl ether with oxygen and hydrogen atoms',
        journal = "Int. J. Chem. Kinet.",
        volume = "39",
        pages = """97-108""",
        year = "2007",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2007TAK/YAM97-108:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005801
Pressure dependence: None reported
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption

The uncertainty of log(A) is +/- 0.48.
""",
)

entry(
    index = 426,
    label = "C2H6O-4 + H <=> H2 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.096e-05, 'm^3/(mol*s)'),
        n = 4,
        Ea = (7.7, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Takahashi, K.", "Yamamoto, O.", "Inomata, T.", "Kogoma, M."],
        title = u'Shock-tube studies on the reactions of dimethyl ether with oxygen and hydrogen atoms',
        journal = "Int. J. Chem. Kinet.",
        volume = "39",
        pages = """97-108""",
        year = "2007",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2007TAK/YAM97-108:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00005801
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 427,
    label = "C2H6O-4 + H <=> H2 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (32, 'm^3/(mol*s)'),
        n = 1.9,
        Ea = (15.481, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (900, 'K'),
        Tmax = (1900, 'K'),
        Pmin = (84100, 'Pa'),
        Pmax = (294000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hidaka, Y.", "Sato, K.", "Yamane, M."],
        title = u'High-temperature pyrolysis of dimethyl ether in shock waves',
        journal = "Combust. Flame",
        volume = "123",
        pages = """1-22""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000HID/SAT1-22:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005801
Experimental procedure: Shock tube
Time resolution: In real time
Analytical technique: Vis-UV absorption

The high-temperature pyrolysis of dimethyl ether (DME) was studied behind reflected shock waves using single-pulse (reaction time between 1.3 and 2.9 ms), time-resolved IR absorption (3.39 mm), IR emission (4.24mm), and UV absorption (216 nm) methods. The studies were done using DME-Ar, DME-H2-Ar, DME-CO-Ar and DME-CH2O-Ar mixtures. From a computer simulation, a 94-reaction mechanism that could explain all exp. data was constructed.
""",
)

entry(
    index = 428,
    label = "C2H6O-4 + H <=> H2 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.64e+06, 'm^3/(mol*s)', '+|-', 340000),
        n = 0,
        Ea = (16.296, 'kJ/mol', '+|-', 0.325),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (426, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Lee, J.H.", "Machen, R.C.", "Nava, D.F.", "Stief, L.J."],
        title = u'Rate Parameters for the Reaction of Atomic Hydrogen with Dimethyl Ether and Dimethyl Sulfide',
        journal = "J. Chem. Phys.",
        volume = "74",
        pages = """2839""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981LEE/MAC2839:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005801
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 429,
    label = "C2H6O-4 + H <=> H2 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.9e+07, 'm^3/(mol*s)', '+|-', 8.9e+06),
        n = 0,
        Ea = (21.618, 'kJ/mol', '+|-', 0.865),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (620, 'K'),
        Pmin = (300, 'Pa'),
        Pmax = (1300, 'Pa'),
    ),
    reference = Article(
        authors = ["Faubel, C.", "Hoyermann, K.", "Strofer, E.", "Wagner, H.Gg."],
        title = u'Untersuchungen zur Reaktion von Wasserstoffatomen mit Dimethylaether, Diaethylaether und tert. Buthyl-methyl-Aether in der Gasphase',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "83",
        pages = """532""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979FAU/HOY532:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005801
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Gas chromatography
""",
)

entry(
    index = 430,
    label = "C2H6O-4 + H <=> H2 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.3e+07, 'm^3/(mol*s)', '+|-', 4.9e+06),
        n = 0,
        Ea = (19.29, 'kJ/mol', '+|-', 0.77),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (404, 'K'),
        Pmin = (53.33, 'Pa'),
        Pmax = (120, 'Pa'),
    ),
    reference = Article(
        authors = ["Meagher, J.F.", "Kim, P.", "Lee, J.H.", "Timmons, R.B."],
        title = u'Kinetic Isotope Effects in the Reactions of Hydrogen and Deuterium Atoms with Dimethyl Ether and Methanol',
        journal = "J. Phys. Chem.",
        volume = "78",
        pages = """2650""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974MEA/KIM2650:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005801
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005801/rk00000001.xml
Uncertainty: 1.26
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 431,
    label = "H2 + C3H7-2 <=> C3H8-2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.496e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.28,
        Ea = (36.251, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:47",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009459
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009459/rk00000002.xml
Uncertainty: 3.0
""",
)

entry(
    index = 432,
    label = "C3H8-2 + H <=> H2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.3, 'm^3/(mol*s)', '*|/', 3),
        n = 2.4,
        Ea = (18.708, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:39",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009459
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009459/rk00000002.xml
Uncertainty: 3.0
""",
)

entry(
    index = 433,
    label = "C3H8-2 + H <=> H2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.46e+06, 'm^3/(mol*s)', '*|/', 1.91),
        n = 0,
        Ea = (21.784, 'kJ/mol', '+|-', 1.746),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (370, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (667, 'Pa'),
    ),
    reference = Article(
        authors = ["Marshall, R.M.", "Purnell, H.", "Sheppard, A."],
        title = u'Reaction of hydrogen atoms with propane in the temperature range 298-534 K',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "80",
        pages = """2999""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984MAR/PUR2999:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009459
Uncertainty: 1.91
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 434,
    label = "C3H8-2 + H <=> H2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.46e+07, 'm^3/(mol*s)', '*|/', 1.17),
        n = 0,
        Ea = (28.768, 'kJ/mol', '+|-', 0.576),
        T0 = (1, 'K'),
        Tmin = (370, 'K'),
        Tmax = (534, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (667, 'Pa'),
    ),
    reference = Article(
        authors = ["Marshall, R.M.", "Purnell, H.", "Sheppard, A."],
        title = u'Reaction of hydrogen atoms with propane in the temperature range 298-534 K',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "80",
        pages = """2999""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984MAR/PUR2999:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009459
Uncertainty: 1.17
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 435,
    label = "C3H8-2 + H <=> H2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.79e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.258, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009459
""",
)

entry(
    index = 436,
    label = "C3H8-2 + H <=> H2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.6e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (34.754, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (730, 'K'),
        Tmax = (780, 'K'),
        Pmin = (33300, 'Pa'),
        Pmax = (89300, 'Pa'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'Addition of C3H8, n- and i-C4H10 to slowly reacting mixtures of hydrogen and oxygen at 480\xb0C',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """2812""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BAK/BAL2812:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009459
Bath gas: N2
""",
)

entry(
    index = 437,
    label = "C3H8-2 + H <=> H2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.507, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1100, 'K'),
        Tmax = (1450, 'K'),
        Pmin = (152000, 'Pa'),
        Pmax = (264000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hidaka, Y.", "Oki, T.", "Kawano, H."],
        title = u'Thermal decomposition of propane in shock waves',
        journal = "Int. J. Chem. Kinet.",
        volume = "21",
        pages = """689-701""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989HID/OKI689-701:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009459
Bath gas: Ar
""",
)

entry(
    index = 438,
    label = "H2 + CH3O2 <=> CH4O2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.01e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (108.92, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:93",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009465
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009465/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 439,
    label = "H2 + C2H3O-2 <=> C2H4O-2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.11, 'm^3/(mol*s)', '*|/', 3),
        n = 1.82,
        Ea = (73.666, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:97",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009482
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009482/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 440,
    label = "C2H4O-2 + H <=> H2 + C2H3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (17.627, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:53",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009482
Uncertainty: 2.0
""",
)

entry(
    index = 441,
    label = "C2H4O-2 + H <=> H2 + C2H3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.34e+07, 'm^3/(mol*s)', '+|-', 2.3e+06),
        n = 0,
        Ea = (13.802, 'kJ/mol', '+|-', 0.552),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Whytock, D.A.", "Michael, J.V.", "Payne, W.A.", "Stief, L.J."],
        title = u'Absolute Rate of the Reaction of Atomic Hydrogen with Acetaldehyde',
        journal = "J. Chem. Phys.",
        volume = "65",
        pages = """4871""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976WHY/MIC4871:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009482
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 442,
    label = "C2H4O-2 + H <=> H2 + C2H3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.6e+06, 'm^3/(mol*s)', '+|-', 210000),
        n = 0,
        Ea = (10.892, 'kJ/mol', '+|-', 0.653),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (389, 'K'),
        Pmin = (653, 'Pa'),
        Pmax = (773, 'Pa'),
    ),
    reference = Article(
        authors = ["Aders, W.-K.", "Wagner, Gg."],
        title = u'Untersuchungen zur Reaktion von Wasserstoffatomen mit Acetaldehyd',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "77",
        pages = """332""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973ADE/WAG332:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00009482
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 443,
    label = "C2H + H2O <=> C2H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.001325, 'm^3/(mol*s)', '+|-', 6.02e-05),
        n = 3.05,
        Ea = (3.126, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Carl, S.A.", "Nguyen, H.MT.", "Elsamra, R.MI.", "Nguyen, M.T.", "Peeters, J."],
        title = u'Pulsed laser photolysis and quantum chemical-statistical rate study of the reaction of the ethynyl radical with water vapor',
        journal = "J. Chem. Phys.",
        volume = "122",
        pages = """114307""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005CAR/NGU114307:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
Pressure dependence: Rate constant is pressure independent

The k(T) dependence is the result of TST calculations based on high-level quantum chemical calculations of the PES and comparison with the experimental data.
""",
)

entry(
    index = 444,
    label = "C2H2 + OH <=> C2H + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.71e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.9, 'kJ/mol', '+|-', 13.22),
        T0 = (1, 'K'),
        Tmin = (1070, 'K'),
        Tmax = (1270, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Liu, A.", "Mulac, W.A.", "Jonah, C.D."],
        title = u'Temperature dependence of the rate constants of the reactions of OH radicals with C2H2 and C2D2 at 1 atm in Ar and from 333 to 1273 K',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """5942""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988LIU/MUL5942:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
Bath gas: Ar
""",
)

entry(
    index = 445,
    label = "C2H2 + OH <=> C2H + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0145, 'm^3/(mol*s)', '*|/', 5),
        n = 2.68,
        Ea = (50.386, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:71",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
Uncertainty: 5.0
""",
)

entry(
    index = 446,
    label = "C2H2 + OH <=> C2H + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (50.6, 'm^3/(mol*s)'),
        n = 2,
        Ea = (58.584, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1150, 'K'),
        Tmax = (2130, 'K'),
        Pmin = (91200, 'Pa'),
        Pmax = (193000, 'Pa'),
    ),
    reference = Article(
        authors = ["Eiteneer, B.", "Frenklach, M."],
        title = u'Experimental and Modeling Study of Shock-Tube Oxidation of Acetylene',
        journal = "Int J. Chem. Kinet.",
        volume = "35",
        pages = """391-414""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003EIT/FRE391-414:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
Pressure dependence: None reported
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: IR absorption

No direct measurements of rate constants. Rate constants reported are either from estimates or optimization fits. Enthalpies of formation were also allowed to be varied in fits. This paper is combined experimental and modeling. These measurements consist of shock tube oxidation of C2H2 at temperatures of 1150-2130 K, pressures of 0.9-1.9 atm, with lean to rich conditions (Phi = 0.06 to 1.7). CO produced was detected using CO laser absorption at 2077.1 cm-1
""",
)

entry(
    index = 447,
    label = "C2H2 + OH <=> C2H + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.71e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1070, 'K'),
        Tmax = (1250, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Liu, A.", "Jonah, C.D.", "Mulac, W.A."],
        title = u'The gas-phase reactions of hydroxyl radicals with several unsaturated hydrocarbons at atmosphere pressure',
        journal = "Radiat. Phys. Chem.",
        volume = "34",
        pages = """687-691""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LIU/JON687-691:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
Bath gas: Ar
Excitation technique: Chemical activation
Analytical technique: Vis-UV absorption
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 448,
    label = "C2H2 + OH <=> C2H + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.62e+06, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (29.267, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (596, 'K'),
        Tmax = (783, 'K'),
        Pmin = (107, 'Pa'),
        Pmax = (320, 'Pa'),
    ),
    reference = Article(
        authors = ["Avramenko, L.I.", "Lorentso, R.V."],
        title = u'Reactions between free hydroxyl and hydrocarbons',
        journal = "Dokl. Akad. Nauk SSR",
        volume = "67",
        pages = """867""",
        year = "1949",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1949AVR/LOR867:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 449,
    label = "C2H2 + OH <=> C2H + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (33.9, 'm^3/(mol*s)'),
        n = 2,
        Ea = (58.534, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Miller, J.A.", "Melius, C.F."],
        title = u'A theoretical analysis of the reaction between hydroxyl and acetylene',
        journal = "Symp. Int. Combust. Proc.",
        volume = "22",
        pages = """1031-1039""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989MIL/MEL1031-1039:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
""",
)

entry(
    index = 450,
    label = "C2H2 + OH <=> C2H + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (29.267, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1700, 'K'),
    ),
    reference = Article(
        authors = ["Browne, W.G.", "Porter, R.P.", "Verlin, J.D.", "Clark, A.H."],
        title = u'A study of acetylene-oxygen flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "12",
        pages = """1035""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969BRO/POR1035:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
Bath gas: Ar
""",
)

entry(
    index = 451,
    label = "CH3O + H2O <=> CH4O + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.5e-07, 'm^3/(mol*s)'),
        n = 3.8,
        Ea = (48.058, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:11",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010587
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010587/rk00000001.xml

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 452,
    label = "CH4O + OH <=> CH3O + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (7.101, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:8",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010587
Uncertainty: 3.1600001
""",
)

entry(
    index = 453,
    label = "CH4O + OH <=> CH3O + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (19200, 'm^3/(mol*s)', '+|-', 4100),
        n = 0,
        Ea = (-4.797, 'kJ/mol', '+|-', 0.59),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Galano, A.", "Alvarez-Idaboy, J.R.", "Bravo-Perez, G.", "Ruiz-Santoyo, Ma. E."],
        title = u'Gas Phase Reactions of C1-C4 Alcohols with the OH Radical:  A Quantum Mechanical Approach',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "4",
        pages = """4648-4662""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GAL/ALV4648-4662:8",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010587
Pressure dependence: Rate constant is high pressure limit

Reported uncertainties are two sigma and are precision only.
""",
)

entry(
    index = 454,
    label = "CH4O + OH <=> CH3O + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.731e-05, 'm^3/(mol*s)'),
        n = 3.4,
        Ea = (-4.781, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:9",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00010587
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010587/rk00000001.xml

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 455,
    label = "CH4O + OH <=> CH3O + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.26e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (13.636, 'kJ/mol', '+|-', 3.002),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (348, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Lorenz, K.", "Rhasa, D.", "Zellner, R."],
        title = u'LIF studies of formation and kinetics of primary radical products in OH-oxygenated hydrocarbon reactions',
        journal = "Phys. Chem. Behav. Atmos. Pollut. Proc. Eur. Symp.",
        pages = """158""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984LOR/RHA158:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00010587
Bath gas: He
""",
)

entry(
    index = 457,
    label = "CH3O-2 + H2O <=> CH4O-2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000937, 'm^3/(mol*s)'),
        n = 3,
        Ea = (86.803, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:12",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00011303

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 458,
    label = "CH3O-2 + H2O <=> CH4O-2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.55e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (109.751, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1800, 'K'),
        Pmin = (20300, 'Pa'),
        Pmax = (507000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tsuboi, T.", "Hashimoto, K."],
        title = u'Shock Tube Study on Homogeneous Thermal Oxidation of Methanol',
        journal = "Combust. Flame",
        volume = "42",
        pages = """61""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981TSU/HAS61:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011303
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011303/rk00000001.xml
Bath gas: Ar
""",
)

entry(
    index = 459,
    label = "CH4O-2 + OH <=> CH3O-2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.87e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (2.993, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:64",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011303
Pressure dependence: None reported
""",
)

entry(
    index = 460,
    label = "CH4O-2 + OH <=> CH3O-2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.44, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-3.517, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Li, S.C.", "Williams, F.A."],
        title = u'Experimental and numerical studies of two-stage methanol flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "26",
        pages = """1017-1024""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996LI/WIL1017-1024:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011303
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 461,
    label = "CH4O-2 + OH <=> CH3O-2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.8e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (18.791, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (5333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Vandooren, J.", "Van Tiggelen, P.J."],
        title = u'Experimental Investigation of Methanol Oxidation in Flames: Mechanism and Rate Constants of Elementary Steps',
        journal = "Symp. Int. Combust. Proc.",
        volume = "18",
        pages = """473""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981VAN/VAN473:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011303
Uncertainty: 2.0
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 462,
    label = "CH4O-2 + OH <=> CH3O-2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.98e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.398, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2180, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (507000, 'Pa'),
    ),
    reference = Article(
        authors = ["Westbrook, C.K.", "Dryer, F.L."],
        title = u'A comprehensive mechanism for methanol oxidation',
        journal = "Combust. Sci. Technol.",
        volume = "20",
        pages = """125""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979WES/DRY125:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00011303
Bath gas: N2
""",
)

entry(
    index = 463,
    label = "CH4O-2 + OH <=> CH3O-2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (24.943, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1540, 'K'),
        Tmax = (2180, 'K'),
        Pmin = (21300, 'Pa'),
        Pmax = (62000, 'Pa'),
    ),
    reference = Article(
        authors = ["Bowman, C.T."],
        title = u'A Shock-Tube Investigation of the High-Temperature Oxidation of Methanol',
        journal = "Combust. Flame",
        volume = "25",
        pages = """343""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975BOW343:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011303
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 464,
    label = "CH4O-2 + OH <=> CH3O-2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.16e+06, 'm^3/(mol*s)', '+|-', 120000),
        n = 0,
        Ea = (3.825, 'kJ/mol', '+|-', 0.316),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Galano, A.", "Alvarez-Idaboy, J.R.", "Bravo-Perez, G.", "Ruiz-Santoyo, Ma. E."],
        title = u'Gas Phase Reactions of C1-C4 Alcohols with the OH Radical:  A Quantum Mechanical Approach',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "4",
        pages = """4648-4662""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GAL/ALV4648-4662:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00011303
Pressure dependence: Rate constant is high pressure limit

Reported uncertainties are two sigma and are precision only.
""",
)

entry(
    index = 465,
    label = "CH4O-2 + OH <=> CH3O-2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0244, 'm^3/(mol*s)'),
        n = 2.8,
        Ea = (-1.746, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Jodkowski, J.T.", "Rayez, M.-T.", "Rayez, J.-C."],
        title = u'Theoretical Study of the Kinetics of the Hydrogen Abstraction from Methanol. 3. Reaction of Methanol with Hydrogen Atom, Methyl, and Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3750-3765""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999JOD/RAY3750-3765:10",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00011303

The calculated rate constants are in good agreement with experiment.
""",
)

entry(
    index = 466,
    label = "CH4O-2 + OH <=> CH3O-2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (25.027, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1800, 'K'),
        Pmin = (20300, 'Pa'),
        Pmax = (507000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tsuboi, T.", "Hashimoto, K."],
        title = u'Shock Tube Study on Homogeneous Thermal Oxidation of Methanol',
        journal = "Combust. Flame",
        volume = "42",
        pages = """61""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981TSU/HAS61:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011303
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011303/rk00000001.xml
Bath gas: Ar
""",
)

entry(
    index = 467,
    label = "CHO + H2O <=> CH2O + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (235, 'm^3/(mol*s)', '*|/', 5),
        n = 1.35,
        Ea = (108.92, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:183",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011341/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 468,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.94e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-0.333, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (220, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:53",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Pressure dependence: None reported
Note: Invalid activation energy uncertainty (1.247) found and ignored
""",
)

entry(
    index = 469,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.18e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-0.166, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:31",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Note: Invalid activation energy uncertainty (1.247) found and ignored
""",
)

entry(
    index = 470,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3430, 'm^3/(mol*s)', '*|/', 10),
        n = 1.18,
        Ea = (-1.871, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:6",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Uncertainty: 10.0
""",
)

entry(
    index = 471,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.3e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-0.208, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:35",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Note: Invalid activation energy uncertainty (1.247) found and ignored
""",
)

entry(
    index = 472,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.64e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (0.915, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (580, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Uncertainty: 1.26
Note: Invalid activation energy uncertainty (1.247) found and ignored
""",
)

entry(
    index = 473,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3440, 'm^3/(mol*s)', '*|/', 2),
        n = 1.18,
        Ea = (-1.871, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (1600, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:8",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011341/rk00000001.xml
Uncertainty: 2.0
""",
)

entry(
    index = 474,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (4.997, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Uncertainty: 2.0
""",
)

entry(
    index = 475,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5e+09, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (54.044, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (1600, 'K'),
    ),
    reference = Article(
        authors = ["Wilson, W.E., Jr."],
        title = u'A critical review of the gas-phase reaction kinetics of the hydroxyl radical',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "1",
        pages = """535-573""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972WIL535-573:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Uncertainty: 10.0
""",
)

entry(
    index = 476,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.001323, 'm^3/(mol*s)', '*|/', 1.25),
        n = 2.99,
        Ea = (-18.19, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (934, 'K'),
        Tmax = (1670, 'K'),
        Pmin = (133000, 'Pa'),
        Pmax = (213000, 'Pa'),
    ),
    reference = Article(
        authors = ["Vasudevan, V.", "Davidson, D.F.", "Hanson, R.K."],
        title = u'Atoms Regeneration from Hydroperoxyl Radicals in the Reaction between Fluorine and Hydrogen Inhibited with Oxygen',
        journal = "Inter. J. Chem. Kinet.",
        volume = "37",
        pages = """98-109""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005VAS/DAV98-109:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Uncertainty: 1.25
Pressure dependence: None reported
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption

Equation was derived at NIST and is an unweighted fit to the data reported by the authors in Table 1 of the paper. The equation fits the experimental rate constants within 2.3%.

The authors estimate the uncertainty in their absolute rates to be +/- 15% at 1229 K and +/- 25% at 1595 K, taking into account both experimental and mechanism-induced contributions.
""",
)

entry(
    index = 477,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)', '+|-', 1.2e+06),
        n = 0,
        Ea = (0.715, 'kJ/mol', '+|-', 0.336),
        T0 = (1, 'K'),
        Tmin = (296, 'K'),
        Tmax = (576, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Zabarnick, S.", "Fleming, J.W.", "Lin, M.C."],
        title = u'Kinetics of hydroxyl radical reactions with formaldehyde and 1,3,5-trioxane between 290 and 600 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "20",
        pages = """117""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988ZAB/FLE117:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 478,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.8e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (1.829, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1600, 'K'),
        Pmin = (3000, 'Pa'),
        Pmax = (3000, 'Pa'),
    ),
    reference = Article(
        authors = ["Vandooren, J.", "Oldenhove de Guertechin, L.", "van Tiggelen, P.J."],
        title = u'Kinetics in a lean formaldehyde flame',
        journal = "Combust. Flame",
        volume = "64",
        pages = """127""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986VAN/OLD127:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 479,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.53e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (0.698, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1700, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (16800, 'Pa'),
        Pmax = (23300, 'Pa'),
    ),
    reference = Article(
        authors = ["Dean, A.M.", "Johnson, R.L.", "Steiner, D.C."],
        title = u'Shock-Tube Studies of Formaldehyde Oxidation',
        journal = "Combust. Flame",
        volume = "37",
        pages = """41""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980DEA/JOH41:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Uncertainty: 2.0
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Other (IR)
""",
)

entry(
    index = 480,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.41e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.003, 'kJ/mol', '+|-', 1.979),
        T0 = (1, 'K'),
        Tmin = (268, 'K'),
        Tmax = (334, 'K'),
        Pmin = (66.66, 'Pa'),
        Pmax = (147, 'Pa'),
    ),
    reference = Article(
        authors = ["Smith, R.H."],
        title = u'Rate Constant and Activation Energy for the Gaseous Reaction Between Hydroxyl and Formaldehyde',
        journal = "Int. J. Chem. Kinet.",
        volume = "10",
        pages = """519""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978SMI519:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 481,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.53e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (0.732, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (299, 'K'),
        Tmax = (426, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Pitts, J.N., Jr."],
        title = u'Kinetics of the Reactions of the OH Radical with HCHO and CH3CHO over the Temperature Range 299-426oK',
        journal = "J. Chem. Phys.",
        volume = "68",
        pages = """3581""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978ATK/PIT3581:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
Note: Invalid activation energy uncertainty (1.247) found and ignored
""",
)

entry(
    index = 482,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.9e+07, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (5.862, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1600, 'K'),
        Pmin = (5333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Vandooren, J.", "Van Tiggelen, P.J."],
        title = u'Reaction Mechanisms of Combustion in Low Pressure Acetylene-Oxygen Flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "16",
        pages = """1133""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977VAN/VAN1133:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Uncertainty: 2.51
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 483,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5e+09, 'm^3/(mol*s)'),
        n = 0,
        Ea = (54.377, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1300, 'K'),
        Tmax = (1550, 'K'),
        Pmin = (10100, 'Pa'),
        Pmax = (10100, 'Pa'),
    ),
    reference = Article(
        authors = ["Westenberg, A.A.", "Fristrom, R.M."],
        title = u'H and O atom profiles measured by ESR in C2 hydrocarbon-O2 flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "10",
        pages = """473""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965WES/FRI473:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 484,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.001475, 'm^3/(mol*s)'),
        n = 2.98,
        Ea = (-14.55, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (400, 'K'),
    ),
    reference = Article(
        authors = ["Xu, S.C.", "Zhu, R.S.", "Lin, M.C."],
        title = u'Ab initio study of the OH+CH(2)Oreaction: The effect of the OH center dot center dot OCH2 complex on the H-abstraction kinetics',
        journal = "Int. J. Chem. Kinet.",
        volume = "38",
        pages = """322-326""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006XU/ZHU322-326:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011341

Reaction potential energy surface was studied using quantum chemistry and rate constants were calculated using variational transition state theory.
""",
)

entry(
    index = 485,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.94, 'm^3/(mol*s)'),
        n = 2.11,
        Ea = (-7.059, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Xu, S.C.", "Zhu, R.S.", "Lin, M.C."],
        title = u'Ab initio study of the OH+CH(2)Oreaction: The effect of the OH center dot center dot OCH2 complex on the H-abstraction kinetics',
        journal = "Int. J. Chem. Kinet.",
        volume = "38",
        pages = """322-326""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006XU/ZHU322-326:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011341

Reaction potential energy surface was studied using quantum chemistry and rate constants were calculated using variational transition state theory.
""",
)

entry(
    index = 486,
    label = "CH2O + OH <=> CHO + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.55e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.735, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (305, 'K'),
    ),
    reference = Article(
        authors = ["Francisco, J.S."],
        title = u'An examination of substituent effects on the reaction of OH radicals with HXCO (where X = H, F, and Cl)',
        journal = "J. Chem. Phys.",
        volume = "96",
        pages = """7597-7602""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992FRA7597-7602:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011341
""",
)

entry(
    index = 487,
    label = "C2H3 + H2O <=> C2H4 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000483, 'm^3/(mol*s)', '*|/', 5),
        n = 2.9,
        Ea = (62.192, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:199",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011431/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 488,
    label = "C2H3 + H2O <=> C2H4 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.251e-05, 'm^3/(mol*s)'),
        n = 3.18,
        Ea = (45.822, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (5000, 'K'),
    ),
    reference = Article(
        authors = ["Liu, G.-x.", "Ding, Y.-h.", "Li, Z.-s.", "Fu, Q.", "Huang, X.-r.", "Sun, C.-c.", "Tang, A.-c."],
        title = u'Theoretical Study on Mechanisms of the High-Temperature Reactions C2H3 + H2O and C2H4 + OH',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "4",
        pages = """1021-1027""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002LIU/DIN1021-1027:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Pressure dependence: Rate constant is high pressure limit

Abstracter fit reported rate constants to modified Arrhenius expression. Small tunneling corrections (not included in calculations of present rate constants) indicate that tunneling makes a significant contribution at low temperatures (see text).
""",
)

entry(
    index = 489,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.05e+07, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (24.86, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (650, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:46",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Uncertainty: 3.1600001
""",
)

entry(
    index = 490,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0157, 'm^3/(mol*s)', '*|/', 5),
        n = 2.75,
        Ea = (17.46, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:53",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011431/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 491,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3e+07, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (12.472, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:26",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Uncertainty: 2.51
""",
)

entry(
    index = 492,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.553, 'm^3/(mol*s)', '+|-', 0.014),
        n = 2.31,
        Ea = (12.134, 'kJ/mol', '+|-', 0.251),
        T0 = (1, 'K'),
        Tmin = (1850, 'K'),
        Tmax = (2150, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Bhargava, A.", "Westmoreland, P.R."],
        title = u'Measured flame structure and kinetics in a fuel-rich ethylene flame',
        journal = "Combust. Flame",
        volume = "113",
        pages = """333-347""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998BHA/WES333-347:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Experimental procedure: Flames
Time resolution: In real time
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 493,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (24.943, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1200, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Westbrook, C.K.", "Thornton, M.M.", "Pitz, W.J.", "Malte, P.C."],
        title = u'A kinetic study of ethylene oxidation in a well-stirred reactor',
        journal = "Symp. Int. Combust. Proc.",
        volume = "22",
        pages = """863-871""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989WES/THO863-871:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 494,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.02e+07, 'm^3/(mol*s)', '+|-', 3.8e+06),
        n = 0,
        Ea = (24.86, 'kJ/mol', '+|-', 1.239),
        T0 = (1, 'K'),
        Tmin = (650, 'K'),
        Tmax = (901, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (46700, 'Pa'),
    ),
    reference = Article(
        authors = ["Tully, F.P."],
        title = u'Hydrogen-atom abstraction from alkenes by OH. Ethene and 1-butene',
        journal = "Chem. Phys. Lett.",
        volume = "143",
        pages = """510""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TUL510:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 495,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.45e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.46, 'kJ/mol', '+|-', 1.048),
        T0 = (1, 'K'),
        Tmin = (748, 'K'),
        Tmax = (1170, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Liu, A.-D.", "Mulac, W.A.", "Jonah, C.D."],
        title = u'Pulse radiolysis study of the reaction of OH radicals with C2H4 over the temperature range 343-1173 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "19",
        pages = """25""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987LIU/MUL25:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Bath gas: Ar
Excitation technique: Chemical activation
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 496,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.08e+07, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (25.11, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (623, 'K'),
        Tmax = (724, 'K'),
        Pmin = (347, 'Pa'),
        Pmax = (600, 'Pa'),
    ),
    reference = Article(
        authors = ["Avramenko, L.I.", "Lorentso, R.V."],
        title = u'Reactions between free hydroxyl and hydrocarbons',
        journal = "Dokl. Akad. Nauk SSR",
        volume = "67",
        pages = """867""",
        year = "1949",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1949AVR/LOR867:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 497,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.3e-07, 'm^3/(mol*s)'),
        n = 4.2,
        Ea = (-3.6, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Huynh, L.K.", "Barriger, K.", "Violi, A."],
        title = u'Kinetics study of the OH plus alkene -&gt; H2O plus alkenyl reaction class',
        journal = "J. Phys. Chem. A",
        volume = "112",
        pages = """1436-1444""",
        year = "2008",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2008HUY/BAR1436-1444:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011431

The rate constant was determined using the CVT method with the molecular-property data obtained at the RQCISD(T)/cc-pVZ//UB3LYP/6-311++G(d,p) level
""",
)

entry(
    index = 498,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.457, 'm^3/(mol*s)'),
        n = 2.53,
        Ea = (18.198, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (5000, 'K'),
    ),
    reference = Article(
        authors = ["Liu, G.-x.", "Ding, Y.-h.", "Li, Z.-s.", "Fu, Q.", "Huang, X.-r.", "Sun, C.-c.", "Tang, A.-c."],
        title = u'Theoretical Study on Mechanisms of the High-Temperature Reactions C2H3 + H2O and C2H4 + OH',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "4",
        pages = """1021-1027""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002LIU/DIN1021-1027:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Pressure dependence: Rate constant is high pressure limit

Abstracter fit reported rate constants to modified Arrhenius expression. Small tunneling corrections (not included in calculations of present rate constants) indicate that tunneling makes a >7% contribution to the rate constant for temperatures <730 K (see text).
""",
)

entry(
    index = 499,
    label = "C2H4 + OH <=> C2H3 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.1, 'm^3/(mol*s)', '+|-', 0.128),
        n = 2.01,
        Ea = (4.864, 'kJ/mol', '+|-', 0.09728),
        T0 = (1, 'K'),
        Tmin = (723, 'K'),
        Tmax = (1170, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Liu, A.", "Mulac, W.A.", "Jonah, C.D."],
        title = u'Kinetic isotope effects in the gas-phase reaction of hydroxyl radicals with ethylene in the temperature range 343-1173 K and at 1-atm pressure',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """3828""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988LIU/MUL3828:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011431
Bath gas: Ar
""",
)

entry(
    index = 500,
    label = "HO2 + H2O <=> H2O2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.8e+07, 'm^3/(mol*s)', '*|/', 1.51),
        n = 0,
        Ea = (137.189, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:14",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011842/rk00000002.xml
Uncertainty: 1.51
""",
)

entry(
    index = 501,
    label = "HO2 + H2O <=> H2O2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.81e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (125.549, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (586, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (133, 'Pa'),
    ),
    reference = Article(
        authors = ["Kondratiev, V.N."],
        title = u'Rate constant for the reaction HO2+H2O \u2192\x92 H2O2+OH',
        journal = "Dokl. Akad. Nauk SSR",
        volume = "137",
        pages = """120-122""",
        year = "1961",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1961KON120-122:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: H2O2
""",
)

entry(
    index = 502,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (1.33, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (460, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F.", "Hynes, R.G.", "Jenkin, M.E.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic and photochemical data for atmospheric chemistry: Volume I - gas phase reactions of Ox, HOx, NOx and SOx species',
        journal = "Atmos. Chem. Phys.",
        volume = "4",
        pages = """1461-1738""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004ATK/BAU1461-1738:57",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
""",
)

entry(
    index = 503,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (1.33, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (460, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:20",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Pressure dependence: None reported
""",
)

entry(
    index = 504,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (1.33, 'kJ/mol', '+|-', 0.84),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:340",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
""",
)

entry(
    index = 505,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (1.33, 'kJ/mol', '+|-', 0.84),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (460, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic and photochemical data for atmospheric chemistry: supplement VI. IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """1329-1499""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU1329-1499:72",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
""",
)

entry(
    index = 506,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (1.33, 'kJ/mol', '+|-', 0.84),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.J.", "Molina, M.J."],
        title = u'Chemical Kinetic and Photochemical Data for Use in Stratospheric Modeling: Evaluation No. 11 of the NASA Panel for Data Evaluation',
        journal = "JPL Publication 94-26",
        pages = """1-2""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DEM/SAN:323",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 1.2
""",
)

entry(
    index = 507,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.83e+06, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (5.571, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:183",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 1.58
""",
)

entry(
    index = 508,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (1.33, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (460, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:253",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
""",
)

entry(
    index = 509,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (1.33, 'kJ/mol', '+|-', 0.825),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (460, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:173",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 1.26
""",
)

entry(
    index = 510,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (1.33, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:226",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 3.0
""",
)

entry(
    index = 511,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7e+06, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (6.003, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:172",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 1.58
""",
)

entry(
    index = 512,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.7e+06, 'm^3/(mol*s)', '+|-', 190000),
        n = 0,
        Ea = (1.389, 'kJ/mol', '+|-', 0.292),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (410, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Wine, P.H.", "Semmes, D.H.", "Ravishankara, A.R."],
        title = u'A Laser Flash Photolysis Kinetics Study of the Reaction OH + H2O2 \u2192\x92 HO2 + H2O',
        journal = "J. Chem. Phys.",
        volume = "75",
        pages = """4390""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981WIN/SEM4390:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
""",
)

entry(
    index = 513,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (14.966, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Wilson, W.E., Jr."],
        title = u'A critical review of the gas-phase reaction kinetics of the hydroxyl radical',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "1",
        pages = """535-573""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972WIL535-573:18",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 10.0
""",
)

entry(
    index = 514,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)', '+|-', 1.08e+06),
        n = 0,
        Ea = (0.915, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (254, 'K'),
        Tmax = (356, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Jimenez, E.", "Gierczak, T.", "Stark, H.", "Burkholder, J.B.", "Ravishankara, A.R."],
        title = u'Reaction of OH with HO2NO2 (peroxynitric acid): Rate coefficients between 218 and 335 K and product yields at 298 K',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """1139-1149""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004JIM/GIE1139-1149:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Mass spectrometry

Reported uncertainty includes estimated systematic error.
Note: Invalid activation energy uncertainty (1.247) found and ignored
""",
)

entry(
    index = 515,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (410000, 'm^3/(mol*s)', '+|-', 60200),
        n = 0,
        Ea = (-2.37, 'kJ/mol', '+|-', 0.224),
        T0 = (1, 'K'),
        Tmin = (96, 'K'),
        Tmax = (296, 'K'),
    ),
    reference = Article(
        authors = ["Vakhtin, A.B.", "McCabe, D.C.", "Ravishankara, A.R.", "Leone, S.R."],
        title = u'Low-temperature kinetics of the reaction of the OH radical with hydrogen peroxide',
        journal = "J. Phys. Chem. A",
        volume = "107",
        pages = """10642-10647""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003VAK/MCC10642-10647:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: N2
Experimental procedure: Laval nozzle
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 516,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-0.382, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (249, 'K'),
        Tmax = (299, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Lovejoy, E.R.", "Murrells, T.P.", "Ravishankara, A.R.", "Howard, C.J."],
        title = u'Oxidation of CS2 by reaction with OH. 2. Yields of HO2 and SO2 in oxygen',
        journal = "J. Phys. Chem.",
        volume = "94",
        pages = """2386-2393""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990LOV/MUR2386-2393:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Laser magnetic resonance (LMR)
""",
)

entry(
    index = 517,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.66e+06, 'm^3/(mol*s)', '+|-', 480000),
        n = 0,
        Ea = (0.915, 'kJ/mol', '+|-', 0.503),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (410, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Vaghjiani, G.L.", "Ravishankara, A.R."],
        title = u'Reactions of OH and OD with H2O2 and D2O2',
        journal = "J. Phys. Chem.",
        volume = "93",
        pages = """7833-7837""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989VAG/RAV7833-7837:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 518,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.042, 'm^3/(mol*s)', '+|-', 0.0124),
        n = 2.5,
        Ea = (-6.968, 'kJ/mol', '+|-', 0.697),
        T0 = (1, 'K'),
        Tmin = (241, 'K'),
        Tmax = (413, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Lamb, J.J.", "Molina, L.T.", "Smith, C.A.", "Molina, M.J."],
        title = u'Rate constant of the OH + H2O2 \u2192\x92 HO2 + H2O reaction',
        journal = "J. Phys. Chem.",
        volume = "87",
        pages = """4467""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983LAM/MOL4467:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 519,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75e+06, 'm^3/(mol*s)', '+|-', 180000),
        n = 0,
        Ea = (1.339, 'kJ/mol', '+|-', 0.268),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (370, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Kurylo, M.J.", "Murphy, J.L.", "Haller, G.S.", "Cornett, K.D."],
        title = u'A Flash Photolysis Resonance Fluorescence Investigation of the Reaction OH + H2O2 \u2192\x92 HO2 + H2O',
        journal = "Int. J. Chem. Kinet.",
        volume = "14",
        pages = """1149""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982KUR/MUR1149:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 1.48
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 520,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.23e+06, 'm^3/(mol*s)', '+|-', 360000),
        n = 0,
        Ea = (2.162, 'kJ/mol', '+|-', 0.411),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (410, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Wine, P.H.", "Semmes, D.H.", "Ravishankara, A.R."],
        title = u'A Laser Flash Photolysis Kinetics Study of the Reaction OH + H2O2 \u2192\x92 HO2 + H2O',
        journal = "J. Chem. Phys.",
        volume = "75",
        pages = """4390""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981WIN/SEM4390:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 521,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.78e+06, 'm^3/(mol*s)', '+|-', 300000),
        n = 0,
        Ea = (1.364, 'kJ/mol', '+|-', 0.437),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (459, 'K'),
        Pmin = (267, 'Pa'),
        Pmax = (400, 'Pa'),
    ),
    reference = Article(
        authors = ["Sridharan, U.C.", "Reimann, B.", "Kaufman, F."],
        title = u'Kinetics of the Reaction OH + H2O2 \u2192\x92 HO2 + H2O',
        journal = "J. Chem. Phys.",
        volume = "73",
        pages = """1286""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980SRI/REI1286:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 522,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.51e+06, 'm^3/(mol*s)', '+|-', 360000),
        n = 0,
        Ea = (1.048, 'kJ/mol', '+|-', 0.629),
        T0 = (1, 'K'),
        Tmin = (245, 'K'),
        Tmax = (423, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (533, 'Pa'),
    ),
    reference = Article(
        authors = ["Keyser, L.F."],
        title = u'Absolute Rate Constant of the Reaction OH + H2 O2 \u2192\x92 HO2 + H2O from 245 to 423 K',
        journal = "J. Phys. Chem.",
        volume = "84",
        pages = """1659""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980KEY1659:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 523,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.8e+06, 'm^3/(mol*s)', '+|-', 1e+06),
        n = 0,
        Ea = (5.571, 'kJ/mol', '+|-', 0.557),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (670, 'K'),
        Pmin = (267, 'Pa'),
        Pmax = (267, 'Pa'),
    ),
    reference = Article(
        authors = ["Hack, W.", "Hoyermann, K.", "Wagner, H.G."],
        title = u'The Reaction of NO + HO2 \u2192\x92 NO2 + OH with OH + H2O2 \u2192\x92 HO2 + H2O as an HO2-Source',
        journal = "Proc. Symp. Chem. Kinet. Data Upper Lower Atmos. 1974",
        pages = """329""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975HAC/HOY329:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 524,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.8e+06, 'm^3/(mol*s)', '+|-', 1e+06),
        n = 0,
        Ea = (5.571, 'kJ/mol', '+|-', 0.557),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (669, 'K'),
    ),
    reference = Article(
        authors = ["Hack, W.", "Hoyermann, K.", "Wagner, H.Gg."],
        title = u'Ueber einige Radikalreaktionen im H-O-N-System',
        journal = "Z. Naturforsch. A",
        volume = "29",
        pages = """1236""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974HAC/HOY1236:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 525,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (245000, 'm^3/(mol*s)', '*|/', 1.12),
        n = 0.5,
        Ea = (5.014, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (950, 'K'),
        Tmax = (1450, 'K'),
        Pmin = (159000, 'Pa'),
        Pmax = (179000, 'Pa'),
    ),
    reference = Article(
        authors = ["Troe, J."],
        title = u'Ultraviolettspektrum und reaktionen des HO2-radikals im thermischen zerfall von H2O2',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "73",
        pages = """946""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969TRO946:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 1.12
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 526,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (245000, 'm^3/(mol*s)', '*|/', 1.1),
        n = 0.5,
        Ea = (5.014, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (458, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. III. Reactions with H2O2 in the range 300-458\xb0K',
        journal = "J. Phys. Chem.",
        volume = "72",
        pages = """406""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968GRE406:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Uncertainty: 1.1
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 527,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (306, 'm^3/(mol*s)'),
        n = 1.4,
        Ea = (-0.457, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (410, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Vaghjiani, G.L.", "Ravishankara, A.R."],
        title = u'Reactions of OH and OD with H2O2 and D2O2',
        journal = "J. Phys. Chem.",
        volume = "93",
        pages = """7833-7837""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989VAG/RAV7833-7837:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
""",
)

entry(
    index = 528,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.11, 'm^3/(mol*s)'),
        n = 2.45,
        Ea = (0.416, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (410, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Vaghjiani, G.L.", "Ravishankara, A.R."],
        title = u'Reactions of OH and OD with H2O2 and D2O2',
        journal = "J. Phys. Chem.",
        volume = "93",
        pages = """7833-7837""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989VAG/RAV7833-7837:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
Bath gas: He
""",
)

entry(
    index = 529,
    label = "H2O2 + OH <=> HO2 + H2O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.7e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (4.797, 'kJ/mol', '+|-', 0.575),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:35",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011842
""",
)

entry(
    index = 530,
    label = "H2O + C2H5 <=> C2H6 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.39, 'm^3/(mol*s)', '*|/', 2),
        n = 1.44,
        Ea = (84.808, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:243",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 2.0
""",
)

entry(
    index = 531,
    label = "H2O + C2H5 <=> C2H6 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0085, 'm^3/(mol*s)', '*|/', 5),
        n = 2.3,
        Ea = (81.565, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:34",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013765/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 532,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.61, 'm^3/(mol*s)'),
        n = 2.22,
        Ea = (3.101, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (138, 'K'),
        Tmax = (1367, 'K'),
    ),
    reference = Article(
        authors = ["Krasnoperov, L.N.", "Michael, J.V."],
        title = u'Shock tube studies using a novel multipass absorption cell: Rate constant results for OH + H2 and OH + C2H6',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """5643-5648""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004KRA/MIC5643-5648:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765

Evaluated rate expression derived from data reported in previous reaction rate measurements and shock tube data reported in this manuscript.
""",
)

entry(
    index = 533,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.16e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.314, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:51",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Pressure dependence: None reported
""",
)

entry(
    index = 534,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.24e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.896, 'kJ/mol', '+|-', 0.801),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:96",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
""",
)

entry(
    index = 535,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.75e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.564, 'kJ/mol', '+|-', 0.856),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:65",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
""",
)

entry(
    index = 536,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.24e+06, 'm^3/(mol*s)', '*|/', 1.1),
        n = 0,
        Ea = (8.896, 'kJ/mol', '+|-', 0.801),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.J.", "Molina, M.J."],
        title = u'Chemical Kinetic and Photochemical Data for Use in Stratospheric Modeling: Evaluation No. 11 of the NASA Panel for Data Evaluation',
        journal = "JPL Publication 94-26",
        pages = """1-2""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DEM/SAN:97",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 1.1
""",
)

entry(
    index = 537,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.22, 'm^3/(mol*s)', '*|/', 1.41),
        n = 2,
        Ea = (3.617, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:38",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 1.41
""",
)

entry(
    index = 538,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.7e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.481, 'kJ/mol', '+|-', 0.848),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:63",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
""",
)

entry(
    index = 539,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.46e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (8.231, 'kJ/mol', '+|-', 0.823),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:26",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 1.26
""",
)

entry(
    index = 540,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8840, 'm^3/(mol*s)', '*|/', 2),
        n = 1.04,
        Ea = (7.591, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:37",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 2.0
""",
)

entry(
    index = 541,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.4e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (11.141, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1200, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Bowers, D.G.", "Malcolm, D.G.", "Tuckersman, R.T."],
        title = u'Evaluated kinetic data for high-temperature reactions. Volume 5. Part 1. Homogeneous gas phase reactions of the hydroxyl radical with alkanes',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """465""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986BAU/BOW465:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 2.0
""",
)

entry(
    index = 542,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.28, 'm^3/(mol*s)', '*|/', 1.2),
        n = 2,
        Ea = (3.692, 'kJ/mol', '+|-', 0.443),
        T0 = (1, 'K'),
        Tmin = (238, 'K'),
        Tmax = (850, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics and mechanisms of the gas-phase reactions of the hydroxyl radical with organic compounds under atmospheric conditions',
        journal = "Chem. Rev.",
        volume = "86",
        pages = """69""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK69:12",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 1.2
""",
)

entry(
    index = 543,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.28, 'm^3/(mol*s)', '*|/', 2),
        n = 2,
        Ea = (2.702, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:20",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 2.0
""",
)

entry(
    index = 544,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (22.1, 'm^3/(mol*s)', '*|/', 2),
        n = 1.9,
        Ea = (4.739, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013765/rk00000001.xml
Uncertainty: 2.0
""",
)

entry(
    index = 545,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.5e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (14.966, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Wilson, W.E., Jr."],
        title = u'A critical review of the gas-phase reaction kinetics of the hydroxyl radical',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "1",
        pages = """535-573""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972WIL535-573:5",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 2.0
""",
)

entry(
    index = 546,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.62e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.094, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (822, 'K'),
        Tmax = (1367, 'K'),
        Pmin = (1453, 'Pa'),
        Pmax = (2794, 'Pa'),
    ),
    reference = Article(
        authors = ["Krasnoperov, L.N.", "Michael, J.V."],
        title = u'Shock tube studies using a novel multipass absorption cell: Rate constant results for OH + H2 and OH + C2H6',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """5643-5648""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004KRA/MIC5643-5648:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 547,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.68e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.896, 'kJ/mol', '+|-', 0.08896),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (390, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Donahue, N.M.", "Anderson, J.G.", "Demerjian, K.L."],
        title = u'New rate constants for ten OH alkane reactions from 300 to 400 K: an assessment of accuracy',
        journal = "J. Phys. Chem. A",
        volume = "102",
        pages = """3121-3126""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998DON/AND3121-3126:8",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: N2
Excitation technique: Electron beam
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 548,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.02e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (9.894, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (247, 'K'),
        Tmax = (303, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Crowley, J.N.", "Campuzano-Jost, P.", "Moortgat, G.K."],
        title = u'Temperature dependent rate constants for the gas-phase reaction between OH and CH3OCl',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """3601-3606""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996CRO/CAM3601-3606:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 549,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.76e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (32.011, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1530, 'K'),
        Tmax = (1790, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (9333, 'Pa'),
    ),
    reference = Article(
        authors = ["Ancia, R.", "Vandooren, J.", "Van Tiggelen, P.J."],
        title = u'Experimental study of the structure of rich ethane flames',
        journal = "Symp. Int. Combust. Proc.",
        volume = "26",
        pages = """1009-1016""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996ANC/VAN1009-1016:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: Ar
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Other (direct)
""",
)

entry(
    index = 550,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.21e+06, 'm^3/(mol*s)', '+|-', 430000),
        n = 0,
        Ea = (9.229, 'kJ/mol', '+|-', 0.369),
        T0 = (1, 'K'),
        Tmin = (231, 'K'),
        Tmax = (377, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Talukdar, R.K.", "Melouki, A.", "Gierczak, T.", "Barone, S.", "Chiang, S-Y.", "Ravishankara, A.R."],
        title = u'Kinetics of the reactions of OH with alkanes',
        journal = "Int. J. Chem. Kinet.",
        volume = "26",
        pages = """973-990""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994TAL/MEL973-990:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 551,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.11e-13, 'm^3/(mol*s)'),
        n = 6.93,
        Ea = (-4.54, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (138, 'K'),
        Tmax = (298, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Sharkey, P.", "Smith, I.W.M."],
        title = u'Kinetics of elementary reactions at low temperatures: rate constants for the reactions of OH with HCl (298 \xe2\x89\xa5 T/K \xe2\x89\xa5 138), CH4 (298 \xe2\x89\xa5 T/K \xe2\x89\xa5 178) and C2H6 (298 \xe2\x89\xa5 T/K \xe2\x89\xa5 138)',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "89",
        pages = """631-638""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993SHA/SMI631-638:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 552,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.06e+06, 'm^3/(mol*s)', '+|-', 1.9e+06),
        n = 0,
        Ea = (8.73, 'kJ/mol', '+|-', 0.873),
        T0 = (1, 'K'),
        Tmin = (226, 'K'),
        Tmax = (363, 'K'),
        Pmin = (3333, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Wallington, T.J.", "Neuman, D.M.", "Kurylo, M.J."],
        title = u'Kinetics of the gas phase reaction of hydroxyl radicals with ethane, benzene and a series of halogenated benzenes over the temperature range 234-438 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "19",
        pages = """725""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987WAL/NEU725:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 553,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.1, 'm^3/(mol*s)'),
        n = 2.06,
        Ea = (3.575, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (293, 'K'),
        Tmax = (705, 'K'),
        Pmin = (80000, 'Pa'),
        Pmax = (80000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tully, F.P.", "Droege, A.T.", "Koszykowski, M.L.", "Melius, C.F."],
        title = u'Hydrogen-atom abstraction from alkanes by OH. 2. Ethane',
        journal = "J. Phys. Chem.",
        volume = "90",
        pages = """691""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TUL/DRO691:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 554,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.08e+07, 'm^3/(mol*s)', '+|-', 1.5e+06),
        n = 0,
        Ea = (10.31, 'kJ/mol', '+|-', 0.931),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (295, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Smith, C.A.", "Molina, L.T.", "Lamb, J.J.", "Molina, M.J."],
        title = u'Kinetics of the reaction of OH with pernitric and nitric acids',
        journal = "Int. J. Chem. Kinet.",
        volume = "16",
        pages = """41""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SMI/MOL41:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: He
Excitation technique: Thermal
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 555,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.09e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (9.063, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (400, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Nielsen, O.J.", "Pagsberg, P.", "Sillesen, A."],
        title = u'Kinetics of the reaction of OH with ethane and a series of Cl- and F-substituted methanes at 300-400 K, studied by pulse radiolysis combined with kinetic spectroscopy',
        journal = "Phys. Chem. Behav. Atmos. Pollut. Proc. Eur. Symp.",
        pages = """283""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984NIE/PAG283:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: Ar
Excitation technique: Ultrasonics
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 556,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.68e+06, 'm^3/(mol*s)', '+|-', 370000),
        n = 0,
        Ea = (7.367, 'kJ/mol', '+|-', 0.294),
        T0 = (1, 'K'),
        Tmin = (248, 'K'),
        Tmax = (472, 'K'),
    ),
    reference = Article(
        authors = ["Jeong, K.-M.", "Hsu, K.-J.", "Jeffries, J.B.", "Kaufman, F."],
        title = u'Kinetics of the reactions of OH with C2H6, CH3CCl3, CH2ClCHCl2, CH2ClCClF2, and CH2FCF3',
        journal = "J. Phys. Chem.",
        volume = "88",
        pages = """1222""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984JEO/HSU1222:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Excitation technique: Electron beam
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 557,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.002353, 'm^3/(mol*s)'),
        n = (3.09, '', '+|-', 1),
        Ea = (-1.405, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (248, 'K'),
        Tmax = (472, 'K'),
    ),
    reference = Article(
        authors = ["Jeong, K.-M.", "Hsu, K.-J.", "Jeffries, J.B.", "Kaufman, F."],
        title = u'Kinetics of the reactions of OH with C2H6, CH3CCl3, CH2ClCHCl2, CH2ClCClF2, and CH2FCF3',
        journal = "J. Phys. Chem.",
        volume = "88",
        pages = """1222""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984JEO/HSU1222:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Excitation technique: Thermal
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 558,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8610, 'm^3/(mol*s)'),
        n = 1.05,
        Ea = (7.574, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (800, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Tully, F.P.", "Ravishankara, A.R.", "Carr, K."],
        title = u'Kinetics study of the reactions of the hydroxyl radical with ethane and propane',
        journal = "Int. J. Chem. Kinet.",
        volume = "15",
        pages = """1111""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983TUL/RAV1111:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 559,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (22.1, 'm^3/(mol*s)'),
        n = 1.9,
        Ea = (4.739, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (2853, 'Pa'),
        Pmax = (12600, 'Pa'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Craven, R.J.B.", "Din, M.", "Drysdale, D.D.", "Grant, S.", "Richardson, D.J.", "Walker, A.", "Watling, G."],
        title = u'Rates of hydroxy radical reactions with methane, ethane and propane over the temperature range 403-696 K',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "79",
        pages = """689""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983BAU/CRA689:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 560,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.49e+06, 'm^3/(mol*s)', '+|-', 210000),
        n = 0,
        Ea = (6.868, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (381, 'K'),
        Tmax = (416, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Gordon, S.", "Mulac, W.A."],
        title = u'Reaction of the OH(X2\u03c0) Radical Produced by the Pulse Radiolysis of Water Vapor',
        journal = "Proc. Symp. Chem. Kinet. Data Upper Lower Atmos. 1974",
        pages = """289""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975GOR/MUL289:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 2.51
Bath gas: H2O
Excitation technique: Ultrasonics
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 561,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.71e+07, 'm^3/(mol*s)', '*|/', 1.38),
        n = 0,
        Ea = (14.717, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'The Use of the H2 + O2 Reaction in Determining the Velocity Constants of Elementary Reactions in Hydrocarbon Oxidation',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """291""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAK/BAL291:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 1.38
""",
)

entry(
    index = 562,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.12e+07, 'm^3/(mol*s)', '*|/', 1.17),
        n = 0,
        Ea = (10.227, 'kJ/mol', '+|-', 0.409),
        T0 = (1, 'K'),
        Tmin = (299, 'K'),
        Tmax = (493, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 1.17
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 563,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.71e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (14.717, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (730, 'K'),
        Tmax = (780, 'K'),
        Pmin = (33300, 'Pa'),
        Pmax = (90700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Hopkins, D.E.", "Walker, R.W."],
        title = u'Addition of ethane to slowly reacting mixtures of hydrogen and oxygen at 500\xb0C',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """189""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BAL/HOP189:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 564,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.26e+08, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (15.049, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (423, 'K'),
        Pmin = (41200, 'Pa'),
        Pmax = (41200, 'Pa'),
    ),
    reference = Article(
        authors = ["Horne, D.G.", "Norrish, R.G.W."],
        title = u'Rate of H-abstraction by OH from hydrocarbons',
        journal = "Nature (London)",
        volume = "215",
        pages = """1373""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967HOR/NOR1373:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Uncertainty: 10.0
Bath gas: Ar
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 565,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.02e+06, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (23.031, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (611, 'K'),
        Tmax = (774, 'K'),
        Pmin = (293, 'Pa'),
        Pmax = (573, 'Pa'),
    ),
    reference = Article(
        authors = ["Avramenko, L.I.", "Lorentso, R.V."],
        title = u'Reactions between free hydroxyl and hydrocarbons',
        journal = "Dokl. Akad. Nauk SSR",
        volume = "67",
        pages = """867""",
        year = "1949",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1949AVR/LOR867:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 566,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.41e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (9.54, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (380, 'K'),
    ),
    reference = Article(
        authors = ["Bravo-Perez, G.", "Alvarez-Idaboy, J.R.", "Jimenez, A.G.", "Cruz-Torres, A."],
        title = u'Quantum chemical and conventional TST calculations of rate constants for the OH plus alkane reaction',
        journal = "Chem. Phys.",
        volume = "310",
        pages = """213-223""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005BRA/ALV213-223:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013765

1) The rate coefficent is the result of BHandHLYP/6-311G(d,p) calculations. The paper also lists rate coeffients computed at the MP2/6-311G(d,p) level.

The title reaction was modeled using ab initio MP2 and a hybrid density functional method (BHandHLYP) methods, and the 6-311G(d,p) basis set. Single-point calculations at the CCSD(T) level were carried out at the optimized geometries. Hindered Internal Rotation partition functions calculations were explicitly carried out and included in the total partition functions. The explicit participation of the tunnel effect was taken into account.
""",
)

entry(
    index = 567,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.19, 'm^3/(mol*s)'),
        n = 2.51,
        Ea = (1.854, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (140, 'K'),
        Tmax = (1600, 'K'),
    ),
    reference = Article(
        authors = ["Krasnoperov, L.N.", "Michael, J.V."],
        title = u'Shock tube studies using a novel multipass absorption cell: Rate constant results for OH + H2 and OH + C2H6',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """5643-5648""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004KRA/MIC5643-5648:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013765

Evaluated rate expression derived by fitting a theoretical extrapolation based on conventional transition state theory (computed with B3LYP/6-31G* calculations) with experimental data reported in previous reaction rate measurements and wtih the shock tube data reported in this manuscript. Wigner tunneling corrections were included in the fit model.
""",
)

entry(
    index = 568,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (39.8, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (4.739, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
""",
)

entry(
    index = 569,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.4e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (9.562, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (306, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Benson, S.W."],
        title = u'Empirical correlations for rate coefficients for reactions of OH with haloalkanes',
        journal = "J. Phys. Chem.",
        volume = "91",
        pages = """171-175""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987COH/BEN171-175:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
""",
)

entry(
    index = 570,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.69, 'm^3/(mol*s)'),
        n = 2,
        Ea = (2.519, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
Bath gas: N2
""",
)

entry(
    index = 571,
    label = "C2H6 + OH <=> H2O + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.76, 'm^3/(mol*s)'),
        n = 2,
        Ea = (3.575, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'The use of transition-state theory to extrapolate rate coefficients for reactions of OH with alkanes',
        journal = "Int. J. Chem. Kinet.",
        volume = "14",
        pages = """1339""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982COH1339:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013765
""",
)

entry(
    index = 572,
    label = "H2O + O2 <=> HO2-2 + OH",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (4.65e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (310.13, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Mayer, S.W.", "Schieler, L."],
        title = u'Activation energies and rate constants computed for reactions of oxygen with hydrocarbons',
        journal = "J. Phys. Chem.",
        volume = "72",
        pages = """2628-2631""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968MAY/SCH2628-2631:12",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013767/rk00000001.xml
""",
)

entry(
    index = 573,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (400, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F.", "Hynes, R.G.", "Jenkin, M.E.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic and photochemical data for atmospheric chemistry: Volume I - gas phase reactions of Ox, HOx, NOx and SOx species',
        journal = "Atmos. Chem. Phys.",
        volume = "4",
        pages = """1461-1738""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004ATK/BAU1461-1738:54",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
""",
)

entry(
    index = 574,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (400, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:19",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
Pressure dependence: None reported
""",
)

entry(
    index = 575,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:309",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
""",
)

entry(
    index = 576,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (400, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic and photochemical data for atmospheric chemistry: supplement VI. IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """1329-1499""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU1329-1499:53",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
""",
)

entry(
    index = 577,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)', '*|/', 1.3),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.J.", "Molina, M.J."],
        title = u'Chemical Kinetic and Photochemical Data for Use in Stratospheric Modeling: Evaluation No. 11 of the NASA Panel for Data Evaluation',
        journal = "JPL Publication 94-26",
        pages = """1-2""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DEM/SAN:291",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
Uncertainty: 1.3
""",
)

entry(
    index = 578,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (-2.079, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Frank, P.", "Hayman, G.", "Just, Th.", "Kerr, J.A.", "Murrells, T.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combusion modelling. Supplement I',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "23",
        pages = """847-1033""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994BAU/COB847-1033:91",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
Uncertainty: 1.58
""",
)

entry(
    index = 579,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (-2.079, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:170",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
Uncertainty: 3.1600001
""",
)

entry(
    index = 580,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (400, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:225",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
""",
)

entry(
    index = 581,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (400, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:142",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
Uncertainty: 1.26
""",
)

entry(
    index = 582,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (4.182, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:12",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
Uncertainty: 2.0
""",
)

entry(
    index = 583,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.89e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 0.416),
        T0 = (1, 'K'),
        Tmin = (254, 'K'),
        Tmax = (382, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (133, 'Pa'),
    ),
    reference = Article(
        authors = ["Keyser, L.F."],
        title = u'Kinetics of the reaction OH + HO2 \u2192\x92 H2O + O2 from 254 to 382 K',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """1193""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988KEY1193:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 584,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.02e+07, 'm^3/(mol*s)', '+|-', 3e+06),
        n = 0,
        Ea = (-3.459, 'kJ/mol', '+|-', 0.727),
        T0 = (1, 'K'),
        Tmin = (252, 'K'),
        Tmax = (420, 'K'),
        Pmin = (333, 'Pa'),
        Pmax = (333, 'Pa'),
    ),
    reference = Article(
        authors = ["Sridharan, U.C.", "Qiu, L.X.", "Kaufman, F."],
        title = u'Rate constant of the OH + HO2 reaction from 252 to 420 K',
        journal = "J. Phys. Chem.",
        volume = "88",
        pages = """1281""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SRI/QIU1281:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 585,
    label = "HO2-2 + OH <=> H2O + O2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.42e+08, 'm^3/(mol*s)'),
        n = -0.21,
        Ea = (-0.466, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Gonzalez, C.", "Theisen, J.", "Schlegel, H.B.", "Hase, W.L.", "Kaiser, E.W."],
        title = u'Kinetics of the reaction between OH and HO2 on the triplet potential energy surface',
        journal = "J. Phys. Chem.",
        volume = "96",
        pages = """1767-1774""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992GON/THE1767-1774:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00013767
""",
)

entry(
    index = 586,
    label = "C3H6-3 + H <=> H2 + C3H5-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.783, 'm^3/(mol*s)'),
        n = 2.5,
        Ea = (51.383, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (950, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for hydrocarbon pyrolysis',
        journal = "Ind. Eng. Chem.",
        volume = "31",
        pages = """3-8""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992TSA3-8:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00005746
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005746/rk00000002.xml
""",
)

entry(
    index = 587,
    label = "C3H6-4 + H <=> H2 + C3H5-4",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.39, 'm^3/(mol*s)'),
        n = 2.5,
        Ea = (24.361, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for hydrocarbon pyrolysis',
        journal = "Ind. Eng. Chem.",
        volume = "31",
        pages = """3-8""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992TSA3-8:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00005747
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005747/rk00000002.xml
""",
)

entry(
    index = 588,
    label = "C2H + H2O <=> C2H2 + OH",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.26e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (18.225, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (451, 'K'),
    ),
    reference = Article(
        authors = ["Ding, Y.", "Zhang, X.", "Li, Z.", "Huang, X.", "Sun, C."],
        title = u'Is the C2H + H2O Reaction Anomalous?',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """8206-8215""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001DIN/ZHA8206-8215:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010403
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010403/rk00000003.xml

The rate constant was calculated by CCSD(T)/6-311+G(3df,2p)/QCISD/6-311G(d,p)+ZPVE CVT/SCT. The results of this theoretical study indicate that the C2H+H2O ->C2H2+OH reaction is slow.
""",
)

entry(
    index = 589,
    label = "CH2O + CH3O <=> CH4O + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (102000, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (12.472, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001351
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001351/rk00000003.xml
Uncertainty: 3.0
""",
)

entry(
    index = 590,
    label = "CH2O + C2H3 <=> C2H4 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.005421, 'm^3/(mol*s)', '*|/', 5),
        n = 2.81,
        Ea = (24.528, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:5",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001357
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001357/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 591,
    label = "CH2O + C2H3 <=> C2H4 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7e-08, 'm^3/(mol*s)'),
        n = 4.21,
        Ea = (6.795, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Zhang, Y.", "Zhang, S.W.", "Li, Q.S."],
        title = u'Ab initio and direct dynamics study on the hydrogen abstraction reaction C2H3 + HCHO',
        journal = "Chem. Phys.",
        volume = "306",
        pages = """51-56""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004ZHA/ZHA51-56:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001357

Results of an ab initio direct dynamics study are reported. Geometries of stationary points on the PES were optimized using the MP2/cc-pVDZ method and the energies further refined at the QCISD(T)/cc-pVTZ level of theory. Rate constants were evaluated using canonical variational transition state theory (CVT) and canonical variational transition state theory with small-curvature tunneling contributions (CVT/SCT) in the temperature range of 300 - 2500 K. Calculations are in good agreement with the very limited experimental data.
""",
)

entry(
    index = 592,
    label = "CH2O + C2H3 <=> C2H4 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (174000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.294, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    reference = Article(
        authors = ["Scherzer, K.", "Loser, U.", "Stiller, W."],
        title = u'BSBL-Rechnungen zu wasserstoffabspaltungsreaktionen durch alkenylradikale; Vinylradikale',
        journal = "Z. Chem.",
        volume = "27",
        pages = """300""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987SCH/LOS300:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00001357
""",
)

entry(
    index = 593,
    label = "CH2O + O2 <=> CHO + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (6.03e+07, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (170.447, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:7",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001370
Uncertainty: 3.1600001
""",
)

entry(
    index = 594,
    label = "CH2O + O2 <=> CHO + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.05e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (162.964, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001370
Uncertainty: 2.0
""",
)

entry(
    index = 595,
    label = "CH2O + O2 <=> CHO + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (8.07e+09, 'm^3/(mol*s)'),
        n = 0,
        Ea = (223.518, 'kJ/mol', '+|-', 18.782),
        T0 = (1, 'K'),
        Tmin = (1303, 'K'),
        Tmax = (2272, 'K'),
        Pmin = (1453, 'Pa'),
        Pmax = (2133, 'Pa'),
    ),
    reference = Article(
        authors = ["Srinivasan, N.K.", "Su, M.C.", "Sutherland, J.W.", "Michael, J.V."],
        title = u'reflected shock tube studies of high-temperature rate constants for CH3+O-2, H2CO+O-2, and OH+O-2',
        journal = "J. Phys. Chem. A",
        volume = "109",
        pages = """7902-7914""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005SRI/SU7902-7914:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001370
Pressure dependence: None reported
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 596,
    label = "CH2O + O2 <=> CHO + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.9e+10, 'm^3/(mol*s)', '+|-', 4.34e+09),
        n = 0,
        Ea = (236.763, 'kJ/mol', '+|-', 13.536),
        T0 = (1, 'K'),
        Tmin = (1600, 'K'),
        Tmax = (2100, 'K'),
        Pmin = (789.3, 'Pa'),
        Pmax = (1465.2, 'Pa'),
    ),
    reference = Article(
        authors = ["Michael, J.V.", "Kumaran, S.S.", "Su, M.-C."],
        title = u'Rate Constants for CH3 + O2\u2192\x92CH3 + O at High Temperature and Evidence for H2CO + O2\u2192\x92HCO + HO2',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """5942-5948""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999MIC/KUM5942-5948:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001370
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 597,
    label = "CH2O + O2 <=> CHO + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.04e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (162.964, 'kJ/mol', '+|-', 6.51),
        T0 = (1, 'K'),
        Tmin = (713, 'K'),
        Tmax = (816, 'K'),
        Pmin = (7466, 'Pa'),
        Pmax = (7866, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Fuller, A.R.", "Longthorn, D.", "Walker, R.W."],
        title = u'Oxidation of Formaldehyde in KCl-coated Vessels',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "70",
        pages = """1257""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974BAL/FUL1257:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001370
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001370/rk00000002.xml
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 598,
    label = "CH2O + O2 <=> CHO + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (46.9, 'm^3/(mol*s)'),
        n = 2.05,
        Ea = (158.715, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1600, 'K'),
        Tmax = (2100, 'K'),
        Pmin = (789.3, 'Pa'),
        Pmax = (1465.2, 'Pa'),
    ),
    reference = Article(
        authors = ["Michael, J.V.", "Kumaran, S.S.", "Su, M.-C."],
        title = u'Rate Constants for CH3 + O2\u2192\x92CH3 + O at High Temperature and Evidence for H2CO + O2\u2192\x92HCO + HO2',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """5942-5948""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999MIC/KUM5942-5948:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001370
""",
)

entry(
    index = 599,
    label = "C2H6O + CH3 <=> CH4 + C2H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (79400, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.327, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (403, 'K'),
        Tmax = (523, 'K'),
    ),
    reference = Article(
        authors = ["Gray, P.", "Herod, A.A."],
        title = u'Methyl radical reactions with ethanol and deuterated ethanols',
        journal = "Trans. Faraday Soc.",
        volume = "64",
        pages = """1568""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968GRA/HER1568:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001604
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001604/rk00000001.xml
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 600,
    label = "C2H6O + CH3 <=> CH4 + C2H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.67e-81, 'm^3/(mol*s)'),
        n = 19.68,
        Ea = (43.194, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (600, 'K'),
    ),
    reference = Article(
        authors = ["Xu, Z.F.", "Park, J.", "Lin, M.C."],
        title = u'Thermal decomposition of ethanol. III. A computational study of the kinetics and mechanism for the CH3 + C2H5OH reaction',
        journal = "J. Chem. Phys.",
        volume = "120",
        pages = """6593-6599""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004XU/PAR6593-6599:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001604
Pressure dependence: Rate constant is high pressure limit

Significant minor channel at all temperatures, modified G2/B3LYP 6-311G(d,p) geometries, rates by TST and CVTST plus tunneling
""",
)

entry(
    index = 601,
    label = "C2H6O + CH3 <=> CH4 + C2H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.38e-30, 'm^3/(mol*s)'),
        n = 3.57,
        Ea = (-32.31, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Xu, Z.F.", "Park, J.", "Lin, M.C."],
        title = u'Thermal decomposition of ethanol. III. A computational study of the kinetics and mechanism for the CH3 + C2H5OH reaction',
        journal = "J. Chem. Phys.",
        volume = "120",
        pages = """6593-6599""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004XU/PAR6593-6599:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001604
Pressure dependence: Rate constant is high pressure limit

Significant minor channel at all temperatures, modified G2/B3LYP 6-311G(d,p) geometries, rates by TST and CVTST plus tunneling
""",
)

entry(
    index = 602,
    label = "C2H6O-2 + CH3 <=> CH4 + C2H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (398000, 'm^3/(mol*s)', '*|/', 1.41),
        n = 0,
        Ea = (40.575, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (403, 'K'),
        Tmax = (523, 'K'),
    ),
    reference = Article(
        authors = ["Gray, P.", "Herod, A.A."],
        title = u'Methyl radical reactions with ethanol and deuterated ethanols',
        journal = "Trans. Faraday Soc.",
        volume = "64",
        pages = """1568""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968GRA/HER1568:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001605
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001605/rk00000003.xml
Uncertainty: 1.41
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 603,
    label = "C2H6O-2 + CH3 <=> CH4 + C2H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.31e-29, 'm^3/(mol*s)'),
        n = 3.37,
        Ea = (-31.944, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Xu, Z.F.", "Park, J.", "Lin, M.C."],
        title = u'Thermal decomposition of ethanol. III. A computational study of the kinetics and mechanism for the CH3 + C2H5OH reaction',
        journal = "J. Chem. Phys.",
        volume = "120",
        pages = """6593-6599""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004XU/PAR6593-6599:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001605
Pressure dependence: Rate constant is high pressure limit

Dominant below 800 K, significant minor channel above 1000 K, modified G2/B3LYP 6-311G(d,p) geometries, rates by TST and CVTST plus tunneling
""",
)

entry(
    index = 604,
    label = "C2H6O-2 + CH3 <=> CH4 + C2H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.69e-77, 'm^3/(mol*s)'),
        n = 18.51,
        Ea = (39.369, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (600, 'K'),
    ),
    reference = Article(
        authors = ["Xu, Z.F.", "Park, J.", "Lin, M.C."],
        title = u'Thermal decomposition of ethanol. III. A computational study of the kinetics and mechanism for the CH3 + C2H5OH reaction',
        journal = "J. Chem. Phys.",
        volume = "120",
        pages = """6593-6599""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004XU/PAR6593-6599:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001605
Pressure dependence: Rate constant is high pressure limit

Dominant below 800 K, significant minor channel above 1000 K, modified G2/B3LYP 6-311G(d,p) geometries, rates by TST and CVTST plus tunneling
""",
)

entry(
    index = 605,
    label = "C2H6O-2 + OH <=> H2O + C2H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.47e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (0.582, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (270, 'K'),
        Tmax = (340, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:69",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001609
Pressure dependence: None reported
Note: Invalid activation energy uncertainty (1.663) found and ignored
""",
)

entry(
    index = 606,
    label = "C2H6O-2 + OH <=> H2O + C2H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (24200, 'm^3/(mol*s)', '+|-', 5180),
        n = 0,
        Ea = (-3.309, 'kJ/mol', '+|-', 0.582),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Galano, A.", "Alvarez-Idaboy, J.R.", "Bravo-Perez, G.", "Ruiz-Santoyo, Ma. E."],
        title = u'Gas Phase Reactions of C1-C4 Alcohols with the OH Radical:  A Quantum Mechanical Approach',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "4",
        pages = """4648-4662""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GAL/ALV4648-4662:11",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001609
Pressure dependence: Rate constant is high pressure limit

Reported uncertainties are two sigma and are precision only.
""",
)

entry(
    index = 607,
    label = "C2H6O-2 + OH <=> H2O + C2H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (24.943, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1300, 'K'),
        Tmax = (1700, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (203000, 'Pa'),
    ),
    reference = Article(
        authors = ["Natarajan, K.", "Bhaskaran, K.A."],
        title = u'An Experimental and Analytical Investigation of High Temperature Ignition of Ethanol',
        journal = "Proc. Int. Symp. Shock Tubes Waves",
        volume = "13",
        pages = """834""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982NAT/BHA834:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00001609
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001609/rk00000001.xml
Bath gas: Ar
""",
)

entry(
    index = 608,
    label = "CH4O + CH3O-2 <=> CH4O-2 + CH3O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (7830, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (50.469, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001687
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001687/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 609,
    label = "CH4O-2 + CH3O <=> CH4O + CH3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (301000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (17.045, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:6",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001687
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001687/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 610,
    label = "CH4O-2 + CHO <=> CH2O + CH3O-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.009686, 'm^3/(mol*s)', '*|/', 5),
        n = 2.9,
        Ea = (54.876, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:10",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001688
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001688/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 611,
    label = "CH2O + CH3O-2 <=> CH4O-2 + CHO",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.005491, 'm^3/(mol*s)', '*|/', 3),
        n = 2.8,
        Ea = (24.528, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001688
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001688/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 612,
    label = "CH4O + C2H3 <=> C2H4 + CH3O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.443e-05, 'm^3/(mol*s)', '*|/', 5),
        n = 3.1,
        Ea = (29.018, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:11",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001689
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001689/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 613,
    label = "CH4O-2 + C2H3 <=> C2H4 + CH3O-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (3.192e-05, 'm^3/(mol*s)', '*|/', 5),
        n = 3.2,
        Ea = (30.015, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:12",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001690
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001690/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 614,
    label = "CH4O-2 + O2 <=> HO2-2 + CH3O-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.05e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (187.907, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:16",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001705
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001705/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 615,
    label = "C3H8O + H <=> H2 + C3H7O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.47e+07, 'm^3/(mol*s)', '+|-', 4.9e+06),
        n = 0,
        Ea = (26.773, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (843, 'K'),
        Tmax = (963, 'K'),
        Pmin = (1107, 'Pa'),
        Pmax = (2146, 'Pa'),
    ),
    reference = Article(
        authors = ["Oganesyan, K.T.", "Nalbandyan, A.B."],
        title = u'Determination of rate constants of reactions of atomic hydrogen with propyl and butyl alcohols',
        journal = "Izv. Akad. Nauk Arm. SSR, Khim. Nauki",
        volume = "18",
        pages = """237""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965OGA/NAL237:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001752
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001752/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Pressure measurement
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 616,
    label = "C3H6O + H <=> H2 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (23, 'm^3/(mol*s)'),
        n = 2,
        Ea = (20.92, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1050, 'K'),
        Tmax = (1650, 'K'),
        Pmin = (122000, 'Pa'),
        Pmax = (324000, 'Pa'),
    ),
    reference = Article(
        authors = ["Sato, K.", "Hidaka, Y."],
        title = u'Shock-tube and modeling study of acetone pyrolysis and oxidation',
        journal = "Combust. Flame",
        volume = "122",
        pages = """291-311""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000SAT/HID291-311:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001783
Experimental procedure: Shock tube
Time resolution: In real time
Analytical technique: IR absorption
""",
)

entry(
    index = 617,
    label = "C3H6O + H <=> H2 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.86e+07, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (26.606, 'kJ/mol', '+|-', 1.33),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (465, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (267, 'Pa'),
    ),
    reference = Article(
        authors = ["Ambidge, P.F.", "Bradley, J.N.", "Whytock, D.A."],
        title = u'Kinetic Study of the Reactions of Hydrogen and Oxygen Atoms with Acetone',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "72",
        pages = """1870""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976AMB/BRA1870:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001783
Uncertainty: 1.26
Bath gas: Ar
Excitation technique: Electron beam
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 618,
    label = "C3H6O + H <=> H2 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.29e+08, 'm^3/(mol*s)', '+|-', 8.9e+07),
        n = 0,
        Ea = (58.201, 'kJ/mol', '+|-', 6.394),
        T0 = (1, 'K'),
        Tmin = (843, 'K'),
        Tmax = (928, 'K'),
    ),
    reference = Article(
        authors = ["Azatyan, V.V.", "Gyulbekyan, Zh.Kh.", "Nalbandyan, A.B.", "Romanovich, L.B."],
        title = u'Kinetics of the Reaction of Hydrogen and Oxygen with Acetone',
        journal = "Arm. Khim. Zh.",
        volume = "25",
        pages = """727""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972AZA/GYU727:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001783
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001783/rk00000001.xml
Uncertainty: 1.05
Excitation technique: Thermal
Analytical technique: Other
""",
)

entry(
    index = 619,
    label = "CH4 + CH3O2 <=> CH4O2 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (181000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (77.325, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:16",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001954
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001954/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 620,
    label = "C2H6 + CH3O <=> CH4O + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (241000, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (29.683, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:31",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002098
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002098/rk00000005.xml
Uncertainty: 3.0
""",
)

entry(
    index = 621,
    label = "CH4O + C2H5 <=> C2H6 + CH3O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.443e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.1,
        Ea = (37.415, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:18",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002098
Uncertainty: 3.0
""",
)

entry(
    index = 622,
    label = "C2H6 + CH3O-2 <=> CH4O-2 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.000199, 'm^3/(mol*s)', '*|/', 5),
        n = 3,
        Ea = (58.451, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:24",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002103
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002103/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 623,
    label = "CH4O-2 + C2H5 <=> C2H6 + CH3O-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.192e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.2,
        Ea = (38.33, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:19",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002103
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002103/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 624,
    label = "C2H6 + CHO <=> CH2O + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.0469, 'm^3/(mol*s)', '*|/', 5),
        n = 2.72,
        Ea = (76.327, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:33",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002104
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002104/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 625,
    label = "C2H6 + CHO <=> CH2O + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.25e-06, 'm^3/(mol*s)', '*|/', 5),
        n = 3.74,
        Ea = (70.848, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Huynh, L.K.", "Truong, T.N."],
        title = u'Kinetics of the hydrogen abstraction CHO plus Alkane -&gt; HCHO plus Alkyl reaction class: an application of the reaction class transition state theory',
        journal = "Theor. Chem. Acct.",
        volume = "120",
        pages = """107-118""",
        year = "2008",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2008HUY/TRU107-118:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002104
Uncertainty: 5.0
""",
)

entry(
    index = 626,
    label = "CH2O + C2H5 <=> C2H6 + CHO",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.005499, 'm^3/(mol*s)', '*|/', 5),
        n = 2.81,
        Ea = (24.528, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:11",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002104
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002104/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 627,
    label = "C2H6 + C2H3 <=> C2H4 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.000601, 'm^3/(mol*s)', '*|/', 5),
        n = 3.3,
        Ea = (43.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:34",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002105
Uncertainty: 5.0
""",
)

entry(
    index = 628,
    label = "C2H6 + C2H3 <=> C2H4 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.5e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.822, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1700, 'K'),
        Pmin = (172000, 'Pa'),
        Pmax = (253000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hidaka, Y.", "Shiba, S.", "Takuma, H.", "Suga, M."],
        title = u'Thermal decomposition of ethane in shock waves',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """441""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985HID/SHI441:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002105
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002105/rk00000001.xml
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 629,
    label = "C2H6 + C2H3 <=> C2H4 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (112000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.121, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    reference = Article(
        authors = ["Scherzer, K.", "Loser, U.", "Stiller, W."],
        title = u'BSBL-Rechnungen zu wasserstoffabspaltungsreaktionen durch alkenylradikale; Vinylradikale',
        journal = "Z. Chem.",
        volume = "27",
        pages = """300""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987SCH/LOS300:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00002105
""",
)

entry(
    index = 630,
    label = "C2H4 + C2H5 <=> C2H6 + C2H3",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.000632, 'm^3/(mol*s)', '*|/', 5),
        n = 3.13,
        Ea = (75.329, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:58",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002105
Uncertainty: 5.0
""",
)

entry(
    index = 631,
    label = "C2H4 + C2H5 <=> C2H6 + C2H3",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (158000, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (62.192, 'kJ/mol', '+|-', 3.11),
        T0 = (1, 'K'),
        Tmin = (650, 'K'),
        Tmax = (770, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Zhang, H-X.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from ethylene by methyl and ethyl radicals over the temperature range 650-770K',
        journal = "Int. J. Chem. Kinet.",
        volume = "22",
        pages = """21-35""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990ZHA/BAC21-35:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002105
Uncertainty: 1.58
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 632,
    label = "C2H4 + C2H5 <=> C2H6 + C2H3",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.98e+06, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (89.796, 'kJ/mol', '+|-', 4.498),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (766, 'K'),
        Pmin = (10400, 'Pa'),
        Pmax = (50900, 'Pa'),
    ),
    reference = Article(
        authors = ["Ahonkhai, S.I.", "Lin, X-H.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from ethylene by methyl and ethyl radicals relative to abstraction from propane and isobutane',
        journal = "Int. J. Chem. Kinet.",
        volume = "21",
        pages = """1-20""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989AHO/LIN1-20:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002105
Uncertainty: 2.51
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 633,
    label = "C2H4 + C2H5 <=> C2H6 + C2H3",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (6.31e+06, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (81.149, 'kJ/mol', '+|-', 5.679),
        T0 = (1, 'K'),
        Tmin = (798, 'K'),
        Tmax = (924, 'K'),
    ),
    reference = Article(
        authors = ["Halstead, M.P.", "Quinn, C.P."],
        title = u'Pyrolysis of ethylene',
        journal = "Trans. Faraday Soc.",
        volume = "64",
        pages = """103""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968HAL/QUI103:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002105
Uncertainty: 2.51
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 634,
    label = "C2H4 + C2H5 <=> C2H6 + C2H3",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (316000, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (54.377, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (773, 'K'),
        Tmax = (873, 'K'),
        Pmin = (20000, 'Pa'),
        Pmax = (80000, 'Pa'),
    ),
    reference = Article(
        authors = ["Boyd, M.L.", "Wu, T-M.", "Back, M.H."],
        title = u'Kinetics of the thermal reactions of ethylene. Part I',
        journal = "Can. J. Chem.",
        volume = "46",
        pages = """415""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968BOY/WU2415:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002105
Uncertainty: 10.0
Bath gas: C2H6
Excitation technique: Thermal
Analytical technique: Mass spectrometry
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 635,
    label = "C2H6 + O2 <=> HO2-2 + C2H5",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (6.03e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (217.008, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:39",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002126
Uncertainty: 10.0
""",
)

entry(
    index = 636,
    label = "C2H6 + O2 <=> HO2-2 + C2H5",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (4.04e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (212.85, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:38",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002126
Uncertainty: 5.0
""",
)

entry(
    index = 637,
    label = "C2H6 + O2 <=> HO2-2 + C2H5",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (213.682, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (865, 'K'),
        Tmax = (905, 'K'),
    ),
    reference = Article(
        authors = ["Taylor, J.E.", "Kulich, D.M."],
        title = u'Homogeneous gas-phase pyrolyses with a wall-less reactor. III. The oxygen-ethane reaction. A double reversal in oxygen and surface effects',
        journal = "Int. J. Chem. Kinet.",
        volume = "5",
        pages = """455-468""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973TAY/KUL455-468:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002126
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002126/rk00000003.xml
Bath gas: N2
""",
)

entry(
    index = 638,
    label = "C2H4 + O2 <=> HO2-2 + C2H3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (4.22e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (241.12, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:55",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002294
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002294/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 639,
    label = "C2H2 + C2H5 <=> C2H6 + C2H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (271000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (98.111, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:75",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002411
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002411/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 640,
    label = "C2H6 + C2H <=> C2H2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.11e+07, 'm^3/(mol*s)', '+|-', 1.9e+06),
        n = 0,
        Ea = (-0.01663, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (153, 'K'),
        Tmax = (357, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (11100, 'Pa'),
    ),
    reference = Article(
        authors = ["Opansky, B.J.", "Leone, S.R."],
        title = u'Rate coefficients of C2H with C2H4, C2H6, and H2 from 150 to 359 K',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """19904-19910""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996OPA/LEO19904-19910:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002411
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: IR absorption
Note: Invalid activation energy uncertainty (0.133) found and ignored
""",
)

entry(
    index = 641,
    label = "C3H8 + CH3 <=> CH4 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (9e-07, 'm^3/(mol*s)', '*|/', 1.5),
        n = 3.65,
        Ea = (29.932, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:25",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002724
Uncertainty: 1.5
""",
)

entry(
    index = 642,
    label = "C3H8 + CH3 <=> CH4 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (4.52e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (62.442, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (609, 'K'),
        Tmax = (648, 'K'),
        Pmin = (2533, 'Pa'),
        Pmax = (2533, 'Pa'),
    ),
    reference = Article(
        authors = ["Mintz, K.J.", "Le Roy, D.J."],
        title = u'Kinetics of radical reactions in sodium diffusion flames',
        journal = "Can. J. Chem.",
        volume = "56",
        pages = """941""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978MIN/LER941:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002724
Bath gas: He
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 643,
    label = "C3H8 + CH3 <=> CH4 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (4.37e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (73.25, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (714, 'K'),
        Tmax = (776, 'K'),
        Pmin = (3466, 'Pa'),
        Pmax = (55500, 'Pa'),
    ),
    reference = Article(
        authors = ["Leathard, D.A.", "Purnell, J.H."],
        title = u'Propyl radical isomerization and heterogeneous effects in the pyrolysis of propane below 500\xb0C',
        journal = "Proc. R. Soc. London A",
        volume = "306",
        pages = """553""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968LEA/PUR553:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002724
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002724/rk00000003.xml
Bath gas: C3H8
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 644,
    label = "CH4 + C3H7 <=> C3H8 + CH3",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2e-08, 'm^3/(mol*s)', '*|/', 2),
        n = 4.02,
        Ea = (45.48, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:8",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002724
Uncertainty: 2.0
""",
)

entry(
    index = 645,
    label = "C3H8-2 + OH <=> H2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.58e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (4.864, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:52",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002745
Pressure dependence: None reported
""",
)

entry(
    index = 646,
    label = "C3H8-2 + OH <=> H2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2900, 'm^3/(mol*s)'),
        n = 1,
        Ea = (1.081, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002745
""",
)

entry(
    index = 647,
    label = "C3H8-2 + OH <=> H2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.92e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.559, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (299, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002745
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 648,
    label = "C3H8-2 + OH <=> H2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.4e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (10.643, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (730, 'K'),
        Tmax = (780, 'K'),
        Pmin = (33300, 'Pa'),
        Pmax = (89300, 'Pa'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'Addition of C3H8, n- and i-C4H10 to slowly reacting mixtures of hydrogen and oxygen at 480\xb0C',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """2812""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BAK/BAL2812:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00002745
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002745/rk00000001.xml
Bath gas: N2
""",
)

entry(
    index = 649,
    label = "C3H8-2 + OH <=> H2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.4e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (9.312, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (854, 'K'),
    ),
    reference = Article(
        authors = ["Hu, W-P.", "Rossi, I.", "Corchado, J.C.", "Truhlar, D.G."],
        title = u'Molecular modeling of combustion kinetics. The abstraction of primary and secondary hydrogens by hydroxyl radical',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """6911-6921""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997HU/ROS6911-6921:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002745
""",
)

entry(
    index = 650,
    label = "C3H8-2 + OH <=> H2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.28e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.156, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (854, 'K'),
    ),
    reference = Article(
        authors = ["Hu, W-P.", "Rossi, I.", "Corchado, J.C.", "Truhlar, D.G."],
        title = u'Molecular modeling of combustion kinetics. The abstraction of primary and secondary hydrogens by hydroxyl radical',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """6911-6921""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997HU/ROS6911-6921:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002745
""",
)

entry(
    index = 651,
    label = "C3H8-2 + OH <=> H2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.09, 'm^3/(mol*s)'),
        n = 1.9,
        Ea = (-0.665, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (1220, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002745
""",
)

entry(
    index = 652,
    label = "C3H8-2 + OH <=> H2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.6, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-1.937, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002745
Bath gas: N2
""",
)

entry(
    index = 653,
    label = "C3H8 + OH <=> H2O + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.69e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.843, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (299, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002746
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002746/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 654,
    label = "C3H8 + OH <=> H2O + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.28e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (10.892, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (854, 'K'),
    ),
    reference = Article(
        authors = ["Hu, W-P.", "Rossi, I.", "Corchado, J.C.", "Truhlar, D.G."],
        title = u'Molecular modeling of combustion kinetics. The abstraction of primary and secondary hydrogens by hydroxyl radical',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """6911-6921""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997HU/ROS6911-6921:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002746
""",
)

entry(
    index = 655,
    label = "C3H8 + OH <=> H2O + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (31.6, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (3.908, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (1220, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002746
""",
)

entry(
    index = 656,
    label = "C3H8 + OH <=> H2O + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (5.39, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002746
Bath gas: N2
""",
)

entry(
    index = 657,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.99e-12, 'm^3/(mol*s)', '*|/', 2),
        n = 5.64,
        Ea = (10.31, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1250, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:68",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Uncertainty: 2.0
""",
)

entry(
    index = 658,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (84900, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (25.11, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (525, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:51",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Uncertainty: 2.0
""",
)

entry(
    index = 659,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.6e+06, 'm^3/(mol*s)', '+|-', 610000),
        n = 0,
        Ea = (34.339, 'kJ/mol', '+|-', 2.062),
        T0 = (1, 'K'),
        Tmin = (713, 'K'),
        Tmax = (813, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Matchan, M.J.", "Walker, R.W."],
        title = u'The high-temperature oxidation of acetaldehyde',
        journal = "Combust. Flame",
        volume = "15",
        pages = """109""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BAL/MAT109:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 660,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.74e+06, 'm^3/(mol*s)', '*|/', 1.15),
        n = 0,
        Ea = (35.337, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (813, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (74700, 'Pa'),
    ),
    reference = Article(
        authors = ["Liu, M.T.H.", "Laidler, K.J."],
        title = u'Elementary processes in the acetaldehyde pyrolysis',
        journal = "Can. J. Chem.",
        volume = "46",
        pages = """479""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968LIU/LAI479:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Uncertainty: 1.15
Bath gas: He
Excitation technique: Thermal
Analytical technique: Gas chromatography
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 661,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (316000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (28.435, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (400, 'K'),
        Pmin = (20300, 'Pa'),
        Pmax = (20300, 'Pa'),
    ),
    reference = Article(
        authors = ["Kerr, J.A.", "Calvert, J.G."],
        title = u'The formation and decomposition reactions of the acetyl radical and the heat of formation of the acetyl radical',
        journal = "J. Phys. Chem.",
        volume = "69",
        pages = """1022""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965KER/CAL1022:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Bath gas: (CH3N)2
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 662,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (794000, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (31.761, 'kJ/mol', '+|-', 0.956),
        T0 = (1, 'K'),
        Tmin = (395, 'K'),
        Tmax = (447, 'K'),
        Pmin = (4866, 'Pa'),
        Pmax = (5959, 'Pa'),
    ),
    reference = Article(
        authors = ["Birrell, R.N.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VI. The reactions of methyl radicals with aliphatic aldehydes',
        journal = "J. Chem. Soc.",
        pages = """2059""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960BIR/TRO2059:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Uncertainty: 1.26
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 663,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (63100, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (33.424, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (391, 'K'),
        Tmax = (654, 'K'),
        Pmin = (1200, 'Pa'),
        Pmax = (1733, 'Pa'),
    ),
    reference = Article(
        authors = ["Dodd, R.E."],
        title = u'The reaction of methyl radicals with acetaldehyde',
        journal = "Can. J. Chem.",
        volume = "33",
        pages = """699""",
        year = "1955",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1955DOD699:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Bath gas: CH3CHO
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 664,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (41900, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (31.346, 'kJ/mol', '+|-', 1.255),
        T0 = (1, 'K'),
        Tmin = (397, 'K'),
        Tmax = (428, 'K'),
        Pmin = (2013, 'Pa'),
        Pmax = (32100, 'Pa'),
    ),
    reference = Article(
        authors = ["Volman, D.H.", "Brinton, R.K."],
        title = u'Reactions of free radicals with aldehydes. The reactions of methyl and t-butoxy radicals with acetaldehyde and acrolein',
        journal = "J. Chem. Phys.",
        volume = "20",
        pages = """1764""",
        year = "1952",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1952VOL/BRI1764:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Bath gas: CH3CHO
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 665,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (41900, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (31.346, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (397, 'K'),
        Tmax = (429, 'K'),
    ),
    reference = Article(
        authors = ["Brinton, R.K.", "Volman, D.H."],
        title = u'Induced decomposition of acetaldehyde by radicals',
        journal = "J. Chem. Phys.",
        volume = "20",
        pages = """1053""",
        year = "1952",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1952BRI/VOL1053:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Pressure measurement
""",
)

entry(
    index = 666,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (6.31e+06, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (44.732, 'kJ/mol', '+|-', 2.237),
        T0 = (1, 'K'),
        Tmin = (429, 'K'),
        Tmax = (723, 'K'),
    ),
    reference = Article(
        authors = ["Dodd, R.E."],
        title = u'Rate constants in the high temperature photolysis of acetaldehyde',
        journal = "Trans. Faraday Soc.",
        volume = "47",
        pages = """56-62""",
        year = "1951",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1951DOD56-62:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003010/rk00000001.xml
Bath gas: CH3CHO
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 667,
    label = "C2H4O-2 + CH3 <=> CH4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.6e+06, 'm^3/(mol*s)', '+|-', 610000),
        n = 0,
        Ea = (34.339, 'kJ/mol', '+|-', 2.062),
        T0 = (1, 'K'),
        Tmin = (713, 'K'),
        Tmax = (813, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Langford, D.H.", "Matchan, M.J.", "Walker, R.W.", "Yorke, D.A."],
        title = u'The High-Temperature Oxidation of Aldehydes',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """251""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAL/LAN251:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
""",
)

entry(
    index = 668,
    label = "CH4 + C2H3O-2 <=> C2H4O-2 + CH3",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.002171, 'm^3/(mol*s)', '*|/', 5),
        n = 2.88,
        Ea = (89.796, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:20",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003010
Uncertainty: 5.0
""",
)

entry(
    index = 669,
    label = "C2H4O-2 + OH <=> H2O + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.65e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-3.035, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (350, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:54",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003024
Pressure dependence: None reported
""",
)

entry(
    index = 670,
    label = "C2H4O-2 + OH <=> H2O + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.37e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.245, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:129",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003024
""",
)

entry(
    index = 671,
    label = "C2H4O-2 + OH <=> H2O + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.37e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.577, 'kJ/mol', '+|-', 1.68),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (530, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:91",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003024
""",
)

entry(
    index = 672,
    label = "C2H4O-2 + OH <=> H2O + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.61e+06, 'm^3/(mol*s)', '*|/', 1.4),
        n = 0,
        Ea = (-2.079, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.J.", "Molina, M.J."],
        title = u'Chemical Kinetic and Photochemical Data for Use in Stratospheric Modeling: Evaluation No. 11 of the NASA Panel for Data Evaluation',
        journal = "JPL Publication 94-26",
        pages = """1-2""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DEM/SAN:129",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003024
Uncertainty: 1.4
""",
)

entry(
    index = 673,
    label = "C2H4O-2 + OH <=> H2O + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.37e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.577, 'kJ/mol', '+|-', 1.68),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (530, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:87",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003024
""",
)

entry(
    index = 674,
    label = "C2H4O-2 + OH <=> H2O + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.37e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (-2.577, 'kJ/mol', '+|-', 1.68),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (530, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:45",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003024
Uncertainty: 1.26
""",
)

entry(
    index = 675,
    label = "C2H4O-2 + OH <=> H2O + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (-5.438, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (600, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (98700, 'Pa'),
    ),
    reference = Article(
        authors = ["Taylor, P.H.", "Rahman, M.S.", "Arif, M.", "Dellinger, B.", "Marshall, P."],
        title = u'Kinetic and mechanistic studies of the reaction of hydroxyl radicals with acetaldehyde over an extended temperature range',
        journal = "Symp. Int. Combust. Proc.",
        volume = "26",
        pages = """497-504""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996TAY/RAH497-504:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00003024
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003024/rk00000007.xml
Bath gas: He
Pressure dependence: Rate constant is high pressure limit
""",
)

entry(
    index = 676,
    label = "C2H4O-3 + OH <=> H2O + C2H3O-3",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1.55, 'm^3/(mol*s)'),
        n = 2.2,
        Ea = (4.182, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (600, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (98700, 'Pa'),
    ),
    reference = Article(
        authors = ["Taylor, P.H.", "Rahman, M.S.", "Arif, M.", "Dellinger, B.", "Marshall, P."],
        title = u'Kinetic and mechanistic studies of the reaction of hydroxyl radicals with acetaldehyde over an extended temperature range',
        journal = "Symp. Int. Combust. Proc.",
        volume = "26",
        pages = """497-504""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996TAY/RAH497-504:8",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00003025
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003025/rk00000001.xml
Bath gas: He
Pressure dependence: Rate constant is high pressure limit
""",
)

entry(
    index = 677,
    label = "C3H6 + OH <=> H2O + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.54, 'm^3/(mol*s)'),
        n = 2,
        Ea = (3.775, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (460, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics of the gas-phase reactions of OH radicals with alkanes and cycloalkanes',
        journal = "Atmos. Chem. Phys.",
        volume = "3",
        pages = """2233-2307""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003ATK2233-2307:22",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003205
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003205/rk00000001.xml
""",
)

entry(
    index = 678,
    label = "C3H6 + OH <=> H2O + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (4.63e+06, 'm^3/(mol*s)', '+|-', 1.2e+06),
        n = 0,
        Ea = (11.441, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (272, 'K'),
        Tmax = (463, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Wilson, E.W., Jr.", "Sawyer, A.A.", "Sawyer, H.A."],
        title = u'Rates of Reaction for Cyclopropane and Difluoromethoxydifluoromethane with Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """1445-1448""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001WIL/SAW1445-1448:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Relative value normalized by a reference value""",
    longDesc = 
u"""
PrIMe Reaction: r00003205
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Direct photolysis
Time resolution: By end product analysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 679,
    label = "C3H6 + OH <=> H2O + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (4.11e+06, 'm^3/(mol*s)', '+|-', 903000),
        n = 0,
        Ea = (11.1, 'kJ/mol', '+|-', 0.748),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (459, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Wilson, E.W., Jr.", "Sawyer, A.A.", "Sawyer, H.A."],
        title = u'Rates of Reaction for Cyclopropane and Difluoromethoxydifluoromethane with Hydroxyl Radicals',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """1445-1448""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001WIL/SAW1445-1448:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Relative value normalized by a reference value""",
    longDesc = 
u"""
PrIMe Reaction: r00003205
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Direct photolysis
Time resolution: By end product analysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 680,
    label = "C3H6 + OH <=> H2O + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.1e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (10.476, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (423, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Bayes, K.D."],
        title = u'Rate constants for the reactions of hydroxyl radical with several alkanes, cycloakanes, and dimethyl ether',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """2649-2654""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999DEM/BAY2649-2654:9",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003205
Bath gas: Ar
Excitation technique: Direct photolysis
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 681,
    label = "C3H6 + OH <=> H2O + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (70.4, 'm^3/(mol*s)', '+|-', 9.14),
        n = 1.5,
        Ea = (4.332, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (492, 'K'),
        Pmin = (10700, 'Pa'),
        Pmax = (11300, 'Pa'),
    ),
    reference = Article(
        authors = ["Dobe, S.", "Turanyi, T.", "Iogansen, A.A.", "Berces, T."],
        title = u'Rate constants of the reactions of OH radicals with cyclopropane and cyclobutane',
        journal = "Int. J. Chem. Kinet.",
        volume = "24",
        pages = """191-198""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992DOB/TUR191-198:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003205
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 682,
    label = "C3H6 + OH <=> H2O + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.35e+06, 'm^3/(mol*s)', '+|-', 350000),
        n = 0,
        Ea = (9.229, 'kJ/mol', '+|-', 0.461),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (490, 'K'),
        Pmin = (10700, 'Pa'),
        Pmax = (12000, 'Pa'),
    ),
    reference = Article(
        authors = ["Dobe, S.", "Turanyi, T.", "Berces, T.", "Marta, F."],
        title = u'The kinetics of hydroxyl radical reactions with cyclopropane and cyclobutane',
        journal = "Proc. Indian Acad. Sci. (Chem. Sci.)",
        volume = "103",
        pages = """499-503""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991DOB/TUR499-503:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003205
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 683,
    label = "C2H4O + CH3 <=> CH4 + C2H3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.07e+06, 'm^3/(mol*s)', '*|/', 1.41),
        n = 0,
        Ea = (49.471, 'kJ/mol', '+|-', 1.488),
        T0 = (1, 'K'),
        Tmin = (373, 'K'),
        Tmax = (753, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Keen, A.", "Walker, R.W."],
        title = u'Studies of the decomposition of oxirane and of its addition to slowly reacting mixtures of hydrogen and oxygen at 480 C',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "80",
        pages = """435""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984BAL/KEE435:4",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00003225
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003225/rk00000002.xml
Uncertainty: 1.41
Bath gas: N2
""",
)

entry(
    index = 684,
    label = "C2H4O + OH <=> H2O + C2H3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.78e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (15.132, 'kJ/mol', '+|-', 1.962),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (753, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Keen, A.", "Walker, R.W."],
        title = u'Studies of the decomposition of oxirane and of its addition to slowly reacting mixtures of hydrogen and oxygen at 480 C',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "80",
        pages = """435""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984BAL/KEE435:5",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00003226
Bath gas: N2
""",
)

entry(
    index = 685,
    label = "C2H4O + OH <=> H2O + C2H3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.62e+06, 'm^3/(mol*s)', '+|-', 2.4e+06),
        n = 0,
        Ea = (12.139, 'kJ/mol', '+|-', 1.214),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (435, 'K'),
        Pmin = (1300, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Lorenz, K.", "Zellner, R."],
        title = u'Rate constants and vinoxy product yield in the reaction OH + Ethylene Oxide',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "88",
        pages = """1228""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984LOR/ZEL1228:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003226
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 686,
    label = "C2H4O + OH <=> H2O + C2H3O",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.62e+06, 'm^3/(mol*s)', '+|-', 2.4e+06),
        n = 0,
        Ea = (12.139, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (435, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Fritz, B.", "Lorenz, K.", "Steinert, W.", "Zellner, R."],
        title = u'Laboratory kinetic investigations of the tropospheric oxidation of selected industrial emissions',
        journal = "Phys. Chem. Behav. Atmos. Pollut. Proc. Eur. Symp.",
        pages = """192""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982FRI/LOR192:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003226
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003226/rk00000001.xml
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 687,
    label = "C4H10 + H <=> H2 + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:22",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00004630
""",
)

entry(
    index = 688,
    label = "C4H10 + H <=> H2 + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.01e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (29.267, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (853, 'K'),
        Tmax = (953, 'K'),
    ),
    reference = Article(
        authors = ["Parsamyan, N.I.", "Nalbandyan, A.B."],
        title = u'Determination of the rate constants of the reaction of atomic hydrogen with propane and n-butane',
        journal = "Bull. of Acad. of Sci. USSR Div. Chem. Sci. (Engl. Transl.)",
        pages = """724""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968PAR/NAL724:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00004630
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004630/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 689,
    label = "C4H10 + H <=> H2 + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.8e+07, 'm^3/(mol*s)', '+|-', 1.1e+07),
        n = 0,
        Ea = (50.968, 'kJ/mol', '+|-', 5.097),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Nicholas, J.E.", "Vaghijiani, G.L."],
        title = u'Reaction probabilities, cross sections, and threshold energies in the reaction of isotopically pure H atoms and n-butane',
        journal = "J. Chem. Phys.",
        volume = "91",
        pages = """5121-5123""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989NIC/VAG5121-5123:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00004630
""",
)

entry(
    index = 690,
    label = "C4H6 + H <=> H2 + C4H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (63000, 'm^3/(mol*s)'),
        n = 0.7,
        Ea = (25.11, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Weissman, M.A.", "Benson, S.W."],
        title = u'Rate parameters for the reactions of C2H3 and C4H5 with H2 and C2H2',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """4080""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988WEI/BEN4080:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00004785
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004785/rk00000002.xml
""",
)

entry(
    index = 691,
    label = "H2 + C4H5 <=> C4H6 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3980, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (15.465, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Weissman, M.A.", "Benson, S.W."],
        title = u'Rate parameters for the reactions of C2H3 and C4H5 with H2 and C2H2',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """4080""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988WEI/BEN4080:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00004785
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004785/rk00000002.xml
""",
)

entry(
    index = 692,
    label = "H2 + C4H5 <=> C4H6 + H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.51e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (24.694, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1190, 'K'),
        Tmax = (1680, 'K'),
    ),
    reference = Article(
        authors = ["Benson, S.W.", "Haugen, G.R."],
        title = u'Mechanisms for some high-temperature gas-phase reactions of ethylene, acetylene, and butadiene',
        journal = "J. Phys. Chem.",
        volume = "71",
        pages = """1735""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967BEN/HAU1735:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004785
Bath gas: H2
""",
)

entry(
    index = 693,
    label = "C3H6-2 + CH3 <=> CH4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (140000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (36.501, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (296, 'K'),
        Tmax = (770, 'K'),
    ),
    reference = Article(
        authors = ["Kinsman, A.C.", "Roscoe, J.M."],
        title = u'A kinetic analysis of the photolysis of mixtures of acetone and propylene',
        journal = "Int. J. Chem. Kinet.",
        volume = "26",
        pages = """191-200""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994KIN/ROS191-200:4",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
Bath gas: Ar
""",
)

entry(
    index = 694,
    label = "C3H6-2 + CH3 <=> CH4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (2.21e-06, 'm^3/(mol*s)', '*|/', 1.4),
        n = 3.5,
        Ea = (23.779, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:37",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
Uncertainty: 1.4
""",
)

entry(
    index = 695,
    label = "C3H6-2 + CH3 <=> CH4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (140000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (36.833, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (350, 'K'),
        Tmax = (600, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:73",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005661/rk00000002.xml
Uncertainty: 2.0
""",
)

entry(
    index = 696,
    label = "C3H6-2 + CH3 <=> CH4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (160000, 'm^3/(mol*s)', '*|/', 1.32),
        n = 0,
        Ea = (36.916, 'kJ/mol', '+|-', 0.738),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (580, 'K'),
        Pmin = (14700, 'Pa'),
        Pmax = (100000, 'Pa'),
    ),
    reference = Article(
        authors = ["Kinsman, A.C.", "Roscoe, J.M."],
        title = u'A kinetic analysis of the photolysis of mixtures of acetone and propylene',
        journal = "Int. J. Chem. Kinet.",
        volume = "26",
        pages = """191-200""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994KIN/ROS191-200:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
Uncertainty: 1.3200001
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 697,
    label = "C3H6-2 + CH3 <=> CH4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.424, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1800, 'K'),
    ),
    reference = Article(
        authors = ["Hidaka, Y.", "Nakamura, T.", "Tanaka, H.", "Jinno, A.", "Kawano, H."],
        title = u'Shock tube and modeling study of propene pyrolysis',
        journal = "Int. J. Chem. Kinet.",
        volume = "24",
        pages = """761-780""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992HID/NAK761-780:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
""",
)

entry(
    index = 698,
    label = "C3H6-2 + CH3 <=> CH4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (107000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (22.283, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (490, 'K'),
        Tmax = (510, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:8",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
""",
)

entry(
    index = 699,
    label = "C3H6-2 + CH3 <=> CH4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (44000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (31.512, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (353, 'K'),
        Tmax = (753, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Keen, A.", "Walker, R.W."],
        title = u'Rate constants for the addition of methyl radicals to propene',
        journal = "J. Chem. Soc. Faraday Trans. 2",
        volume = "83",
        pages = """759""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987BAL/KEE759:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
Bath gas: H2
""",
)

entry(
    index = 700,
    label = "CH4 + C3H5-2 <=> C3H6-2 + CH3",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (3.986e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.4,
        Ea = (97.279, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
Uncertainty: 3.0
""",
)

entry(
    index = 701,
    label = "CH4 + C3H5-2 <=> C3H6-2 + CH3",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (490000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (93.954, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (790, 'K'),
        Tmax = (810, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005661
""",
)

entry(
    index = 702,
    label = "C3H6-2 + OH <=> H2O + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (3.12, 'm^3/(mol*s)', '*|/', 1.2),
        n = 2,
        Ea = (-1.247, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:53",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005688
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005688/rk00000002.xml
Uncertainty: 1.2
""",
)

entry(
    index = 703,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.55e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (49.388, 'kJ/mol', '+|-', 0.989),
        T0 = (1, 'K'),
        Tmin = (373, 'K'),
        Tmax = (935, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (107000, 'Pa'),
    ),
    reference = Article(
        authors = ["Batt, L.", "Alvarado-Salinas, G.", "Reid, I.A.B.", "Robinson, C.", "Smith, D.B."],
        title = u'The Pyrolysis of Dimethyl Ether and Formaldehyde',
        journal = "Symp. Int. Combust. Proc.",
        volume = "19",
        pages = """81""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982BAT/ALV81:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
Uncertainty: 1.26
Bath gas: (CH3)2O
""",
)

entry(
    index = 704,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.68e-05, 'm^3/(mol*s)'),
        n = 3.78,
        Ea = (40.296, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (1350, 'K'),
    ),
    reference = Article(
        authors = ["Zhao, Z.", "Chaos, M.", "Kazakov, A.", "Dryer, F.L."],
        title = u'Thermal decomposition reaction and a comprehensive kinetic model of dimethyl ether',
        journal = "Int. J. Chem. Kinet.",
        volume = "40",
        pages = """1-18""",
        year = "2008",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2008ZHA/CHA1-18:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
Experimental procedure: Stirred flow reactor(PSR etc.)
Time resolution: In real time
Analytical technique: Fourier transform (FTIR)
""",
)

entry(
    index = 705,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (8e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (52.3, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (900, 'K'),
        Tmax = (1900, 'K'),
        Pmin = (84100, 'Pa'),
        Pmax = (294000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hidaka, Y.", "Sato, K.", "Yamane, M."],
        title = u'High-temperature pyrolysis of dimethyl ether in shock waves',
        journal = "Combust. Flame",
        volume = "123",
        pages = """1-22""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000HID/SAT1-22:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
Experimental procedure: Shock tube
Time resolution: In real time
Analytical technique: Vis-UV absorption

The high-temperature pyrolysis of dimethyl ether (DME) was studied behind reflected shock waves using single-pulse (reaction time between 1.3 and 2.9 ms), time-resolved IR absorption (3.39 mm), IR emission (4.24mm), and UV absorption (216 nm) methods. The studies were done using DME-Ar, DME-H2-Ar, DME-CO-Ar and DME-CH2O-Ar mixtures. From a computer simulation, a 94-reaction mechanism that could explain all exp. data was constructed.
""",
)

entry(
    index = 706,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (200000, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (39.743, 'kJ/mol', '+|-', 0.795),
        T0 = (1, 'K'),
        Tmin = (373, 'K'),
        Tmax = (473, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (107000, 'Pa'),
    ),
    reference = Article(
        authors = ["Batt, L.", "Alvarado-Salinas, G.", "Reid, I.A.B.", "Robinson, C.", "Smith, D.B."],
        title = u'The Pyrolysis of Dimethyl Ether and Formaldehyde',
        journal = "Symp. Int. Combust. Proc.",
        volume = "19",
        pages = """81""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982BAT/ALV81:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
Uncertainty: 1.26
Bath gas: (CH3)2O
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 707,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.16e+07, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (63.024, 'kJ/mol', '+|-', 6.926),
        T0 = (1, 'K'),
        Tmin = (782, 'K'),
        Tmax = (936, 'K'),
        Pmin = (3333, 'Pa'),
        Pmax = (52700, 'Pa'),
    ),
    reference = Article(
        authors = ["Pacey, P.D."],
        title = u'The Initial Stages of the Pyrolysis of Dimethyl Ether',
        journal = "Can. J. Chem.",
        volume = "53",
        pages = """2742""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975PAC2742:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
Uncertainty: 2.51
Bath gas: (CH3)2O
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 708,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (417000, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (41.822, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (408, 'K'),
        Tmax = (523, 'K'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Gray, P.", "Herod, A.A."],
        title = u'Methyl and trifluoromethyl radical attack on ethers',
        journal = "Can. J. Chem.",
        volume = "47",
        pages = """1347""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969ART/GRA1347:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
Uncertainty: 1.2
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 709,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (417000, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (41.822, 'kJ/mol', '+|-', 0.84),
        T0 = (1, 'K'),
        Tmin = (408, 'K'),
        Tmax = (523, 'K'),
    ),
    reference = Article(
        authors = ["Gray, P.", "Herod, A.A."],
        title = u'Methyl radical reactions with isopropanol and methanol, their ethers and their deuterated derivatives',
        journal = "Trans. Faraday Soc.",
        volume = "64",
        pages = """2723""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968GRA/HER2723:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
Uncertainty: 1.2
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 710,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (110000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.327, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (473, 'K'),
        Tmax = (573, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (40000, 'Pa'),
    ),
    reference = Article(
        authors = ["Loucks, L.F."],
        title = u'Mercury-photosensitized decomposition of dimethyl ether. Part I',
        journal = "Can. J. Chem.",
        volume = "45",
        pages = """2775""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967LOU2775:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
Bath gas: (CH3)2O
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 711,
    label = "C2H6O-4 + CH3 <=> CH4 + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1400, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (37.665, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (493, 'K'),
    ),
    reference = Article(
        authors = ["Gomer, R.", "Kistiakowsky, G.B."],
        title = u'The rate constant of ethane formation from methyl radicals',
        journal = "J. Chem. Phys.",
        volume = "19",
        pages = """85""",
        year = "1951",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1951GOM/KIS85:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005793
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005793/rk00000001.xml
""",
)

entry(
    index = 712,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.276, 'm^3/(mol*s)', '+|-', 0.0126),
        n = 2.46,
        Ea = (-3.958, 'kJ/mol', '+|-', 0.116),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (650, 'K'),
    ),
    reference = Article(
        authors = ["Bonard, A.", "Daele, V.", "Delfau, J.-L", "Vovelle, C."],
        title = u'Kinetics of OH Radical Reactions with Methane in the Temperature Range 295-660 K and with Dimethyl Ether and Methyl-tert-butyl Ether in the Temperature Range 295-618 K',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """4384-4389""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002BON/DAE4384-4389:3",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
""",
)

entry(
    index = 713,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.43e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (1.788, 'kJ/mol', '+|-', 0.831),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:76",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
Pressure dependence: None reported
""",
)

entry(
    index = 714,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (6.03e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.076, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (450, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:132",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
""",
)

entry(
    index = 715,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (6.27e+06, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (3.093, 'kJ/mol', '+|-', 0.279),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (442, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics and mechanisms of the gas-phase reactions of the hydroxyl radical with organic compounds under atmospheric conditions',
        journal = "Chem. Rev.",
        volume = "86",
        pages = """69""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK69:81",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
Uncertainty: 1.2
""",
)

entry(
    index = 716,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.0182, 'm^3/(mol*s)', '+|-', 0.000602),
        n = 2.85,
        Ea = (-5.138, 'kJ/mol', '+|-', 0.116),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (618, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Bonard, A.", "Daele, V.", "Delfau, J.-L", "Vovelle, C."],
        title = u'Kinetics of OH Radical Reactions with Methane in the Temperature Range 295-660 K and with Dimethyl Ether and Methyl-tert-butyl Ether in the Temperature Range 295-618 K',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """4384-4389""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002BON/DAE4384-4389:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 717,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (9.1e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (4.124, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (263, 'K'),
        Tmax = (361, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Bayes, K.D."],
        title = u'Rate constants for the reactions of hydroxyl radical with several alkanes, cycloakanes, and dimethyl ether',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """2649-2654""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999DEM/BAY2649-2654:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
Bath gas: Ar
Excitation technique: Direct photolysis
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 718,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (6.32, 'm^3/(mol*s)', '+|-', 0.631),
        n = 2,
        Ea = (-2.727, 'kJ/mol', '+|-', 0.273),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (650, 'K'),
        Pmin = (98700, 'Pa'),
        Pmax = (98700, 'Pa'),
    ),
    reference = Article(
        authors = ["Arif, M.", "Dellinger, B.", "Taylor, P.H."],
        title = u'Rate coefficients of hydroxyl radical reaction with dimethyl ether and methyl tert-butyl ether over an extended temperature range',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """2436-2441""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ARI/DEL2436-2441:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 719,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.79e+06, 'm^3/(mol*s)', '+|-', 76000),
        n = 0,
        Ea = (1.946, 'kJ/mol', '+|-', 0.292),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (372, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Mellouki, A.", "Teton, S.", "LeBras, G."],
        title = u'Kinetics of OH radical reactions with a series of ethers',
        journal = "Int. J. Chem. Kinet.",
        volume = "27",
        pages = """791-805""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995MEL/TET791-805:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 720,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (4.04e+06, 'm^3/(mol*s)', '+|-', 890000),
        n = 0,
        Ea = (2.494, 'kJ/mol', '+|-', 0.574),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (440, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Wallington, T.J.", "Liu, R.", "Dagaut, P.", "Kurylo, M.J."],
        title = u'The gas phase reactions of hydroxyl radicals with a series of aliphatic ethers over the temperature range 240-440 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "20",
        pages = """41""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988WAL/LIU41:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 721,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (7.76e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.218, 'kJ/mol', '+|-', 1.255),
        T0 = (1, 'K'),
        Tmin = (299, 'K'),
        Tmax = (427, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Perry, R.A.", "Atkinson, R.", "Pitts, J.N., Jr."],
        title = u'Rate Constants for the Reaction of OH Radicals with Dimethyl Ether and Vinyl Methyl Ether over the Temperature Range 299-427oK',
        journal = "J. Chem. Phys.",
        volume = "67",
        pages = """611""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977PER/ATK611:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005795
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005795/rk00000001.xml
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 722,
    label = "C2H6O-4 + OH <=> H2O + C2H5O-4",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.0201, 'm^3/(mol*s)'),
        n = 2.91,
        Ea = (3.406, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Wu, J.Y.", "Liu, J.Y.", "Li, Z.S.", "Sun, C.C."],
        title = u'Dual-level direct dynamics studies for the reactions of CH3OCH3 and CF3OCH3 with the OH radical',
        journal = "J. Chem. Phys.",
        volume = "118",
        pages = """10986-10995""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003WU/LIU10986-10995:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00005795

The reactions of CH3OCH3 + OH and CF3OCH3 + OH via two hydrogen abstractionchannels are investigated theoretically using the dual-level direct dynamics approach. The minimumenergy path calculation is carried out at the MP2/6-311G(d,p) level, and energetic information isfurther refined by the G3 theory. For each reaction hydrogen abstraction is favored for theout-of-plane hydrogen, while the abstraction from the in-plane hydrogen is a minor channel.Hydrogen-bonded complexes are present on the reactants and products sides of the primary channel, indicating that the reactions may proceed via an indirect mechanism. By means of variational transition state theory with interpolated single-point energies method the dynamic results of all channels are obtained, and the small-curvature tunneling is included.
""",
)

entry(
    index = 723,
    label = "H2 + C4H9-2 <=> C4H10-2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2e-08, 'm^3/(mol*s)', '*|/', 3),
        n = 4.24,
        Ea = (37.498, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:57",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009456
Uncertainty: 3.0
""",
)

entry(
    index = 724,
    label = "H2 + C4H9-2 <=> C4H10-2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.3e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (71.006, 'kJ/mol', '+|-', 5.679),
        T0 = (1, 'K'),
        Tmin = (713, 'K'),
        Tmax = (813, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Evans, G.A.", "Walker, R.W."],
        title = u'Reaction of t-Butyl Radicals with Hydrogen and with Oxygen',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """1458""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979EVA/WAL1458:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00009456
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009456/rk00000001.xml
Bath gas: N2
""",
)

entry(
    index = 725,
    label = "C4H10-2 + H <=> H2 + C4H9-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.602, 'm^3/(mol*s)', '*|/', 3),
        n = 2.4,
        Ea = (10.809, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:49",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009456
Uncertainty: 3.0
""",
)

entry(
    index = 726,
    label = "C4H10-2 + H <=> H2 + C4H9-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.11e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (25.193, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:9",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009456
""",
)

entry(
    index = 727,
    label = "C4H10-2 + H <=> H2 + C4H9-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.71e+07, 'm^3/(mol*s)', '*|/', 1.38),
        n = 0,
        Ea = (29.516, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'The Use of the H2 + O2 Reaction in Determining the Velocity Constants of Elementary Reactions in Hydrocarbon Oxidation',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """291""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAK/BAL291:11",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009456
Uncertainty: 1.38
""",
)

entry(
    index = 728,
    label = "C4H10-2 + H <=> H2 + C4H9-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.71e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (29.267, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (730, 'K'),
        Tmax = (780, 'K'),
        Pmin = (33300, 'Pa'),
        Pmax = (89300, 'Pa'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'Addition of C3H8, n- and i-C4H10 to slowly reacting mixtures of hydrogen and oxygen at 480\xb0C',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """2812""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BAK/BAL2812:12",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009456
Bath gas: N2
""",
)

entry(
    index = 729,
    label = "H2 + C4H9-3 <=> C4H10-3 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.98e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (74.082, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (773, 'K'),
        Tmax = (794, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (80000, 'Pa'),
    ),
    reference = Article(
        authors = ["Collongues, C.", "Richard, C.", "Martin, R."],
        title = u'Thermal reaction of hydrogen-butene-2-cis mixtures at 500\xb0C: Hydrogenation, hydrogenolysis, and thermal reaction of the olefin',
        journal = "Int. J. Chem. Kinet.",
        volume = "15",
        pages = """5""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COL/RIC5:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009474
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009474/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 730,
    label = "C4H10-3 + H <=> H2 + C4H9-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.96e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.258, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:21",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009474
""",
)

entry(
    index = 731,
    label = "C4H10-3 + H <=> H2 + C4H9-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.2e+08, 'm^3/(mol*s)', '*|/', 1.38),
        n = 0,
        Ea = (35.337, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'The Use of the H2 + O2 Reaction in Determining the Velocity Constants of Elementary Reactions in Hydrocarbon Oxidation',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """291""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAK/BAL291:12",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009474
Uncertainty: 1.38
""",
)

entry(
    index = 732,
    label = "C4H10-3 + H <=> H2 + C4H9-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.12e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (35.17, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (730, 'K'),
        Tmax = (780, 'K'),
        Pmin = (33300, 'Pa'),
        Pmax = (89300, 'Pa'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'Addition of C3H8, n- and i-C4H10 to slowly reacting mixtures of hydrogen and oxygen at 480\xb0C',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """2812""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BAK/BAL2812:17",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009474
Bath gas: N2
""",
)

entry(
    index = 733,
    label = "C4H10-3 + H <=> H2 + C4H9-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.1e+07, 'm^3/(mol*s)', '+|-', 6.3e+06),
        n = 0,
        Ea = (33.008, 'kJ/mol', '+|-', 4.947),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Nicholas, J.E.", "Vaghijiani, G.L."],
        title = u'Reaction probabilities, cross sections, and threshold energies in the reaction of isotopically pure H atoms and n-butane',
        journal = "J. Chem. Phys.",
        volume = "91",
        pages = """5121-5123""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989NIC/VAG5121-5123:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00009474
""",
)

entry(
    index = 734,
    label = "H2 + C4H9-4 <=> C4H10-4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.002831, 'm^3/(mol*s)', '*|/', 3),
        n = 2.72,
        Ea = (40.99, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:58",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009496
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009496/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 735,
    label = "H2 + C4H9-4 <=> C4H10-4 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (501000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (47.309, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (763, 'K'),
        Tmax = (813, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Douhou, S.", "Perrin, D.", "Martin, R."],
        title = u"Etude cinetique et modelisation de la reaction thermique de l'isobutene vers 800 K. II. Isobutene en presence d'hydrogene",
        journal = "J. Chim. Phys.",
        volume = "91",
        pages = """1628-1647""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DOU/PER1628-1647:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009496
Bath gas: iso-C4H8
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 736,
    label = "C4H10-4 + H <=> H2 + C4H9-4",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.81, 'm^3/(mol*s)', '*|/', 3),
        n = 2.54,
        Ea = (28.269, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:50",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00009496
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009496/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 737,
    label = "C4H10-4 + H <=> H2 + C4H9-4",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.98e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:10",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00009496
""",
)

entry(
    index = 738,
    label = "H2 + C4H7 <=> C4H8 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.01e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (90.628, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (763, 'K'),
        Tmax = (813, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Douhou, S.", "Perrin, D.", "Martin, R."],
        title = u"Etude cinetique et modelisation de la reaction thermique de l'isobutene vers 800 K. II. Isobutene en presence d'hydrogene",
        journal = "J. Chim. Phys.",
        volume = "91",
        pages = """1628-1647""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DOU/PER1628-1647:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009557
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009557/rk00000001.xml
Bath gas: iso-C4H8
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 739,
    label = "C4H8 + H <=> H2 + C4H7",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.72e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.424, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1180, 'K'),
        Pmin = (253000, 'Pa'),
        Pmax = (304000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Walker, J.A."],
        title = u'Mechanism and rate constants for the reactions of hydrogen atoms with isobutene at high temperatures',
        journal = "Symp. Int. Combust. Proc.",
        volume = "22",
        pages = """1015-1022""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989TSA/WAL1015-1022:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009557
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 740,
    label = "C2H2 + O2 <=> HO2-2 + C2H",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.21e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (311.793, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:72",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010391
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010391/rk00000002.xml
Uncertainty: 5.0
""",
)

entry(
    index = 743,
    label = "CH3O-2 + H2O2 <=> CH4O-2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3010, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (10.809, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:45",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011302
Uncertainty: 5.0
""",
)

entry(
    index = 744,
    label = "CH3O-2 + H2O2 <=> CH4O-2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (269000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.004, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1800, 'K'),
        Pmin = (20300, 'Pa'),
        Pmax = (507000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tsuboi, T.", "Hashimoto, K."],
        title = u'Shock Tube Study on Homogeneous Thermal Oxidation of Methanol',
        journal = "Combust. Flame",
        volume = "42",
        pages = """61""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981TSU/HAS61:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011302
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011302/rk00000001.xml
Bath gas: Ar
""",
)

entry(
    index = 745,
    label = "CH4O-2 + HO2 <=> CH3O-2 + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (96400, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (52.631, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:14",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011302
Uncertainty: 5.0
""",
)

entry(
    index = 746,
    label = "CH4O-2 + HO2 <=> CH3O-2 + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.988, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1800, 'K'),
        Pmin = (20300, 'Pa'),
        Pmax = (507000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tsuboi, T.", "Hashimoto, K."],
        title = u'Shock Tube Study on Homogeneous Thermal Oxidation of Methanol',
        journal = "Combust. Flame",
        volume = "42",
        pages = """61""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981TSU/HAS61:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011302
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011302/rk00000001.xml
Bath gas: Ar
""",
)

entry(
    index = 747,
    label = "CHO + H2O2 <=> CH2O + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (102000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (29.018, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:182",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011339/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 748,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.01e+06, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (54.709, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
Uncertainty: 3.1600001
""",
)

entry(
    index = 749,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.99e+06, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (48.806, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:7",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011339/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 750,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (33.424, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (800, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
Uncertainty: 10.0
""",
)

entry(
    index = 751,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0411, 'm^3/(mol*s)'),
        n = 2.5,
        Ea = (42.703, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (540, 'K'),
        Tmax = (1600, 'K'),
    ),
    reference = Article(
        authors = ["Eiteneer, B.", "Yu, C.-L.", "Goldenberg, M.", "Frenklach, M."],
        title = u'Determination of rate coefficients for reactions of formaldehyde pyrolysis and oxidation in the gas phase',
        journal = "J. Phys. Chem. A",
        volume = "102",
        pages = """5196-5205""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998EIT/YU5196-5205:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
""",
)

entry(
    index = 752,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (211000, 'm^3/(mol*s)', '+|-', 160000),
        n = 0,
        Ea = (38.413, 'kJ/mol', '+|-', 3.068),
        T0 = (1, 'K'),
        Tmin = (541, 'K'),
        Tmax = (773, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Jemi-Alade, A.A.", "Lightfoot, P.D.", "Lesclaux, R."],
        title = u'A flash photolysis study of the HO2 + HCHO \u2192\x92 H2O2 + HCO reaction between 541 and 656 K',
        journal = "Chem. Phys. Lett.",
        volume = "195",
        pages = """25-30""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992JEM/LIG25-30:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 753,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (550000, 'm^3/(mol*s)', '+|-', 300000),
        n = 0,
        Ea = (37.581, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (943, 'K'),
        Tmax = (995, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hochgreb, S.", "Yetter, R.A.", "Dryer, F.L."],
        title = u'The oxidation of CH2O in the intermediate temperature range (943-995 K)',
        journal = "Symp. Int. Combust. Proc.",
        volume = "23",
        pages = """171-177""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991HOC/YET171-177:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 754,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.15e+07, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (43.485, 'kJ/mol', '+|-', 12.638),
        T0 = (1, 'K'),
        Tmin = (773, 'K'),
        Tmax = (973, 'K'),
    ),
    reference = Article(
        authors = ["Vardanyan, I.A.", "Sachyan, G.A.", "Nalbandyan, A.B."],
        title = u'Kinetics and Mechanism of Formaldehyde Oxidation',
        journal = "Combust. Flame",
        volume = "17",
        pages = """315""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971VAR/SAC315:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
Uncertainty: 2.51
Bath gas: CH2O
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 755,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0188, 'm^3/(mol*s)'),
        n = 2.7,
        Ea = (48.2, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (3000, 'K'),
    ),
    reference = Article(
        authors = ["Li, Q.S.", "Zhang, X.", "Zhang, S.W."],
        title = u'Direct dynamics study on the hydrogen abstraction reaction CH2O+HO2\xabrarrow\xbb CHO+H2O2',
        journal = "J. Phys. Chem. A",
        volume = "109",
        pages = """12027-12035""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005LI/ZHA12027-12035:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
Pressure dependence: Rate constant is pressure independent

Reaction potential energy surface was studied using quantum chemistry and rate constants were calculated using variational transition state theory with tunneling correction. The article incorrectly reports the units of the preexponential factor as cm3mol-1s-1. The correct units are cm3molecule-1s-1, as can be seen from the rate constant values given in tables and plots.
""",
)

entry(
    index = 756,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.15e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.485, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (825, 'K'),
        Tmax = (875, 'K'),
    ),
    reference = Article(
        authors = ["Vardanyan, I.A.", "Sachyan, G.A.", "Philiposyan, A.G.", "Nalbandyan, A.B."],
        title = u'Kinetics and mechanism of formaldehyde oxidation - II',
        journal = "Combust. Flame",
        volume = "22",
        pages = """153-159""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974VAR/SAC153-159:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
""",
)

entry(
    index = 757,
    label = "CH2O + HO2 <=> CHO + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.822, 'kJ/mol', '+|-', 8.398),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Langford, D.H.", "Matchan, M.J.", "Walker, R.W.", "Yorke, D.A."],
        title = u'The High-Temperature Oxidation of Aldehydes',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """251""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAL/LAN251:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011339
""",
)

entry(
    index = 758,
    label = "C2H3 + H2O2 <=> C2H4 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (12100, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (-2.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:198",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011429
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011429/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 759,
    label = "CH4O2 + OH <=> H2O + CH3O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.14e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-1.58, 'kJ/mol', '+|-', 1.247),
        T0 = (1, 'K'),
        Tmin = (220, 'K'),
        Tmax = (430, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:79",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011638
Pressure dependence: None reported
""",
)

entry(
    index = 760,
    label = "CH4O2 + OH <=> H2O + CH3O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.15e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-1.58, 'kJ/mol', '+|-', 1.247),
        T0 = (1, 'K'),
        Tmin = (220, 'K'),
        Tmax = (430, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:242",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011638
""",
)

entry(
    index = 761,
    label = "CH4O2 + OH <=> H2O + CH3O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (723000, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (-1.081, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:162",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011638
Uncertainty: 2.51
""",
)

entry(
    index = 762,
    label = "CH4O2 + OH <=> H2O + CH3O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.15e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-1.58, 'kJ/mol', '+|-', 1.247),
        T0 = (1, 'K'),
        Tmin = (220, 'K'),
        Tmax = (430, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:211",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011638
""",
)

entry(
    index = 763,
    label = "CH4O2 + OH <=> H2O + CH3O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.07e+06, 'm^3/(mol*s)', '+|-', 150000),
        n = 0,
        Ea = (-1.829, 'kJ/mol', '+|-', 0.183),
        T0 = (1, 'K'),
        Tmin = (203, 'K'),
        Tmax = (423, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Vaghjiani, G.L.", "Ravishankara, A.R.", "Cohen, N."],
        title = u'Kinetics and mechanism of OH reaction with CH3OOH',
        journal = "J. Phys. Chem.",
        volume = "93",
        pages = """1948-1959""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989VAG/RAV1948-1959:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011638
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011638/rk00000002.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 764,
    label = "H2O2 + C2H5 <=> C2H6 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8730, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (4.074, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:237",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013691/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 765,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.32e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (85.639, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:36",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
Uncertainty: 2.0
""",
)

entry(
    index = 766,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (295000, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (62.525, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:36",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013691/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 767,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6e+06, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (81.232, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:19",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
Uncertainty: 3.1600001
""",
)

entry(
    index = 768,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (58.534, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
Uncertainty: 10.0
""",
)

entry(
    index = 769,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.7e+07, 'm^3/(mol*s)', '*|/', 1.45),
        n = 0,
        Ea = (85.639, 'kJ/mol', '+|-', 2.569),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (793, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (2000, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Dean, C.E.", "(the late) Honeyman, M.R.", "Walker, R.W."],
        title = u'Arrhenius parameters for the reaction HO2 + C2H6 \u2192\x92 C2H5 + H2O2 over the temperature range 400-500 \xb0C',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "82",
        pages = """89""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986BAL/DEA89:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
Uncertainty: 1.45
Bath gas: O2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 770,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (54.377, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (318, 'K'),
        Tmax = (386, 'K'),
        Pmin = (39500, 'Pa'),
        Pmax = (58900, 'Pa'),
    ),
    reference = Article(
        authors = ["Knox, J.H.", "Wells, C.H.J."],
        title = u'Slow oxidation of ethane and ethylene in the gas phase. Part 1. General features at 362\xb0C',
        journal = "Trans. Faraday Soc.",
        volume = "59",
        pages = """2786-2800""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963KNO/WEL2786-2800:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
Bath gas: C2H6
Excitation technique: Thermal
Analytical technique: Pressure measurement
""",
)

entry(
    index = 771,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.087, 'm^3/(mol*s)'),
        n = 2.69,
        Ea = (79.078, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Carstensen, H.H.", "Dean, A.M."],
        title = u'Rate constants for the abstraction reactions RO2 + C2H6; R = H, CH3, and C2H5',
        journal = "Proc. Combust. Inst.",
        volume = "30",
        pages = """995-1003""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005CAR/DEA995-1003:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
Pressure dependence: Rate constant is pressure independent
""",
)

entry(
    index = 772,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000261, 'm^3/(mol*s)'),
        n = 3.37,
        Ea = (66.526, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Carstensen, H.H.", "Dean, A.M."],
        title = u'Rate constants for the abstraction reactions RO2 + C2H6; R = H, CH3, and C2H5',
        journal = "Proc. Combust. Inst.",
        volume = "30",
        pages = """995-1003""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005CAR/DEA995-1003:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
Pressure dependence: Rate constant is pressure independent

Reaction potential energy surface was studied using quantum chemistry and rate constants were calculated using variational transition state theory with tunneling correction.
""",
)

entry(
    index = 773,
    label = "C2H6 + HO2 <=> H2O2 + C2H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (316000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (54.377, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (873, 'K'),
        Tmax = (903, 'K'),
        Pmin = (111000, 'Pa'),
        Pmax = (111000, 'Pa'),
    ),
    reference = Article(
        authors = ["Sampson, R.J."],
        title = u'976. The reaction between ethane and oxygen at 600-630\xb0',
        journal = "J. Chem. Soc.",
        pages = """5095-5106""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963SAM5095-5106:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00013691
Bath gas: N2
""",
)

entry(
    index = 774,
    label = "H2O2 + O2 <=> HO2-2 + HO2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.42e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (166.289, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:234",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 775,
    label = "C3H8O-2 + H <=> H2 + C3H7O-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (2.77e+07, 'm^3/(mol*s)', '+|-', 6.1e+06),
        n = 0,
        Ea = (27.188, 'kJ/mol', '+|-', 2.178),
        T0 = (1, 'K'),
        Tmin = (843, 'K'),
        Tmax = (963, 'K'),
        Pmin = (1107, 'Pa'),
        Pmax = (2200, 'Pa'),
    ),
    reference = Article(
        authors = ["Oganesyan, K.T.", "Nalbandyan, A.B."],
        title = u'Determination of rate constants of reactions of atomic hydrogen with propyl and butyl alcohols',
        journal = "Izv. Akad. Nauk Arm. SSR, Khim. Nauki",
        volume = "18",
        pages = """237""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965OGA/NAL237:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001845
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001845/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Pressure measurement
""",
)

entry(
    index = 776,
    label = "C3H6 + OH <=> H2O + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (39100, 'm^3/(mol*s)', '+|-', 2770),
        n = 0,
        Ea = (0, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (298, 'K'),
    ),
    reference = Article(
        authors = ["Clarke, J.S.", "Kroll, J.H.", "Donahue, N.M.", "Anderson, J.G."],
        title = u'Testing frontier orbital control: kinetics of OH with ethane, propane, and cyclopropane from 180 to 360K',
        journal = "J. Phys. Chem. A",
        volume = "102",
        pages = """9847-9857""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998CLA/KRO9847-9857:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003205
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003205/rk00000006.xml
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Fourier transform (FTIR)

All data sets were fit to a modified Arrhenius expression k=(1.250.06)x10-14e(-73314/T)/T/(1-e(-1.44x280/T))2/(1-e(-1.44x500/T)) cm3molecule-1s-1at 200-360 K.
""",
)

entry(
    index = 777,
    label = "C2H4O2 + H <=> H2 + C2H3O2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (14.2, 'm^3/(mol*s)'),
        n = 2.05,
        Ea = (37.17, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Good, D.A.", "Francisco, LJ.S."],
        title = u'A Computational Study of the Reaction of Methyl Formate with \xb7H and \xb7CH3 Radicals',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """1733-1738""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GOO/FRA1733-1738:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00004969
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004969/rk00000001.xml

The authors used ab initio molecular orbital theory to examine the kinetics and mechanism of the reaction of hydrogen and methyl radicals with methyl formate. Structures, energies, and molecular properties of the species and transition-states are reported. The branching ratios for abstraction of the hydrogens are calculated. Abstraction of the carbonyl hydrogen of methyl formate is significantly favored (85% for H atom) at 298 K, becoming relatively less favored as the temperature increases. Results are compared with previous calculations and experiments on the reaction OH with methyl formate.

The listed rate expression is a fit derived at NIST to the calculated rate constants reported by the authors at 298, 600, 1000, 1500, 2000, and 2500 K. The fitted expression reproduces the calculated rates within 2.5%.
""",
)

entry(
    index = 778,
    label = "C2H4O2-2 + H <=> H2 + C2H3O2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (27.2, 'm^3/(mol*s)'),
        n = 1.94,
        Ea = (32.97, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Good, D.A.", "Francisco, LJ.S."],
        title = u'A Computational Study of the Reaction of Methyl Formate with \xb7H and \xb7CH3 Radicals',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """1733-1738""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GOO/FRA1733-1738:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00004970
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004970/rk00000001.xml

The authors used ab initio molecular orbital theory to examine the kinetics and mechanism of the reaction of hydrogen and methyl radicals with methyl formate. Structures, energies, and molecular properties of the species and transition-states are reported. The branching ratios for abstraction of the hydrogens are calculated. Abstraction of the carbonyl hydrogen of methyl formate is significantly favored (85% for H atom) at 298 K, becoming relatively less favored as the temperature increases. Results are compared with previous calculations and experiments on the reaction OH with methyl formate.

The listed rate expression is a fit derived at NIST to the calculated rate constants reported by the authors at 298, 600, 1000, 1500, 2000, and 2500 K. The fitted expression reproduces the calculated rates within 2.5%.
""",
)

entry(
    index = 779,
    label = "C3H6-3 + OH <=> H2O + C3H5-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.6e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (0, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (723, 'K'),
        Tmax = (723, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Hisham, M.W.M.", "Walker, R.W."],
        title = u'Elementary reactions involved in the oxidation of propene: Arrhenius parameters for the reaction HO2 + C3H6 = C3H6O + OH',
        journal = "Symp. Int. Combust. Proc.",
        volume = "20",
        pages = """743""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985BAL/HIS743:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005689
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005689/rk00000002.xml
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 780,
    label = "C3H6-3 + OH <=> H2O + C3H5-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.14, 'm^3/(mol*s)', '*|/', 2),
        n = 2,
        Ea = (11.64, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:54",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005689
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005689/rk00000003.xml
Uncertainty: 2.0
""",
)

entry(
    index = 781,
    label = "C3H6-4 + OH <=> H2O + C3H5-4",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.11, 'm^3/(mol*s)'),
        n = 2,
        Ea = (6.07, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:55",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005691
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005691/rk00000001.xml
""",
)

entry(
    index = 782,
    label = "H2 + C4H7-2 <=> C4H8-2 + H",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.26e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (101.437, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (773, 'K'),
        Tmax = (794, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (80000, 'Pa'),
    ),
    reference = Article(
        authors = ["Collongues, C.", "Richard, C.", "Martin, R."],
        title = u'Thermal reaction of hydrogen-butene-2-cis mixtures at 500\xb0C: Hydrogenation, hydrogenolysis, and thermal reaction of the olefin',
        journal = "Int. J. Chem. Kinet.",
        volume = "15",
        pages = """5""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COL/RIC5:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009579
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009579/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 783,
    label = "CH4O2-2 + OH <=> H2O + CH3O2-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1.08e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (-1.829, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:163",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011639
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011639/rk00000006.xml
Uncertainty: 2.0
""",
)

entry(
    index = 784,
    label = "CH4O2-2 + OH <=> H2O + CH3O2-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (603000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-1.58, 'kJ/mol', '+|-', 1.247),
        T0 = (1, 'K'),
        Tmin = (220, 'K'),
        Tmax = (430, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:243",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011639
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011639/rk00000007.xml
""",
)

entry(
    index = 785,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (4.22e+08, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (50.136, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (850, 'K'),
        Tmax = (1250, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Frank, P.", "Hayman, G.", "Just, Th.", "Kerr, J.A.", "Murrells, T.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combusion modelling. Supplement I',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "23",
        pages = """847-1033""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994BAU/COB847-1033:90",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000003.xml
Uncertainty: 2.51
""",
)

entry(
    index = 786,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (4.182, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:11",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000006.xml
Uncertainty: 2.0
""",
)

entry(
    index = 787,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (22900, 'm^3/(mol*s)', '+|-', 8500),
        n = 0,
        Ea = (-10.393, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (339, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Cox, R.A.", "Burrows, J.P."],
        title = u'Kinetics and Mechanism of the Disproportionation of HO2 in the Gas Phase',
        journal = "J. Phys. Chem.",
        volume = "83",
        pages = """2560""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979COX/BUR2560:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000010.xml
Bath gas: O2
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 788,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (68700, 'm^3/(mol*s)', '+|-', 9600),
        n = 0,
        Ea = (-8.813, 'kJ/mol', '+|-', 0.352),
        T0 = (1, 'K'),
        Tmin = (276, 'K'),
        Tmax = (400, 'K'),
        Pmin = (160000, 'Pa'),
        Pmax = (160000, 'Pa'),
    ),
    reference = Article(
        authors = ["Lii, R.-R.", "Gorse, R.A., Jr.", "Sauer, M.C., Jr.", "Gordon, S."],
        title = u'Negative Activation Energy for the Self-Reaction of HO2 in the Gas Phase. Dimerization ofHO2',
        journal = "J. Phys. Chem.",
        volume = "83",
        pages = """1803""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979LII/GOR1803:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000012.xml
Bath gas: H2
Excitation technique: Ultrasonics
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 789,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (53600, 'm^3/(mol*s)', '+|-', 1600),
        n = 0,
        Ea = (-8.813, 'kJ/mol', '+|-', 0.352),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (400, 'K'),
        Pmin = (160000, 'Pa'),
        Pmax = (160000, 'Pa'),
    ),
    reference = Article(
        authors = ["Lii, R.-R.", "Gorse, R.A., Jr.", "Sauer, M.C., Jr.", "Gordon, S."],
        title = u'Temperature Dependence of the Gas-Phase Self-Reaction of HO2 in the Presence of NH3',
        journal = "J. Phys. Chem.",
        volume = "84",
        pages = """813""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980LII/GOR813:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000018.xml
Bath gas: H2
Excitation technique: Chemical activation
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 790,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (46300, 'm^3/(mol*s)', '+|-', 1400),
        n = 0,
        Ea = (-8.481, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (308, 'K'),
        Tmax = (348, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Burrows, J.P.", "Cox, R.a.", "Derwent, R.G."],
        title = u'Modulated Photolysis of the Ozone-Water Vapour System: Kinetics of the Reaction of OH with HO2',
        journal = "J. Photochem.",
        volume = "16",
        pages = """147""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981BUR/COX147:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000019.xml
Bath gas: He
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 791,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (55500, 'm^3/(mol*s)', '+|-', 1100),
        n = 0,
        Ea = (-8.813, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (373, 'K'),
        Pmin = (3333, 'Pa'),
        Pmax = (160000, 'Pa'),
    ),
    reference = Article(
        authors = ["Lii, R.-R.", "Sauer, M.C., Jr.", "Gordon, S."],
        title = u'Temperature Dependence of the Gas-Phase Self-Reaction of HO2 in the Presence of H2O',
        journal = "J. Phys. Chem.",
        volume = "85",
        pages = """2833""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981LII/SAU2833:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000020.xml
Bath gas: H2
Excitation technique: Ultrasonics
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 792,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (249000, 'm^3/(mol*s)', '+|-', 70000),
        n = 0,
        Ea = (-5.238, 'kJ/mol', '+|-', 0.94),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (510, 'K'),
        Pmin = (93300, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Patrick, R.", "Pilling, M.J."],
        title = u'The Temperature Dependence of the HO2 + HO2 Reaction',
        journal = "Chem. Phys. Lett.",
        volume = "91",
        pages = """343""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982PAT/PIL343:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000021.xml
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 793,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (145000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-4.656, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (358, 'K'),
        Pmin = (933, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Thrush, B.A.", "Tyndall, G.S."],
        title = u'The Rate of Reaction between HO2 Radicals at Low Pressures',
        journal = "Chem. Phys. Lett.",
        volume = "92",
        pages = """232""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982THR/TYN232:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000023.xml
Bath gas: O2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: IR absorption
Note: Invalid Ea value uncertainty (8314472.0) found and ignored
""",
)

entry(
    index = 794,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3770, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-18.708, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (241, 'K'),
        Tmax = (417, 'K'),
    ),
    reference = Article(
        authors = ["Mozurkewich, M.", "Benson, S.W."],
        title = u'Self-reaction of HO2 and DO2: Negative temperature dependence and pressure effects',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """787""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985MOZ/BEN787:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""RRK(M) extrapolation""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000028.xml
""",
)

entry(
    index = 795,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (4.182, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Pitz, W.J.", "Westbrook, C.K."],
        title = u'Chemical kinetics of the high pressure oxidation of n-butane and its relation to engine knock',
        journal = "Combust. Flame",
        volume = "63",
        pages = """113-133""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986PIT/WES113-133:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000030.xml
Bath gas: N2
""",
)

entry(
    index = 796,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (121000, 'm^3/(mol*s)', '+|-', 36000),
        n = 0,
        Ea = (-4.947, 'kJ/mol', '+|-', 0.989),
        T0 = (1, 'K'),
        Tmin = (253, 'K'),
        Tmax = (390, 'K'),
        Pmin = (133, 'Pa'),
        Pmax = (800, 'Pa'),
    ),
    reference = Article(
        authors = ["Takacs, G.A.", "Howard, C.J."],
        title = u'Temperature dependence of the reaction HO2 + HO2 at low pressures',
        journal = "J. Phys. Chem.",
        volume = "90",
        pages = """687""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TAK/HOW687:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000031.xml
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Laser magnetic resonance (LMR)
""",
)

entry(
    index = 797,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5550, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-14.135, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (278, 'K'),
        Tmax = (299, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Andersson, B.Y.", "Cox, R.A.", "Jenkin, M.E."],
        title = u'The effect of methanol on the self reaction of HO2 radicals',
        journal = "Int. J. Chem. Kinet.",
        volume = "20",
        pages = """283""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988AND/COX283:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000034.xml
Bath gas: N2
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 798,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.87e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (6.444, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (550, 'K'),
        Tmax = (1250, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:169",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000038.xml
Uncertainty: 2.0
""",
)

entry(
    index = 799,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (271000, 'm^3/(mol*s)', '+|-', 33000),
        n = 0,
        Ea = (-4.324, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (243, 'K'),
        Tmax = (368, 'K'),
    ),
    reference = Article(
        authors = ["Dobis, O.", "Benson, S.W."],
        title = u'Reaction of the ethyl radical with oxygen at millitorr pressures at 243-368 K and a study of the Cl + HO2, ethyl + HO2, and HO2 + HO2 reactions',
        journal = "J. Am. Chem. Soc.",
        volume = "115",
        pages = """8798-8809""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993DOB/BEN8798-8809:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000039.xml
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Mass spectrometry
Note: Invalid Ea value uncertainty (8314472.0) found and ignored
""",
)

entry(
    index = 800,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (169000, 'm^3/(mol*s)', '+|-', 30000),
        n = 0,
        Ea = (-4.939, 'kJ/mol', '+|-', 0.445),
        T0 = (1, 'K'),
        Tmin = (210, 'K'),
        Tmax = (363, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Maricq, M.M.", "Szente, J.J."],
        title = u'A kinetic study of the reaction between ethylperoxy radicals and HO2',
        journal = "J. Phys. Chem.",
        volume = "98",
        pages = """2078-2082""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994MAR/SZE2078-2082:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000041.xml
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 801,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (132000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-4.989, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (420, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic and photochemical data for atmospheric chemistry: supplement VI. IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """1329-1499""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU1329-1499:50",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000042.xml
""",
)

entry(
    index = 802,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (139000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-4.989, 'kJ/mol', '+|-', 1.646),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:307",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000043.xml
""",
)

entry(
    index = 803,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (132000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-4.989, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (420, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:22",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000045.xml
Pressure dependence: None reported
""",
)

entry(
    index = 804,
    label = "HO2-2 + HO2 <=> H2O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (132000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-4.989, 'kJ/mol', '+|-', 1.663),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (420, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F.", "Hynes, R.G.", "Jenkin, M.E.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic and photochemical data for atmospheric chemistry: Volume I - gas phase reactions of Ox, HOx, NOx and SOx species',
        journal = "Atmos. Chem. Phys.",
        volume = "4",
        pages = """1461-1738""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004ATK/BAU1461-1738:60",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00013692
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00013692/rk00000046.xml
""",
)

entry(
    index = 805,
    label = "CH4O2-2 + OH <=> H2O + CH3O2-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (602000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-1.58, 'kJ/mol', '+|-', 1.247),
        T0 = (1, 'K'),
        Tmin = (220, 'K'),
        Tmax = (430, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:78",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011639
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011639/rk00000008.xml
Pressure dependence: None reported
""",
)

entry(
    index = 806,
    label = "CH2O + CH3O2 <=> CH4O2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.99e+06, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (48.806, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001347
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001347/rk00000002.xml
Uncertainty: 5.0
""",
)

entry(
    index = 807,
    label = "CH2O + C2H3O-2 <=> C2H4O-2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (181000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (54.044, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:6",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001360
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001360/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 808,
    label = "CH4O-2 + CH3O2 <=> CH4O2 + CH3O-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1.81e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (57.37, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:5",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001676
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001676/rk00000001.xml
Uncertainty: 2.0
""",
)

entry(
    index = 809,
    label = "CH4O-2 + C2H3O-2 <=> C2H4O-2 + CH3O-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.004837, 'm^3/(mol*s)', '*|/', 3),
        n = 3,
        Ea = (51.633, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 2. Methanol',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "16",
        pages = """471""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987TSA471:13",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001691
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001691/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 810,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (347000, 'm^3/(mol*s)', '*|/', 1.07),
        n = 0,
        Ea = (40.491, 'kJ/mol', '+|-', 0.405),
        T0 = (1, 'K'),
        Tmin = (393, 'K'),
        Tmax = (523, 'K'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Newitt, P.J."],
        title = u'An evaluation of the kinetic data for the hydrogen transfer reactions: CH3 + CH3COCH3, CD3 + CD3COCD3 and CH3 + CH3NNCH3',
        journal = "Can. J. Chem.",
        volume = "63",
        pages = """3486-3491""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985ART/NEW3486-3491:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.0700001
""",
)

entry(
    index = 811,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (324000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (40.325, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (398, 'K'),
        Tmax = (718, 'K'),
        Pmin = (8666, 'Pa'),
        Pmax = (33300, 'Pa'),
    ),
    reference = Article(
        authors = ["Shapiro, J.S.", "Weston, R.E., Jr."],
        title = u'Kinetic Isotope Effects in the Reaction of Methyl Radicals with Molecular Hydrogen',
        journal = "J. Phys. Chem.",
        volume = "76",
        pages = """1669""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972SHA/WES1669:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Bath gas: H2
""",
)

entry(
    index = 812,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.0095, 'm^3/(mol*s)'),
        n = 2.5,
        Ea = (35.146, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1050, 'K'),
        Tmax = (1650, 'K'),
        Pmin = (122000, 'Pa'),
        Pmax = (324000, 'Pa'),
    ),
    reference = Article(
        authors = ["Sato, K.", "Hidaka, Y."],
        title = u'Shock-tube and modeling study of acetone pyrolysis and oxidation',
        journal = "Combust. Flame",
        volume = "122",
        pages = """291-311""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000SAT/HID291-311:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Experimental procedure: Shock tube
Time resolution: In real time
Analytical technique: IR absorption
""",
)

entry(
    index = 813,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (8.51e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (71.671, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (825, 'K'),
        Tmax = (940, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (24000, 'Pa'),
    ),
    reference = Article(
        authors = ["Mousavipour, S.H.", "Pacey, P.D."],
        title = u'Initiation and abstraction reactions in the pyrolysis of acetone',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """3573-3579""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996MOU/PAC3573-3579:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 814,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (450000, 'm^3/(mol*s)', '*|/', 1.4),
        n = 0,
        Ea = (44.067, 'kJ/mol', '+|-', 2.644),
        T0 = (1, 'K'),
        Tmin = (370, 'K'),
        Tmax = (580, 'K'),
        Pmin = (14700, 'Pa'),
        Pmax = (100000, 'Pa'),
    ),
    reference = Article(
        authors = ["Kinsman, A.C.", "Roscoe, J.M."],
        title = u'A kinetic analysis of the photolysis of mixtures of acetone and propylene',
        journal = "Int. J. Chem. Kinet.",
        volume = "26",
        pages = """191-200""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994KIN/ROS191-200:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.4
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 815,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (347000, 'm^3/(mol*s)', '*|/', 1.05),
        n = 0,
        Ea = (39.993, 'kJ/mol', '+|-', 0.4),
        T0 = (1, 'K'),
        Tmin = (398, 'K'),
        Tmax = (522, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (8799, 'Pa'),
    ),
    reference = Article(
        authors = ["Arican, H.", "Arthur, N.L."],
        title = u'Reactions of methyl radicals. IV. Hydrogen abstraction from tetramethylsilane by methyl radicals produced by the photolysis of both acetone and azomethane',
        journal = "Aust. J. Chem.",
        volume = "36",
        pages = """2185""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983ARI/ART2185:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.05
Bath gas: N2
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 816,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (331000, 'm^3/(mol*s)', '*|/', 1.55),
        n = 0,
        Ea = (40.325, 'kJ/mol', '+|-', 0.403),
        T0 = (1, 'K'),
        Tmin = (373, 'K'),
        Tmax = (465, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Duke, M.G.", "Holbrook, K.A."],
        title = u'Reactions of methyl radicals with oxetan, 2-methyloxetan and 2,4-dimethyloxetan',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "76",
        pages = """1232""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980DUK/HOL1232:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.55
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 817,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (339000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (40.575, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (390, 'K'),
        Tmax = (517, 'K'),
        Pmin = (6546, 'Pa'),
        Pmax = (6786, 'Pa'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Newitt, P.J."],
        title = u'Reactions of Methyl Radicals. II. Hydrogen Abstraction from Methyl Trifluoroacetate',
        journal = "Aust. J. Chem.",
        volume = "32",
        pages = """1025""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979ART/NEW1025:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 818,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (407000, 'm^3/(mol*s)', '*|/', 1.12),
        n = 0,
        Ea = (40.491, 'kJ/mol', '+|-', 0.405),
        T0 = (1, 'K'),
        Tmin = (393, 'K'),
        Tmax = (518, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (9333, 'Pa'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Lee, M-S."],
        title = u'Reactions of Methyl Radicals. I. Hydrogen Abstraction from Dimethyl Sulphide',
        journal = "Aust. J. Chem.",
        volume = "29",
        pages = """1483""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976ART/LEE1483:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.12
Bath gas: N2
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 819,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (269000, 'm^3/(mol*s)', '*|/', 1.41),
        n = 0,
        Ea = (39.66, 'kJ/mol', '+|-', 1.189),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (513, 'K'),
    ),
    reference = Article(
        authors = ["Donovan, T.R.", "Dorko, W.", "Harrison, A.G."],
        title = u'Hydrogen Abstraction from Methyl Formate by Methyl Radicals',
        journal = "Can. J. Chem.",
        volume = "49",
        pages = """828""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971DON/DOR828:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.41
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 820,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (316000, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (40.325, 'kJ/mol', '+|-', 0.807),
        T0 = (1, 'K'),
        Tmin = (393, 'K'),
        Tmax = (523, 'K'),
        Pmin = (3200, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Ferguson, K.C.", "Pearson, J.T."],
        title = u'Methyl and trifluoromethyl radical rections with methyl acetate and deuterated methyl acetates',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """910""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970FER/PEA910:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.26
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 821,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (417000, 'm^3/(mol*s)', '*|/', 1.07),
        n = 0,
        Ea = (41.073, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (395, 'K'),
        Tmax = (525, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Gray, P.", "Leyshon, L.J."],
        title = u'Hydrogen abstraction from amides. Isotope effects, reactivity of different sites, and secondary effects in the reaction of methyl radicals with formamide and acetamide',
        journal = "Trans. Faraday Soc.",
        volume = "65",
        pages = """780""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969GRA/LEY780:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.0700001
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 822,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (330000, 'm^3/(mol*s)', '+|-', 150000),
        n = 0,
        Ea = (39.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (394, 'K'),
        Tmax = (571, 'K'),
        Pmin = (40, 'Pa'),
        Pmax = (29300, 'Pa'),
    ),
    reference = Article(
        authors = ["Shaw, H.", "Toby, S."],
        title = u'The photochemistry of gaseous acetone',
        journal = "J. Phys. Chem.",
        volume = "72",
        pages = """2337""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968SHA/TOB2337:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 823,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (288000, 'm^3/(mol*s)', '*|/', 1.17),
        n = 0,
        Ea = (40.325, 'kJ/mol', '+|-', 0.403),
        T0 = (1, 'K'),
        Tmin = (403, 'K'),
        Tmax = (523, 'K'),
    ),
    reference = Article(
        authors = ["Gray, P.", "Herod, A.A."],
        title = u'Methyl radical reactions with ethanol and deuterated ethanols',
        journal = "Trans. Faraday Soc.",
        volume = "64",
        pages = """1568""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968GRA/HER1568:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.17
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 824,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (224000, 'm^3/(mol*s)', '*|/', 1.12),
        n = 0,
        Ea = (39.909, 'kJ/mol', '+|-', 0.797),
        T0 = (1, 'K'),
        Tmin = (398, 'K'),
        Tmax = (473, 'K'),
    ),
    reference = Article(
        authors = ["Greig, G.", "Thynne, J.C.J."],
        title = u'Hydrogen and deuterium atom abstraction from trideuteromethyl mercaptan by methyl radicals. Reactivity of methylthio radicals',
        journal = "Trans. Faraday Soc.",
        volume = "62",
        pages = """379""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966GRE/THY379:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.12
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 825,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (224000, 'm^3/(mol*s)', '*|/', 1.12),
        n = 0,
        Ea = (38.912, 'kJ/mol', '+|-', 0.389),
        T0 = (1, 'K'),
        Tmin = (415, 'K'),
        Tmax = (499, 'K'),
    ),
    reference = Article(
        authors = ["Shannon, T.W.", "Harrison, A.G."],
        title = u'The reaction of methyl radicals with methyl alcohol',
        journal = "Can. J. Chem.",
        volume = "41",
        pages = """2455-2461""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963SHA/HAR2455-2461:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Uncertainty: 1.12
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 826,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (224000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.743, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (395, 'K'),
        Tmax = (526, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (11300, 'Pa'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.J.", "Gray, P."],
        title = u'The methyl-radical-sensitized decomposition of gaseous dimethyl carbonate',
        journal = "Trans. Faraday Soc.",
        volume = "58",
        pages = """2403-2409""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962THY/GRA2403-2409:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 827,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (500000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (40.99, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (393, 'K'),
        Tmax = (653, 'K'),
        Pmin = (8666, 'Pa'),
        Pmax = (16000, 'Pa'),
    ),
    reference = Article(
        authors = ["Dainton, F.S.", "McElcheran, D.E."],
        title = u'The reaction CH3 + CD4 \u2192\x92 CH3D + CD3',
        journal = "Trans. Faraday Soc.",
        volume = "51",
        pages = """657""",
        year = "1955",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1955DAI/MCE657:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Bath gas: CD4
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 828,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (640000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.743, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (403, 'K'),
        Tmax = (428, 'K'),
    ),
    reference = Article(
        authors = ["Pritchard, G.O.", "Pritchard, H.O.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of methyl radicals with acetone, diethyl ketone, and di-tert.-butyl peroxide',
        journal = "J. Chem. Soc.",
        pages = """1425""",
        year = "1954",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1954PRI/PRI1425:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Other (direct)
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 829,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (389000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.323, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (299, 'K'),
        Tmax = (712, 'K'),
    ),
    reference = Article(
        authors = ["Kondrat'ev, V.N."],
        title = u'Determination of rate constants of elementary chemical processes',
        journal = "Kinet. Catal.",
        volume = "8",
        pages = """831-840""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967KON831-840:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
""",
)

entry(
    index = 830,
    label = "C3H6O + CH3 <=> CH4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (18000, 'm^3/(mol*s)'),
        n = 0.5,
        Ea = (39.743, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (493, 'K'),
    ),
    reference = Article(
        authors = ["Gomer, R.", "Kistiakowsky, G.B."],
        title = u'The rate constant of ethane formation from methyl radicals',
        journal = "J. Chem. Phys.",
        volume = "19",
        pages = """85""",
        year = "1951",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1951GOM/KIS85:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00001769
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001769/rk00000001.xml
""",
)

entry(
    index = 831,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.002553, 'm^3/(mol*s)'),
        n = 3,
        Ea = (0.82, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (199, 'K'),
        Tmax = (700, 'K'),
    ),
    reference = Article(
        authors = ["Caralp, F.", "Forst, W.", "Henon, E.", "Bergeat, A.", "Bohr, F."],
        title = u'Tunneling in the reaction of acetone with OH',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "8",
        pages = """1072-1078""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006CAR/FOR1072-1078:2",
    ),
    referenceType = "uncategorized",
    longDesc = 
u"""
PrIMe Reaction: r00001778

Abstraction channel 2. No rate expressions given in paper, only rate constants. Rate expression given here is NIST fit to rate constants in tables in paper.

Studied reaction of CH3C(O)CH3 acetone + OH. Two possible product channels abstraction going to CH3COCH2 + H2O, and the other addition of OH followed by beta scission of CH3. Addition/beta scission channel is small compared to abstraction. Also studied isotope effect using CD3C(O)CD3.

Used ab initio potential surfaces from earlier work by the authors PCCP 5, 333 (2003) and JCP 119, 10600 (2003). Used RRKM theory to derive rate constants. Including tunneling correction zero curvature tunneling WKB approximation.

All reaction channels proceed through weakly bound adducts. The abstraction channel is the sum of two configurations with different hydrogen bonding arrangements. Tunneling correction is very important at low temperatures. The calculated rate constants agree well (20-30%) with experimental values including describing curvature in temperature dependence.
""",
)

entry(
    index = 832,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (9e-08, 'm^3/(mol*s)'),
        n = 4.43,
        Ea = (6.577, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (199, 'K'),
        Tmax = (700, 'K'),
    ),
    reference = Article(
        authors = ["Caralp, F.", "Forst, W.", "Henon, E.", "Bergeat, A.", "Bohr, F."],
        title = u'Tunneling in the reaction of acetone with OH',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "8",
        pages = """1072-1078""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006CAR/FOR1072-1078:3",
    ),
    referenceType = "uncategorized",
    longDesc = 
u"""
PrIMe Reaction: r00001778

Total Abstraction (two channels). No rate expressions given in paper, only rate constants. Rate expression given here is NIST fit to rate constants in tables in paper.

Studied reaction of CH3C(O)CH3 acetone + OH. Two possible product channels abstraction going to CH3COCH2 + H2O, and the other addition of OH followed by beta scission of CH3. Addition/beta scission channel is small compared to abstraction. Also studied isotope effect using CD3C(O)CD3.

Used ab initio potential surfaces from earlier work by the authors PCCP 5, 333 (2003) and JCP 119, 10600 (2003). Used RRKM theory to derive rate constants. Including tunneling correction zero curvature tunneling WKB approximation.

All reaction channels proceed through weakly bound adducts. The abstraction channel is the sum of two configurations with different hydrogen bonding arrangements. Tunneling correction is very important at low temperatures. The calculated rate constants agree well (20-30%) with experimental values including describing curvature in temperature dependence.
""",
)

entry(
    index = 833,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.897e-05, 'm^3/(mol*s)'),
        n = 3.73,
        Ea = (-7.358, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (199, 'K'),
        Tmax = (700, 'K'),
    ),
    reference = Article(
        authors = ["Caralp, F.", "Forst, W.", "Henon, E.", "Bergeat, A.", "Bohr, F."],
        title = u'Tunneling in the reaction of acetone with OH',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "8",
        pages = """1072-1078""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006CAR/FOR1072-1078:1",
    ),
    referenceType = "uncategorized",
    longDesc = 
u"""
PrIMe Reaction: r00001778

Abstraction channel 1. No rate expressions given in paper, only rate constants. Rate expression given here is NIST fit to rate constants in tables in paper.

Studied reaction of CH3C(O)CH3 acetone + OH. Two possible product channels abstraction going to CH3COCH2 + H2O, and the other addition of OH followed by beta scission of CH3. Addition/beta scission channel is small compared to abstraction. Also studied isotope effect using CD3C(O)CD3.

Used ab initio potential surfaces from earlier work by the authors PCCP 5, 333 (2003) and JCP 119, 10600 (2003). Used RRKM theory to derive rate constants. Including tunneling correction zero curvature tunneling WKB approximation.

All reaction channels proceed through weakly bound adducts. The abstraction channel is the sum of two configurations with different hydrogen bonding arrangements. Tunneling correction is very important at low temperatures. The calculated rate constants agree well (20-30%) with experimental values including describing curvature in temperature dependence.
""",
)

entry(
    index = 834,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.32e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (5.695, 'kJ/mol', '+|-', 0.856),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:83",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001778
""",
)

entry(
    index = 835,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.69e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.319, 'kJ/mol', '+|-', 1.646),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:49",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001778
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001778/rk00000006.xml
""",
)

entry(
    index = 836,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.02e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (4.989, 'kJ/mol', '+|-', 2.494),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (440, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:51",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001778
""",
)

entry(
    index = 837,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.02e+06, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (4.989, 'kJ/mol', '+|-', 2.494),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (440, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:17",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00001778
Uncertainty: 1.58
""",
)

entry(
    index = 838,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.95e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (19.098, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (982, 'K'),
        Tmax = (1300, 'K'),
        Pmin = (154000, 'Pa'),
        Pmax = (182000, 'Pa'),
    ),
    reference = Article(
        authors = ["Vasudevan, V.", "Davidson, D.F.", "Hanson, R.K."],
        title = u'High-temperature measurements of the reactions of OH with toluene and acetone',
        journal = "J. Phys. Chem. A",
        volume = "109",
        pages = """3352-3359""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005VAS/DAV3352-3359:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001778
Pressure dependence: None reported
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 839,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (12.552, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1050, 'K'),
        Tmax = (1650, 'K'),
        Pmin = (122000, 'Pa'),
        Pmax = (324000, 'Pa'),
    ),
    reference = Article(
        authors = ["Sato, K.", "Hidaka, Y."],
        title = u'Shock-tube and modeling study of acetone pyrolysis and oxidation',
        journal = "Combust. Flame",
        volume = "122",
        pages = """291-311""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000SAT/HID291-311:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001778
Experimental procedure: Shock tube
Time resolution: In real time
Analytical technique: IR absorption
""",
)

entry(
    index = 840,
    label = "C3H6O + OH <=> H2O + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.12e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (8.201, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (280, 'K'),
        Tmax = (440, 'K'),
    ),
    reference = Article(
        authors = ["Alvarez-Idaboy, J.R.", "Cruz-Torres, A.", "Galano, A.", "Ruiz-Santoyo, M.E."],
        title = u'Structure-reactivity relationship in ketones plus OH reactions: A quantum mechanical and TST approach',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """2740-2749""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004ALV/CRU2740-2749:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001778
Pressure dependence: Rate constant is pressure independent

The authors used CCSD(T)//BHandHLYP/6-311G(d,p) calculations to study the OH hydrogen abstraction reaction from acetone, 2-pentanone, and methyl butanone (3-methyl-2-butanone). The calulations appear to confirm the formation of a hydogen-bonded transition-state complex involving the carbonyl oxygen for some H abstractions, particularly those beta to the carbonyl, which result in a 6-center transition state. Good agreement between calculated and experimental k at 298 K has been obtained.
""",
)

entry(
    index = 841,
    label = "C4H10O + H <=> H2 + C4H9O",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1.99e+07, 'm^3/(mol*s)', '+|-', 5.4e+06),
        n = 0,
        Ea = (21.368, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (843, 'K'),
        Tmax = (963, 'K'),
        Pmin = (1120, 'Pa'),
        Pmax = (2173, 'Pa'),
    ),
    reference = Article(
        authors = ["Oganesyan, K.T.", "Nalbandyan, A.B."],
        title = u'Determination of rate constants of reactions of atomic hydrogen with propyl and butyl alcohols',
        journal = "Izv. Akad. Nauk Arm. SSR, Khim. Nauki",
        volume = "18",
        pages = """237""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965OGA/NAL237:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001856
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001856/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Pressure measurement
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 842,
    label = "C2H6 + C3H7-2 <=> C3H8-2 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (8.4e-07, 'm^3/(mol*s)', '*|/', 2),
        n = 4.2,
        Ea = (36.501, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002092
Uncertainty: 2.0
""",
)

entry(
    index = 843,
    label = "C2H6 + C3H7-2 <=> C3H8-2 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (100000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (54.044, 'kJ/mol', '+|-', 3.243),
        T0 = (1, 'K'),
        Tmin = (496, 'K'),
        Tmax = (548, 'K'),
        Pmin = (5066, 'Pa'),
        Pmax = (30700, 'Pa'),
    ),
    reference = Article(
        authors = ["Szirovicza, L.", "Marta, F."],
        title = u'Some Reactions of the Isopropyl Radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "8",
        pages = """897""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976SZI/MAR897:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002092
Bath gas: C2H6
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 844,
    label = "C2H6 + C3H7-2 <=> C3H8-2 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (25100, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (53.129, 'kJ/mol', '+|-', 3.184),
        T0 = (1, 'K'),
        Tmin = (496, 'K'),
        Tmax = (548, 'K'),
        Pmin = (27200, 'Pa'),
        Pmax = (33600, 'Pa'),
    ),
    reference = Article(
        authors = ["Szirovicza, L.", "Marta, F."],
        title = u'Kinetics of the Decomposition of Ethane Sensitized by Azoisopropane',
        journal = "React. Kinet. Catal. Lett.",
        volume = "1",
        pages = """417""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974SZI/MAR417:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002092
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002092/rk00000001.xml
Uncertainty: 2.51
Bath gas: C2H6
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 845,
    label = "C3H8-2 + C2H5 <=> C2H6 + C3H7-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.21e-06, 'm^3/(mol*s)', '*|/', 2.5),
        n = 3.46,
        Ea = (31.262, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:41",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002092
Uncertainty: 2.5
""",
)

entry(
    index = 846,
    label = "C2H6 + CH3O2 <=> CH4O2 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (295000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (62.525, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:30",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002096
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002096/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 847,
    label = "C2H6 + CH3O2 <=> CH4O2 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.94e-05, 'm^3/(mol*s)'),
        n = 3.64,
        Ea = (71.546, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Carstensen, H.H.", "Dean, A.M."],
        title = u'Rate constants for the abstraction reactions RO2 + C2H6; R = H, CH3, and C2H5',
        journal = "Proc. Combust. Inst.",
        volume = "30",
        pages = """995-1003""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005CAR/DEA995-1003:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00002096
Pressure dependence: Rate constant is pressure independent

Reaction potential energy surface was studied using quantum chemistry and rate constants were calculated using variational transition state theory with tunneling correction.
""",
)

entry(
    index = 848,
    label = "C2H6 + CH3O2 <=> CH4O2 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.087, 'm^3/(mol*s)'),
        n = 2.69,
        Ea = (83.262, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Carstensen, H.H.", "Dean, A.M."],
        title = u'Rate constants for the abstraction reactions RO2 + C2H6; R = H, CH3, and C2H5',
        journal = "Proc. Combust. Inst.",
        volume = "30",
        pages = """995-1003""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005CAR/DEA995-1003:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00002096
Pressure dependence: Rate constant is pressure independent
""",
)

entry(
    index = 849,
    label = "C3H8 + C2H5 <=> C2H6 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (9e-07, 'm^3/(mol*s)', '*|/', 2.5),
        n = 3.65,
        Ea = (38.247, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:42",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002710
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002710/rk00000001.xml
Uncertainty: 2.5
""",
)

entry(
    index = 850,
    label = "C2H6 + C3H7 <=> C3H8 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.5e-07, 'm^3/(mol*s)', '*|/', 3),
        n = 3.82,
        Ea = (37.831, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:10",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002710
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002710/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 851,
    label = "C3H8-2 + CH3O <=> CH4O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (145000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (19.123, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:22",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002719
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002719/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 852,
    label = "CH4O + C3H7-2 <=> C3H8-2 + CH3O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.445e-05, 'm^3/(mol*s)', '*|/', 5),
        n = 3.1,
        Ea = (43.235, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002719
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002719/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 853,
    label = "C3H8 + CH3O <=> CH4O + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (434000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (27.022, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:23",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002720
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002720/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 854,
    label = "CH4O + C3H7 <=> C3H8 + CH3O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.445e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.1,
        Ea = (37.415, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:5",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002720
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002720/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 855,
    label = "C3H8-2 + CH3O-2 <=> CH4O-2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (6.029e-05, 'm^3/(mol*s)', '*|/', 5),
        n = 2.95,
        Ea = (50.136, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:26",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002728
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002728/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 856,
    label = "CH4O-2 + C3H7-2 <=> C3H8-2 + CH3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.194e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.7,
        Ea = (44.067, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002728
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002728/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 857,
    label = "C3H8 + CH3O-2 <=> CH4O-2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.000198, 'm^3/(mol*s)', '*|/', 5),
        n = 2.95,
        Ea = (58.451, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:27",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002729
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002729/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 858,
    label = "CH4O-2 + C3H7 <=> C3H8 + CH3O-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.371e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.17,
        Ea = (38.33, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:6",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002729
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002729/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 859,
    label = "C3H8-2 + CHO <=> CH2O + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (10.8, 'm^3/(mol*s)', '*|/', 3),
        n = 1.9,
        Ea = (71.172, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:28",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002730
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002730/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 860,
    label = "CH2O + C3H7-2 <=> C3H8-2 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (108000, 'm^3/(mol*s)', '*|/', 2.5),
        n = 0,
        Ea = (29.101, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002730
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002730/rk00000001.xml
Uncertainty: 2.5
""",
)

entry(
    index = 861,
    label = "C3H8 + CHO <=> CH2O + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.205, 'm^3/(mol*s)', '*|/', 3),
        n = 2.5,
        Ea = (77.158, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:29",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002731
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002731/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 862,
    label = "CH2O + C3H7 <=> C3H8 + CHO",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.003013, 'm^3/(mol*s)', '*|/', 5),
        n = 2.9,
        Ea = (24.528, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002731
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002731/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 863,
    label = "CH2O + C3H7 <=> C3H8 + CHO",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (100000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (32.593, 'kJ/mol', '+|-', 1.954),
        T0 = (1, 'K'),
        Tmin = (333, 'K'),
        Tmax = (363, 'K'),
        Pmin = (7733, 'Pa'),
        Pmax = (7733, 'Pa'),
    ),
    reference = Article(
        authors = ["Knoll, H.", "Nacsa, A.", "Foergeteg, S.", "Berces, T."],
        title = u'Free Radical Additions to the C=O Bond of Formaldehyde',
        journal = "React. Kinet. Catal. Lett.",
        volume = "15",
        pages = """481""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980KNO/NAC481:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002731
Bath gas: (n-C3H7)-N=N-(n-C3H7)
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 864,
    label = "C3H8-2 + C2H3 <=> C2H4 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.001024, 'm^3/(mol*s)', '*|/', 10),
        n = 3.1,
        Ea = (36.916, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:30",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002732
Uncertainty: 10.0
""",
)

entry(
    index = 865,
    label = "C3H8-2 + C2H3 <=> C2H4 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (45700, 'm^3/(mol*s)'),
        n = 0,
        Ea = (19.373, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    reference = Article(
        authors = ["Scherzer, K.", "Loser, U.", "Stiller, W."],
        title = u'BSBL-Rechnungen zu wasserstoffabspaltungsreaktionen durch alkenylradikale; Vinylradikale',
        journal = "Z. Chem.",
        volume = "27",
        pages = """300""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987SCH/LOS300:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00002732
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002732/rk00000001.xml
""",
)

entry(
    index = 866,
    label = "C3H8 + C2H3 <=> C2H4 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.000603, 'm^3/(mol*s)', '*|/', 10),
        n = 3.3,
        Ea = (43.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:31",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002733
Uncertainty: 10.0
""",
)

entry(
    index = 867,
    label = "C3H8 + C2H3 <=> C2H4 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (112000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (20.786, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    reference = Article(
        authors = ["Scherzer, K.", "Loser, U.", "Stiller, W."],
        title = u'BSBL-Rechnungen zu wasserstoffabspaltungsreaktionen durch alkenylradikale; Vinylradikale',
        journal = "Z. Chem.",
        volume = "27",
        pages = """300""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987SCH/LOS300:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00002733
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002733/rk00000001.xml
""",
)

entry(
    index = 868,
    label = "C3H8-2 + HO2 <=> H2O2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.009631, 'm^3/(mol*s)', '*|/', 10),
        n = 2.6,
        Ea = (58.201, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:34",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002740
Uncertainty: 10.0
""",
)

entry(
    index = 869,
    label = "C3H8-2 + HO2 <=> H2O2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (200000, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (43.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002740
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002740/rk00000003.xml
Uncertainty: 10.0
""",
)

entry(
    index = 870,
    label = "H2O2 + C3H7-2 <=> C3H8-2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000289, 'm^3/(mol*s)', '*|/', 10),
        n = 2.83,
        Ea = (16.962, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:77",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002740
Uncertainty: 10.0
""",
)

entry(
    index = 871,
    label = "C3H8-2 + O2 <=> HO2-2 + C3H7-2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3.97e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (199.547, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:37",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002766
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002766/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 872,
    label = "C3H8 + O2 <=> HO2-2 + C3H7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (3.97e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (212.85, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:38",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002767
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002767/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 873,
    label = "C2H4O-2 + C2H5 <=> C2H6 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.26e+06, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (35.586, 'kJ/mol', '+|-', 6.402),
        T0 = (1, 'K'),
        Tmin = (357, 'K'),
        Tmax = (676, 'K'),
        Pmin = (4666, 'Pa'),
        Pmax = (280000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hohlein, G.", "Freeman, G.R."],
        title = u'Radiation-sensitized pyrolysis of diethyl ether. Free-radical reaction rate parameters',
        journal = "J. Am. Chem. Soc.",
        volume = "92",
        pages = """6118""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970HOH/FRE6118:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003005
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003005/rk00000001.xml
Uncertainty: 5.0
Bath gas: (C2H5)2O
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 874,
    label = "C2H6 + C2H3O-2 <=> C2H4O-2 + C2H5",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.0181, 'm^3/(mol*s)', '*|/', 5),
        n = 2.75,
        Ea = (73.334, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:35",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003005
Uncertainty: 5.0
""",
)

entry(
    index = 875,
    label = "C2H4O-2 + C2H3 <=> C2H4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (81300, 'm^3/(mol*s)'),
        n = 0,
        Ea = (15.382, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    reference = Article(
        authors = ["Scherzer, K.", "Loser, U.", "Stiller, W."],
        title = u'BSBL-Rechnungen zu wasserstoffabspaltungsreaktionen durch alkenylradikale; Vinylradikale',
        journal = "Z. Chem.",
        volume = "27",
        pages = """300""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987SCH/LOS300:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00003016
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003016/rk00000001.xml
""",
)

entry(
    index = 876,
    label = "C2H4O-2 + O2 <=> HO2-2 + C2H3O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.01e+07, 'm^3/(mol*s)', '*|/', 1),
        n = 0,
        Ea = (163.795, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (1100, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:71",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003032
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003032/rk00000002.xml
Uncertainty: 1.0
""",
)

entry(
    index = 877,
    label = "C4H10-2 + CH3 <=> CH4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.6e-06, 'm^3/(mol*s)'),
        n = 3.46,
        Ea = (19.2, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (800, 'K'),
        Tmax = (950, 'K'),
        Pmin = (8000, 'Pa'),
        Pmax = (13000, 'Pa'),
    ),
    reference = Article(
        authors = ["Goos, E.", "Hippler, H.", "Hoyermann, K.", "Jurges, B."],
        title = u'Reactions of Methyl Radicals with Isobutane at Temperatures Between 800 and 950 Kelvin',
        journal = "Int. J. Chem. Kinet.",
        volume = "33",
        pages = """732-740""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001GOO/HIP732-740:1",
    ),
    referenceType = "uncategorized",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003291
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Thermal
Time resolution: By end product analysis
Analytical technique: Gas chromatography

Heating of the reaction mixtures are achived through CO2-laser induced excitation of SF6 and V-T energy transfer to reactants.Methyl radicals are produced from thermal decomposition of di-tert-butyl-peroxide.Products are analyzed using GC/MS. 

Note: iso-butyl product corrected to tert-butyl (Aug 30, 2011)
""",
)

entry(
    index = 878,
    label = "C4H10-2 + CH3 <=> CH4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (141000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.757, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (855, 'K'),
    ),
    reference = Article(
        authors = ["Zhang, H.X.", "Back, M.H."],
        title = u'Comment: A re-evaluation of the rate constant for abstraction of hydrogen from isobutane by methyl radicals',
        journal = "Int. J. Chem. Kinet.",
        volume = "22",
        pages = """537""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990ZHA/BAC537:2",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00003291
""",
)

entry(
    index = 879,
    label = "C4H10-2 + CH3 <=> CH4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (9e-07, 'm^3/(mol*s)', '*|/', 2),
        n = 3.46,
        Ea = (19.206, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:32",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003291
Uncertainty: 2.0
""",
)

entry(
    index = 880,
    label = "C4H10-2 + CH3 <=> CH4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (182000, 'm^3/(mol*s)', '*|/', 1.6),
        n = 0,
        Ea = (34.172, 'kJ/mol', '+|-', 2.395),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M."],
        title = u'Kinetics of abstraction reactions of methyl radicals with alkanes in gas phase',
        journal = "Indian J. Chem.",
        volume = "29",
        pages = """748""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990SWA748:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003291
Uncertainty: 1.6
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 881,
    label = "C4H10-2 + CH3 <=> CH4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.66e+06, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (47.725, 'kJ/mol', '+|-', 10.476),
        T0 = (1, 'K'),
        Tmin = (903, 'K'),
        Tmax = (1070, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (7333, 'Pa'),
    ),
    reference = Article(
        authors = ["Yampol'skii, Yu.P.", "Tsikhinski, V."],
        title = u'Concentrations of Radicals during the Pyrolysis of Isobutane in the 630-800o Range',
        journal = "Neftekhimiya",
        volume = "16",
        pages = """560""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976YAM/TSI560:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003291
Uncertainty: 5.0
Bath gas: iso-C4H10
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 882,
    label = "C4H10-2 + CH3 <=> CH4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.24e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (53.961, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (770, 'K'),
        Tmax = (855, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (20000, 'Pa'),
    ),
    reference = Article(
        authors = ["Konar, R.S.", "Marshall, R.M.", "Purnell, J.H."],
        title = u'The Self-Inhibited Pyrolysis of Isobutane',
        journal = "Int. J. Chem. Kinet.",
        volume = "5",
        pages = """1007""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973KON/MAR1007:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00003291
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003291/rk00000001.xml
Bath gas: iso-C4H8
""",
)

entry(
    index = 883,
    label = "CH4 + C4H9-2 <=> C4H10-2 + CH3",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (4.93e-13, 'm^3/(mol*s)', '*|/', 3),
        n = 5.38,
        Ea = (49.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:7",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003291
Uncertainty: 3.0
""",
)

entry(
    index = 884,
    label = "C4H10-4 + CH3 <=> CH4 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (759000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (48.39, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (855, 'K'),
    ),
    reference = Article(
        authors = ["Zhang, H.X.", "Back, M.H."],
        title = u'Comment: A re-evaluation of the rate constant for abstraction of hydrogen from isobutane by methyl radicals',
        journal = "Int. J. Chem. Kinet.",
        volume = "22",
        pages = """537""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990ZHA/BAC537:4",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00003292
""",
)

entry(
    index = 885,
    label = "C4H10-4 + CH3 <=> CH4 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1.36e-06, 'm^3/(mol*s)', '*|/', 2),
        n = 3.65,
        Ea = (29.932, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:33",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003292
Uncertainty: 2.0
""",
)

entry(
    index = 886,
    label = "C4H10-4 + CH3 <=> CH4 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1.45e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (68.179, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (770, 'K'),
        Tmax = (855, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (20000, 'Pa'),
    ),
    reference = Article(
        authors = ["Konar, R.S.", "Marshall, R.M.", "Purnell, J.H."],
        title = u'The Self-Inhibited Pyrolysis of Isobutane',
        journal = "Int. J. Chem. Kinet.",
        volume = "5",
        pages = """1007""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973KON/MAR1007:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00003292
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003292/rk00000001.xml
Bath gas: iso-C4H8
""",
)

entry(
    index = 887,
    label = "CH4 + C4H9-4 <=> C4H10-4 + CH3",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (2e-08, 'm^3/(mol*s)', '*|/', 3),
        n = 3.72,
        Ea = (33.424, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:8",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003292
Uncertainty: 3.0
""",
)

entry(
    index = 888,
    label = "C4H10-2 + OH <=> H2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (57500, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0.51,
        Ea = (0.266, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:44",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003317
Uncertainty: 1.2
""",
)

entry(
    index = 889,
    label = "C4H10-2 + OH <=> H2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2700, 'm^3/(mol*s)'),
        n = 1,
        Ea = (-0.624, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003317
""",
)

entry(
    index = 890,
    label = "C4H10-2 + OH <=> H2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.3e+07, 'm^3/(mol*s)', '*|/', 1.38),
        n = 0,
        Ea = (9.977, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'The Use of the H2 + O2 Reaction in Determining the Velocity Constants of Elementary Reactions in Hydrocarbon Oxidation',
        journal = "Symp. Int. Combust. Proc.",
        volume = "13",
        pages = """291""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971BAK/BAL291:9",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00003317
Uncertainty: 1.38
""",
)

entry(
    index = 891,
    label = "C4H10-2 + OH <=> H2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.26e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-0.798, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (498, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:7",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003317
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 892,
    label = "C4H10-2 + OH <=> H2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.3e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (9.977, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (730, 'K'),
        Tmax = (780, 'K'),
        Pmin = (33300, 'Pa'),
        Pmax = (89300, 'Pa'),
    ),
    reference = Article(
        authors = ["Baker, R.R.", "Baldwin, R.R.", "Walker, R.W."],
        title = u'Addition of C3H8, n- and i-C4H10 to slowly reacting mixtures of hydrogen and oxygen at 480\xb0C',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """2812""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BAK/BAL2812:9",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00003317
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003317/rk00000001.xml
Bath gas: N2
""",
)

entry(
    index = 893,
    label = "C4H10-2 + OH <=> H2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.57, 'm^3/(mol*s)'),
        n = 1.9,
        Ea = (-6.07, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1150, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00003317
""",
)

entry(
    index = 894,
    label = "C4H10-2 + OH <=> H2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.14, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.912, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00003317
Bath gas: N2
""",
)

entry(
    index = 895,
    label = "C4H10-2 + OH <=> H2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.57e+06, 'm^3/(mol*s)', '*|/', 1.23),
        n = 0,
        Ea = (2.253, 'kJ/mol', '+|-', 0.811),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (500, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Walker, R.W.", "Walker, R.W."],
        title = u'Addition of 2,2,3-Trimethylbutane to Slowly Reacting Mixtures of Hydrogen and Oxygen at 480oC',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "77",
        pages = """2157""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981BAL/WAL2157:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00003317
Uncertainty: 1.23
Bath gas: N2
""",
)

entry(
    index = 896,
    label = "C4H10-4 + OH <=> H2O + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (229, 'm^3/(mol*s)', '*|/', 1.2),
        n = 1.53,
        Ea = (3.243, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:45",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003318
Uncertainty: 1.2
""",
)

entry(
    index = 897,
    label = "C4H10-4 + OH <=> H2O + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (5.55e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.843, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (498, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:8",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003318
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003318/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 898,
    label = "C4H10-4 + OH <=> H2O + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (51.4, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (6.07, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1150, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:8",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00003318
""",
)

entry(
    index = 899,
    label = "C4H10-4 + OH <=> H2O + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (8.06, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00003318
Bath gas: N2
""",
)

entry(
    index = 900,
    label = "C4H10O-2 + H <=> H2 + C4H9O-2",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1.69e+07, 'm^3/(mol*s)', '+|-', 5.4e+06),
        n = 0,
        Ea = (22.2, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (843, 'K'),
        Tmax = (963, 'K'),
        Pmin = (1120, 'Pa'),
        Pmax = (2133, 'Pa'),
    ),
    reference = Article(
        authors = ["Oganesyan, K.T.", "Nalbandyan, A.B."],
        title = u'Determination of rate constants of reactions of atomic hydrogen with propyl and butyl alcohols',
        journal = "Izv. Akad. Nauk Arm. SSR, Khim. Nauki",
        volume = "18",
        pages = """237""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965OGA/NAL237:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003593
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003593/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Pressure measurement
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 901,
    label = "C5H12 + H <=> H2 + C5H11",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (6.61e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:15",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00003832
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003832/rk00000001.xml
""",
)

entry(
    index = 902,
    label = "C5H12-2 + H <=> H2 + C5H11-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.79e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.258, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:16",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00003833
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003833/rk00000001.xml
""",
)

entry(
    index = 903,
    label = "C5H12-3 + H <=> H2 + C5H11-3",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.11e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (25.193, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:17",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003834
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003834/rk00000001.xml
""",
)

entry(
    index = 904,
    label = "C4H10-3 + CH3 <=> CH4 + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (550000, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (39.993, 'kJ/mol', '+|-', 1.197),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M."],
        title = u'Kinetics of abstraction reactions of methyl radicals with alkanes in gas phase',
        journal = "Indian J. Chem.",
        volume = "29",
        pages = """748""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990SWA748:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004593
Uncertainty: 1.26
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 905,
    label = "C4H10-3 + CH3 <=> CH4 + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (427000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (980, 'K'),
        Tmax = (1060, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Yampol'skii, Yu.P."],
        title = u'Reactivity of Primary and Secondary Carbon-Hydrogen Bonds in Radical Processes',
        journal = "React. Kinet. Catal. Lett.",
        volume = "2",
        pages = """449""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975YAM449:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004593
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004593/rk00000002.xml
Bath gas: n-C4H10
""",
)

entry(
    index = 906,
    label = "C4H10 + CH3 <=> CH4 + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (501000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (56.871, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (980, 'K'),
        Tmax = (1060, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Yampol'skii, Yu.P."],
        title = u'Reactivity of Primary and Secondary Carbon-Hydrogen Bonds in Radical Processes',
        journal = "React. Kinet. Catal. Lett.",
        volume = "2",
        pages = """449""",
        year = "1975",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1975YAM449:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004594
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004594/rk00000001.xml
Bath gas: n-C4H10
""",
)

entry(
    index = 907,
    label = "C4H10-3 + OH <=> H2O + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2900, 'm^3/(mol*s)'),
        n = 1,
        Ea = (0.499, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:11",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00004608
""",
)

entry(
    index = 908,
    label = "C4H10-3 + OH <=> H2O + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (72.3, 'm^3/(mol*s)'),
        n = 1.64,
        Ea = (-1.031, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (294, 'K'),
        Tmax = (509, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Droege, A.T.", "Tully, F.P."],
        title = u'Hydrogen-atom abstraction from alkanes by OH. 5. n-Butane',
        journal = "J. Phys. Chem.",
        volume = "90",
        pages = """5937""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986DRO/TUL5937:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004608
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 909,
    label = "C4H10-3 + OH <=> H2O + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.64e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.559, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:12",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004608
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004608/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 910,
    label = "C4H10-3 + OH <=> H2O + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.36, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:16",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00004608
""",
)

entry(
    index = 911,
    label = "C4H10-3 + OH <=> H2O + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.2, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.569, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:8",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004608
Bath gas: N2
""",
)

entry(
    index = 912,
    label = "C4H10 + OH <=> H2O + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (41.4, 'm^3/(mol*s)'),
        n = 1.73,
        Ea = (3.151, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (294, 'K'),
        Tmax = (509, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Droege, A.T.", "Tully, F.P."],
        title = u'Hydrogen-atom abstraction from alkanes by OH. 5. n-Butane',
        journal = "J. Phys. Chem.",
        volume = "90",
        pages = """5937""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986DRO/TUL5937:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004609
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 913,
    label = "C4H10 + OH <=> H2O + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.69e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.843, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:13",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004609
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004609/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 914,
    label = "C4H10 + OH <=> H2O + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (33.1, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (3.991, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:17",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00004609
""",
)

entry(
    index = 915,
    label = "C4H10 + OH <=> H2O + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (5.39, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:9",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004609
Bath gas: N2
""",
)

entry(
    index = 916,
    label = "C4H6 + CH3 <=> CH4 + C4H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (7e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (77.408, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1300, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (20300, 'Pa'),
        Pmax = (55700, 'Pa'),
    ),
    reference = Article(
        authors = ["Kern, R.D.", "Singh, H.J.", "Wu, C.H."],
        title = u'Thermal decomposition of 1,2 butadiene',
        journal = "Int. J. Chem. Kinet.",
        volume = "20",
        pages = """731""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988KER/SIN731:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00004743
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004743/rk00000001.xml
Bath gas: Ne
""",
)

entry(
    index = 917,
    label = "C5H12-4 + H <=> H2 + C5H11-4",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.96e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.258, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:26",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00005291
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005291/rk00000001.xml
""",
)

entry(
    index = 918,
    label = "C5H12-5 + H <=> H2 + C5H11-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:27",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00005292
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005292/rk00000001.xml
""",
)

entry(
    index = 919,
    label = "C5H12-6 + H <=> H2 + C5H11-6",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (9.79e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.258, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:28",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00005293
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005293/rk00000001.xml
""",
)

entry(
    index = 920,
    label = "C3H6-2 + C2H5 <=> C2H6 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (2.23e-06, 'm^3/(mol*s)', '*|/', 3),
        n = 3.5,
        Ea = (27.77, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:65",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005641
Uncertainty: 3.0
""",
)

entry(
    index = 921,
    label = "C3H6-2 + C2H5 <=> C2H6 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (69200, 'm^3/(mol*s)'),
        n = 0,
        Ea = (21.701, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (490, 'K'),
        Tmax = (510, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:12",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005641
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005641/rk00000001.xml
""",
)

entry(
    index = 922,
    label = "C2H6 + C3H5-2 <=> C3H6-2 + C2H5",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.000235, 'm^3/(mol*s)', '*|/', 5),
        n = 3.3,
        Ea = (83.062, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005641
Uncertainty: 5.0
""",
)

entry(
    index = 923,
    label = "C2H6 + C3H5-2 <=> C3H6-2 + C2H5",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (724000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (68.594, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (790, 'K'),
        Tmax = (810, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005641
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005641/rk00000001.xml
""",
)

entry(
    index = 924,
    label = "C3H6-2 + CH3O <=> CH4O + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (8.993e-05, 'm^3/(mol*s)', '*|/', 10),
        n = 2.95,
        Ea = (50.136, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:36",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005655
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005655/rk00000001.xml
Uncertainty: 10.0
Bath gas: Products
""",
)

entry(
    index = 925,
    label = "C3H6-2 + CH3O-2 <=> CH4O-2 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (6.029e-05, 'm^3/(mol*s)', '*|/', 10),
        n = 2.95,
        Ea = (50.136, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:42",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005669
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005669/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 926,
    label = "CH4O-2 + C3H5-2 <=> C3H6-2 + CH3O-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.001743, 'm^3/(mol*s)', '*|/', 10),
        n = 2.9,
        Ea = (85.639, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005669
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005669/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 927,
    label = "C3H6-2 + CHO <=> CH2O + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (10.8, 'm^3/(mol*s)', '*|/', 10),
        n = 1.9,
        Ea = (71.172, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:43",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005671
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005671/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 928,
    label = "CH2O + C3H5-2 <=> C3H6-2 + CHO",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (126, 'm^3/(mol*s)', '*|/', 10),
        n = 1.9,
        Ea = (76.077, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005671
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005671/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 929,
    label = "C3H6-2 + C2H3 <=> C2H4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (2.21e-06, 'm^3/(mol*s)', '*|/', 10),
        n = 3.5,
        Ea = (19.622, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:44",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005672
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005672/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 930,
    label = "C4H8 + CH3 <=> CH4 + C4H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (6.81e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (81.981, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1060, 'K'),
        Tmax = (1320, 'K'),
        Pmin = (292000, 'Pa'),
        Pmax = (400000, 'Pa'),
    ),
    reference = Article(
        authors = ["Bradley, J.N.", "West, K.O."],
        title = u'Single-pulse Shock Tube Studies of Hydrocarbon Pyrolysis. Part 6. The Pyrolysis of Isobutene',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "72",
        pages = """558""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976BRA/WES558:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005825
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 931,
    label = "C4H8 + CH3 <=> CH4 + C4H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (5.89e+08, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (81.981, 'kJ/mol', '+|-', 14.8),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (833, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (73300, 'Pa'),
    ),
    reference = Article(
        authors = ["Halstead, M.P.", "Konar, R.S.", "Leathard, D.A.", "Marshall, R.M.", "Purnell, J.H."],
        title = u'The self-inhibited pyrolysis of neopentane at small extents of reaction',
        journal = "Proc. R. Soc. London A",
        volume = "310",
        pages = """525""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969HAL/KON525:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005825
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005825/rk00000002.xml
Uncertainty: 10.0
Bath gas: neo-C5H12
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 932,
    label = "C4H8 + CH3 <=> CH4 + C4H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (603000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (37.249, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (800, 'K'),
    ),
    reference = Article(
        authors = ["Mitchell, T.J.", "Benson, S.W."],
        title = u'Modelling of the homogeneously catalyzed and uncatalyzed pyrolysis of neopentane: thermochemistry of the neopentyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "25",
        pages = """931-955""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993MIT/BEN931-955:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005825
""",
)

entry(
    index = 933,
    label = "C4H8 + CH3 <=> CH4 + C4H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.6e+10, 'm^3/(mol*s)'),
        n = 0,
        Ea = (111.414, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1030, 'K'),
        Tmax = (1300, 'K'),
        Pmin = (300000, 'Pa'),
        Pmax = (400000, 'Pa'),
    ),
    reference = Article(
        authors = ["Bradley, J.N.", "West, K.O."],
        title = u'Single-pulse Shock Tube Studies of Hydrocarbon Pyrolysis. Part 5. Pyrolysis of Neopentane',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "72",
        pages = """8""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976BRA/WES8:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005825
Bath gas: Ar
""",
)

entry(
    index = 934,
    label = "C4H8 + CH3 <=> CH4 + C4H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.12e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (73.666, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (770, 'K'),
        Tmax = (855, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (20000, 'Pa'),
    ),
    reference = Article(
        authors = ["Konar, R.S.", "Marshall, R.M.", "Purnell, J.H."],
        title = u'The Self-Inhibited Pyrolysis of Isobutane',
        journal = "Int. J. Chem. Kinet.",
        volume = "5",
        pages = """1007""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973KON/MAR1007:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005825
Bath gas: iso-C4H8
""",
)

entry(
    index = 935,
    label = "C4H8-3 + OH <=> H2O + C4H7-3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (12.6, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-0.208, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (270, 'K'),
        Tmax = (370, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics of the gas-phase reactions of OH radicals with alkanes and cycloalkanes',
        journal = "Atmos. Chem. Phys.",
        volume = "3",
        pages = """2233-2307""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003ATK2233-2307:23",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00006461
""",
)

entry(
    index = 936,
    label = "C4H8-3 + OH <=> H2O + C4H7-3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (8.4, 'm^3/(mol*s)', '*|/', 3.16),
        n = 2,
        Ea = (0.249, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:11",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00006461
Uncertainty: 3.1600001
""",
)

entry(
    index = 937,
    label = "C4H8-3 + OH <=> H2O + C4H7-3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (9.82e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (5.08, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (368, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Bayes, K.D."],
        title = u'Rate constants for the reactions of hydroxyl radical with several alkanes, cycloakanes, and dimethyl ether',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """2649-2654""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999DEM/BAY2649-2654:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006461
Bath gas: Ar
Excitation technique: Direct photolysis
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 938,
    label = "C4H8-3 + OH <=> H2O + C4H7-3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (305, 'm^3/(mol*s)', '+|-', 33),
        n = 1.5,
        Ea = (0.948, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (492, 'K'),
        Pmin = (10700, 'Pa'),
        Pmax = (11300, 'Pa'),
    ),
    reference = Article(
        authors = ["Dobe, S.", "Turanyi, T.", "Iogansen, A.A.", "Berces, T."],
        title = u'Rate constants of the reactions of OH radicals with cyclopropane and cyclobutane',
        journal = "Int. J. Chem. Kinet.",
        volume = "24",
        pages = """191-198""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992DOB/TUR191-198:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00006461
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 939,
    label = "C4H8-3 + OH <=> H2O + C4H7-3",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (8.14, 'm^3/(mol*s)'),
        n = 2,
        Ea = (0.249, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'The use of transition-state theory to extrapolate rate coefficients for reactions of OH with alkanes',
        journal = "Int. J. Chem. Kinet.",
        volume = "14",
        pages = """1339""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982COH1339:12",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006461
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006461/rk00000002.xml
""",
)

entry(
    index = 940,
    label = "H2O + C4H7-3 <=> C4H8-3 + OH",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (0.006808, 'm^3/(mol*s)'),
        n = 2.3,
        Ea = (93.122, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:28",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00006461
""",
)

entry(
    index = 941,
    label = "C5H10 + H <=> H2 + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (2410, 'm^3/(mol*s)'),
        n = 1.5,
        Ea = (20.287, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1250, 'K'),
        Pmin = (23300, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Handford-Styring, S.M.", "Walker, R.W."],
        title = u'Addition of cyclopentane to slowly reacting mixtures of H2 + O2 between 673 and 783 K: reactions of H and OH with cyclopentane and of cyclopentyl radicals',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "91",
        pages = """1431-1438""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995HAN/WAL1431-1438:4",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00006492
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006492/rk00000003.xml
Bath gas: O2
""",
)

entry(
    index = 942,
    label = "C5H12-7 + H <=> H2 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (2.64e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:30",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00007071
""",
)

entry(
    index = 943,
    label = "C5H12-7 + H <=> H2 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (40.575, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (335, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (37300, 'Pa'),
    ),
    reference = Article(
        authors = ["Furimsky, E.", "Laidler, K.J."],
        title = u'Kinetics of the Mercury- Photosensitized Decomposition of Neopentane. Part I. The Overall Mechanism',
        journal = "Can. J. Chem.",
        volume = "50",
        pages = """1115""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972FUR/LAI1115:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007071
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007071/rk00000001.xml
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 944,
    label = "C3H5-2 + HO2-2 <=> C3H6-2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.89e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (14.467, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (480, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Lodhi, Z.H.", "Walker, R.W."],
        title = u'Oxidation of allyl radicals: kinetic parameters for the reactions of allyl radicals with HO2 and O2 between 400 and 480\xb0C',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "87",
        pages = """2361-2365""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991LOD/WAL2361-2365:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00010120
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010120/rk00000001.xml
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 945,
    label = "C3H6-2 + O2 <=> C3H5-2 + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.93e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (163.795, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Frank, P.", "Hayman, G.", "Just, Th.", "Kerr, J.A.", "Murrells, T.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combusion modelling. Supplement I',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "23",
        pages = """847-1033""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994BAU/COB847-1033:54",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010120
Uncertainty: 2.0
""",
)

entry(
    index = 946,
    label = "C3H6-2 + O2 <=> C3H5-2 + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (6.03e+07, 'm^3/(mol*s)', '*|/', 20),
        n = 0,
        Ea = (199.547, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:58",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010120
Uncertainty: 20.0
""",
)

entry(
    index = 947,
    label = "C3H6-2 + O2 <=> C3H5-2 + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.95e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (163.795, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (793, 'K'),
        Tmax = (800, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Barbe, P.", "Baronnet, F.", "Martin, R.", "Perrin, D."],
        title = u'Kinetics and modeling of the thermal reaction of propene at 800 K. Part III. Propene in the presence of small amounts of oxygen',
        journal = "Int. J. Chem. Kinet.",
        volume = "30",
        pages = """503-522""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998BAR/BAR503-522:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010120
Bath gas: CH3CH=CH2
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 948,
    label = "C3H6-2 + O2 <=> C3H5-2 + HO2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.95e+06, 'm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        Ea = (163.795, 'kJ/mol', '+|-', 6.543),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (793, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Stothard, N.D.", "Walker, R.W."],
        title = u'Determination of the arrhenius parameters for the initiation reaction C3H6 + O2 \u2192\x92 CH2CHCH2 + HO2',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "87",
        pages = """241-247""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991STO/WAL241-247:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010120
Uncertainty: 2.51
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 949,
    label = "C3H5-2 + H2O2 <=> C3H6-2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.391, 'm^3/(mol*s)', '*|/', 5),
        n = 2.05,
        Ea = (56.788, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (911000, 'Pa'),
        Pmax = (911000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:107",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010128
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010128/rk00000002.xml
Uncertainty: 5.0
""",
)

entry(
    index = 950,
    label = "C3H5-2 + H2O2 <=> C3H6-2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.391, 'm^3/(mol*s)', '*|/', 5),
        n = 2.05,
        Ea = (56.788, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (1333, 'Pa'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:106",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010128
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010128/rk00000002.xml
Uncertainty: 5.0
""",
)

entry(
    index = 951,
    label = "C3H6-2 + HO2 <=> C3H5-2 + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.009631, 'm^3/(mol*s)', '*|/', 10),
        n = 2.6,
        Ea = (58.201, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:51",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010128
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010128/rk00000002.xml
Uncertainty: 10.0
""",
)

entry(
    index = 952,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (229000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-6.485, 'kJ/mol', '+|-', 4.157),
        T0 = (1, 'K'),
        Tmin = (225, 'K'),
        Tmax = (580, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:97",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
Pressure dependence: None reported
""",
)

entry(
    index = 953,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (229000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-6.652, 'kJ/mol', '+|-', 3.326),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:260",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
""",
)

entry(
    index = 954,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (229000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-6.485, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (225, 'K'),
        Tmax = (580, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:203",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
""",
)

entry(
    index = 955,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (229000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (-6.652, 'kJ/mol', '+|-', 3.326),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.J.", "Molina, M.J."],
        title = u'Chemical Kinetic and Photochemical Data for Use in Stratospheric Modeling: Evaluation No. 11 of the NASA Panel for Data Evaluation',
        journal = "JPL Publication 94-26",
        pages = """1-2""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DEM/SAN:240",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
Uncertainty: 2.0
""",
)

entry(
    index = 956,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (247000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-6.568, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (680, 'K'),
    ),
    reference = Article(
        authors = ["Lightfoot, P.D.", "Cox, R.A.", "Crowley, J.N.", "Destriau, M.", "Hayman, G.D.", "Jenkin, M.E.", "Moortgat, G.K.", "Zabel, F."],
        title = u'Organic peroxy radicals: kinetics, spectroscopy and tropospheric chemistry',
        journal = "Atmos. Environ. Part A",
        volume = "26",
        pages = """1805-1961""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992LIG/COX1805-1961:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
""",
)

entry(
    index = 957,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (229000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-6.485, 'kJ/mol', '+|-', 4.149),
        T0 = (1, 'K'),
        Tmin = (225, 'K'),
        Tmax = (580, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:174",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
""",
)

entry(
    index = 958,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (102000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (-8.314, 'kJ/mol', '+|-', 4.157),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (380, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:99",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
Uncertainty: 2.0
""",
)

entry(
    index = 959,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (46300, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (-10.809, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:133",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
Uncertainty: 5.0
""",
)

entry(
    index = 960,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (175000, 'm^3/(mol*s)', '+|-', 17000),
        n = 0,
        Ea = (-7.167, 'kJ/mol', '+|-', 0.358),
        T0 = (1, 'K'),
        Tmin = (248, 'K'),
        Tmax = (700, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Lightfoot, P.D.", "Roussel, P.", "Caralp, F.", "Lesclaux, R."],
        title = u'Flash photolysis study of the CH3O2 + CH3O2 and CH3O2 + HO2 reactions between 600 and 719 K: unimolecular decomposition of methylhydroperoxide',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "87",
        pages = """3213-3220""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991LIG/ROU3213-3220:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 961,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (181000, 'm^3/(mol*s)', '+|-', 72000),
        n = 0,
        Ea = (-5.986, 'kJ/mol', '+|-', 0.84),
        T0 = (1, 'K'),
        Tmin = (228, 'K'),
        Tmax = (380, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Dagaut, P.", "Wallington, T.J.", "Kurylo, M.J."],
        title = u'Temperature dependence of the rate constant for the HO2 + CH3O2 gas-phase reaction',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """3833""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988DAG/WAL3833:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 962,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (46300, 'm^3/(mol*s)', '*|/', 3.4),
        n = 0,
        Ea = (-10.809, 'kJ/mol', '+|-', 3.018),
        T0 = (1, 'K'),
        Tmin = (275, 'K'),
        Tmax = (338, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Cox, R.A.", "Tyndall, G.S."],
        title = u'Rate Constants for the Reactions of CH3O2 with HO2, NO and NO2 using Molecular Modulation Spectrometry',
        journal = "J. Chem. Soc. Faraday Trans. 2",
        volume = "76",
        pages = """153""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980COX/TYN153:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
Uncertainty: 3.4000001
Bath gas: N2
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 963,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (47000, 'm^3/(mol*s)', '+|-', 7000),
        n = 0,
        Ea = (-10.726, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (274, 'K'),
        Tmax = (338, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Cox, R.A.", "Tyndall, G.S."],
        title = u'Rate Constants for Reactions of CH3O2 in the Gas Phase',
        journal = "Chem. Phys. Lett.",
        volume = "65",
        pages = """357""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979COX/TYN357:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010441
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010441/rk00000001.xml
Bath gas: N2
Excitation technique: Direct photolysis
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 964,
    label = "CH3O2 + HO2-2 <=> CH4O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (21100, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-15.215, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (225, 'K'),
        Tmax = (375, 'K'),
    ),
    reference = Article(
        authors = ["Anglada, J.M.", "Olivella, S.", "Sole, A."],
        title = u'Mechanistic study of the CH3O2 center dot+HO2 center dot -&gt; CH3O2H+O-2 reaction in the gas phase. Computational evidence for the formation of a hydrogen-bonded diradical complex',
        journal = "J. Phys. Chem. A",
        volume = "110",
        pages = """6073-6082""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006ANG/OLI6073-6082:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00010441

Geometries of stationary points of both singlet and triplet surfaces optimized at MCSCG/CASSCF level of theory with the 6-311+(3df,2p) basis set.
The lowest energy pathway is on the triplet PES and leads to CH3OOH and O2. The strong negative temperature dependence is due to the formation of a hydrogen-bonded diradical complex.
Reported rate constants for all reaction channels and include an Eckart tunneling factor. Parameters are abstractor fit to the reported data.
""",
)

entry(
    index = 965,
    label = "CH3O2 + H2O2 <=> CH4O2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.41e+06, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (41.572, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:135",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010450
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010450/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 966,
    label = "C3H7 + H2O2 <=> C3H8 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0187, 'm^3/(mol*s)', '*|/', 5),
        n = 2.11,
        Ea = (10.726, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:113",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010539
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010539/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 967,
    label = "C3H8 + HO2 <=> C3H7 + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0476, 'm^3/(mol*s)', '*|/', 10),
        n = 2.55,
        Ea = (69.01, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:35",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010539
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010539/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 968,
    label = "C2H3O-2 + H2O2 <=> C2H4O-2 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (181000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (34.422, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W.", "Hampson, R.F."],
        title = u'Chemical kinetic data base for combustion chemistry. Part I. Methane and related compounds',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """1087""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986TSA/HAM1087:210",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011760
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011760/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 969,
    label = "C2H4O-2 + HO2 <=> C2H3O-2 + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.01e+06, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (49.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (900, 'K'),
        Tmax = (1200, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:69",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011760
Uncertainty: 10.0
""",
)

entry(
    index = 970,
    label = "C2H4O-2 + HO2 <=> C2H3O-2 + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.7e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (44.482, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1030, 'K'),
        Tmax = (1120, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Colket, M.B., III", "Naegeli, D.W.", "Glassman, I."],
        title = u'High Temperature Oxidation of Acetaldehyde',
        journal = "Symp. Int. Combust. Proc.",
        volume = "16",
        pages = """1023""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977COL/NAE1023:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00011760
Bath gas: N2
""",
)

entry(
    index = 971,
    label = "C5H12-8 + H <=> H2 + C5H11-8",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.32e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (39.244, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (753, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Baldwin, R.F.", "Walker, R.W."],
        title = u'Rate Constants for Hydrogen + Oxygen System, and for H Atoms and OH Radicals + Alkanes',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "75",
        pages = """140""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAL/WAL140:18",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00003835
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003835/rk00000001.xml
""",
)

entry(
    index = 972,
    label = "C4H8-4 + CH3 <=> CH4 + C4H7-4",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (250000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (34.838, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (700, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:68",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00004666
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004666/rk00000002.xml
Uncertainty: 2.0
""",
)

entry(
    index = 973,
    label = "C2H4O2-2 + CH3 <=> CH4 + C2H3O2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (79400, 'm^3/(mol*s)'),
        n = 0,
        Ea = (37.665, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (382, 'K'),
        Tmax = (510, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (17300, 'Pa'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.j."],
        title = u'Reactions of alkyl radicals. Part 1.-Methyl radical photosensitized decomposition of ethyl formate',
        journal = "Trans. Faraday Soc.",
        volume = "58",
        pages = """676""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962THY676:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004963
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004963/rk00000001.xml
Bath gas: HC(O)OCH3
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 974,
    label = "C2H4O2-2 + CH3 <=> CH4 + C2H3O2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (501000, 'm^3/(mol*s)', '*|/', 1.41),
        n = 0,
        Ea = (43.069, 'kJ/mol', '+|-', 0.865),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (519, 'K'),
    ),
    reference = Article(
        authors = ["Donovan, T.R.", "Dorko, W.", "Harrison, A.G."],
        title = u'Hydrogen Abstraction from Methyl Formate by Methyl Radicals',
        journal = "Can. J. Chem.",
        volume = "49",
        pages = """828""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971DON/DOR828:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004963
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004963/rk00000002.xml
Uncertainty: 1.41
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 975,
    label = "C2H4O2-2 + CH3 <=> CH4 + C2H3O2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (6.564e-05, 'm^3/(mol*s)'),
        n = 3.32,
        Ea = (41.87, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Good, D.A.", "Francisco, LJ.S."],
        title = u'A Computational Study of the Reaction of Methyl Formate with \xb7H and \xb7CH3 Radicals',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """1733-1738""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GOO/FRA1733-1738:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00004963
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004963/rk00000003.xml

The authors used ab initio molecular orbital theory to examine the kinetics and mechanism of the reaction of hydrogen and methyl radicals with methyl formate. Structures, energies, and molecular properties of the species and transition-states are reported. The branching ratios for abstraction of the hydrogens are calculated. Abstraction of the carbonyl hydrogen of methyl formate is significantly favored (85% for H atom) at 298 K, becoming relatively less favored as the temperature increases. Results are compared with previous calculations and experiments on the reaction OH with methyl formate.

The listed rate expression is a fit derived at NIST to the calculated rate constants reported by the authors at 298, 600, 1000, 1500, 2000, and 2500 K. The fitted expression reproduces the calculated rates within 2.5%.
""",
)

entry(
    index = 976,
    label = "C2H4O2 + OH <=> H2O + C2H3O2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (2.13, 'm^3/(mol*s)'),
        n = 2,
        Ea = (6.1, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Good, D.A.", "Francisco, LJ.S."],
        title = u'A Computational Study of the Reaction of Methyl Formate with \xb7H and \xb7CH3 Radicals',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """1733-1738""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GOO/FRA1733-1738:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00004966
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004966/rk00000001.xml

The authors used ab initio molecular orbital theory to examine the kinetics and mechanism of the reaction of hydrogen and methyl radicals with methyl formate. Structures, energies, and molecular properties of the species and transition-states are reported. The branching ratios for abstraction of the hydrogens are calculated. Abstraction of the carbonyl hydrogen of methyl formate is significantly favored (85% for H atom) at 298 K, becoming relatively less favored as the temperature increases. Results are compared with previous calculations and experiments on the reaction OH with methyl formate.

The listed rate expression is a fit derived at NIST to the calculated rate constants reported by the authors at 298, 600, 1000, 1500, 2000, and 2500 K. The fitted expression reproduces the calculated rates within 2.5%.
""",
)

entry(
    index = 977,
    label = "C2H4O2-2 + OH <=> H2O + C2H3O2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.61, 'm^3/(mol*s)'),
        n = 1.87,
        Ea = (0.11, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Good, D.A.", "Francisco, LJ.S."],
        title = u'A Computational Study of the Reaction of Methyl Formate with \xb7H and \xb7CH3 Radicals',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """1733-1738""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GOO/FRA1733-1738:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00004967
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004967/rk00000001.xml

The authors used ab initio molecular orbital theory to examine the kinetics and mechanism of the reaction of hydrogen and methyl radicals with methyl formate. Structures, energies, and molecular properties of the species and transition-states are reported. The branching ratios for abstraction of the hydrogens are calculated. Abstraction of the carbonyl hydrogen of methyl formate is significantly favored (85% for H atom) at 298 K, becoming relatively less favored as the temperature increases. Results are compared with previous calculations and experiments on the reaction OH with methyl formate.

The listed rate expression is a fit derived at NIST to the calculated rate constants reported by the authors at 298, 600, 1000, 1500, 2000, and 2500 K. The fitted expression reproduces the calculated rates within 2.5%.
""",
)

entry(
    index = 978,
    label = "C2H4O2 + CH3 <=> CH4 + C2H3O2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1.391e-05, 'm^3/(mol*s)'),
        n = 3.35,
        Ea = (48.22, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Good, D.A.", "Francisco, LJ.S."],
        title = u'A Computational Study of the Reaction of Methyl Formate with \xb7H and \xb7CH3 Radicals',
        journal = "J. Phys. Chem. A",
        volume = "106",
        pages = """1733-1738""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002GOO/FRA1733-1738:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00004962
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004962/rk00000001.xml

The authors used ab initio molecular orbital theory to examine the kinetics and mechanism of the reaction of hydrogen and methyl radicals with methyl formate. Structures, energies, and molecular properties of the species and transition-states are reported. The branching ratios for abstraction of the hydrogens are calculated. Abstraction of the carbonyl hydrogen of methyl formate is significantly favored (85% for H atom) at 298 K, becoming relatively less favored as the temperature increases. Results are compared with previous calculations and experiments on the reaction OH with methyl formate.

The listed rate expression is a fit derived at NIST to the calculated rate constants reported by the authors at 298, 600, 1000, 1500, 2000, and 2500 K. The fitted expression reproduces the calculated rates within 2.5%.
""",
)

entry(
    index = 979,
    label = "C4H8-5 + CH3 <=> CH4 + C4H7-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (16000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (30.514, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (436, 'K'),
        Pmin = (5466, 'Pa'),
        Pmax = (8666, 'Pa'),
    ),
    reference = Article(
        authors = ["Yokoyama, N.", "Brinton, R.K."],
        title = u'Reaction of methyl radicals with cis-butene-2',
        journal = "Can. J. Chem.",
        volume = "47",
        pages = """2987""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969YOK/BRI2987:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007720
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007720/rk00000001.xml
Bath gas: CH3CHO
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 980,
    label = "C4H8-5 + CH3 <=> CH4 + C4H7-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (180000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (33.923, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (700, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:92",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00007720
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007720/rk00000002.xml
Uncertainty: 2.0
""",
)

entry(
    index = 981,
    label = "C4H8-5 + CH3 <=> CH4 + C4H7-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (309000, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (34.921, 'kJ/mol', '+|-', 2.444),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
    ),
    reference = Article(
        authors = ["Sway, M.I."],
        title = u'Arrhenius parameters for reactions of methyl radicals with alkenes',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "29",
        pages = """900-902""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990SWA900-902:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007720
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007720/rk00000004.xml
Uncertainty: 1.58
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Laser magnetic resonance (LMR)
""",
)

entry(
    index = 982,
    label = "C4H8-5 + CH3 <=> CH4 + C4H7-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (40.242, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (700, 'K'),
    ),
    reference = Book(
        authors = ["Warnatz, J."],
        title = u'Rate coefficients in the C/H/O system',
        publisher = "ed. W.C. Gardiner,Jr., pub. Springer-Verlag,NY",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984WAR197C:96",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00008211
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008211/rk00000002.xml
Uncertainty: 2.0
""",
)

entry(
    index = 983,
    label = "C4H10O-3 + CH3 <=> CH4 + C4H9O-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (40.824, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (418, 'K'),
        Tmax = (453, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (2666, 'Pa'),
    ),
    reference = Article(
        authors = ["Long, J.", "Skirrow, G."],
        title = u'Reaction of methyl radicals with di-ethyl ether',
        journal = "Trans. Faraday Soc.",
        volume = "58",
        pages = """1403""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962LON/SKI1403:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001562
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001562/rk00000001.xml
Uncertainty: 2.0
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Pressure measurement
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 984,
    label = "C3H6O + C2H3 <=> C2H4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (123000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.876, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    reference = Article(
        authors = ["Scherzer, K.", "Loser, U.", "Stiller, W."],
        title = u'BSBL-Rechnungen zu wasserstoffabspaltungsreaktionen durch alkenylradikale; Vinylradikale',
        journal = "Z. Chem.",
        volume = "27",
        pages = """300""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987SCH/LOS300:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Bond energy-bond order (BEBO)""",
    longDesc = 
u"""
PrIMe Reaction: r00001773
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001773/rk00000001.xml
""",
)

entry(
    index = 985,
    label = "C6H6 + H <=> H2 + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (602, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (68.428, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (800, 'K'),
    ),
    reference = Article(
        authors = ["Mebel, A.M.", "Lin, M.C.", "Yu, T.", "Morokuma, K."],
        title = u'Theoretical study of potential energy surface and thermal rate constants for the C6H5 + H2 and C6H6 + H reactions',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """3189-3196""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997MEB/LIN3189-3196:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""RRK(M) extrapolation""",
    longDesc = 
u"""
PrIMe Reaction: r00001912
Pressure dependence: Rate constant is high pressure limit
""",
)

entry(
    index = 986,
    label = "C6H6 + H <=> H2 + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.01e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.923, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Nicovich, J.M.", "Ravishankara, A.R."],
        title = u'Reaction of hydrogen atom with benzene: Kinetics and mechanism',
        journal = "J. Phys. Chem.",
        volume = "88",
        pages = """2534-2541""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984NIC/RAV2534-2541:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001912
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 987,
    label = "C6H6 + H <=> H2 + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (142, 'm^3/(mol*s)'),
        n = 1.77,
        Ea = (54.626, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Violi, A.", "Truong, T.N.", "Sarofim, A.F."],
        title = u'Kinetics of hydrogen abstraction reactions from polycyclic aromatic hydrocarbons by H atoms',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """4846-4852""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004VIO/TRU4846-4852:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001912

Expressions are derived for rate constants of the reactions of hydrogen abstraction by H atom from six-member aromatic rings.
""",
)

entry(
    index = 988,
    label = "C6H6 + H <=> H2 + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (106000, 'm^3/(mol*s)'),
        n = (1.08, '', '+|-', 0.06),
        Ea = (43.639, 'kJ/mol', '+|-', 1.674),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Barckholtz, C.", "Barchholtz, T.A.", "Hadad, C.M."],
        title = u'A Mechanistic Study of the Reactions of H, O(3P), and OH with Monocyclic Aromatic Hydrocarbons by Density Functional Theory',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """140-152""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001BAR/BAR140-152:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001912
Pressure dependence: Rate constant is high pressure limit

Authors reported rate constant for forward reaction at 298.15 K (units assumed to cm3molecule-1s-1from the magnitude) and the temperature exponent (n) and activation energy (Ea) in a modified Arrhenius expression calculated from transition state theory rate constants (not reported) at 298-2000 K. Abstracter used the reported rate constant at 298.15 K to calculate the A-factor, which is abstracted without error bounds. Error bounds on n and Eaare assumed to be one sigma from the least-squares fit.
""",
)

entry(
    index = 989,
    label = "C6H6 + H <=> H2 + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.98e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (30.098, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1700, 'K'),
        Pmin = (203000, 'Pa'),
        Pmax = (811000, 'Pa'),
    ),
    reference = Article(
        authors = ["Asaba, T.", "Fujii, N."],
        title = u'High temperature oxidation of benzene',
        journal = "Proc. Int. Symp. Shock Tubes Waves",
        volume = "8",
        pages = """1-12""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971ASA/FUJ1-12:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00001912
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001912/rk00000001.xml
Bath gas: Ar
""",
)

entry(
    index = 990,
    label = "H2 + C6H5 <=> C6H6 + H",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.79e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (34.754, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (548, 'K'),
        Tmax = (607, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Park, J.", "Dyakov, I.V.", "Lin, M.C."],
        title = u'FTIR and mass-spectrometric measurements of the rate constant for the C6H5 + H2 reaction',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """8839-8843""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997PAR/DYA8839-8843:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001912
Bath gas: Ar
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Fourier transform (FTIR)
""",
)

entry(
    index = 991,
    label = "H2 + C6H5 <=> C6H6 + H",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.98e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.008, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1050, 'K'),
        Tmax = (1450, 'K'),
    ),
    reference = Article(
        authors = ["Heckmann, E.", "Hippler, H.", "Troe, J."],
        title = u'High-temperature reactions and thermodynamic properties of phenyl radicals',
        journal = "Symp. Int. Combust. Proc.",
        volume = "26",
        pages = """543-550""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996HEC/HIP543-550:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001912
Bath gas: Ar
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 992,
    label = "H2 + C6H5 <=> C6H6 + H",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.0571, 'm^3/(mol*s)'),
        n = 2.43,
        Ea = (26.274, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (5000, 'K'),
    ),
    reference = Article(
        authors = ["Mebel, A.M.", "Lin, M.C.", "Yu, T.", "Morokuma, K."],
        title = u'Theoretical study of potential energy surface and thermal rate constants for the C6H5 + H2 and C6H6 + H reactions',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """3189-3196""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997MEB/LIN3189-3196:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001912
""",
)

entry(
    index = 993,
    label = "C2H6 + C4H9 <=> C4H10 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (500000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (62.774, 'kJ/mol', '+|-', 16.962),
        T0 = (1, 'K'),
        Tmin = (823, 'K'),
        Tmax = (999, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (80000, 'Pa'),
    ),
    reference = Article(
        authors = ["Lin, M.C.", "Back, M.H."],
        title = u'The thermal decomposition of ethane. Part III. Secondary reactions',
        journal = "Can. J. Chem.",
        volume = "44",
        pages = """2369""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966LIN/BAC2369:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002102
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002102/rk00000001.xml
Bath gas: C2H6
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 994,
    label = "C3H8 + C3H7-2 <=> C3H8-2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (8.44e-09, 'm^3/(mol*s)', '*|/', 2),
        n = 4.2,
        Ea = (36.501, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:16",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002707
Uncertainty: 2.0
""",
)

entry(
    index = 995,
    label = "C3H8 + C3H7-2 <=> C3H8-2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (31600, 'm^3/(mol*s)'),
        n = 0,
        Ea = (53.961, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (301, 'K'),
        Tmax = (399, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (28100, 'Pa'),
    ),
    reference = Article(
        authors = ["Berkley, R.E.", "Woodall, G.N.C.", "Strausz, O.P.", "Gunning, H.E."],
        title = u'Arrbenius parameters for the reaction of propyl radicals with propane',
        journal = "Can. J. Chem.",
        volume = "47",
        pages = """3305-3311""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969BER/WOO3305-3311:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002707
Bath gas: C3H8
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 996,
    label = "C3H8 + C3H7-2 <=> C3H8-2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.26e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (73.25, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (714, 'K'),
        Tmax = (776, 'K'),
        Pmin = (3466, 'Pa'),
        Pmax = (55500, 'Pa'),
    ),
    reference = Article(
        authors = ["Leathard, D.A.", "Purnell, J.H."],
        title = u'Propyl radical isomerization and heterogeneous effects in the pyrolysis of propane below 500\xb0C',
        journal = "Proc. R. Soc. London A",
        volume = "306",
        pages = """553""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968LEA/PUR553:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002707
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002707/rk00000001.xml
Bath gas: C3H8
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 997,
    label = "C3H8-2 + C3H7 <=> C3H8 + C3H7-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (8.43e-10, 'm^3/(mol*s)', '*|/', 1.5),
        n = 4,
        Ea = (19.788, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:21",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002707
Uncertainty: 1.5
""",
)

entry(
    index = 998,
    label = "C3H8-2 + C3H7 <=> C3H8 + C3H7-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (7940, 'm^3/(mol*s)'),
        n = 0,
        Ea = (38.912, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (301, 'K'),
        Tmax = (399, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (28100, 'Pa'),
    ),
    reference = Article(
        authors = ["Berkley, R.E.", "Woodall, G.N.C.", "Strausz, O.P.", "Gunning, H.E."],
        title = u'Arrbenius parameters for the reaction of propyl radicals with propane',
        journal = "Can. J. Chem.",
        volume = "47",
        pages = """3305-3311""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969BER/WOO3305-3311:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002707
Bath gas: C3H8
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 999,
    label = "C3H8-2 + CH3O2 <=> CH4O2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.99e+06, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (71.338, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:19",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002716
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002716/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1000,
    label = "C3H8 + CH3O2 <=> CH4O2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (6.03e+06, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (81.066, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:20",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002717
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002717/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1001,
    label = "C3H8-2 + C2H3O-2 <=> C2H4O-2 + C3H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (5.3, 'm^3/(mol*s)', '*|/', 3),
        n = 2,
        Ea = (67.929, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:32",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002734
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002734/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1002,
    label = "C3H8 + C2H3O-2 <=> C2H4O-2 + C3H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.0421, 'm^3/(mol*s)', '*|/', 3),
        n = 2.6,
        Ea = (73.916, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 3. Propane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "17",
        pages = """887""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988TSA887:33",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00002735
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002735/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1003,
    label = "C2H4O-2 + C3H5-2 <=> C3H6-2 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (380000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (30.182, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (790, 'K'),
        Tmax = (810, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00003004
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003004/rk00000001.xml
""",
)

entry(
    index = 1004,
    label = "C3H6-2 + C2H3O-2 <=> C2H4O-2 + C3H5-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.3, 'm^3/(mol*s)', '*|/', 10),
        n = 2,
        Ea = (67.929, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:49",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003004
Uncertainty: 10.0
""",
)

entry(
    index = 1005,
    label = "C3H6-2 + C2H3O-2 <=> C2H4O-2 + C3H5-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (155000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (29.184, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (490, 'K'),
        Tmax = (510, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:10",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00003004
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003004/rk00000001.xml
""",
)

entry(
    index = 1006,
    label = "C4H10-2 + C2H5 <=> C2H6 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.4e-07, 'm^3/(mol*s)', '*|/', 2.5),
        n = 3.46,
        Ea = (24.943, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:51",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003275
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003275/rk00000001.xml
Uncertainty: 2.5
""",
)

entry(
    index = 1007,
    label = "C2H6 + C4H9-2 <=> C4H10-2 + C2H5",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.38e-12, 'm^3/(mol*s)', '*|/', 3),
        n = 5.17,
        Ea = (37.914, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003275
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003275/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1008,
    label = "C4H10-4 + C2H5 <=> C2H6 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1.39e-06, 'm^3/(mol*s)', '*|/', 2.5),
        n = 3.65,
        Ea = (38.247, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:52",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003276
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003276/rk00000001.xml
Uncertainty: 2.5
""",
)

entry(
    index = 1009,
    label = "C2H6 + C4H9-4 <=> C4H10-4 + C2H5",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (2.9e-07, 'm^3/(mol*s)', '*|/', 3),
        n = 3.7,
        Ea = (40.907, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:10",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003276
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003276/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1010,
    label = "C4H10-2 + CH3O <=> CH4O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (22900, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (12.056, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:30",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003287
Uncertainty: 10.0
""",
)

entry(
    index = 1011,
    label = "C4H10-2 + CH3O <=> CH4O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (398000, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (10.061, 'kJ/mol', '+|-', 4.623),
        T0 = (1, 'K'),
        Tmin = (383, 'K'),
        Tmax = (433, 'K'),
        Pmin = (68000, 'Pa'),
        Pmax = (68000, 'Pa'),
    ),
    reference = Article(
        authors = ["Batt, L.", "Rattray, G.N."],
        title = u'The Reaction of Methoxy Radicals with Nitric Oxide and Nitrogen Dioxide',
        journal = "Int. J. Chem. Kinet.",
        volume = "11",
        pages = """1183""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979BAT/RAT1183:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003287
Uncertainty: 5.0
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1012,
    label = "C4H10-2 + CH3O <=> CH4O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (200000, 'm^3/(mol*s)', '*|/', 1.74),
        n = 0,
        Ea = (17.128, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (464, 'K'),
        Tmax = (533, 'K'),
        Pmin = (453, 'Pa'),
        Pmax = (760, 'Pa'),
    ),
    reference = Article(
        authors = ["Berces, T.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of methoxyl radicals with cyclopropane and isobutane',
        journal = "J. Chem. Soc.",
        pages = """348""",
        year = "1961",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1961BER/TRO348:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003287
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003287/rk00000001.xml
Uncertainty: 1.74
Bath gas: iso-C4H10
Excitation technique: Thermal
Analytical technique: Gas chromatography
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 1013,
    label = "CH4O + C4H9-2 <=> C4H10-2 + CH3O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.001506, 'm^3/(mol*s)', '*|/', 10),
        n = 1.8,
        Ea = (39.161, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003287
Uncertainty: 10.0
""",
)

entry(
    index = 1014,
    label = "C4H10-4 + CH3O <=> CH4O + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (482000, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (30.597, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:31",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003288
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003288/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1015,
    label = "CH4O + C4H9-4 <=> C4H10-4 + CH3O",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1.445e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.1,
        Ea = (37.498, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:5",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003288
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003288/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1016,
    label = "C4H10-2 + CH3O-2 <=> CH4O-2 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.000121, 'm^3/(mol*s)', '*|/', 5),
        n = 2.76,
        Ea = (45.148, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:34",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003298
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003298/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1017,
    label = "CH4O-2 + C4H9-2 <=> C4H10-2 + CH3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (7.83e-11, 'm^3/(mol*s)', '*|/', 10),
        n = 4.7,
        Ea = (37.997, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:4",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003298
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003298/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1018,
    label = "C4H10-4 + CH3O-2 <=> CH4O-2 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (0.000301, 'm^3/(mol*s)', '*|/', 5),
        n = 2.95,
        Ea = (58.451, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:35",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003299
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003299/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1019,
    label = "CH4O-2 + C4H9-4 <=> C4H10-4 + CH3O-2",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (3.185e-05, 'm^3/(mol*s)', '*|/', 3),
        n = 3.17,
        Ea = (38.33, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:6",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003299
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003299/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1020,
    label = "C4H10-2 + CHO <=> CH2O + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.0343, 'm^3/(mol*s)', '*|/', 5),
        n = 2.5,
        Ea = (56.538, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:36",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003300
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003300/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1021,
    label = "CH2O + C4H9-2 <=> C4H10-2 + CHO",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3250, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (14.883, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003300
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003300/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1022,
    label = "C4H10-4 + CHO <=> CH2O + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (0.307, 'm^3/(mol*s)', '*|/', 5),
        n = 2.5,
        Ea = (77.158, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:37",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003301
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003301/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1023,
    label = "CH2O + C4H9-4 <=> C4H10-4 + CHO",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (301000, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (27.188, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:2",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003301
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003301/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1024,
    label = "C4H10-2 + C2H3 <=> C2H4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (9e-07, 'm^3/(mol*s)', '*|/', 5),
        n = 3.46,
        Ea = (10.892, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:38",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003302
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003302/rk00000002.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1025,
    label = "C4H10-4 + C2H3 <=> C2H4 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1.36e-06, 'm^3/(mol*s)', '*|/', 5),
        n = 3.65,
        Ea = (21.618, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:39",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003303
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003303/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1026,
    label = "C4H10-2 + HO2 <=> H2O2 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.003611, 'm^3/(mol*s)', '*|/', 10),
        n = 2.55,
        Ea = (44.067, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:42",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003313
Uncertainty: 10.0
""",
)

entry(
    index = 1027,
    label = "C4H10-2 + HO2 <=> H2O2 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (100000, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (29.267, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:5",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003313
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003313/rk00000003.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1028,
    label = "H2O2 + C4H9-2 <=> C4H10-2 + HO2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3e-08, 'm^3/(mol*s)', '*|/', 5),
        n = 3.79,
        Ea = (1.131, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:88",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003313
Uncertainty: 5.0
""",
)

entry(
    index = 1029,
    label = "C4H10-2 + O2 <=> HO2-2 + C4H9-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (3.97e+07, 'm^3/(mol*s)', '*|/', 3),
        n = 0,
        Ea = (183.75, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:47",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003329
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003329/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1030,
    label = "C4H10-4 + O2 <=> HO2-2 + C4H9-4",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (4.04e+07, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (212.85, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:48",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003330
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003330/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1031,
    label = "C5H12-2 + OH <=> H2O + C5H11-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2900, 'm^3/(mol*s)'),
        n = 1,
        Ea = (-0.09146, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:5",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003823
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003823/rk00000003.xml
""",
)

entry(
    index = 1032,
    label = "C5H12-3 + OH <=> H2O + C5H11-3",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2550, 'm^3/(mol*s)'),
        n = 1,
        Ea = (-1.33, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:6",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003824
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003824/rk00000003.xml
""",
)

entry(
    index = 1033,
    label = "C4H8O + CH3 <=> CH4 + C4H7O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.98e+06, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (36.417, 'kJ/mol', '+|-', 1.089),
        T0 = (1, 'K'),
        Tmin = (395, 'K'),
        Tmax = (448, 'K'),
        Pmin = (5706, 'Pa'),
        Pmax = (6866, 'Pa'),
    ),
    reference = Article(
        authors = ["Birrell, R.N.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VI. The reactions of methyl radicals with aliphatic aldehydes',
        journal = "J. Chem. Soc.",
        pages = """2059""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960BIR/TRO2059:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003871
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003871/rk00000001.xml
Uncertainty: 1.58
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1034,
    label = "C3H4O2 + OH <=> H2O + C3H3O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.1e+06, 'm^3/(mol*s)', '+|-', 289000),
        n = 0,
        Ea = (-4.656, 'kJ/mol', '+|-', 0.582),
        T0 = (1, 'K'),
        Tmin = (233, 'K'),
        Tmax = (500, 'K'),
        Pmin = (667, 'Pa'),
        Pmax = (40000, 'Pa'),
    ),
    reference = Article(
        authors = ["Baeza-Romero, M.T.", "Glowacki, D.R.", "Blitz, M.A.", "Heard, D.E.", "Pilling, M.J.", "Rickard, A.R.", "Seakins, P.W."],
        title = u'A combined experimental and theoretical study of the reaction between methylglyoxal and OH/OD radical: OH regeneration',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "9",
        pages = """4114-4128""",
        year = "2007",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2007BAE/GLO4114-4128:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003940
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1035,
    label = "C3H4O2 + OH <=> H2O + C3H3O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (506000, 'm^3/(mol*s)', '+|-', 71000),
        n = 0,
        Ea = (-6.901, 'kJ/mol', '+|-', 0.414),
        T0 = (1, 'K'),
        Tmin = (260, 'K'),
        Tmax = (333, 'K'),
        Pmin = (267, 'Pa'),
        Pmax = (400, 'Pa'),
    ),
    reference = Article(
        authors = ["Tyndall, G.S.", "Staffelbach, T.A.", "Orlando, J.J.", "Calvert, J.G."],
        title = u'Rate coefficients for the reactions of OH radicals with methylglyoxal and acetaldehyde',
        journal = "Int. J. Chem. Kinet.",
        volume = "27",
        pages = """1009-1020""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995TYN/STA1009-1020:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003940
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003940/rk00000003.xml
Bath gas: He
Excitation technique: Electron beam
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1036,
    label = "C3H4O2 + OH <=> H2O + C3H3O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (237000, 'm^3/(mol*s)', '+|-', 6620),
        n = 0,
        Ea = (-8.813, 'kJ/mol', '+|-', 0.06652),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Galano, A.", "Alvarez-Idaboy, J.R.", "Ruiz-Santoyo, M.E.", "Vivier-Bunge, A."],
        title = u'Mechanism and kinetics of the reaction of OH radicals with glyoxal and methylglyoxal: A quantum chemistry plus CVT/SCT approach',
        journal = "ChemPhysChem",
        volume = "5",
        pages = """1379-1388""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004GAL/ALV1379-1388:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00003940

A theoretical study of the kinetics of the hydrogen abstractions from glyoxal and methylglyoxal by OH at several levels of theory is reported. Geometries, frequencies, and gradients were calculated at the BHandHLYP/6-311++G(d,p) level of theory with PES energies obtained using CCSD(T)/6-311++G(d,p) calculations. Rate coefficients were calculated using CVT/SCT methodology.

Only abstraction of the aldehydic H is found to be important over the studied range of 200-500 K. Results suggest the formation of a reactive complex and are in excellent agreement with experimental data. Calculations performed assuming a direct abstacion (no complex) are in significantly poorer agreement..

Uncertainties represent 2 standard deviations of the analytical expression from the actual calculated values.
""",
)

entry(
    index = 1037,
    label = "C4H10-3 + HO2 <=> H2O2 + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (500000, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (43.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Lloyd, A.C."],
        title = u'Evaluated and estimated kinetic data for phase reactions of the hydroperoxyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "6",
        pages = """169-228""",
        year = "1974",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1974LLO169-228:6",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00004604
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004604/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1038,
    label = "C4H10 + HO2 <=> H2O2 + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.12e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (81.149, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Pitz, W.J.", "Westbrook, C.K."],
        title = u'Chemical kinetics of the high pressure oxidation of n-butane and its relation to engine knock',
        journal = "Combust. Flame",
        volume = "63",
        pages = """113-133""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986PIT/WES113-133:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004605
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004605/rk00000001.xml
Bath gas: N2
""",
)

entry(
    index = 1039,
    label = "C3H6O-2 + C2H5 <=> C2H6 + C3H5O-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (339000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (36.168, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (323, 'K'),
        Tmax = (415, 'K'),
    ),
    reference = Article(
        authors = ["Brown, A.C.R.", "James, D.G.L."],
        title = u'A kinetic study of the metathetical and addition reactions characteristic of allyl polymerization',
        journal = "Can. J. Chem.",
        volume = "40",
        pages = """796-803""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962BRO/JAM796-803:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004932
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004932/rk00000001.xml
Bath gas: (C2H5)2CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1040,
    label = "C2H4O2-2 + CH3O <=> CH4O + C2H3O2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.62e+06, 'm^3/(mol*s)', '*|/', 1.74),
        n = 0,
        Ea = (34.256, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (393, 'K'),
        Tmax = (455, 'K'),
        Pmin = (1733, 'Pa'),
        Pmax = (9999, 'Pa'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.J.", "Gray, P."],
        title = u'Methoxyl-radical-induced decomposition of methyl formate: Kinetics of methoxyl and methyl radical reactions',
        journal = "Trans. Faraday Soc.",
        volume = "59",
        pages = """1149""",
        year = "1963",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1963THY/GRA1149:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004961
Uncertainty: 1.74
Bath gas: He
Excitation technique: Thermal
Analytical technique: Mass spectrometry
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 1041,
    label = "C2H4O2-2 + CH3O <=> CH4O + C2H3O2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.02e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (34.256, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (393, 'K'),
        Tmax = (458, 'K'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.J.", "Gray, P."],
        title = u'The reactions of methoxyl radicals with methyl formate; comparisons between alkoxyl and alkyl',
        journal = "Proc. Chem. Soc. London",
        pages = """295""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962THY/GRA295:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004961
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004961/rk00000001.xml
Bath gas: (CH3O)2
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 1042,
    label = "C5H12-4 + OH <=> H2O + C5H11-4",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (4.91, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:19",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005282
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005282/rk00000003.xml
""",
)

entry(
    index = 1043,
    label = "C5H12-5 + OH <=> H2O + C5H11-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (25.7, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (4.074, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:20",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005283
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005283/rk00000003.xml
""",
)

entry(
    index = 1044,
    label = "C5H12-6 + OH <=> H2O + C5H11-6",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2900, 'm^3/(mol*s)'),
        n = 1,
        Ea = (-0.09146, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:12",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005285
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005285/rk00000002.xml
""",
)

entry(
    index = 1045,
    label = "C5H12-6 + OH <=> H2O + C5H11-6",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.75, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.737, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (753, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:21",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005285
""",
)

entry(
    index = 1046,
    label = "C3H6O2 + CH3 <=> CH4 + C3H5O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (31600, 'm^3/(mol*s)'),
        n = 0,
        Ea = (34.339, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (370, 'K'),
        Tmax = (521, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (17300, 'Pa'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.j."],
        title = u'Reactions of alkyl radicals. Part 1.-Methyl radical photosensitized decomposition of ethyl formate',
        journal = "Trans. Faraday Soc.",
        volume = "58",
        pages = """676""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962THY676:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005362
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005362/rk00000001.xml
Bath gas: HCOOC2H5
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1047,
    label = "C3H6-2 + C3H7-2 <=> C3H8-2 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (7e-08, 'm^3/(mol*s)', '*|/', 3),
        n = 4,
        Ea = (33.757, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:26",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005638
Uncertainty: 3.0
""",
)

entry(
    index = 1048,
    label = "C3H6-2 + C3H7-2 <=> C3H8-2 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (5010, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (32.011, 'kJ/mol', '+|-', 7.042),
        T0 = (1, 'K'),
        Tmin = (496, 'K'),
        Tmax = (548, 'K'),
        Pmin = (5066, 'Pa'),
        Pmax = (30700, 'Pa'),
    ),
    reference = Article(
        authors = ["Szirovicza, L.", "Marta, F."],
        title = u'Some Reactions of the Isopropyl Radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "8",
        pages = """897""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976SZI/MAR897:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005638
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005638/rk00000001.xml
Uncertainty: 5.0
Bath gas: CH3CH=CH2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1049,
    label = "C3H8-2 + C3H5-2 <=> C3H6-2 + C3H7-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (7.867e-05, 'm^3/(mol*s)', '*|/', 5),
        n = 3.3,
        Ea = (75.994, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:13",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005638
Uncertainty: 5.0
""",
)

entry(
    index = 1050,
    label = "C3H8-2 + C3H5-2 <=> C3H6-2 + C3H7-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (347000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (56.206, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (790, 'K'),
        Tmax = (810, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005638
""",
)

entry(
    index = 1051,
    label = "C3H6-2 + CH3O2 <=> CH4O2 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1.99e+06, 'm^3/(mol*s)', '*|/', 10),
        n = 0,
        Ea = (71.338, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:33",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005652
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005652/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1052,
    label = "C3H6-2 + C3H7 <=> C3H8 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (2.23e-06, 'm^3/(mol*s)', '*|/', 3),
        n = 3.5,
        Ea = (27.77, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:34",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005653
Uncertainty: 3.0
""",
)

entry(
    index = 1053,
    label = "C3H6-2 + C3H7 <=> C3H8 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (79400, 'm^3/(mol*s)'),
        n = 0,
        Ea = (18.458, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (490, 'K'),
        Tmax = (510, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005653
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005653/rk00000001.xml
""",
)

entry(
    index = 1054,
    label = "C3H8 + C3H5-2 <=> C3H6-2 + C3H7",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.000235, 'm^3/(mol*s)', '*|/', 5),
        n = 3.3,
        Ea = (83.062, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:14",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005653
Uncertainty: 5.0
""",
)

entry(
    index = 1055,
    label = "C3H8 + C3H5-2 <=> C3H6-2 + C3H7",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (724000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (69.176, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (790, 'K'),
        Tmax = (810, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005653
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005653/rk00000001.xml
""",
)

entry(
    index = 1056,
    label = "C4H8 + O2 <=> HO2-2 + C4H7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (4.79e+06, 'm^3/(mol*s)', '*|/', 2.75),
        n = 0,
        Ea = (161.301, 'kJ/mol', '+|-', 6.452),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (793, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (6799, 'Pa'),
    ),
    reference = Article(
        authors = ["Ingham, T.", "Walker, R.W.", "Woolford, R.E."],
        title = u'Kinetic parameters for the initiation reaction RH + O2 \u2192\x92 R + HO2',
        journal = "Symp. Int. Combust. Proc.",
        volume = "25",
        pages = """767-774""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994ING/WAL767-774:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005864
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005864/rk00000001.xml
Uncertainty: 2.75
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1057,
    label = "C4H8 + O2 <=> HO2-2 + C4H7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1860, 'm^3/(mol*s)'),
        n = 1.3,
        Ea = (171.289, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Chen, C.-J.", "Bozzelli, J.W."],
        title = u'Thermochemical Property, Pathway and Kinetic Analysis on the Reactions of Allylic Isobutenyl Radical with O2: an Elementary Reaction Mechanism for Isobutene Oxidation',
        journal = "J. Phys. Chem.",
        volume = "104",
        pages = """9715-9732""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000CHE/BOZ9715-9732:1",
    ),
    referenceType = "theory",
    shortDesc = u"""RRK(M) extrapolation""",
    longDesc = 
u"""
PrIMe Reaction: r00005864
""",
)

entry(
    index = 1058,
    label = "HO2-2 + C4H7 <=> C4H8 + O2",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (639, 'm^3/(mol*s)'),
        n = 0.94,
        Ea = (0.515, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Chen, C.-J.", "Bozzelli, J.W."],
        title = u'Thermochemical Property, Pathway and Kinetic Analysis on the Reactions of Allylic Isobutenyl Radical with O2: an Elementary Reaction Mechanism for Isobutene Oxidation',
        journal = "J. Phys. Chem.",
        volume = "104",
        pages = """9715-9732""",
        year = "2000",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2000CHE/BOZ9715-9732:2",
    ),
    referenceType = "theory",
    shortDesc = u"""RRK(M) extrapolation""",
    longDesc = 
u"""
PrIMe Reaction: r00005864
""",
)

entry(
    index = 1059,
    label = "C3H6O-3 + C2H5 <=> C2H6 + C3H5O-3",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (50100, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (26.274, 'kJ/mol', '+|-', 0.789),
        T0 = (1, 'K'),
        Tmin = (538, 'K'),
        Tmax = (596, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Peter, A.", "Acs, G.", "Horvath, I.", "Huhn, P."],
        title = u'Decomposition of propionaldehyde initiated by the thermal decomposition of azoethane',
        journal = "Acta Chim. Hung.",
        volume = "108",
        pages = """235""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981PET/ACS235:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006060
Uncertainty: 1.26
Bath gas: C2H5CHO
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 1060,
    label = "C3H6O-3 + C2H5 <=> C2H6 + C3H5O-3",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (126000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (24.694, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (364, 'K'),
        Tmax = (588, 'K'),
        Pmin = (1667, 'Pa'),
        Pmax = (8679, 'Pa'),
    ),
    reference = Article(
        authors = ["Kerr, J.A.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part V. Ethyl radicals from propionaldehyde',
        journal = "J. Chem. Soc.",
        pages = """1611""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960KER/TRO1611:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006060
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006060/rk00000001.xml
Bath gas: C2H5CHO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1061,
    label = "C4H8O-2 + CH3 <=> CH4 + C4H7O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (631000, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (30.514, 'kJ/mol', '+|-', 1.222),
        T0 = (1, 'K'),
        Tmin = (394, 'K'),
        Tmax = (447, 'K'),
        Pmin = (6186, 'Pa'),
        Pmax = (7079, 'Pa'),
    ),
    reference = Article(
        authors = ["Birrell, R.N.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VI. The reactions of methyl radicals with aliphatic aldehydes',
        journal = "J. Chem. Soc.",
        pages = """2059""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960BIR/TRO2059:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006097
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006097/rk00000001.xml
Uncertainty: 1.58
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1062,
    label = "C5H10 + CH3 <=> CH4 + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (200000, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (36.002, 'kJ/mol', '+|-', 6.843),
        T0 = (1, 'K'),
        Tmin = (650, 'K'),
        Tmax = (770, 'K'),
        Pmin = (25300, 'Pa'),
        Pmax = (52900, 'Pa'),
    ),
    reference = Article(
        authors = ["Zhang, H.X.", "Ahonkhai, S.I.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from benzene, toluene, and cyclopentane by methyl and ethyl radicals over the temperature range 650-770 K',
        journal = "Can. J. Chem.",
        volume = "67",
        pages = """1541-1549""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ZHA/AHO1541-1549:9",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006481
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006481/rk00000001.xml
Uncertainty: 3.1600001
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1063,
    label = "C5H10 + OH <=> H2O + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (16.4, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-1.779, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (270, 'K'),
        Tmax = (1200, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics of the gas-phase reactions of OH radicals with alkanes and cycloalkanes',
        journal = "Atmos. Chem. Phys.",
        volume = "3",
        pages = """2233-2307""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003ATK2233-2307:24",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00006488
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006488/rk00000001.xml
""",
)

entry(
    index = 1064,
    label = "C5H10 + OH <=> H2O + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (0.365, 'm^3/(mol*s)'),
        n = 2.5,
        Ea = (-4.315, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1500, 'K'),
        Pmin = (23300, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Handford-Styring, S.M.", "Walker, R.W."],
        title = u'Addition of cyclopentane to slowly reacting mixtures of H2 + O2 between 673 and 783 K: reactions of H and OH with cyclopentane and of cyclopentyl radicals',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "91",
        pages = """1431-1438""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995HAN/WAL1431-1438:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00006488
Bath gas: O2
""",
)

entry(
    index = 1065,
    label = "C5H10 + OH <=> H2O + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (4.8, 'm^3/(mol*s)', '*|/', 3.16),
        n = 2.1,
        Ea = (-3.575, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:12",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00006488
Uncertainty: 3.1600001
""",
)

entry(
    index = 1066,
    label = "C5H10 + OH <=> H2O + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (1.55e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (4.141, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (423, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Bayes, K.D."],
        title = u'Rate constants for the reactions of hydroxyl radical with several alkanes, cycloakanes, and dimethyl ether',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """2649-2654""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999DEM/BAY2649-2654:7",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006488
Bath gas: Ar
Excitation technique: Direct photolysis
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1067,
    label = "C5H10 + OH <=> H2O + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (1.13e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (2.927, 'kJ/mol', '+|-', 0.556),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (390, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Donahue, N.M.", "Anderson, J.G.", "Demerjian, K.L."],
        title = u'New rate constants for ten OH alkane reactions from 300 to 400 K: an assessment of accuracy',
        journal = "J. Phys. Chem. A",
        volume = "102",
        pages = """3121-3126""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998DON/AND3121-3126:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00006488
Bath gas: N2
Excitation technique: Electron beam
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1068,
    label = "C5H10 + OH <=> H2O + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (363, 'm^3/(mol*s)'),
        n = 1.52,
        Ea = (-0.923, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (491, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Droege, A.T.", "Tully, F.P."],
        title = u'Hydrogen-atom abstraction from alkanes by OH. 6. Cyclopentane and cyclohexane',
        journal = "J. Phys. Chem.",
        volume = "91",
        pages = """1222""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987DRO/TUL1222:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00006488
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1069,
    label = "C5H10 + OH <=> H2O + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (4.79, 'm^3/(mol*s)'),
        n = 2.1,
        Ea = (-3.575, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'The use of transition-state theory to extrapolate rate coefficients for reactions of OH with alkanes',
        journal = "Int. J. Chem. Kinet.",
        volume = "14",
        pages = """1339""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982COH1339:13",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006488
""",
)

entry(
    index = 1070,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (832000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (46.062, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (800, 'K'),
    ),
    reference = Article(
        authors = ["Mitchell, T.J.", "Benson, S.W."],
        title = u'Modelling of the homogeneously catalyzed and uncatalyzed pyrolysis of neopentane: thermochemistry of the neopentyl radical',
        journal = "Int. J. Chem. Kinet.",
        volume = "25",
        pages = """931-955""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993MIT/BEN931-955:3",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
""",
)

entry(
    index = 1071,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1.02e+06, 'm^3/(mol*s)', '*|/', 1.4),
        n = 0,
        Ea = (47.559, 'kJ/mol', '+|-', 1.43),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M."],
        title = u'Kinetics of abstraction reactions of methyl radicals with alkanes in gas phase',
        journal = "Indian J. Chem.",
        volume = "29",
        pages = """748""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990SWA748:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
Uncertainty: 1.4
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1072,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (3.33e+07, 'm^3/(mol*s)', '+|-', 2.3e+06),
        n = 0,
        Ea = (68.844, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (829, 'K'),
        Tmax = (930, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Rodriguez, A.E.", "Pacey, P.D."],
        title = u'Kinetics of the reaction of methyl radicals with molecular deuterium at 829 and 930 K',
        journal = "J. Phys. Chem.",
        volume = "90",
        pages = """6298""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ROD/PAC6298:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
Bath gas: neo-C5H12
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1073,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (62.026, 'kJ/mol', '+|-', 1.862),
        T0 = (1, 'K'),
        Tmin = (607, 'K'),
        Tmax = (823, 'K'),
        Pmin = (933, 'Pa'),
        Pmax = (20000, 'Pa'),
    ),
    reference = Article(
        authors = ["Furue, H.", "Manthorne, K.C.", "Pacey, P.D."],
        title = u'The reaction of methyl radicals with neopentane in flow photolysis at 607-823 K',
        journal = "Can. J. Chem.",
        volume = "62",
        pages = """1203""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984FUR/MAN1203:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
Bath gas: neo-C5H12
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1074,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (501000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (43.069, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (703, 'K'),
        Tmax = (743, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Marquaire, P.M.", "Come, G.M."],
        title = u'Non Quasi-Stationary State Pyrolysis. Kinetic Parameters of Neopentane Pyrolysis Mechanism',
        journal = "React. Kinet. Catal. Lett.",
        volume = "9",
        pages = """171""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978MAR/COM171:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
Bath gas: neo-C5H12
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1075,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (6.61e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (89.796, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1030, 'K'),
        Tmax = (1300, 'K'),
        Pmin = (300000, 'Pa'),
        Pmax = (400000, 'Pa'),
    ),
    reference = Article(
        authors = ["Bradley, J.N.", "West, K.O."],
        title = u'Single-pulse Shock Tube Studies of Hydrocarbon Pyrolysis. Part 5. Pyrolysis of Neopentane',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "72",
        pages = """8""",
        year = "1976",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1976BRA/WES8:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1076,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (3.16e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (67.015, 'kJ/mol', '+|-', 2.012),
        T0 = (1, 'K'),
        Tmin = (793, 'K'),
        Tmax = (953, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Pacey, P.D."],
        title = u'The Reaction of Methyl Radicals with Neopentane',
        journal = "Can. J. Chem.",
        volume = "51",
        pages = """2415""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973PAC2415:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
Uncertainty: 5.0
Bath gas: neo-C5H12
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1077,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (832000, 'm^3/(mol*s)', '*|/', 3.02),
        n = 0,
        Ea = (49.055, 'kJ/mol', '+|-', 3.924),
        T0 = (1, 'K'),
        Tmin = (365, 'K'),
        Tmax = (495, 'K'),
    ),
    reference = Article(
        authors = ["Berkley, R.E.", "Safarik, I.", "Gunning, H.E.", "Strausz, O.P."],
        title = u'Arrhenius parameters for the reactions of methyl radicals with silane and methylsilanes',
        journal = "J. Phys. Chem.",
        volume = "77",
        pages = """1734""",
        year = "1973",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1973BER/SAF1734:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
Uncertainty: 3.02
Bath gas: (CH3N)2
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1078,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (490000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (48.141, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (529, 'K'),
        Tmax = (608, 'K'),
        Pmin = (3600, 'Pa'),
        Pmax = (30000, 'Pa'),
    ),
    reference = Article(
        authors = ["Furimsky, E.", "Laidler, K.J."],
        title = u'Kinetics of the Mercury- Photosensitized Decomposition of Neopentane. Part II. Reactions of the Methyl and Neopentyl Radicals',
        journal = "Can. J. Chem.",
        volume = "50",
        pages = """1123""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972FUR/LAI1123:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
Bath gas: neo-C5H12
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1079,
    label = "C5H12-7 + CH3 <=> CH4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (6.31e+07, 'm^3/(mol*s)', '*|/', 2.69),
        n = 0,
        Ea = (72.003, 'kJ/mol', '+|-', 7.915),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (833, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (73300, 'Pa'),
    ),
    reference = Article(
        authors = ["Halstead, M.P.", "Konar, R.S.", "Leathard, D.A.", "Marshall, R.M.", "Purnell, J.H."],
        title = u'The self-inhibited pyrolysis of neopentane at small extents of reaction',
        journal = "Proc. R. Soc. London A",
        volume = "310",
        pages = """525""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969HAL/KON525:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007057
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007057/rk00000004.xml
Uncertainty: 2.6900001
Bath gas: neo-C5H12
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1080,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (11.2, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.721, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (280, 'K'),
        Tmax = (910, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics of the gas-phase reactions of OH radicals with alkanes and cycloalkanes',
        journal = "Atmos. Chem. Phys.",
        volume = "3",
        pages = """2233-2307""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003ATK2233-2307:11",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007065/rk00000001.xml
""",
)

entry(
    index = 1081,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (4.79, 'm^3/(mol*s)', '*|/', 2),
        n = 2.08,
        Ea = (0.582, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Bowers, D.G.", "Malcolm, D.G.", "Tuckersman, R.T."],
        title = u'Evaluated kinetic data for high-temperature reactions. Volume 5. Part 1. Homogeneous gas phase reactions of the hydroxyl radical with alkanes',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """465""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986BAU/BOW465:22",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
Uncertainty: 2.0
""",
)

entry(
    index = 1082,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (10.5, 'm^3/(mol*s)', '*|/', 1.2),
        n = 2,
        Ea = (1.488, 'kJ/mol', '+|-', 0.417),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (900, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics and mechanisms of the gas-phase reactions of the hydroxyl radical with organic compounds under atmospheric conditions',
        journal = "Chem. Rev.",
        volume = "86",
        pages = """69""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK69:91",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
Uncertainty: 1.2
""",
)

entry(
    index = 1083,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (14100, 'm^3/(mol*s)', '+|-', 1850),
        n = 1,
        Ea = (5.396, 'kJ/mol', '+|-', 0.594),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:14",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
""",
)

entry(
    index = 1084,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (6.28, 'm^3/(mol*s)', '*|/', 3.16),
        n = 2,
        Ea = (0.08314, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:13",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
Uncertainty: 3.1600001
""",
)

entry(
    index = 1085,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (0.006575, 'm^3/(mol*s)'),
        n = 3.02,
        Ea = (-2.918, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (287, 'K'),
        Tmax = (903, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Tully, F.P.", "Koszykowski, M.L.", "Binkley, J.S."],
        title = u'Hydrogen-atom abstraction from alkanes by OH. I. Neopentane and neooctane',
        journal = "Symp. Int. Combust. Proc.",
        volume = "20",
        pages = """715""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985TUL/KOS715:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1086,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (8.51e+06, 'm^3/(mol*s)', '*|/', 1.15),
        n = 0,
        Ea = (7.017, 'kJ/mol', '+|-', 0.351),
        T0 = (1, 'K'),
        Tmin = (292, 'K'),
        Tmax = (493, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:20",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
Uncertainty: 1.15
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1087,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (31.6, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (1.247, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:43",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
""",
)

entry(
    index = 1088,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (10.7, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:15",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
Bath gas: N2
""",
)

entry(
    index = 1089,
    label = "C5H12-7 + OH <=> H2O + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (6.31, 'm^3/(mol*s)'),
        n = 2,
        Ea = (0.08314, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'The use of transition-state theory to extrapolate rate coefficients for reactions of OH with alkanes',
        journal = "Int. J. Chem. Kinet.",
        volume = "14",
        pages = """1339""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982COH1339:14",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00007065
""",
)

entry(
    index = 1090,
    label = "C4H6O + CH3 <=> CH4 + C4H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.63e+06, 'm^3/(mol*s)', '*|/', 1.1),
        n = 0,
        Ea = (37.498, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (411, 'K'),
        Tmax = (459, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Kerr, J.A.", "Smith, A.", "Trotman-Dickenson, A.F."],
        title = u'Reactions of cyclopropyl radicals in the methyl-initiated decomposition of cyclopropanecarbaldehyde',
        journal = "J. Chem. Soc. A",
        pages = """1400""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969KER/SMI1400:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009651
Uncertainty: 1.1
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Other (direct)
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 1091,
    label = "C4H6O + CH3 <=> CH4 + C4H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.14e+06, 'm^3/(mol*s)', '*|/', 1.07),
        n = 0,
        Ea = (36.417, 'kJ/mol', '+|-', 0.364),
        T0 = (1, 'K'),
        Tmin = (373, 'K'),
        Tmax = (473, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Greig, G.", "Thynne, J.C.J."],
        title = u'Reactions of cyclic alkyl radicals. Part 1.-Methyl-radical-sensitized decomposition of cyclopropane carboxaldehyde',
        journal = "Trans. Faraday Soc.",
        volume = "62",
        pages = """3338""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966GRE/THY3338:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009651
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009651/rk00000001.xml
Uncertainty: 1.0700001
Bath gas: (CH3N)2
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1092,
    label = "CH3 + C4H6O-2 <=> CH4 + C4H5O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (45.563, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (394, 'K'),
        Tmax = (448, 'K'),
        Pmin = (3773, 'Pa'),
        Pmax = (5186, 'Pa'),
    ),
    reference = Article(
        authors = ["Birrell, R.N.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VI. The reactions of methyl radicals with aliphatic aldehydes',
        journal = "J. Chem. Soc.",
        pages = """2059""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960BIR/TRO2059:8",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00010815
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010815/rk00000001.xml
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1093,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (229000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-7.483, 'kJ/mol', '+|-', 3.326),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:94",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
Pressure dependence: None reported
""",
)

entry(
    index = 1094,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (229000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-7.483, 'kJ/mol', '+|-', 3.326),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Crowley, J.N.", "Hampson, R.F, Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Summary of Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry',
        journal = "Not in System",
        pages = """1-56""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001ATK/BAU1-56:98",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
Pressure dependence: None reported
""",
)

entry(
    index = 1095,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (452000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-5.82, 'kJ/mol', '+|-', 2.095),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.E.", "Molina, M.J."],
        title = u'Chemical kinetics and photochemical data for use in stratospheric modeling. Evaluation number 12',
        journal = "JPL Publication 97-4",
        pages = """1-266""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997DEM/SAN1-266:301",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
""",
)

entry(
    index = 1096,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (163000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-8.314, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson, R.F., Jr.", "Kerr, J.A.", "Rossi, M.J.", "Troe, J."],
        title = u'Evaluated kinetic, photochemical and heterogeneous data for atmospheric chemistry: supplement V, IUPAC subcommittee on gas kinetic data evaluation for atmospheric chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "26",
        pages = """521-1011""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997ATK/BAU521-1011:247",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
""",
)

entry(
    index = 1097,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (452000, 'm^3/(mol*s)', '*|/', 1.5),
        n = 0,
        Ea = (-5.82, 'kJ/mol', '+|-', 2.095),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (300, 'K'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Sander, S.P.", "Golden, D.M.", "Hampson, R.F.", "Kurylo, M.J.", "Howard, C.J.", "Ravishankara, A.R.", "Kolb, C.J.", "Molina, M.J."],
        title = u'Chemical Kinetic and Photochemical Data for Use in Stratospheric Modeling: Evaluation No. 11 of the NASA Panel for Data Evaluation',
        journal = "JPL Publication 94-26",
        pages = """1-2""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994DEM/SAN:283",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
Uncertainty: 1.5
""",
)

entry(
    index = 1098,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (337000, 'm^3/(mol*s)', '+|-', 150000),
        n = 0,
        Ea = (-5.404, 'kJ/mol', '+|-', 1.031),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (380, 'K'),
    ),
    reference = Article(
        authors = ["Wallington, T.J.", "Dagaut, P.", "Kurylo, M.J."],
        title = u'Ultraviolet absorption cross sections and reaction kinetics and mechanisms for peroxy radicals in the gas phase',
        journal = "Chem. Rev.",
        volume = "92",
        pages = """667-710""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992WAL/DAG667-710:13",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
""",
)

entry(
    index = 1099,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (392000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-5.404, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (380, 'K'),
    ),
    reference = Article(
        authors = ["Lightfoot, P.D.", "Cox, R.A.", "Crowley, J.N.", "Destriau, M.", "Hayman, G.D.", "Jenkin, M.E.", "Moortgat, G.K.", "Zabel, F."],
        title = u'Organic peroxy radicals: kinetics, spectroscopy and tropospheric chemistry',
        journal = "Atmos. Environ. Part A",
        volume = "26",
        pages = """1805-1961""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992LIG/COX1805-1961:15",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011731/rk00000003.xml
""",
)

entry(
    index = 1100,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (392000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-5.404, 'kJ/mol', '+|-', 1.68),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (380, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:215",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
""",
)

entry(
    index = 1101,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (392000, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (-5.404, 'kJ/mol', '+|-', 1.68),
        T0 = (1, 'K'),
        Tmin = (240, 'K'),
        Tmax = (380, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry: Supplement III',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "18",
        pages = """881-1097""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ATK/BAU881-1097:132",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
Uncertainty: 1.58
""",
)

entry(
    index = 1102,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (416000, 'm^3/(mol*s)', '+|-', 120000),
        n = 0,
        Ea = (-5.837, 'kJ/mol', '+|-', 0.584),
        T0 = (1, 'K'),
        Tmin = (210, 'K'),
        Tmax = (363, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Maricq, M.M.", "Szente, J.J."],
        title = u'A kinetic study of the reaction between ethylperoxy radicals and HO2',
        journal = "J. Phys. Chem.",
        volume = "98",
        pages = """2078-2082""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994MAR/SZE2078-2082:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1103,
    label = "C2H5O2 + HO2-2 <=> C2H6O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (97100, 'm^3/(mol*s)', '+|-', 24000),
        n = 0,
        Ea = (-10.476, 'kJ/mol', '+|-', 1.048),
        T0 = (1, 'K'),
        Tmin = (248, 'K'),
        Tmax = (480, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Fenter, F.F.", "Catoire, V.", "Lesclaux, R.", "Lightfoot, P.D."],
        title = u'The ethylperoxy radical: its ultraviolet spectrum, self-reaction, and reaction with HO2, each studied as a function of temperature',
        journal = "J. Phys. Chem.",
        volume = "97",
        pages = """3530-3538""",
        year = "1993",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1993FEN/CAT3530-3538:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011731
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1104,
    label = "C4H9-4 + H2O2 <=> C4H10-4 + HO2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0259, 'm^3/(mol*s)', '*|/', 10),
        n = 2.13,
        Ea = (12.139, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:125",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00012776
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00012776/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1105,
    label = "C4H10-4 + HO2 <=> C4H9-4 + H2O2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.0301, 'm^3/(mol*s)', '*|/', 10),
        n = 2.55,
        Ea = (64.853, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:43",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00012776
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00012776/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1106,
    label = "C3H6O2-2 + CH3 <=> CH4 + C3H5O2-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (158000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (49.804, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (393, 'K'),
        Tmax = (523, 'K'),
        Pmin = (3200, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Ferguson, K.C.", "Pearson, J.T."],
        title = u'Methyl and trifluoromethyl radical rections with methyl acetate and deuterated methyl acetates',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """910""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970FER/PEA910:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004000
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004000/rk00000001.xml
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1107,
    label = "C3H6O2-2 + CH3 <=> CH4 + C3H5O2-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (275000, 'm^3/(mol*s)', '*|/', 1.45),
        n = 0,
        Ea = (46.977, 'kJ/mol', '+|-', 1.413),
        T0 = (1, 'K'),
        Tmin = (389, 'K'),
        Tmax = (497, 'K'),
        Pmin = (8133, 'Pa'),
        Pmax = (10500, 'Pa'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Newitt, P.J."],
        title = u'Reactions of Methyl Radicals. III. Hydrogen Abstraction from Methyl Acetate and Methyl [2H3] Acetate',
        journal = "Aust. J. Chem.",
        volume = "32",
        pages = """1697""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979ART/NEW1697:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00004000
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004000/rk00000002.xml
Uncertainty: 1.45
Bath gas: CH3C(O)OCH3
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1108,
    label = "C3H6O2-3 + CH3 <=> CH4 + C3H5O2-3",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (200000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.24, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (393, 'K'),
        Tmax = (553, 'K'),
        Pmin = (3200, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Ferguson, K.C.", "Pearson, J.T."],
        title = u'Methyl and trifluoromethyl radical rections with methyl acetate and deuterated methyl acetates',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """910""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970FER/PEA910:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004001
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004001/rk00000001.xml
Bath gas: (CH3)2CO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1109,
    label = "C3H6O2-3 + CH3 <=> CH4 + C3H5O2-3",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (148000, 'm^3/(mol*s)', '*|/', 1.66),
        n = 0,
        Ea = (42.903, 'kJ/mol', '+|-', 1.713),
        T0 = (1, 'K'),
        Tmin = (389, 'K'),
        Tmax = (497, 'K'),
        Pmin = (8133, 'Pa'),
        Pmax = (10500, 'Pa'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Newitt, P.J."],
        title = u'Reactions of Methyl Radicals. III. Hydrogen Abstraction from Methyl Acetate and Methyl [2H3] Acetate',
        journal = "Aust. J. Chem.",
        volume = "32",
        pages = """1697""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979ART/NEW1697:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00004001
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004001/rk00000002.xml
Uncertainty: 1.66
Bath gas: CH3C(O)OCH3
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1110,
    label = "C3H6O2-3 + CH3 <=> CH4 + C3H5O2-3",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (162000, 'm^3/(mol*s)', '*|/', 1.78),
        n = 0,
        Ea = (42.903, 'kJ/mol', '+|-', 2.145),
        T0 = (1, 'K'),
        Tmin = (386, 'K'),
        Tmax = (505, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Arthur, N.L.", "Newitt, P.J."],
        title = u'Hydrogen Abstraction from (2H3) Methyl Acetate by Methyl and Trifluoromethyl Radicals',
        journal = "Aust. J. Chem.",
        volume = "34",
        pages = """727""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981ART/NEW727:1",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00004001
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004001/rk00000003.xml
Uncertainty: 1.78
Bath gas: CH3C(O)OCH3
""",
)

entry(
    index = 1111,
    label = "C3H6O-4 + C2H5 <=> C2H6 + C3H5O-4",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (100000, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (34.838, 'kJ/mol', '+|-', 1.048),
        T0 = (1, 'K'),
        Tmin = (538, 'K'),
        Tmax = (596, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Peter, A.", "Acs, G.", "Horvath, I.", "Huhn, P."],
        title = u'Decomposition of propionaldehyde initiated by the thermal decomposition of azoethane',
        journal = "Acta Chim. Hung.",
        volume = "108",
        pages = """235""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981PET/ACS235:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006061
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006061/rk00000001.xml
Uncertainty: 1.26
Bath gas: C2H5CHO
Excitation technique: Thermal
Analytical technique: Electron spin resonance (ESR or EPR)
""",
)

entry(
    index = 1112,
    label = "C3H6O-5 + C2H5 <=> C2H6 + C3H5O-5",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (126000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (53.296, 'kJ/mol', '+|-', 3.201),
        T0 = (1, 'K'),
        Tmin = (538, 'K'),
        Tmax = (596, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Peter, A.", "Acs, G.", "Horvath, I.", "Huhn, P."],
        title = u'Decomposition of propionaldehyde initiated by the thermal decomposition of azoethane',
        journal = "Acta Chim. Hung.",
        volume = "108",
        pages = """235""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981PET/ACS235:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006062
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006062/rk00000001.xml
Uncertainty: 2.0
Bath gas: C2H5CHO
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1113,
    label = "CH2O + C4H9O-4 <=> C4H10O-4 + CHO",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (7.94e+06, 'm^3/(mol*s)', '*|/', 1.74),
        n = 0,
        Ea = (19.29, 'kJ/mol', '+|-', 2.32),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Al Akeel, N.Y.", "Selby, K.", "Waddington, D.J."],
        title = u'Reactions of Oxygenated Radicals in the Gas Phase. Part 8. Reactions of Alkoxyl Radicals with Aldehydes and Ketones',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1036""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981ALA/SEL1036:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001359
Uncertainty: 1.74
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1114,
    label = "C4H10O-3 + C2H5 <=> C2H6 + C4H9O-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.26e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (49.804, 'kJ/mol', '+|-', 5.479),
        T0 = (1, 'K'),
        Tmin = (697, 'K'),
        Tmax = (761, 'K'),
        Pmin = (4400, 'Pa'),
        Pmax = (21700, 'Pa'),
    ),
    reference = Article(
        authors = ["Seres, I.", "Huhn, P."],
        title = u'Radical steps in diethyl ether decomposition',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """829""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986SER/HUH829:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001560
Bath gas: (C2H5)2O
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1115,
    label = "C4H10O-3 + C2H5 <=> C2H6 + C4H9O-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (51.467, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (763, 'K'),
        Tmax = (798, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Foucaut, J.-F.", "Martin, R."],
        title = u"No. 18. - Etude analytique et cinetique de la pyrolyse de l'ether ethylique vers 500 \xb0C et a faible avancement",
        journal = "J. Chim. Phys.",
        volume = "75",
        pages = """132""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978FOU/MAR132:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001560
Bath gas: (C2H5)2O
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1116,
    label = "C4H10O-3 + C2H5 <=> C2H6 + C4H9O-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (794000, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (43.9, 'kJ/mol', '+|-', 2.195),
        T0 = (1, 'K'),
        Tmin = (357, 'K'),
        Tmax = (676, 'K'),
        Pmin = (4666, 'Pa'),
        Pmax = (280000, 'Pa'),
    ),
    reference = Article(
        authors = ["Hohlein, G.", "Freeman, G.R."],
        title = u'Radiation-sensitized pyrolysis of diethyl ether. Free-radical reaction rate parameters',
        journal = "J. Am. Chem. Soc.",
        volume = "92",
        pages = """6118""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970HOH/FRE6118:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001560
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001560/rk00000001.xml
Uncertainty: 1.58
Bath gas: (C2H5)2O
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1117,
    label = "CH4 + C6H5 <=> C6H6 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (51.558, 'kJ/mol', '+|-', 1.871),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (980, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (400, 'Pa'),
    ),
    reference = Article(
        authors = ["Tokmakov, I.V.", "Park, J.", "Gheyas, S.", "Lin, M.C."],
        title = u'Experimental and theoretical studies of the reaction of the phenyl radical with methane',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """3636-3645""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999TOK/PAR3636-3645:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001964
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Fourier transform (FTIR)

This work was also studied by pulsed laser photolysis/mass spectrometry, and got the same result.
""",
)

entry(
    index = 1118,
    label = "CH4 + C6H5 <=> C6H6 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (36.002, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (560, 'K'),
        Tmax = (1410, 'K'),
    ),
    reference = Article(
        authors = ["Heckmann, E.", "Hippler, H.", "Troe, J."],
        title = u'High-temperature reactions and thermodynamic properties of phenyl radicals',
        journal = "Symp. Int. Combust. Proc.",
        volume = "26",
        pages = """543-550""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996HEC/HIP543-550:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001964
Bath gas: Ar
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1119,
    label = "CH4 + C6H5 <=> C6H6 + CH3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (794000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (46.395, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (550, 'K'),
        Tmax = (680, 'K'),
        Pmin = (1867, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Duncan, F.J.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of phenyl radicals from the photolysis of acetophenone and the strength of the C-H bond in benzene',
        journal = "J. Chem. Soc.",
        pages = """4672""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962DUN/TRO4672:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001964
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001964/rk00000001.xml
Bath gas: 1-Phenylethanone
Excitation technique: Direct photolysis
Analytical technique: Other (direct)
""",
)

entry(
    index = 1120,
    label = "C6H6 + CH3 <=> CH4 + C6H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2e+06, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (63.024, 'kJ/mol', '+|-', 5.039),
        T0 = (1, 'K'),
        Tmin = (650, 'K'),
        Tmax = (770, 'K'),
        Pmin = (30700, 'Pa'),
        Pmax = (50700, 'Pa'),
    ),
    reference = Article(
        authors = ["Zhang, H.X.", "Ahonkhai, S.I.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from benzene, toluene, and cyclopentane by methyl and ethyl radicals over the temperature range 650-770 K',
        journal = "Can. J. Chem.",
        volume = "67",
        pages = """1541-1549""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ZHA/AHO1541-1549:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001964
Uncertainty: 2.0
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1121,
    label = "C6H6 + CH3 <=> CH4 + C6H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (63100, 'm^3/(mol*s)'),
        n = 0,
        Ea = (38.912, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (744, 'K'),
        Tmax = (800, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (21600, 'Pa'),
    ),
    reference = Article(
        authors = ["Krech, M.", "Price, S.J.W."],
        title = u'Hydrogen abstraction by methyl radicals from benzene and the pressure dependence of the recombination of methyl radicals',
        journal = "Can. J. Chem.",
        volume = "45",
        pages = """157""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967KRE/PRI157:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001964
Bath gas: (CH3)2Hg
Excitation technique: Thermal
Analytical technique: Other (direct)
""",
)

entry(
    index = 1122,
    label = "C6H6 + CH3 <=> CH4 + C6H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.62e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (80.9, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (1100, 'K'),
    ),
    reference = Article(
        authors = ["Hemelsoet, K.", "Van Speybroeck, V.", "Moran, D.", "Marin, G.B.", "Radom, L.", "Waroquier, M."],
        title = u'Thermochemistry and kinetics of hydrogen abstraction by methyl radical from polycyclic aromatic hydrocarbons',
        journal = "J. Phys. Chem. A",
        volume = "110",
        pages = """13624-13631""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006HEM/VAN13624-13631:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00001964
Pressure dependence: None reported

Ab initio study, using density functional theory (DFT) and transition state theory (TST) coupled with Eckart tunneling correction factors. Geometries are optimized by B3-LYP/6-311G(d,p) geometries, followed by BMK/6-311+G-(3df,2p) single-point energies. 

Ea = 71.8kJ/mol
DrH = 30.6kJ/mol
no uncertainties reported.
""",
)

entry(
    index = 1123,
    label = "C4H10-2 + C3H7-2 <=> C3H8-2 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.51e-09, 'm^3/(mol*s)', '*|/', 5),
        n = 4.2,
        Ea = (24.943, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:22",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003271
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003271/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1124,
    label = "C3H8-2 + C4H9-2 <=> C4H10-2 + C3H7-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.08e-12, 'm^3/(mol*s)', '*|/', 10),
        n = 5.16,
        Ea = (34.006, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:16",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003271
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003271/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1125,
    label = "C4H10-4 + C3H7-2 <=> C3H8-2 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1e-08, 'm^3/(mol*s)', '*|/', 3),
        n = 4.2,
        Ea = (36.501, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:23",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003272
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003272/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1126,
    label = "C3H8-2 + C4H9-4 <=> C4H10-4 + C3H7-2",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1.51e-06, 'm^3/(mol*s)', '*|/', 3),
        n = 3.46,
        Ea = (31.179, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:18",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003272
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003272/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1127,
    label = "C4H10-2 + CH3O2 <=> CH4O2 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.003611, 'm^3/(mol*s)', '*|/', 10),
        n = 2.55,
        Ea = (44.067, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:26",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003281
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003281/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1128,
    label = "C4H10-4 + CH3O2 <=> CH4O2 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (0.0301, 'm^3/(mol*s)', '*|/', 10),
        n = 2.55,
        Ea = (64.853, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:27",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003282
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003282/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1129,
    label = "C4H10-2 + C3H7 <=> C3H8 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.4e-07, 'm^3/(mol*s)', '*|/', 3),
        n = 3.46,
        Ea = (24.943, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:28",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003283
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003283/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1130,
    label = "C3H8 + C4H9-2 <=> C4H10-2 + C3H7",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.14e-11, 'm^3/(mol*s)', '*|/', 10),
        n = 5,
        Ea = (39.993, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:17",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003283
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003283/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1131,
    label = "C4H10-4 + C3H7 <=> C3H8 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (1.39e-06, 'm^3/(mol*s)', '*|/', 3),
        n = 3.65,
        Ea = (38.247, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:29",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003284
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003284/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1132,
    label = "C3H8 + C4H9-4 <=> C4H10-4 + C3H7",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (9e-07, 'm^3/(mol*s)', '*|/', 3),
        n = 3.65,
        Ea = (38.247, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:19",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003284
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003284/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1133,
    label = "C4H10-2 + C2H3O-2 <=> C2H4O-2 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.0343, 'm^3/(mol*s)', '*|/', 10),
        n = 2.5,
        Ea = (56.538, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:40",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003307
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003307/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1134,
    label = "C4H10-4 + C2H3O-2 <=> C2H4O-2 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (0.308, 'm^3/(mol*s)', '*|/', 10),
        n = 5.1,
        Ea = (77.158, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:41",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003308
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003308/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1135,
    label = "C5H12O + OH <=> H2O + C5H11O",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.51e+06, 'm^3/(mol*s)', '+|-', 60000),
        n = 0,
        Ea = (-1.646, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (293, 'K'),
        Tmax = (600, 'K'),
        Pmin = (100000, 'Pa'),
        Pmax = (100000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tully, F.P."],
        title = u'Catalytic dehydration of alcohols by OH. (H3C)3CCH2OH: a limiting case',
        journal = "Symp. Int. Combust. Proc.",
        volume = "23",
        pages = """147-153""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TUL147-153:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003729
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003729/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
Note: Invalid activation energy uncertainty (108.92) found and ignored
""",
)

entry(
    index = 1136,
    label = "C4H10O2 + CH3 <=> CH4 + C4H9O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (6.81e+10, 'm^3/(mol*s)'),
        n = 0,
        Ea = (71.338, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (501, 'K'),
        Tmax = (528, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Mulder, P.", "Louw, R."],
        title = u'Gas-phase thermolysis of tert-butyl hydroperoxide in a nitrogen atmosphere. The effect of added toluene',
        journal = "Recl. Trav. Chim. Pays-Bas",
        volume = "103",
        pages = """148-152""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984MUL/LOU148-152:2",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00003753
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003753/rk00000001.xml
""",
)

entry(
    index = 1137,
    label = "C6H14 + OH <=> H2O + C6H13",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2400, 'm^3/(mol*s)'),
        n = 1,
        Ea = (-2.037, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:9",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00004242
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004242/rk00000001.xml
""",
)

entry(
    index = 1138,
    label = "C3H4O + C3H7-2 <=> C3H8-2 + C3H3O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (10200, 'm^3/(mol*s)', '+|-', 7000),
        n = 0,
        Ea = (28.602, 'kJ/mol', '+|-', 2.86),
        T0 = (1, 'K'),
        Tmin = (473, 'K'),
        Tmax = (563, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Szirovicza, L."],
        title = u'Kinetics of some reactions of vinyl and isopropyl radicals in the gas-phase',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """117""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985SZI117:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004844
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004844/rk00000001.xml
Bath gas: CH2=CHCHO
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1139,
    label = "C6H6O + H <=> H2 + C6H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.15e+08, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (51.882, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1150, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:98",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005240
Uncertainty: 2.0
""",
)

entry(
    index = 1140,
    label = "C6H6O + H <=> H2 + C6H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.15e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (51.882, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1000, 'K'),
        Tmax = (1150, 'K'),
        Pmin = (253000, 'Pa'),
        Pmax = (507000, 'Pa'),
    ),
    reference = Article(
        authors = ["He, Y.Z.", "Mallard, W.G.", "Tsang, W."],
        title = u'Kinetics of hydrogen and hydroxyl radical attack on phenol at high temperatures',
        journal = "J. Phys. Chem.",
        volume = "92",
        pages = """196""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988HE/MAL2196:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005240
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1141,
    label = "C3H6O2 + C2H5 <=> C2H6 + C3H5O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (79400, 'm^3/(mol*s)'),
        n = 0,
        Ea = (32.593, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (370, 'K'),
        Tmax = (521, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (17300, 'Pa'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.j."],
        title = u'Reactions of alkyl radicals. Part 1.-Methyl radical photosensitized decomposition of ethyl formate',
        journal = "Trans. Faraday Soc.",
        volume = "58",
        pages = """676""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962THY676:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005361
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005361/rk00000001.xml
Bath gas: HCOOC2H5
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1142,
    label = "C6H14-2 + OH <=> H2O + C6H13-2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3.98, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:23",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005439
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005439/rk00000001.xml
""",
)

entry(
    index = 1143,
    label = "C6H14-3 + OH <=> H2O + C6H13-3",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (19.1, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (4.074, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:24",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005440
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005440/rk00000001.xml
""",
)

entry(
    index = 1144,
    label = "C5H10O + CH3 <=> CH4 + C5H9O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.26e+06, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (33.424, 'kJ/mol', '+|-', 1.339),
        T0 = (1, 'K'),
        Tmin = (394, 'K'),
        Tmax = (447, 'K'),
        Pmin = (4933, 'Pa'),
        Pmax = (5866, 'Pa'),
    ),
    reference = Article(
        authors = ["Birrell, R.N.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VI. The reactions of methyl radicals with aliphatic aldehydes',
        journal = "J. Chem. Soc.",
        pages = """2059""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960BIR/TRO2059:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005457
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005457/rk00000001.xml
Uncertainty: 1.58
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1145,
    label = "C4H8O2 + CH3 <=> CH4 + C4H7O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (12600, 'm^3/(mol*s)'),
        n = 0,
        Ea = (30.514, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (368, 'K'),
        Tmax = (455, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (17300, 'Pa'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.J."],
        title = u'Reactions of alkyl radicals. Part 2.-Methyl radical photosensitized decomposition of n-propyl and isopropyl formates',
        journal = "Trans. Faraday Soc.",
        volume = "58",
        pages = """1394""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962THY1394:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005470
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005470/rk00000001.xml
Bath gas: HCOOCH2CH2CH3
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1146,
    label = "C6H12 + CH3 <=> CH4 + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1.35e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (39.909, 'kJ/mol', '+|-', 1.197),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M."],
        title = u'Kinetics of abstraction reactions of methyl radicals with alkanes in gas phase',
        journal = "Indian J. Chem.",
        volume = "29",
        pages = """748""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990SWA748:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005484
Uncertainty: 1.26
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1147,
    label = "C6H12 + CH3 <=> CH4 + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (851000, 'm^3/(mol*s)', '*|/', 2.75),
        n = 0,
        Ea = (37.083, 'kJ/mol', '+|-', 2.594),
        T0 = (1, 'K'),
        Tmin = (373, 'K'),
        Tmax = (473, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (16000, 'Pa'),
    ),
    reference = Article(
        authors = ["Al-Niami, K.", "Holbrook, K.A.", "Oldershaw, G.A."],
        title = u'Reactions of methyl radicals with cyclohexane and methyl-substituted cyclohexanes',
        journal = "J. Chem. Soc. Faraday Trans. 2",
        volume = "85",
        pages = """1601-1608""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ALN/HOL1601-1608:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005484
Uncertainty: 2.75
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1148,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (19.6, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.178, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics of the gas-phase reactions of OH radicals with alkanes and cycloalkanes',
        journal = "Atmos. Chem. Phys.",
        volume = "3",
        pages = """2233-2307""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003ATK2233-2307:25",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005493/rk00000001.xml
""",
)

entry(
    index = 1149,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1.63e+07, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (3.243, 'kJ/mol', '+|-', 0.681),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics and mechanisms of the gas-phase reactions of the hydroxyl radical with organic compounds under atmospheric conditions',
        journal = "Chem. Rev.",
        volume = "86",
        pages = """69""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK69:74",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
Uncertainty: 1.2
""",
)

entry(
    index = 1150,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (140, 'm^3/(mol*s)', '*|/', 3.16),
        n = 1.6,
        Ea = (-3.326, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:10",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
Uncertainty: 3.1600001
""",
)

entry(
    index = 1151,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (2.16e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (4.157, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (368, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["DeMore, W.B.", "Bayes, K.D."],
        title = u'Rate constants for the reactions of hydroxyl radical with several alkanes, cycloakanes, and dimethyl ether',
        journal = "J. Phys. Chem. A",
        volume = "103",
        pages = """2649-2654""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999DEM/BAY2649-2654:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
Bath gas: Ar
Excitation technique: Direct photolysis
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1152,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1.71e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.392, 'kJ/mol', '+|-', 0.373),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (390, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Donahue, N.M.", "Anderson, J.G.", "Demerjian, K.L."],
        title = u'New rate constants for ten OH alkane reactions from 300 to 400 K: an assessment of accuracy',
        journal = "J. Phys. Chem. A",
        volume = "102",
        pages = """3121-3126""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998DON/AND3121-3126:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
Bath gas: N2
Excitation technique: Electron beam
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1153,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (657, 'm^3/(mol*s)'),
        n = 1.47,
        Ea = (-1.039, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (292, 'K'),
        Tmax = (491, 'K'),
        Pmin = (53300, 'Pa'),
        Pmax = (53300, 'Pa'),
    ),
    reference = Article(
        authors = ["Droege, A.T.", "Tully, F.P."],
        title = u'Hydrogen-atom abstraction from alkanes by OH. 6. Cyclopentane and cyclohexane',
        journal = "J. Phys. Chem.",
        volume = "91",
        pages = """1222""",
        year = "1987",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1987DRO/TUL1222:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1154,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (1.41e+07, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (2.652, 'kJ/mol', '+|-', 0.61),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:14",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
Uncertainty: 1.2
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1155,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (15.7, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-3.201, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:10",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
Bath gas: N2
""",
)

entry(
    index = 1156,
    label = "C6H12 + OH <=> H2O + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (139, 'm^3/(mol*s)'),
        n = 1.6,
        Ea = (-3.326, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'The use of transition-state theory to extrapolate rate coefficients for reactions of OH with alkanes',
        journal = "Int. J. Chem. Kinet.",
        volume = "14",
        pages = """1339""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982COH1339:11",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005493
""",
)

entry(
    index = 1157,
    label = "C3H6O3 + OH <=> H2O + C3H5O3",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (8.18e+06, 'm^3/(mol*s)', '+|-', 1.2e+06),
        n = 0,
        Ea = (1.921, 'kJ/mol', '+|-', 0.422),
        T0 = (1, 'K'),
        Tmin = (292, 'K'),
        Tmax = (597, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Zabarnick, S.", "Fleming, J.W.", "Lin, M.C."],
        title = u'Kinetics of hydroxyl radical reactions with formaldehyde and 1,3,5-trioxane between 290 and 600 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "20",
        pages = """117""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988ZAB/FLE117:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005544
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005544/rk00000001.xml
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1158,
    label = "C3H6-2 + C4H9-2 <=> C4H10-2 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (3.01e-11, 'm^3/(mol*s)', '*|/', 10),
        n = 4.9,
        Ea = (33.258, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:23",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005634
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005634/rk00000001.xml
Uncertainty: 10.0
""",
)

entry(
    index = 1159,
    label = "C4H10-2 + C3H5-2 <=> C3H6-2 + C4H9-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (4.221e-05, 'm^3/(mol*s)', '*|/', 5),
        n = 3.3,
        Ea = (71.837, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:15",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005634
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005634/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1160,
    label = "C3H6-2 + C3H5O <=> C3H6O + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (25900, 'm^3/(mol*s)'),
        n = 0,
        Ea = (18.874, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (490, 'K'),
        Tmax = (510, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:9",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005677
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005677/rk00000001.xml
""",
)

entry(
    index = 1161,
    label = "C3H6O + C3H5-2 <=> C3H6-2 + C3H5O",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (708000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (69.01, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (790, 'K'),
        Tmax = (810, 'K'),
    ),
    reference = Article(
        authors = ["Loser, U.", "Scherzer, K.", "Weber, K."],
        title = u'Abschatzung kinetischer daten fur H-transferreaktionen mit hilfe der, bond strength-bond length (BSBL) "Methode"',
        journal = "Z. Phys. Chem. (Leipzig)",
        volume = "270",
        pages = """237-245""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOS/SCH237-245:1",
    ),
    referenceType = "theory",
    shortDesc = u"""Other theoretical""",
    longDesc = 
u"""
PrIMe Reaction: r00005677
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005677/rk00000001.xml
""",
)

entry(
    index = 1162,
    label = "C3H6-2 + C4H9-4 <=> C4H10-4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (2.23e-06, 'm^3/(mol*s)', '*|/', 3),
        n = 3.5,
        Ea = (27.77, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:57",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005700
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005700/rk00000001.xml
Uncertainty: 3.0
""",
)

entry(
    index = 1163,
    label = "C4H10-4 + C3H5-2 <=> C3H6-2 + C4H9-4",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (0.000356, 'm^3/(mol*s)', '*|/', 5),
        n = 3.3,
        Ea = (83.062, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part V. Propene',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "20",
        pages = """221-273""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991TSA221-273:16",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00005700
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005700/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1164,
    label = "C5H10 + C2H5 <=> C2H6 + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (158000, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (39.993, 'kJ/mol', '+|-', 7.2),
        T0 = (1, 'K'),
        Tmin = (650, 'K'),
        Tmax = (770, 'K'),
        Pmin = (25300, 'Pa'),
        Pmax = (52900, 'Pa'),
    ),
    reference = Article(
        authors = ["Zhang, H.X.", "Ahonkhai, S.I.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from benzene, toluene, and cyclopentane by methyl and ethyl radicals over the temperature range 650-770 K',
        journal = "Can. J. Chem.",
        volume = "67",
        pages = """1541-1549""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ZHA/AHO1541-1549:11",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006478
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006478/rk00000001.xml
Uncertainty: 3.1600001
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1165,
    label = "C5H10 + HO2 <=> H2O2 + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (1.66e+07, 'm^3/(mol*s)', '+|-', 1.29e+07),
        n = 0,
        Ea = (74.4, 'kJ/mol', '+|-', 4.7),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (783, 'K'),
        Pmin = (2000, 'Pa'),
        Pmax = (2000, 'Pa'),
    ),
    reference = Article(
        authors = ["Handford-Styring, S.M.", "Walker, R.W."],
        title = u'Rate Constants for the Reaction of HO2 Radicals with Cyclopentane and Propane Between 673 and 783 K',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "4",
        pages = """620-627""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002HAN/WAL620-627:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Relative value normalized by a reference value""",
    longDesc = 
u"""
PrIMe Reaction: r00006485
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006485/rk00000001.xml
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Thermal
Time resolution: By end product analysis
Analytical technique: Gas chromatography

HO2was generated in the reaction t-C4H9+ O2= HO2+ C4H8, where t-C4H9was formed from the thermal decomposition of tetramethylbutane. Rate constants were determined using a detailed kinetic model to match observed products formed when the HO2was generated in the presence of the target substrates in aged, coated pyrex reactors. Rate constants for
(12p)   HO2+ C3H8-> H2O2+ C3H7and
(12c)     HO2+ c-C5H10-> H2O2+ c-C5H9
were determined relative to
(7)   2 HO2= H2O2+ O2,
for which the k7= 1.87E+9exp(-775/T) liter mol-1s-1was used. The reported relative values are
E12p?1/2E7= 75.6?.8 kJ mol-1, log[(A12p= A71/2)/(dm3mol-1s-1)1/2] = (5.53?.52)
and
E12c?1/2E7= 71.2 ?3.9 kJ mol-1, log[(A12c= A71/2)/(dm3mol-1s-1)1/2] = (5.58?.40).
""",
)

entry(
    index = 1166,
    label = "C5H10 + HO2 <=> H2O2 + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (0.097, 'm^3/(mol*s)'),
        n = 2.5,
        Ea = (59.282, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (540, 'K'),
        Tmax = (1600, 'K'),
    ),
    reference = Article(
        authors = ["Handford-Styring, S.M.", "Walker, R.W."],
        title = u'Rate Constants for the Reaction of HO2 Radicals with Cyclopentane and Propane Between 673 and 783 K',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "4",
        pages = """620-627""",
        year = "2002",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2002HAN/WAL620-627:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Relative value normalized by a reference value""",
    longDesc = 
u"""
PrIMe Reaction: r00006485
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006485/rk00000001.xml
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Thermal
Time resolution: By end product analysis
Analytical technique: Gas chromatography

The listed rate expression is recommended by authors for extrapolation of their data outside of their experimental temperature range of 673 to 783 K. The value of n = 2.5 was estimated by the authors on the basis of values for related reactions reported in the literature. No specific range of validity was given by the authors, but an approximate temperature range was inferred by us from the discussion in the paper. Uncertainties in the rate constant derived from this expression are suggested by the authors to be about 40% at 600 to 800 K and a factor of 2 at 1200 K.
The authors also suggest generic values of the RH + OOH reaction for primary, secondary, and tertiary hydrogens in this paper.
""",
)

entry(
    index = 1167,
    label = "C5H12-7 + C2H <=> C2H2 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (4.58e+07, 'm^3/(mol*s)', '+|-', 5.5e+06),
        n = 0,
        Ea = (-0.89, 'kJ/mol', '+|-', 0.0089),
        T0 = (1, 'K'),
        Tmin = (181, 'K'),
        Tmax = (297, 'K'),
        Pmin = (3706, 'Pa'),
        Pmax = (4106, 'Pa'),
    ),
    reference = Article(
        authors = ["Hoobler, R.J.", "Opansky, B.J.", "Leone, S.R."],
        title = u'Low-temperature rate coefficients for reactions of ethynyl radical (C2H) with propane, isobutane, n-butane, and neopentane',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """1338-1342""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997HOO/OPA1338-1342:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00007055
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007055/rk00000004.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: IR absorption
""",
)

entry(
    index = 1168,
    label = "C6H12-2 + CH3 <=> CH4 + C6H11-2",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (851000, 'm^3/(mol*s)', '*|/', 1.62),
        n = 0,
        Ea = (36.251, 'kJ/mol', '+|-', 2.178),
        T0 = (1, 'K'),
        Tmin = (389, 'K'),
        Tmax = (451, 'K'),
        Pmin = (10300, 'Pa'),
        Pmax = (12100, 'Pa'),
    ),
    reference = Article(
        authors = ["Kortvelyesi, T.", "Seres, L."],
        title = u'Thermal reaction of (CH3)2C=C(CH3)2 in the presence of di-tert-butyl peroxide; reactions of the radicals .CH3, (CH3)3C.C(CH3)2 and (CH3)2 C=C(CH3).CH2',
        journal = "J. Chim. Phys.",
        volume = "93",
        pages = """253-273""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996KOR/SER253-273:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007610
Uncertainty: 1.62
Bath gas: CO2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1169,
    label = "C6H12-2 + CH3 <=> CH4 + C6H11-2",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (631000, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (33.424, 'kJ/mol', '+|-', 1.671),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
    ),
    reference = Article(
        authors = ["Sway, M.I."],
        title = u'Arrhenius parameters for reactions of methyl radicals with alkenes',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "29",
        pages = """900-902""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990SWA900-902:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007610
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007610/rk00000002.xml
Uncertainty: 1.26
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1170,
    label = "C5H10O-2 + CH3 <=> CH4 + C5H9O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2e+06, 'm^3/(mol*s)', '*|/', 1.58),
        n = 0,
        Ea = (35.17, 'kJ/mol', '+|-', 1.405),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (444, 'K'),
        Pmin = (5466, 'Pa'),
        Pmax = (5600, 'Pa'),
    ),
    reference = Article(
        authors = ["Birrell, R.N.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VI. The reactions of methyl radicals with aliphatic aldehydes',
        journal = "J. Chem. Soc.",
        pages = """2059""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960BIR/TRO2059:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007794
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007794/rk00000001.xml
Uncertainty: 1.58
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1171,
    label = "C3H6O3-2 + CH3 <=> CH4 + C3H5O3-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (15500, 'm^3/(mol*s)'),
        n = 0,
        Ea = (30.93, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (303, 'K'),
        Tmax = (376, 'K'),
    ),
    reference = Article(
        authors = ["Yee Quee, M.J.", "Thynne, J.C.J."],
        title = u'The photolysis of organic esters',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "72",
        pages = """211""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968YEE/THY211:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008152
Bath gas: CH3OCOOCH3
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1172,
    label = "C3H6O3-2 + CH3 <=> CH4 + C3H5O3-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (15500, 'm^3/(mol*s)'),
        n = 0,
        Ea = (30.764, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (314, 'K'),
        Tmax = (366, 'K'),
    ),
    reference = Article(
        authors = ["Quee, M.J.Y.", "Thynne, J.C.J."],
        title = u'Photolysis of dimethyl carbonate',
        journal = "Trans. Faraday Soc.",
        volume = "62",
        pages = """3154""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966QUE/THY3154:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008152
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008152/rk00000001.xml
Bath gas: CH3OCOOCH3
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1173,
    label = "C3H6O3-2 + OH <=> H2O + C3H5O3-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.14e-14, 'm^3/(mol*s)'),
        n = 6.48,
        Ea = (-15.714, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (252, 'K'),
        Tmax = (370, 'K'),
        Pmin = (95100, 'Pa'),
        Pmax = (100000, 'Pa'),
    ),
    reference = Article(
        authors = ["Bilde, M.", "Mogelberg, T.E.", "Sehested, J.", "Nielsen, O.J.", "Wallington, T.J.", "Hurley, M.D.", "Japar, S.M.", "Dill, M.", "Orkin, V.L.", "Buckley, T.J.", "Huie, R.E.", "Kurylo, M.J."],
        title = u'Atmospheric chemistry of dimethyl carbonate: reaction with OH radicals, UV spectra of CH3OC(O)OCH2 and CH3OC(O)OCH2O2 radicals, reactions of CH3OC(O)OCH2O2 with NO and NO2, and fate of CH3OC(O)OCH2O radicals',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """3514-3525""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997BIL/MOG3514-3525:8",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00008153
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008153/rk00000001.xml
Bath gas: SF6
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 1174,
    label = "C4H8O2-2 + CH3 <=> CH4 + C4H7O2-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (79400, 'm^3/(mol*s)'),
        n = 0,
        Ea = (37.249, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (368, 'K'),
        Tmax = (455, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (17300, 'Pa'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.J."],
        title = u'Reactions of alkyl radicals. Part 2.-Methyl radical photosensitized decomposition of n-propyl and isopropyl formates',
        journal = "Trans. Faraday Soc.",
        volume = "58",
        pages = """1394""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962THY1394:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008321
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008321/rk00000001.xml
Bath gas: HCOOCH(CH3)2
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1175,
    label = "C5H10O-3 + CH3 <=> CH4 + C5H9O-3",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (42.653, 'kJ/mol', '+|-', 1.28),
        T0 = (1, 'K'),
        Tmin = (392, 'K'),
        Tmax = (436, 'K'),
        Pmin = (4466, 'Pa'),
        Pmax = (4973, 'Pa'),
    ),
    reference = Article(
        authors = ["Birrell, R.N.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VI. The reactions of methyl radicals with aliphatic aldehydes',
        journal = "J. Chem. Soc.",
        pages = """2059""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960BIR/TRO2059:7",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008601
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008601/rk00000001.xml
Uncertainty: 2.0
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1176,
    label = "C6H6 + OH <=> H2O + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.29e+07, 'm^3/(mol*s)', '+|-', 690000),
        n = 0,
        Ea = (21.285, 'kJ/mol', '+|-', 1.488),
        T0 = (1, 'K'),
        Tmin = (787, 'K'),
        Tmax = (1410, 'K'),
        Pmin = (33300, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Lin, S-C.", "Kuo, T-C.", "Lee, Y-P."],
        title = u'Detailed rate coefficients and the enthalpy change of the equilibrium reaction OH + C6H6 + M = HOC6H6 + M over the temperature range 345-385 K',
        journal = "J. Chem. Phys.",
        volume = "101",
        pages = """2098-2105""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994LIN/KUO2098-2105:1",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011163
Bath gas: He
""",
)

entry(
    index = 1177,
    label = "C6H6 + OH <=> H2O + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (163, 'm^3/(mol*s)', '*|/', 2),
        n = 1.42,
        Ea = (6.07, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Esser, C.", "Frank, P.", "Just, Th.", "Kerr, J.A.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combustion modelling',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """411-429""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992BAU/COB411-429:18",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011163
Uncertainty: 2.0
""",
)

entry(
    index = 1178,
    label = "C6H6 + OH <=> H2O + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (4.78e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (26.397, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1300, 'K'),
        Tmax = (1750, 'K'),
        Pmin = (150000, 'Pa'),
        Pmax = (240000, 'Pa'),
    ),
    reference = Article(
        authors = ["Seta, T.", "Nakajima, M.", "Miyoshi, A."],
        title = u'Development of a technique for high-temperature chemical kinetics: Shock tube/pulsed laser-induced fluorescence imaging method',
        journal = "Rev. Sci. Instrum.",
        volume = "76",
        pages = """64103""",
        year = "2005",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2005SET/NAK64103:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011163
Pressure dependence: None reported
Experimental procedure: Shock tube
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Laser induced fluorescence

Uncertainties of the Arrhenius parameters are not reported. This article reports development of a novel kinetic technique: shock tube / pulsed laser-induced fluorescence imaging.
""",
)

entry(
    index = 1179,
    label = "C6H6 + OH <=> H2O + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (11.4, 'm^3/(mol*s)', '+|-', 1.8),
        n = 2,
        Ea = (13.719, 'kJ/mol', '+|-', 0.412),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1050, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Knispel, R.", "Koch, R.", "Siese, M.", "Zetzsch, C."],
        title = u'Adduct formation of OH radicals with benzene, toluene, and phenol and consecutive reactions of the adducts with NOx and O2',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "94",
        pages = """1375-1379""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990KNI/KOC1375-1379:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011163
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 1180,
    label = "C6H6 + OH <=> H2O + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.45e+07, 'm^3/(mol*s)', '+|-', 5.4e+06),
        n = 0,
        Ea = (18.791, 'kJ/mol', '+|-', 2.444),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (1150, 'K'),
        Pmin = (3333, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Tully, F.P.", "Ravishankara, A.R.", "Thompson, R.L.", "Nicovich, J.M.", "Shah, R.C.", "Kreuffer, N.M.", "Wine, P.H."],
        title = u'Kinetics of the reactions of hydroxyl radical with benzene and toluene',
        journal = "J. Phys. Chem.",
        volume = "85",
        pages = """2262""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981TUL/RAV2262:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011163
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 1181,
    label = "C6H6 + OH <=> H2O + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (2.4e+07, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (16.712, 'kJ/mol', '+|-', 12.555),
        T0 = (1, 'K'),
        Tmin = (380, 'K'),
        Tmax = (473, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Perry, R.A.", "Atkinson, R.", "Pitts, J.N., Jr."],
        title = u'Kinetics and mechanism of the gas phase reaction of OH radicals with aromatic hydrocarbons over the temperature range 296-473 K',
        journal = "J. Phys. Chem.",
        volume = "81",
        pages = """296""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977PER/ATK296:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011163
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011163/rk00000003.xml
Uncertainty: 5.0
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 1182,
    label = "C6H6 + OH <=> H2O + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (0.0234, 'm^3/(mol*s)', '*|/', 1.35),
        n = 2.68,
        Ea = (3.068, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (700, 'K'),
        Tmax = (1900, 'K'),
        Pmin = (109000, 'Pa'),
        Pmax = (182000, 'Pa'),
    ),
    reference = Article(
        authors = ["Seta, T.", "Nakajima, M.", "Miyoshi, A."],
        title = u'High-temperature reactions of OH radicals with benzene and toluene',
        journal = "J. Phys. Chem. A",
        volume = "110",
        pages = """5081-5090""",
        year = "2006",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2006SET/NAK5081-5090:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011163
Uncertainty: 1.35
Pressure dependence: None reported

The listed rate constants are those recommended in the paper on the basis of transition-state theory (TST) calculations as fitted to their experimental data on the overall rate of reaction. The quantum chemically predicted energetics were adjusted to fit the observed rate constants. To fit the experimental tempoerature dependence, the authors found it necessary to apply anharmonic corrections to two bending and one torsional vibration of the transition state.

The estimated uncertainty factor of 1.35 applies to the overall rate of reaction and the major reaction channels. The minor channels are estimated by the authors to have uncertainty factors of up to 2.
""",
)

entry(
    index = 1183,
    label = "C6H6 + OH <=> H2O + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.2e-06, 'm^3/(mol*s)'),
        n = 4.1,
        Ea = (-1.259, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (230, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Chen, C.C.", "Bozzelli, J.W.", "Farrell, J.T."],
        title = u'Thermochemical properties, pathway, and kinetic analysis on the reactions of benzene with OH: An elementary reaction mechanism',
        journal = "J. Phys. Chem. A",
        volume = "108",
        pages = """4632-4652""",
        year = "2004",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2004CHE/BOZ4632-4652:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00011163
Pressure dependence: Rate constant is pressure independent

Temperature range was not specified. The temperature range used for this record (230 - 1500 K) was taken from table 7 of the article.
""",
)

entry(
    index = 1184,
    label = "HO2-2 + C2H3O3 <=> C2H4O3 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (181000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-8.647, 'kJ/mol', '+|-', 4.149),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (370, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R.", "Baulch, D.L.", "Cox, R.A.", "Hampson Jr., R.F.", "Kerr, J.A.", "Troe, J."],
        title = u'Evaluated Kinetic and Photochemical Data for Atmospheric Chemistry. Supplement IV, IUPAC Subcommittee on Gas Kinetic Data Evaluation for Atmospheric Chemistry',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "21",
        pages = """1125-1568""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ATK/BAU1125-1568:242",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011914
""",
)

entry(
    index = 1185,
    label = "HO2-2 + C2H3O3 <=> C2H4O3 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (307000, 'm^3/(mol*s)', '+|-', 126000),
        n = 0,
        Ea = (-7.691, 'kJ/mol', '+|-', 0.998),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (373, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Tomas, A.", "Villenave, E.", "Lesclaux, R."],
        title = u'Reactions of the HO2 Radical with CH3CHO and CH3C(O)O2 in the Gas Phase',
        journal = "J. Phys. Chem. A",
        volume = "105",
        pages = """3505-3514""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001TOM/VIL3505-3514:7",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00011914
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011914/rk00000006.xml
Uncertainty: 1.15
Bath gas: O2
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Vis-UV absorption

Bath gas was [O2[=2.0-2.4E19 and [N2] 0.1-4.6 molecules/cm3. Flash photolysis of Cl2 in presence CH3CHO and CH3OH forming products CH3C(O)O2 and HO2. Absorption signal as a function of time was measured at 207 and 250 nm. HO2 absorption at 250 nm is low. Used known absorption cross-sections for various molecules at the two wavelengths and a relatively simple kinetic model to describe the chemistry in order to determine k1 (also determined branching ratio). Quoted error limits are 2 sigma. Reported global uncertainty of 15%.

calc equil const k2 1.9E-(27?) exp[+(6925?40 K)/T] at 298-373 K;DrH298 = -64? kJ/mol; So = -157? J/K*mol; DrH is essentially same as for CH2O + HO2 = CH2(OH)O2 from 1989Veryret

Note: Table 2 should be k-2 (k2reverse) = 2.3E13 exp(-6925 K/T). Calculated using assumed temperature dependence by analogy to CH2O + HO2
""",
)

entry(
    index = 1186,
    label = "C6H14-4 + OH <=> H2O + C6H13-4",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.45, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.155, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:10",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00003724
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003724/rk00000001.xml
""",
)

entry(
    index = 1187,
    label = "C6H14-5 + OH <=> H2O + C6H13-5",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (29.5, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (1.164, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:11",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00003725
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003725/rk00000001.xml
""",
)

entry(
    index = 1188,
    label = "C6H14-6 + OH <=> H2O + C6H13-6",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (9.57, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (4.074, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:12",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00003726
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003726/rk00000001.xml
""",
)

entry(
    index = 1189,
    label = "C6H14-7 + OH <=> H2O + C6H13-7",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.52e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-0.798, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (498, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:10",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004048
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004048/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1190,
    label = "C6H14-7 + OH <=> H2O + C6H13-7",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2400, 'm^3/(mol*s)'),
        n = 1,
        Ea = (-2.037, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:8",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00004048
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004048/rk00000003.xml
""",
)

entry(
    index = 1191,
    label = "C6H14-7 + OH <=> H2O + C6H13-7",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (2.27, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-6.543, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004048
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004048/rk00000004.xml
Bath gas: N2
""",
)

entry(
    index = 1192,
    label = "C6H14-7 + OH <=> H2O + C6H13-7",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (1.99, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-7.4, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:14",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00004048
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004048/rk00000005.xml
""",
)

entry(
    index = 1193,
    label = "C4H6 + C3H3 <=> C3H4 + C4H5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (93.954, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1300, 'K'),
        Tmax = (2000, 'K'),
        Pmin = (20300, 'Pa'),
        Pmax = (55700, 'Pa'),
    ),
    reference = Article(
        authors = ["Kern, R.D.", "Singh, H.J.", "Wu, C.H."],
        title = u'Thermal decomposition of 1,2 butadiene',
        journal = "Int. J. Chem. Kinet.",
        volume = "20",
        pages = """731""",
        year = "1988",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1988KER/SIN731:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from detailed balance/reverse rate""",
    longDesc = 
u"""
PrIMe Reaction: r00004761
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004761/rk00000001.xml
Bath gas: Ne
""",
)

entry(
    index = 1194,
    label = "C6H14-8 + OH <=> H2O + C6H13-8",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.88, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.571, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:25",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005442
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005442/rk00000001.xml
""",
)

entry(
    index = 1195,
    label = "C6H6 + O2 <=> HO2-2 + C6H5",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (6.31e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (251.097, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1200, 'K'),
        Tmax = (1700, 'K'),
        Pmin = (203000, 'Pa'),
        Pmax = (811000, 'Pa'),
    ),
    reference = Article(
        authors = ["Asaba, T.", "Fujii, N."],
        title = u'High temperature oxidation of benzene',
        journal = "Proc. Int. Symp. Shock Tubes Waves",
        volume = "8",
        pages = """1-12""",
        year = "1971",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1971ASA/FUJ1-12:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00001906
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001906/rk00000001.xml
Bath gas: Ar
""",
)

entry(
    index = 1196,
    label = "C2H6 + C6H5 <=> C6H6 + C2H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (209000, 'm^3/(mol*s)', '+|-', 20000),
        n = 0,
        Ea = (18.591, 'kJ/mol', '+|-', 0.757),
        T0 = (1, 'K'),
        Tmin = (565, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (400, 'Pa'),
    ),
    reference = Article(
        authors = ["Park, J.", "Gheyas, S.", "Lin, M.C."],
        title = u'Kinetics of Phenyl Radical Reactions with Ethane and Neopentane: Reactivity of C6H5 Toward the Primary C-H Bond of Alkanes',
        journal = "Int J. Chem. Kinet.",
        volume = "33",
        pages = """64-69""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001PAR/GHE64-69:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00002101
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00002101/rk00000001.xml
Bath gas: He
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Vis-UV absorption

Phenyl radicals are produced from 193 nm photolysis of C6H5COCH3.The cavity ringdown spectroscopy and/or mass spectrometry have been used to monitor reactan and/or products.
""",
)

entry(
    index = 1197,
    label = "C6H6 + C2H5 <=> C2H6 + C6H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (631000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (62.192, 'kJ/mol', '+|-', 4.972),
        T0 = (1, 'K'),
        Tmin = (650, 'K'),
        Tmax = (770, 'K'),
        Pmin = (30700, 'Pa'),
        Pmax = (50700, 'Pa'),
    ),
    reference = Article(
        authors = ["Zhang, H.X.", "Ahonkhai, S.I.", "Back, M.H."],
        title = u'Rate constants for abstraction of hydrogen from benzene, toluene, and cyclopentane by methyl and ethyl radicals over the temperature range 650-770 K',
        journal = "Can. J. Chem.",
        volume = "67",
        pages = """1541-1549""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989ZHA/AHO1541-1549:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00002101
Uncertainty: 2.0
Bath gas: C2H4
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1198,
    label = "C2H4O-2 + C4H9O-4 <=> C4H10O-4 + C2H3O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.53e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (16.712, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (20000, 'Pa'),
    ),
    reference = Article(
        authors = ["Al Akeel, N.Y.", "Selby, K.", "Waddington, D.J."],
        title = u'Reactions of Oxygenated Radicals in the Gas Phase. Part 8. Reactions of Alkoxyl Radicals with Aldehydes and Ketones',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1036""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981ALA/SEL1036:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003017
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1199,
    label = "C2H4O-3 + C4H9O-4 <=> C4H10O-4 + C2H3O-3",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (57900, 'm^3/(mol*s)'),
        n = 0,
        Ea = (15.797, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (20000, 'Pa'),
    ),
    reference = Article(
        authors = ["Al Akeel, N.Y.", "Selby, K.", "Waddington, D.J."],
        title = u'Reactions of Oxygenated Radicals in the Gas Phase. Part 8. Reactions of Alkoxyl Radicals with Aldehydes and Ketones',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1036""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981ALA/SEL1036:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003018
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1200,
    label = "C4H10-2 + C4H9-4 <=> C4H10-4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.4e-07, 'm^3/(mol*s)', '*|/', 2.5),
        n = 3.46,
        Ea = (24.943, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:46",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003324
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003324/rk00000001.xml
Uncertainty: 2.5
""",
)

entry(
    index = 1201,
    label = "C4H10-4 + C4H9-2 <=> C4H10-2 + C4H9-4",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (5.06e-12, 'm^3/(mol*s)', '*|/', 5),
        n = 5.17,
        Ea = (37.914, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Tsang, W."],
        title = u'Chemical kinetic data base for combustion chemistry. Part 4. Isobutane',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "19",
        pages = """1-68""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990TSA1-68:21",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00003324
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003324/rk00000001.xml
Uncertainty: 5.0
""",
)

entry(
    index = 1202,
    label = "C4H8O + C3H7-2 <=> C3H8-2 + C4H7O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (200000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (26.357, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (390, 'K'),
        Tmax = (627, 'K'),
        Pmin = (1200, 'Pa'),
        Pmax = (4400, 'Pa'),
    ),
    reference = Article(
        authors = ["Kerr, J.A.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part 2. s-Propyl radicals from the photolysis of isobutyraldehyde',
        journal = "Trans. Faraday Soc.",
        volume = "55",
        pages = """921""",
        year = "1959",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1959KER/TRO921:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003870
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003870/rk00000001.xml
Bath gas: (CH3)2CHCHO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1203,
    label = "C8H10 + H <=> H2 + C8H9",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (720, 'm^3/(mol*s)'),
        n = 1.5,
        Ea = (31.013, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (500, 'K'),
        Tmax = (1500, 'K'),
    ),
    reference = Article(
        authors = ["Ellis, C.", "Scott, M.S.", "Walker, R.W."],
        title = u'Addition of toluene and ethylbenzene to mixture of H2 and O2 at 772 K: Part 2: Formation of products and determination of kinetic data for H plus additive and for other elementary reactions involved',
        journal = "Combust. Flame",
        volume = "132",
        pages = """291-304""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003ELL/SCO291-304:16",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004373
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004373/rk00000002.xml
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Thermal
Time resolution: By end product analysis
Analytical technique: Gas chromatography

The authors carried out a detailed analysis of products obtained from the addition of small amounts of toluene or ethylbenzene to N2 mixtures containing H2 and O2 at 773 K and 500 Torr total pressure. A detainled kinetic model with approximately 50 reactions was constructed to explain the results. Kinetics were obtained using this mechanism and the observed product formation rates. Typically, relative rates were derived and converted to absolute rates using data from the literature.
""",
)

entry(
    index = 1204,
    label = "C6H6O + CH3 <=> CH4 + C6H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (181000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (32.26, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (445, 'K'),
        Tmax = (547, 'K'),
    ),
    reference = Article(
        authors = ["Mulcahy, M.F.R.", "Williams, D.J."],
        title = u'Reactions of free radicals with aromatic compounds in the gaseous phase. II. Kinetics of the reaction of methyl radicals with phenol',
        journal = "Aust. J. Chem.",
        volume = "18",
        pages = """20-38""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965MUL/WIL20-38:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005226
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005226/rk00000001.xml
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1205,
    label = "C6H6O + OH <=> H2O + C6H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.95, 'm^3/(mol*s)', '+|-', 0.912),
        n = 2,
        Ea = (-5.488, 'kJ/mol', '+|-', 0.768),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1030, 'K'),
        Pmin = (1331, 'Pa'),
        Pmax = (1331, 'Pa'),
    ),
    reference = Article(
        authors = ["Knispel, R.", "Koch, R.", "Siese, M.", "Zetzsch, C."],
        title = u'Adduct formation of OH radicals with benzene, toluene, and phenol and consecutive reactions of the adducts with NOx and O2',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "94",
        pages = """1375-1379""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990KNI/KOC1375-1379:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005234
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005234/rk00000002.xml
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 1206,
    label = "C6H12 + HO2 <=> H2O2 + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (0.0103, 'm^3/(mol*s)', '+|-', 0.00047),
        n = 0,
        Ea = (74.3, 'kJ/mol', '+|-', 4.9),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (773, 'K'),
    ),
    reference = Article(
        authors = ["Handford-Styring, S.M.", "Walker, R.W."],
        title = u'Arrhenius Parameters for the Reaction HO2 + Cyclohexane Between 673 and 773 K, and for H Atom Transfer in Cyclohexylperoxy Radicals',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "3",
        pages = """2043-2052""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001HAN/WAL2043-2052:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005489
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005489/rk00000002.xml
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Thermal
Time resolution: By end product analysis
Analytical technique: Gas chromatography

Rate constant used for the reference reaction HO2+ HO2-> H2O2+ O2was
k/(cm3mol-1s-1= 1.87x1012exp(-775/T)
""",
)

entry(
    index = 1207,
    label = "C6H12 + HO2 <=> H2O2 + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (0.112, 'm^3/(mol*s)'),
        n = 2.5,
        Ea = (59.199, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (550, 'K'),
        Tmax = (1400, 'K'),
    ),
    reference = Article(
        authors = ["Handford-Styring, S.M.", "Walker, R.W."],
        title = u'Arrhenius Parameters for the Reaction HO2 + Cyclohexane Between 673 and 773 K, and for H Atom Transfer in Cyclohexylperoxy Radicals',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "3",
        pages = """2043-2052""",
        year = "2001",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2001HAN/WAL2043-2052:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005489
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005489/rk00000002.xml
Pressure dependence: None reported
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Thermal
Time resolution: By end product analysis
Analytical technique: Gas chromatography

Rate constant used for the reference reaction HO2+ HO2-> H2O2+ O2was
k/(cm3mol-1s-1= 1.87x1012exp(-775/T)

Authors do not specifically indicate the temperature range over which they recommend this rate expression. The indicated range is approximate and was inferred by us from their discussion.
""",
)

entry(
    index = 1208,
    label = "C6H10 + C2H5 <=> C2H6 + C6H9",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.84e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (38.496, 'kJ/mol', '+|-', 4.232),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["James, D.G.L.", "Steacie, E.W.R."],
        title = u'Reactions of the ethyl radical. I. Metathesis with unsaturated hydrocarbons',
        journal = "Proc. R. Soc. London A",
        volume = "244",
        pages = """289""",
        year = "1958",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1958JAM/STE289:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005512
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005512/rk00000001.xml
Bath gas: (C2H5)2CO
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1209,
    label = "C3H6-2 + C4H9O-4 <=> C4H10O-4 + C3H5-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (7.94e+06, 'm^3/(mol*s)', '*|/', 1.95),
        n = 0,
        Ea = (27.604, 'kJ/mol', '+|-', 2.212),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005678
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005678/rk00000001.xml
Uncertainty: 1.95
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1210,
    label = "C7H16 + OH <=> H2O + C7H15",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (17.4, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (4.074, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:39",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006329
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006329/rk00000001.xml
""",
)

entry(
    index = 1211,
    label = "C7H16-2 + OH <=> H2O + C7H15-2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3.79, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:40",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006330
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006330/rk00000001.xml
""",
)

entry(
    index = 1212,
    label = "C7H14 + OH <=> H2O + C7H13",
    degeneracy = 14,
    kinetics = Arrhenius(
        A = (2.48e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.093, 'kJ/mol', '+|-', 0.371),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (390, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Donahue, N.M.", "Anderson, J.G.", "Demerjian, K.L."],
        title = u'New rate constants for ten OH alkane reactions from 300 to 400 K: an assessment of accuracy',
        journal = "J. Phys. Chem. A",
        volume = "102",
        pages = """3121-3126""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998DON/AND3121-3126:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00006521
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006521/rk00000002.xml
Bath gas: N2
Excitation technique: Electron beam
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1213,
    label = "C5H12-7 + C3H7-2 <=> C3H8-2 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (31600, 'm^3/(mol*s)', '*|/', 5),
        n = 0,
        Ea = (55.042, 'kJ/mol', '+|-', 4.947),
        T0 = (1, 'K'),
        Tmin = (512, 'K'),
        Tmax = (571, 'K'),
        Pmin = (7466, 'Pa'),
        Pmax = (7466, 'Pa'),
    ),
    reference = Article(
        authors = ["Szirovicza, L.", "Marta, F."],
        title = u'Kinetics of the Decomposition of Neopentane Sensitized by Azoisopropane',
        journal = "Magy. Kem. Foly.",
        volume = "85",
        pages = """369""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979SZI/MAR369:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007053
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007053/rk00000001.xml
Uncertainty: 5.0
Bath gas: neo-C5H12
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1214,
    label = "C5H6 + C3H5-2 <=> C3H6-2 + C5H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (110000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.031, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1080, 'K'),
        Tmax = (1550, 'K'),
        Pmin = (227, 'Pa'),
        Pmax = (12800, 'Pa'),
    ),
    reference = Article(
        authors = ["Burcat, A.", "Dvinyaninov, M."],
        title = u'Detailed kinetics of cyclopentadiene decomposition studied in a shock tube',
        journal = "Int. J. Chem. Kinet.",
        volume = "29",
        pages = """505-514""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997BUR/DVI505-514:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007433
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007433/rk00000001.xml
Bath gas: Ar
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1215,
    label = "C5H6 + C3H3-2 <=> C3H4-2 + C5H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (110000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.031, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1080, 'K'),
        Tmax = (1550, 'K'),
        Pmin = (172000, 'Pa'),
        Pmax = (973000, 'Pa'),
    ),
    reference = Article(
        authors = ["Burcat, A.", "Dvinyaninov, M."],
        title = u'Detailed kinetics of cyclopentadiene decomposition studied in a shock tube',
        journal = "Int. J. Chem. Kinet.",
        volume = "29",
        pages = """505-514""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997BUR/DVI505-514:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007436
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007436/rk00000001.xml
Bath gas: Ar
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1216,
    label = "C6H8 + O2 <=> HO2-2 + C6H7",
    degeneracy = 8,
    kinetics = Arrhenius(
        A = (813000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (103.931, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (573, 'K'),
        Tmax = (623, 'K'),
    ),
    reference = Article(
        authors = ["Mulder, P.", "Louw, R."],
        title = u'Vapour-phase chemistry of arenes. Part 10. Formation of phenols in air oxidation of benzene, chlorobenzene, m-dichlorobenzene, and benzonitrile in the presence of cyclohexa-1,3-diene at ca. 600 K',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1135""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985MUL/LOU1135:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00007911
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007911/rk00000001.xml
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1217,
    label = "C3H6O3-2 + CH3O <=> CH4O + C3H5O3-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (56200, 'm^3/(mol*s)'),
        n = 0,
        Ea = (24.694, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (303, 'K'),
        Tmax = (376, 'K'),
    ),
    reference = Article(
        authors = ["Yee Quee, M.J.", "Thynne, J.C.J."],
        title = u'The photolysis of organic esters',
        journal = "Ber. Bunsenges. Phys. Chem.",
        volume = "72",
        pages = """211""",
        year = "1968",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1968YEE/THY211:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008150
Bath gas: CH3OCOOCH3
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1218,
    label = "C3H6O3-2 + CH3O <=> CH4O + C3H5O3-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (56200, 'm^3/(mol*s)'),
        n = 0,
        Ea = (24.777, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (314, 'K'),
        Tmax = (366, 'K'),
    ),
    reference = Article(
        authors = ["Quee, M.J.Y.", "Thynne, J.C.J."],
        title = u'Photolysis of dimethyl carbonate',
        journal = "Trans. Faraday Soc.",
        volume = "62",
        pages = """3154""",
        year = "1966",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1966QUE/THY3154:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008150
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008150/rk00000001.xml
Bath gas: CH3OCOOCH3
Excitation technique: Direct photolysis
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1219,
    label = "C4H6O + C3H5 <=> C3H6 + C4H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.09e+06, 'm^3/(mol*s)', '*|/', 1.07),
        n = 0,
        Ea = (35.919, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (411, 'K'),
        Tmax = (459, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (6666, 'Pa'),
    ),
    reference = Article(
        authors = ["Kerr, J.A.", "Smith, A.", "Trotman-Dickenson, A.F."],
        title = u'Reactions of cyclopropyl radicals in the methyl-initiated decomposition of cyclopropanecarbaldehyde',
        journal = "J. Chem. Soc. A",
        pages = """1400""",
        year = "1969",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1969KER/SMI1400:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00009652
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00009652/rk00000001.xml
Uncertainty: 1.0700001
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Other (direct)
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 1220,
    label = "C4H8O-2 + C3H7 <=> C3H8 + C4H7O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (200000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (45.148, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (464, 'K'),
        Tmax = (573, 'K'),
        Pmin = (1200, 'Pa'),
        Pmax = (4400, 'Pa'),
    ),
    reference = Article(
        authors = ["Kerr, J.A.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part 1.-n-Propyl radicals from the photolysis of n-butyraldehyde',
        journal = "Trans. Faraday Soc.",
        volume = "55",
        pages = """572""",
        year = "1959",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1959KER/TRO572:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006095
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006095/rk00000001.xml
Bath gas: n-C3H7CHO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1221,
    label = "C4H8O-2 + C3H7 <=> C3H8 + C4H7O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (100000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (27.604, 'kJ/mol', '+|-', 2.212),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (529, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Forgeteg, S.", "Berces, T.", "Dobe, S."],
        title = u'The kinetics and mechanism of n-butyraldehyde photolysis in the vapor phase at 313 nm',
        journal = "Int. J. Chem. Kinet.",
        volume = "11",
        pages = """219""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979FOR/BER219:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006095
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006095/rk00000003.xml
Uncertainty: 2.0
Bath gas: n-C3H7CHO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1222,
    label = "C4H8O-3 + C3H7 <=> C3H8 + C4H7O-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (200000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (28.02, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (371, 'K'),
        Tmax = (634, 'K'),
        Pmin = (1200, 'Pa'),
        Pmax = (4400, 'Pa'),
    ),
    reference = Article(
        authors = ["Kerr, J.A.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part 1.-n-Propyl radicals from the photolysis of n-butyraldehyde',
        journal = "Trans. Faraday Soc.",
        volume = "55",
        pages = """572""",
        year = "1959",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1959KER/TRO572:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006096
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006096/rk00000001.xml
Bath gas: n-C3H7CHO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1223,
    label = "C4H8O-3 + C3H7 <=> C3H8 + C4H7O-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (39800, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (40.99, 'kJ/mol', '+|-', 2.868),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (529, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Forgeteg, S.", "Berces, T.", "Dobe, S."],
        title = u'The kinetics and mechanism of n-butyraldehyde photolysis in the vapor phase at 313 nm',
        journal = "Int. J. Chem. Kinet.",
        volume = "11",
        pages = """219""",
        year = "1979",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1979FOR/BER219:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00006096
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006096/rk00000002.xml
Uncertainty: 3.1600001
Bath gas: n-C3H7CHO
Excitation technique: Direct photolysis
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1224,
    label = "C7H16-3 + OH <=> H2O + C7H15-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (4.37, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.488, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:41",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006332
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006332/rk00000001.xml
""",
)

entry(
    index = 1225,
    label = "C7H16-4 + OH <=> H2O + C7H15-4",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (4.37, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.488, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:42",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006333
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006333/rk00000001.xml
""",
)

entry(
    index = 1226,
    label = "C7H16-5 + OH <=> H2O + C7H15-5",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.26e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-0.798, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (303, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:22",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007083
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007083/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1227,
    label = "C7H16-5 + OH <=> H2O + C7H15-5",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.09e+06, 'm^3/(mol*s)', '*|/', 1.35),
        n = 0,
        Ea = (0.457, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Walker, R.W.", "Walker, R.W."],
        title = u'Addition of 2,2,3-Trimethylbutane to Slowly Reacting Mixtures of Hydrogen and Oxygen at 480oC',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "77",
        pages = """2157""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981BAL/WAL2157:6",
    ),
    referenceType = "review",
    shortDesc = u"""Experimental value and limited review""",
    longDesc = 
u"""
PrIMe Reaction: r00007083
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007083/rk00000002.xml
Uncertainty: 1.35
Bath gas: N2
Note: Invalid Ea value uncertainty (948.0) found and ignored
""",
)

entry(
    index = 1228,
    label = "C7H16-5 + OH <=> H2O + C7H15-5",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.7e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-0.956, 'kJ/mol', '+|-', 0.793),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (500, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Walker, R.W.", "Walker, R.W."],
        title = u'Addition of 2,2,3-Trimethylbutane to Slowly Reacting Mixtures of Hydrogen and Oxygen at 480oC',
        journal = "J. Chem. Soc. Faraday Trans. 1",
        volume = "77",
        pages = """2157""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981BAL/WAL2157:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00007083
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007083/rk00000003.xml
Bath gas: N2
""",
)

entry(
    index = 1229,
    label = "C7H16-5 + OH <=> H2O + C7H15-5",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2200, 'm^3/(mol*s)'),
        n = 1,
        Ea = (-2.744, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:16",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00007083
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007083/rk00000004.xml
""",
)

entry(
    index = 1230,
    label = "C7H16-5 + OH <=> H2O + C7H15-5",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.14, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-6.543, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:16",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00007083
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007083/rk00000005.xml
Bath gas: N2
""",
)

entry(
    index = 1231,
    label = "C7H16-5 + OH <=> H2O + C7H15-5",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (0.932, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-7.899, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:45",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00007083
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007083/rk00000006.xml
""",
)

entry(
    index = 1232,
    label = "C7H16-6 + OH <=> H2O + C7H15-6",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.69e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.843, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (303, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:23",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007084
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007084/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1233,
    label = "C7H16-6 + OH <=> H2O + C7H15-6",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (5.39, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:17",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00007084
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007084/rk00000002.xml
Bath gas: N2
""",
)

entry(
    index = 1234,
    label = "C7H16-6 + OH <=> H2O + C7H15-6",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (20, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (6.07, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:46",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00007084
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007084/rk00000003.xml
""",
)

entry(
    index = 1235,
    label = "C4H8-2 + C4H9-3 <=> C4H10-3 + C4H7-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (251000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (33.507, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (773, 'K'),
        Tmax = (794, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (80000, 'Pa'),
    ),
    reference = Article(
        authors = ["Collongues, C.", "Richard, C.", "Martin, R."],
        title = u'Thermal reaction of hydrogen-butene-2-cis mixtures at 500\xb0C: Hydrogenation, hydrogenolysis, and thermal reaction of the olefin',
        journal = "Int. J. Chem. Kinet.",
        volume = "15",
        pages = """5""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COL/RIC5:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007723
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007723/rk00000001.xml
Bath gas: H2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1236,
    label = "C4H8-5 + C4H7-4 <=> C4H8-4 + C4H7-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.98e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (66.1, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (750, 'K'),
        Tmax = (816, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Richard, C.", "Boiveaut, A.", "Martin, R."],
        title = u'H2S-Promoted Therm al Isomerization of Butene-2 cis to Butene-1 or Butene-2 trans around 500oC',
        journal = "Int. J. Chem. Kinet.",
        volume = "12",
        pages = """921""",
        year = "1980",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1980RIC/BOI921:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00007758
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007758/rk00000001.xml
Bath gas: (Z)-2-C4H8
""",
)

entry(
    index = 1237,
    label = "C7H8O + CH3 <=> CH4 + C7H7O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (3.94e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (37.249, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (445, 'K'),
        Tmax = (547, 'K'),
    ),
    reference = Article(
        authors = ["Mulcahy, M.F.R.", "Williams, D.J."],
        title = u'Reactions of free radicals with aromatic compounds in the gaseous phase. II. Kinetics of the reaction of methyl radicals with phenol',
        journal = "Aust. J. Chem.",
        volume = "18",
        pages = """20-38""",
        year = "1965",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1965MUL/WIL20-38:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00000863
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00000863/rk00000001.xml
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1238,
    label = "C3H6O + C4H9O-4 <=> C4H10O-4 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.26e+07, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (25.692, 'kJ/mol', '+|-', 1.289),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (6133, 'Pa'),
        Pmax = (12000, 'Pa'),
    ),
    reference = Article(
        authors = ["Al Akeel, N.Y.", "Selby, K.", "Waddington, D.J."],
        title = u'Reactions of Oxygenated Radicals in the Gas Phase. Part 8. Reactions of Alkoxyl Radicals with Aldehydes and Ketones',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """1036""",
        year = "1981",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1981ALA/SEL1036:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00001774
Uncertainty: 1.26
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1239,
    label = "C3H6 + C6H5 <=> C6H6 + C3H5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (251000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (35.586, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (550, 'K'),
        Tmax = (680, 'K'),
        Pmin = (1867, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Duncan, F.J.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of phenyl radicals from the photolysis of acetophenone and the strength of the C-H bond in benzene',
        journal = "J. Chem. Soc.",
        pages = """4672""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962DUN/TRO4672:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003202
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003202/rk00000001.xml
Bath gas: 1-Phenylethanone
Excitation technique: Direct photolysis
Analytical technique: Other (direct)
""",
)

entry(
    index = 1240,
    label = "C4H10-2 + C4H9O-4 <=> C4H10O-4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.38e+07, 'm^3/(mol*s)', '*|/', 1.12),
        n = 0,
        Ea = (23.946, 'kJ/mol', '+|-', 0.478),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003305
Uncertainty: 1.12
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1241,
    label = "C4H10-2 + C4H9O-4 <=> C4H10O-4 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (251000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (17.959, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (316, 'K'),
        Tmax = (338, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Park, C.R.", "Song, S.A.", "Lee, Y.E.", "Choo, K.Y."],
        title = u'Arrhenius Parameters for the tert-Butoxy Radical Reactions with Trimethylsilane in the Gas Phase',
        journal = "J. Am. Chem. Soc.",
        volume = "104",
        pages = """6445""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982PAR/SON6445:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00003305
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003305/rk00000003.xml
Bath gas: Ar
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1242,
    label = "C4H10-4 + C4H9O-4 <=> C4H10O-4 + C4H9-4",
    degeneracy = 9,
    kinetics = Arrhenius(
        A = (104000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (26.024, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (283, 'K'),
        Tmax = (343, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Brokenshire, J.L.", "Nechvatal, A.", "Tedder, J.M."],
        title = u'Free-radical substitution in aliphatic compounds. Part 20.-Gas-phase photolytic chlorination of butane and 2-methylpropane by t-butyl hypochlorite',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """2029""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BRO/NEC2029:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00003306
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003306/rk00000001.xml
Bath gas: tert-C4H9OCl
""",
)

entry(
    index = 1243,
    label = "C7H8O-2 + CH3 <=> CH4 + C7H7O-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (501000, 'm^3/(mol*s)', '*|/', 2),
        n = 0,
        Ea = (43.9, 'kJ/mol', '+|-', 3.517),
        T0 = (1, 'K'),
        Tmin = (453, 'K'),
        Tmax = (539, 'K'),
        Pmin = (1333, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Mulcahy, M.F.R.", "Tucker, B.G.", "Williams, D.J.", "Wilmshurst, J.R."],
        title = u'Reactions of free radicals with aromatic compounds in the gaseous phase. III. Kinetics of the reaction of methyl radicals with anisole (methoxybenzene)',
        journal = "Aust. J. Chem.",
        volume = "20",
        pages = """1155-1171""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967MUL/TUC1155-1171:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00004430
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004430/rk00000001.xml
Uncertainty: 2.0
Bath gas: Methoxybenzene
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1244,
    label = "C7H8O-2 + OH <=> H2O + C7H7O-2",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (1.02e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-2.095, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (360, 'K'),
        Tmax = (435, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Perry, R.A.", "Atkinson, R.", "Pitts, J.N., Jr."],
        title = u'Kinetics and mechanism of the gas phase reaction of OH radicals with methoxybenzene and o-cresol over the temperature range 299-435 K',
        journal = "J. Phys. Chem.",
        volume = "81",
        pages = """1607""",
        year = "1977",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1977PER/ATK1607:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004434
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004434/rk00000001.xml
Bath gas: Ar
Excitation technique: Direct photolysis
Analytical technique: Resonance fluorescence
""",
)

entry(
    index = 1245,
    label = "C4H10-3 + C4H9O-4 <=> C4H10O-4 + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.86e+07, 'm^3/(mol*s)', '*|/', 1.86),
        n = 0,
        Ea = (28.934, 'kJ/mol', '+|-', 2.02),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00004599
Uncertainty: 1.86
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1246,
    label = "C4H10-3 + C4H9O-4 <=> C4H10O-4 + C4H9-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (230000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.031, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (283, 'K'),
        Tmax = (343, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Brokenshire, J.L.", "Nechvatal, A.", "Tedder, J.M."],
        title = u'Free-radical substitution in aliphatic compounds. Part 20.-Gas-phase photolytic chlorination of butane and 2-methylpropane by t-butyl hypochlorite',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """2029""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BRO/NEC2029:4",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004599
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004599/rk00000001.xml
Bath gas: tert-C4H9OCl
""",
)

entry(
    index = 1247,
    label = "C4H10 + C4H9O-4 <=> C4H10O-4 + C4H9",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (100000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (27.022, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (283, 'K'),
        Tmax = (343, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (26700, 'Pa'),
    ),
    reference = Article(
        authors = ["Brokenshire, J.L.", "Nechvatal, A.", "Tedder, J.M."],
        title = u'Free-radical substitution in aliphatic compounds. Part 20.-Gas-phase photolytic chlorination of butane and 2-methylpropane by t-butyl hypochlorite',
        journal = "Trans. Faraday Soc.",
        volume = "66",
        pages = """2029""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970BRO/NEC2029:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00004600
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004600/rk00000001.xml
Bath gas: tert-C4H9OCl
""",
)

entry(
    index = 1248,
    label = "C4H8O2 + C3H7 <=> C3H8 + C4H7O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (158000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (31.761, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (368, 'K'),
        Tmax = (455, 'K'),
        Pmin = (7333, 'Pa'),
        Pmax = (17300, 'Pa'),
    ),
    reference = Article(
        authors = ["Thynne, J.C.J."],
        title = u'Reactions of alkyl radicals. Part 2.-Methyl radical photosensitized decomposition of n-propyl and isopropyl formates',
        journal = "Trans. Faraday Soc.",
        volume = "58",
        pages = """1394""",
        year = "1962",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1962THY1394:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005469
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005469/rk00000001.xml
Bath gas: HCOOCH2CH2CH3
Excitation technique: Sensitized photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1249,
    label = "C8H18 + OH <=> H2O + C8H17",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (3.69e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.843, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (296, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:17",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005579
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005579/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1250,
    label = "C8H18 + OH <=> H2O + C8H17",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (17.4, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (4.074, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:28",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005579
""",
)

entry(
    index = 1251,
    label = "C8H18 + OH <=> H2O + C8H17",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (5.39, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:12",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005579
Bath gas: N2
""",
)

entry(
    index = 1252,
    label = "C4H8 + C4H9O-4 <=> C4H10O-4 + C4H7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.45e+07, 'm^3/(mol*s)', '*|/', 1.48),
        n = 0,
        Ea = (26.274, 'kJ/mol', '+|-', 1.314),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005834
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005834/rk00000001.xml
Uncertainty: 1.48
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1253,
    label = "C8H16 + OH <=> H2O + C8H15",
    degeneracy = 16,
    kinetics = Arrhenius(
        A = (3.1e+07, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.426, 'kJ/mol', '+|-', 0.514),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (390, 'K'),
        Pmin = (4000, 'Pa'),
        Pmax = (4000, 'Pa'),
    ),
    reference = Article(
        authors = ["Donahue, N.M.", "Anderson, J.G.", "Demerjian, K.L."],
        title = u'New rate constants for ten OH alkane reactions from 300 to 400 K: an assessment of accuracy',
        journal = "J. Phys. Chem. A",
        volume = "102",
        pages = """3121-3126""",
        year = "1998",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1998DON/AND3121-3126:7",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00006530
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006530/rk00000001.xml
Bath gas: N2
Excitation technique: Electron beam
Analytical technique: Laser induced fluorescence
""",
)

entry(
    index = 1254,
    label = "C3H4 + C6H5 <=> C6H6 + C3H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.87e-06, 'm^3/(mol*s)'),
        n = 3.81,
        Ea = (9.229, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (2500, 'K'),
    ),
    reference = Article(
        authors = ["Park, J.", "Tokmakov, I.V.", "Lin, M.C."],
        title = u'Experimental and computational studies of the phenyl radical reaction with Allene',
        journal = "J. Phys. Chem. A",
        volume = "111",
        pages = """6881-6889""",
        year = "2007",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2007PAR/TOK6881-6889:5",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006974
""",
)

entry(
    index = 1255,
    label = "C3H4 + C6H5 <=> C6H6 + C3H3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (0.00034, 'm^3/(mol*s)'),
        n = 3.2,
        Ea = (18.18, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Vereecken, L.", "Peeters, J."],
        title = u'Reactions of chemically activated C9H9 species II: The reaction of phenyl radicals with allene and cyclopropene, and of benzyl radicals with acetylene',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "5",
        pages = """2807-2817""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003VER/PEE2807-2817:11",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00006974
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006974/rk00000001.xml

Used quantum calculations to compute many, many possible pathways for reactions of Phenyl + Allene, Phenyl + Cyclopropene, and Benzyl + Acetylene. Used B3LYP/6-311+G(d,p) for geometries/frequencies/PES and CCSD(T) or QCISD(T)/6-311G(d,p) for critical energies. RRKM/Master equation methods to calculate rate expressions. Too complicated to abstract all reaction pathways. Article refers reader to companion article by Vereecken et al, JACS 124, 2781 (2002) for more details. Rate expressions for a number of the major reaction pathways are abstracted here from the paper and supplementary material. For more details, see article and companion article.
""",
)

entry(
    index = 1256,
    label = "C6H12-2 + C3H7-2 <=> C3H8-2 + C6H11-2",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (6.17e+06, 'm^3/(mol*s)', '*|/', 3.09),
        n = 0,
        Ea = (57.037, 'kJ/mol', '+|-', 5.13),
        T0 = (1, 'K'),
        Tmin = (490, 'K'),
        Tmax = (540, 'K'),
    ),
    reference = Article(
        authors = ["Kortvelyesi, T.", "Seres, L."],
        title = u'Thermal reaction of the isopropyl radical with 2,3-dimethylbut-2-ene',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "88",
        pages = """2445-2450""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992KOR/SER2445-2450:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007606
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007606/rk00000001.xml
Uncertainty: 3.0899999
Bath gas: (iso-C3H7)-N=N-(iso-C3H7)
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1257,
    label = "C8H18-2 + CH3 <=> CH4 + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (1.91e+06, 'm^3/(mol*s)', '*|/', 1.38),
        n = 0,
        Ea = (46.145, 'kJ/mol', '+|-', 1.389),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M."],
        title = u'Kinetics of abstraction reactions of methyl radicals with alkanes in gas phase',
        journal = "Indian J. Chem.",
        volume = "29",
        pages = """748""",
        year = "1990",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1990SWA748:5",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008063
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008063/rk00000001.xml
Uncertainty: 1.38
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1258,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (12, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.48, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (1180, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics of the gas-phase reactions of OH radicals with alkanes and cycloalkanes',
        journal = "Atmos. Chem. Phys.",
        volume = "3",
        pages = """2233-2307""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003ATK2233-2307:19",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
""",
)

entry(
    index = 1259,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (10.2, 'm^3/(mol*s)', '*|/', 2),
        n = 2,
        Ea = (0.748, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (700, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Bowers, D.G.", "Malcolm, D.G.", "Tuckersman, R.T."],
        title = u'Evaluated kinetic data for high-temperature reactions. Volume 5. Part 1. Homogeneous gas phase reactions of the hydroxyl radical with alkanes',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "15",
        pages = """465""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986BAU/BOW465:25",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
Uncertainty: 2.0
""",
)

entry(
    index = 1260,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (11.3, 'm^3/(mol*s)', '*|/', 1.2),
        n = 2,
        Ea = (1.106, 'kJ/mol', '+|-', 0.476),
        T0 = (1, 'K'),
        Tmin = (290, 'K'),
        Tmax = (750, 'K'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Kinetics and mechanisms of the gas-phase reactions of the hydroxyl radical with organic compounds under atmospheric conditions',
        journal = "Chem. Rev.",
        volume = "86",
        pages = """69""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK69:100",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
Uncertainty: 1.2
""",
)

entry(
    index = 1261,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (11200, 'm^3/(mol*s)'),
        n = 1,
        Ea = (3.359, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Walker, R.W."],
        title = u'Temperature coefficients for reactions of OH radicals with alkanes between 300 and 1000 K',
        journal = "Int. J. Chem. Kinet.",
        volume = "17",
        pages = """573""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985WAL573:17",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
""",
)

entry(
    index = 1262,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (9.99, 'm^3/(mol*s)', '*|/', 2.51),
        n = 2,
        Ea = (0.748, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N.", "Westberg, K.R."],
        title = u'Chemical kinetic data sheets for high-temperature chemical reactions',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "12",
        pages = """531""",
        year = "1983",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1983COH/WES531:15",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
Uncertainty: 2.51
""",
)

entry(
    index = 1263,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (9.77e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (6.668, 'kJ/mol', '+|-', 0.534),
        T0 = (1, 'K'),
        Tmin = (294, 'K'),
        Tmax = (495, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:25",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008065/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1264,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (47.9, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (1.663, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:50",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
""",
)

entry(
    index = 1265,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (16.1, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:20",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
Bath gas: N2
""",
)

entry(
    index = 1266,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (10.2, 'm^3/(mol*s)'),
        n = 2,
        Ea = (0.748, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'The use of transition-state theory to extrapolate rate coefficients for reactions of OH with alkanes',
        journal = "Int. J. Chem. Kinet.",
        volume = "14",
        pages = """1339""",
        year = "1982",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1982COH1339:16",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00008065
""",
)

entry(
    index = 1267,
    label = "C6H5 + C3H4-3 <=> C6H6 + C3H3-3",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000261, 'm^3/(mol*s)'),
        n = 3.2,
        Ea = (15.24, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Vereecken, L.", "Peeters, J."],
        title = u'Reactions of chemically activated C9H9 species II: The reaction of phenyl radicals with allene and cyclopropene, and of benzyl radicals with acetylene',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "5",
        pages = """2807-2817""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003VER/PEE2807-2817:7",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00011159
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011159/rk00000001.xml

Used quantum calculations to compute many, many possible pathways for reactions of Phenyl + Allene, Phenyl + Cyclopropene, and Benzyl + Acetylene. Used B3LYP/6-311+G(d,p) for geometries/frequencies/PES and CCSD(T) or QCISD(T)/6-311G(d,p) for critical energies. RRKM/Master equation methods to calculate rate expressions. Too complicated to abstract all reaction pathways. Article refers reader to companion article by Vereecken et al, JACS 124, 2781 (2002) for more details. Rate expressions for a number of the major reaction pathways are abstracted here from the paper and supplementary material. For more details, see article and companion article.
""",
)

entry(
    index = 1268,
    label = "HO2-2 + C5H9O2 <=> C5H10O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (126000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-10.975, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (360, 'K'),
    ),
    reference = Article(
        authors = ["Lightfoot, P.D.", "Cox, R.A.", "Crowley, J.N.", "Destriau, M.", "Hayman, G.D.", "Jenkin, M.E.", "Moortgat, G.K.", "Zabel, F."],
        title = u'Organic peroxy radicals: kinetics, spectroscopy and tropospheric chemistry',
        journal = "Atmos. Environ. Part A",
        volume = "26",
        pages = """1805-1961""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992LIG/COX1805-1961:22",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00011903
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011903/rk00000001.xml
""",
)

entry(
    index = 1269,
    label = "HO2-2 + C5H9O2 <=> C5H10O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (193000, 'm^3/(mol*s)', '+|-', 91000),
        n = 0,
        Ea = (-9.562, 'kJ/mol', '+|-', 1.63),
        T0 = (1, 'K'),
        Tmin = (214, 'K'),
        Tmax = (539, 'K'),
    ),
    reference = Article(
        authors = ["Crawford, M.A.", "Szente, J.J.", "Maricq, M.M.", "Francisco, J.S."],
        title = u'Kinetics of the reaction between cyclopentylperoxy radicals and HO2',
        journal = "J. Phys. Chem. A",
        volume = "101",
        pages = """5337-5343""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997CRA/SZE5337-5343:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011903
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1270,
    label = "HO2-2 + C5H9O2 <=> C5H10O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (126000, 'm^3/(mol*s)', '+|-', 78000),
        n = 0,
        Ea = (-10.975, 'kJ/mol', '+|-', 1.538),
        T0 = (1, 'K'),
        Tmin = (248, 'K'),
        Tmax = (364, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Rowley, D.M.", "Lesclaux, R.", "Lightfoot, P.D.", "Noziere, B.", "Wallingotn, T.J.", "Hurley, M.D."],
        title = u'Kinetic and mechanistic studies of the reactions of cyclopentylperoxy and cyclohexylperoxy radicals with HO2',
        journal = "J. Phys. Chem.",
        volume = "96",
        pages = """4889-4894""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ROW/LES4889-4894:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011903
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1271,
    label = "HO2-2 + C5H11O2 <=> C5H12O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (86100, 'm^3/(mol*s)', '+|-', 28000),
        n = 0,
        Ea = (-11.474, 'kJ/mol', '+|-', 0.803),
        T0 = (1, 'K'),
        Tmin = (248, 'K'),
        Tmax = (365, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Rowley, D.M.", "Lesclaux, R.", "Lightfoot, P.D.", "Hughes, K.", "Hurley, M.D.", "Rudy, S.", "Wallington, T.J."],
        title = u'A kinetic and mechanistic study of the reaction of neopentylperoxy radicals with HO2',
        journal = "J. Phys. Chem.",
        volume = "96",
        pages = """7043-7048""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ROW/LES7043-7048:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011910
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011910/rk00000001.xml
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Fourier transform (FTIR)
""",
)

entry(
    index = 1272,
    label = "C8H18-3 + OH <=> H2O + C8H17-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.64e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.559, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (296, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:16",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005578
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005578/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1273,
    label = "C8H18-3 + OH <=> H2O + C8H17-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.2, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.569, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:11",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005578
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005578/rk00000002.xml
Bath gas: N2
""",
)

entry(
    index = 1274,
    label = "C8H18-3 + OH <=> H2O + C8H17-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (3.47, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:27",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005578
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005578/rk00000003.xml
""",
)

entry(
    index = 1275,
    label = "C8H18-4 + OH <=> H2O + C8H17-4",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.64e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.559, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (296, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:18",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005581
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005581/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1276,
    label = "C8H18-4 + OH <=> H2O + C8H17-4",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.2, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-3.201, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:13",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005581
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005581/rk00000002.xml
Bath gas: N2
""",
)

entry(
    index = 1277,
    label = "C8H18-4 + OH <=> H2O + C8H17-4",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.26, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.654, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:29",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005581
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005581/rk00000003.xml
""",
)

entry(
    index = 1278,
    label = "C8H18-5 + OH <=> H2O + C8H17-5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.64e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (3.559, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (296, 'K'),
        Tmax = (497, 'K'),
        Pmin = (13300, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Greiner, N.R."],
        title = u'Hydroxyl radical kinetics by kinetic spectroscopy. VI. Reactions with alkanes in the range 300-500\xb0K',
        journal = "J. Chem. Phys.",
        volume = "53",
        pages = """1070""",
        year = "1970",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1970GRE1070:19",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005582
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005582/rk00000001.xml
Bath gas: He
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1279,
    label = "C8H18-5 + OH <=> H2O + C8H17-5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.2, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-3.201, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:14",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005582
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005582/rk00000002.xml
Bath gas: N2
""",
)

entry(
    index = 1280,
    label = "C8H18-5 + OH <=> H2O + C8H17-5",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (5.26, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.654, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:30",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005582
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005582/rk00000003.xml
""",
)

entry(
    index = 1281,
    label = "C8H18-2 + OH <=> H2O + C8H17-2",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (8.99e+07, 'm^3/(mol*s)', '+|-', 5e+07),
        n = 0,
        Ea = (27.022, 'kJ/mol', '+|-', 5.13),
        T0 = (1, 'K'),
        Tmin = (673, 'K'),
        Tmax = (773, 'K'),
        Pmin = (7999, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Baldwin, R.R.", "Hisham, M.W.M.", "Walker, R.W."],
        title = u'Elementary reactions involved in the oxidation of propene: Arrhenius parameters for the reaction HO2 + C3H6 = C3H6O + OH',
        journal = "Symp. Int. Combust. Proc.",
        volume = "20",
        pages = """743""",
        year = "1985",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1985BAL/HIS743:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1282,
    label = "C8H18-6 + OH <=> H2O + C8H17-6",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.14, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-6.543, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:18",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00007395
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007395/rk00000001.xml
Bath gas: N2
""",
)

entry(
    index = 1283,
    label = "C8H18-6 + OH <=> H2O + C8H17-6",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (1.7, 'm^3/(mol*s)'),
        n = 1.9,
        Ea = (-6.07, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1200, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:48",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00007395
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007395/rk00000002.xml
""",
)

entry(
    index = 1284,
    label = "C8H18-7 + OH <=> H2O + C8H17-7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (5.39, 'm^3/(mol*s)'),
        n = 2,
        Ea = (1.887, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (1000, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Atkinson, R."],
        title = u'Estimations of OH radical rate constants from H-atom abstraction from C-H and O-H bonds over the temperature range 250-1000K',
        journal = "Int. J. Chem. Kinet.",
        volume = "18",
        pages = """555""",
        year = "1986",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1986ATK555:19",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00007396
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007396/rk00000001.xml
Bath gas: N2
""",
)

entry(
    index = 1285,
    label = "C8H18-7 + OH <=> H2O + C8H17-7",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (17.8, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (5.986, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1200, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:49",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00007396
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007396/rk00000002.xml
""",
)

entry(
    index = 1286,
    label = "C4H8-5 + C4H9O-4 <=> C4H10O-4 + C4H7-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.17e+07, 'm^3/(mol*s)', '*|/', 2.09),
        n = 0,
        Ea = (25.027, 'kJ/mol', '+|-', 2.503),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:9",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007724
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007724/rk00000001.xml
Uncertainty: 2.0899999
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1287,
    label = "C4H8-5 + C4H9O-4 <=> C4H10O-4 + C4H7-5",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.95e+07, 'm^3/(mol*s)', '*|/', 1.7),
        n = 0,
        Ea = (26.523, 'kJ/mol', '+|-', 1.854),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:10",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008214
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008214/rk00000001.xml
Uncertainty: 1.7
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1288,
    label = "C6H5 + C3H4-4 <=> C6H6 + C3H3-4",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (0.000594, 'm^3/(mol*s)'),
        n = 3.13,
        Ea = (29.88, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (200, 'K'),
        Tmax = (2000, 'K'),
    ),
    reference = Article(
        authors = ["Vereecken, L.", "Peeters, J."],
        title = u'Reactions of chemically activated C9H9 species II: The reaction of phenyl radicals with allene and cyclopropene, and of benzyl radicals with acetylene',
        journal = "Phys. Chem. Chem. Phys.",
        volume = "5",
        pages = """2807-2817""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003VER/PEE2807-2817:6",
    ),
    referenceType = "theory",
    shortDesc = u"""Ab initio""",
    longDesc = 
u"""
PrIMe Reaction: r00011158
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011158/rk00000001.xml

Used quantum calculations to compute many, many possible pathways for reactions of Phenyl + Allene, Phenyl + Cyclopropene, and Benzyl + Acetylene. Used B3LYP/6-311+G(d,p) for geometries/frequencies/PES and CCSD(T) or QCISD(T)/6-311G(d,p) for critical energies. RRKM/Master equation methods to calculate rate expressions. Too complicated to abstract all reaction pathways. Article refers reader to companion article by Vereecken et al, JACS 124, 2781 (2002) for more details. Rate expressions for a number of the major reaction pathways are abstracted here from the paper and supplementary material. For more details, see article and companion article.
""",
)

entry(
    index = 1289,
    label = "HO2-2 + C4H9O3 <=> C4H10O3 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (33700, 'm^3/(mol*s)', '+|-', 12000),
        n = 0,
        Ea = (-13.719, 'kJ/mol', '+|-', 1.098),
        T0 = (1, 'K'),
        Tmin = (306, 'K'),
        Tmax = (398, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Boyd, A.A.", "Lesclaux, R.", "Jenkin, M.E.", "Wallington, T.J."],
        title = u'A spectroscopic, kinetic, and product study of the (CH3)2C(OH)CH2O2 radical self reaction and reaction with HO2',
        journal = "J. Phys. Chem.",
        volume = "100",
        pages = """6594-6603""",
        year = "1996",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1996BOY/LES6594-6603:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011918
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011918/rk00000001.xml
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1290,
    label = "C4H10O-3 + C4H9O-5 <=> C4H10O-5 + C4H9O-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (2.51e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (53.961, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (763, 'K'),
        Tmax = (798, 'K'),
        Pmin = (6666, 'Pa'),
        Pmax = (13300, 'Pa'),
    ),
    reference = Article(
        authors = ["Foucaut, J.-F.", "Martin, R."],
        title = u"No. 18. - Etude analytique et cinetique de la pyrolyse de l'ether ethylique vers 500 \xb0C et a faible avancement",
        journal = "J. Chim. Phys.",
        volume = "75",
        pages = """132""",
        year = "1978",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1978FOU/MAR132:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001564
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001564/rk00000001.xml
Bath gas: (C2H5)2O
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1291,
    label = "C3H6O + C6H5 <=> C6H6 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (420000, 'm^3/(mol*s)', '+|-', 40000),
        n = 0,
        Ea = (7.94, 'kJ/mol', '+|-', 0.249),
        T0 = (1, 'K'),
        Tmin = (299, 'K'),
        Tmax = (451, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (9999, 'Pa'),
    ),
    reference = Article(
        authors = ["Choi, Y.M.", "Park, J.", "Lin, M.C."],
        title = u'Experimental and Computational Studies of the Kinetics and Mechanisms for C6H5 Reactions with Acetone -h6 and -d6',
        journal = "J. Phys. Chem. A",
        volume = "107",
        pages = """7755-7761""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003CHO/PAR7755-7761:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00001772
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001772/rk00000001.xml
Bath gas: Ar
Pressure dependence: Rate constant is pressure independent
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Other (Vis-UV)

Combined experimental and quantum study. C6H5 produced by 248 nm KrF excimer laser photolysis of C6H5NO. C6H5 detected using cavity ring down spectroscopy at 504.8 nm versus time. Typical acetone 0-0.35 torr in 20-75 torr Argon. Used both acetone and deuterated acetone (d6).

DFT quantum calculations B3LYP/aug-cc-pvTZ energies. Rate expressions calculated using Truhlars Polyrate program. Tunneling correction CVT/SCT employed.

Quantum calculations found abstraction barrier of about 3.9 kcal/mol, C addition channel with barrier of about 9.4 kcal/mol, and O addition channel with barrier of about 12.4 kcal/mol. Thus, abstraction dominates. C addition channel can lead to beta scission of CH3 and formation of methyl phenyl ketone with calculated barrier of about 8.1 kcal/mol
""",
)

entry(
    index = 1292,
    label = "C3H6O + C6H5 <=> C6H6 + C3H5O",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.7e-07, 'm^3/(mol*s)', '+|-', 6e-08),
        n = (4.2, '', '+|-', 0.1),
        Ea = (-3.875, 'kJ/mol', '+|-', 0.216),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (1200, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (9999, 'Pa'),
    ),
    reference = Article(
        authors = ["Choi, Y.M.", "Park, J.", "Lin, M.C."],
        title = u'Experimental and Computational Studies of the Kinetics and Mechanisms for C6H5 Reactions with Acetone -h6 and -d6',
        journal = "J. Phys. Chem. A",
        volume = "107",
        pages = """7755-7761""",
        year = "2003",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=2003CHO/PAR7755-7761:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00001772
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00001772/rk00000001.xml
Bath gas: Ar

Combined experimental and quantum study. C6H5 produced by 248 nm KrF excimer laser photolysis of C6H5NO. C6H5 detected using cavity ring down spectroscopy at 504.8 nm versus time. Typical acetone 0-0.35 torr in 20-75 torr Argon. Used both acetone and deuterated acetone (d6).

DFT quantum calculations B3LYP/aug-cc-pvTZ energies. Rate expressions calculated using Truhlars Polyrate program. Tunneling correction CVT/SCT employed.

Quantum calculations found abstraction barrier of about 3.9 kcal/mol, C addition channel with barrier of about 9.4 kcal/mol, and O addition channel with barrier of about 12.4 kcal/mol. Thus, abstraction dominates. C addition channel can lead to beta scission of CH3 and formation of methyl phenyl ketone with calculated barrier of about 8.1 kcal/mol

Used transition states from quantum calculations to get functional form of rate expression in order to provide expression over a range of temperatures (298-1200 K). Adjusted calculated barrier of 3.9 kcal/mol to 3.3 kcal/mol to get rate expression to agree with experimental rate constants.
""",
)

entry(
    index = 1293,
    label = "C4H10-2 + C6H5 <=> C6H6 + C4H9-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (280000, 'm^3/(mol*s)', '+|-', 150000),
        n = 0,
        Ea = (12.571, 'kJ/mol', '+|-', 0.366),
        T0 = (1, 'K'),
        Tmin = (295, 'K'),
        Tmax = (972, 'K'),
        Pmin = (400, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Park, J.", "Gheyas, S.I.", "Lin, M.C."],
        title = u'Kinetics of C6H5 Radical Reactions with 2-Methylpropane, 2,3-Dimethylbutane and 2,3,4-Trimethylpentane',
        journal = "Int J. Chem. Kinet.",
        volume = "31",
        pages = """645-653""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999PAR/GHE645-653:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00003297
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00003297/rk00000001.xml
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Mass spectrometry

The rate constant is higher than the only measurement by 1962DUN/TRO4672. However, the previous rate constant is obtained from the assumed C6H5 recombination rate, and the study was carried out at unspecified wavelengths.
""",
)

entry(
    index = 1294,
    label = "C8H10 + HO2 <=> H2O2 + C8H9",
    degeneracy = 3,
    kinetics = Arrhenius(
        A = (3.19e+06, 'm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        Ea = (81.149, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (600, 'K'),
        Tmax = (1000, 'K'),
    ),
    reference = Article(
        authors = ["Baulch, D.L.", "Cobos, C.J.", "Cox, R.A.", "Frank, P.", "Hayman, G.", "Just, Th.", "Kerr, J.A.", "Murrells, T.", "Pilling, M.J.", "Troe, J.", "Walker, R.W.", "Warnatz, J."],
        title = u'Evaluated kinetic data for combusion modelling. Supplement I',
        journal = "J. Phys. Chem. Ref. Data",
        volume = "23",
        pages = """847-1033""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994BAU/COB847-1033:39",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00004365
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00004365/rk00000001.xml
Uncertainty: 3.1600001
""",
)

entry(
    index = 1295,
    label = "C5H10O + C4H9 <=> C4H10 + C5H9O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (79400, 'm^3/(mol*s)'),
        n = 0,
        Ea = (22.615, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (334, 'K'),
        Tmax = (502, 'K'),
        Pmin = (1600, 'Pa'),
        Pmax = (2800, 'Pa'),
    ),
    reference = Article(
        authors = ["Kerr, J.A.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part III. n-Butyl radicals from the photolysis of n-Valeraldehyde',
        journal = "J. Chem. Soc.",
        pages = """1602""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960KER/TRO1602:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005458
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005458/rk00000001.xml
Bath gas: n-C4H9CHO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1296,
    label = "C9H20 + OH <=> H2O + C9H19",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (14.8, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (4.074, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:32",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00005609
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005609/rk00000001.xml
""",
)

entry(
    index = 1297,
    label = "C5H12-7 + C4H9O-4 <=> C4H10O-4 + C5H11-7",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (2.14e+07, 'm^3/(mol*s)', '*|/', 1.51),
        n = 0,
        Ea = (32.426, 'kJ/mol', '+|-', 1.297),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:6",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007060
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007060/rk00000001.xml
Uncertainty: 1.51
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1298,
    label = "C5H10-2 + C4H9O-4 <=> C4H10O-4 + C5H9-2",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (1.35e+07, 'm^3/(mol*s)', '*|/', 1.7),
        n = 0,
        Ea = (22.782, 'kJ/mol', '+|-', 1.821),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:7",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007257
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007257/rk00000001.xml
Uncertainty: 1.7
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1299,
    label = "C5H10O-2 + C4H9-4 <=> C4H10-4 + C5H9O-2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (513000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (27.188, 'kJ/mol', '+|-', 0.544),
        T0 = (1, 'K'),
        Tmin = (390, 'K'),
        Tmax = (503, 'K'),
        Pmin = (2480, 'Pa'),
        Pmax = (4933, 'Pa'),
    ),
    reference = Article(
        authors = ["Metcalfe, E.L.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VIII. Isobutyl radicals from the photolysis of isovaleraldehyde',
        journal = "J. Chem. Soc.",
        pages = """5072-5077""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960MET/TRO5072-5077:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007798
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007798/rk00000001.xml
Bath gas: iso-C4H9CHO
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1300,
    label = "C5H10O-3 + C4H9-2 <=> C4H10-2 + C5H9O-3",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (794000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (41.822, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (513, 'K'),
        Tmax = (667, 'K'),
    ),
    reference = Article(
        authors = ["Birrell, R.N.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of alkyl radicals. Part VII. t-butyl radicals from the photolysis of pivalaldehyde',
        journal = "J. Chem. Soc.",
        pages = """4218""",
        year = "1960",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1960BIR/TRO4218:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00008600
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00008600/rk00000001.xml
Bath gas: 2,2-dimethylpropanal
Excitation technique: Direct photolysis
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1301,
    label = "C6H11O2 + HO2-2 <=> C6H12O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (157000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (-10.393, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (250, 'K'),
        Tmax = (360, 'K'),
    ),
    reference = Article(
        authors = ["Lightfoot, P.D.", "Cox, R.A.", "Crowley, J.N.", "Destriau, M.", "Hayman, G.D.", "Jenkin, M.E.", "Moortgat, G.K.", "Zabel, F."],
        title = u'Organic peroxy radicals: kinetics, spectroscopy and tropospheric chemistry',
        journal = "Atmos. Environ. Part A",
        volume = "26",
        pages = """1805-1961""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992LIG/COX1805-1961:11",
    ),
    referenceType = "review",
    shortDesc = u"""Extensive literature review""",
    longDesc = 
u"""
PrIMe Reaction: r00010498
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00010498/rk00000001.xml
""",
)

entry(
    index = 1302,
    label = "C6H11O2 + HO2-2 <=> C6H12O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (157000, 'm^3/(mol*s)', '+|-', 72000),
        n = 0,
        Ea = (-10.31, 'kJ/mol', '+|-', 1.039),
        T0 = (1, 'K'),
        Tmin = (248, 'K'),
        Tmax = (364, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Rowley, D.M.", "Lesclaux, R.", "Lightfoot, P.D.", "Noziere, B.", "Wallingotn, T.J.", "Hurley, M.D."],
        title = u'Kinetic and mechanistic studies of the reactions of cyclopentylperoxy and cyclohexylperoxy radicals with HO2',
        journal = "J. Phys. Chem.",
        volume = "96",
        pages = """4889-4894""",
        year = "1992",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1992ROW/LES4889-4894:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00010498
Bath gas: N2
Excitation technique: Flash photolysis (laser or conventional)
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1303,
    label = "C8H18O2 + CH3 <=> CH4 + C8H17O2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (6.31e+06, 'm^3/(mol*s)', '*|/', 1.26),
        n = 0,
        Ea = (53.129, 'kJ/mol', '+|-', 1.064),
        T0 = (1, 'K'),
        Tmin = (377, 'K'),
        Tmax = (432, 'K'),
        Pmin = (1227, 'Pa'),
        Pmax = (5253, 'Pa'),
    ),
    reference = Article(
        authors = ["Cafferata, L.F.R."],
        title = u'Reaccion de extraccion de atomos de hidrogeno del trimetilnitrometano gaseoso por radicales metilo',
        journal = "An. Asoc. Quim. Argent.",
        volume = "60",
        pages = """11""",
        year = "1972",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1972CAF11:1",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005413
Uncertainty: 1.26
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1304,
    label = "C8H18O2 + CH3 <=> CH4 + C8H17O2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (4.47e+06, 'm^3/(mol*s)', '*|/', 1.5),
        n = 0,
        Ea = (49.804, 'kJ/mol', '+|-', 1.497),
        T0 = (1, 'K'),
        Tmin = (400, 'K'),
        Tmax = (444, 'K'),
    ),
    reference = Article(
        authors = ["Morris, E.R.", "Thynne, J.C.J."],
        title = u'Reactions of methyl radicals with fluoroaldehydes',
        journal = "Trans. Faraday Soc.",
        volume = "63",
        pages = """2470-2475""",
        year = "1967",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1967MOR/THY2470-2475:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005413
Uncertainty: 1.5
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Mass spectrometry
""",
)

entry(
    index = 1305,
    label = "C8H18O2 + CH3 <=> CH4 + C8H17O2",
    degeneracy = 18,
    kinetics = Arrhenius(
        A = (2.5e+06, 'm^3/(mol*s)'),
        n = 0,
        Ea = (48.972, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (403, 'K'),
        Tmax = (428, 'K'),
    ),
    reference = Article(
        authors = ["Pritchard, G.O.", "Pritchard, H.O.", "Trotman-Dickenson, A.F."],
        title = u'The reactions of methyl radicals with acetone, diethyl ketone, and di-tert.-butyl peroxide',
        journal = "J. Chem. Soc.",
        pages = """1425""",
        year = "1954",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1954PRI/PRI1425:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005413
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005413/rk00000001.xml
Bath gas: (tert-C4H9O)2
Excitation technique: Thermal
Analytical technique: Other (direct)
Note: Invalid activation energy uncertainty (8314.472) found and ignored
""",
)

entry(
    index = 1306,
    label = "C6H12 + C4H9O-4 <=> C4H10O-4 + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (2.69e+07, 'm^3/(mol*s)', '*|/', 1.1),
        n = 0,
        Ea = (26.274, 'kJ/mol', '+|-', 0.525),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (66700, 'Pa'),
        Pmax = (66700, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I."],
        title = u'Kinetics of abstraction reactions of tert-butoxyl radicals with cyclohexane and methyl-substituted cyclohexanes in the gas phase',
        journal = "J. Chem. Soc. Faraday Trans.",
        volume = "87",
        pages = """2157-2159""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991SWA2157-2159:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005487
Uncertainty: 1.1
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1307,
    label = "C6H12 + C4H9O-4 <=> C4H10O-4 + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (3.47e+07, 'm^3/(mol*s)', '*|/', 1.23),
        n = 0,
        Ea = (27.022, 'kJ/mol', '+|-', 0.27),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00005487
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005487/rk00000001.xml
Uncertainty: 1.23
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1308,
    label = "C5H10 + C6H5 <=> C6H6 + C5H9",
    degeneracy = 10,
    kinetics = Arrhenius(
        A = (2.69e+06, 'm^3/(mol*s)', '*|/', 1.2),
        n = 0,
        Ea = (16.962, 'kJ/mol', '+|-', 0.509),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (500, 'K'),
        Pmin = (2666, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Yu, T.", "Lin, M.C."],
        title = u'Kinetics of phenyl radical reactions with selected cycloalkanes and carbon tetrachloride',
        journal = "J. Phys. Chem.",
        volume = "99",
        pages = """8599-8603""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995YU/LIN8599-8603:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00006483
Uncertainty: 1.2
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1309,
    label = "C5H6 + C6H5 <=> C6H6 + C5H5",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (310000, 'm^3/(mol*s)'),
        n = 0,
        Ea = (23.031, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1080, 'K'),
        Tmax = (1550, 'K'),
        Pmin = (172000, 'Pa'),
        Pmax = (973000, 'Pa'),
    ),
    reference = Article(
        authors = ["Burcat, A.", "Dvinyaninov, M."],
        title = u'Detailed kinetics of cyclopentadiene decomposition studied in a shock tube',
        journal = "Int. J. Chem. Kinet.",
        volume = "29",
        pages = """505-514""",
        year = "1997",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1997BUR/DVI505-514:4",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007435
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007435/rk00000001.xml
Bath gas: Ar
Excitation technique: Thermal
Time resolution: In real time
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1310,
    label = "C6H12-2 + C4H9O-4 <=> C4H10O-4 + C6H11-2",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (2.5e+07, 'm^3/(mol*s)', '*|/', 2.57),
        n = 0,
        Ea = (22.033, 'kJ/mol', '+|-', 3.301),
        T0 = (1, 'K'),
        Tmin = (399, 'K'),
        Tmax = (434, 'K'),
        Pmin = (26700, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Sway, M.I.", "Waddington, D.J."],
        title = u'Reactons of oxygenated radicals in the gas phase. Part 13. Reactions of t-Butoxyl radicals with alkanes and alkenes',
        journal = "J. Chem. Soc. Perkin Trans. 2",
        pages = """63""",
        year = "1984",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1984SWA/WAD63:8",
    ),
    referenceType = "experiment",
    shortDesc = u"""Derived from fitting to a complex mechanism""",
    longDesc = 
u"""
PrIMe Reaction: r00007613
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007613/rk00000001.xml
Uncertainty: 2.5699999
Bath gas: N2
Excitation technique: Thermal
Analytical technique: Gas chromatography
""",
)

entry(
    index = 1311,
    label = "HO2-2 + C7H7O2 <=> C7H8O2 + O2",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (226000, 'm^3/(mol*s)', '+|-', 20000),
        n = 0,
        Ea = (-8.148, 'kJ/mol', '+|-', 1.871),
        T0 = (1, 'K'),
        Tmin = (273, 'K'),
        Tmax = (450, 'K'),
        Pmin = (93300, 'Pa'),
        Pmax = (93300, 'Pa'),
    ),
    reference = Article(
        authors = ["Noziere, B.", "Lesclaux, R.", "Hurley, M.D.", "Dearth, M.A.", "Wallington, T.J."],
        title = u'A kinetic and mechanistic study of the self-reaction and reaction with HO2 of the benzylperoxy radical',
        journal = "J. Phys. Chem.",
        volume = "98",
        pages = """2864-2873""",
        year = "1994",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1994NOZ/LES2864-2873:11",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00011834
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00011834/rk00000001.xml
Bath gas: N2
Excitation technique: Direct photolysis
Analytical technique: Fourier transform (FTIR)
""",
)

entry(
    index = 1312,
    label = "C10H22 + OH <=> H2O + C10H21",
    degeneracy = 6,
    kinetics = Arrhenius(
        A = (14.1, 'm^3/(mol*s)'),
        n = 1.8,
        Ea = (4.074, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:34",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006129
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006129/rk00000001.xml
""",
)

entry(
    index = 1313,
    label = "C10H22-2 + OH <=> H2O + C10H21-2",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (1.99, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-2.494, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:35",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006130
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006130/rk00000001.xml
""",
)

entry(
    index = 1314,
    label = "C10H22-3 + OH <=> H2O + C10H21-3",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.76, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.82, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:36",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006131
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006131/rk00000001.xml
""",
)

entry(
    index = 1315,
    label = "C10H22-4 + OH <=> H2O + C10H21-4",
    degeneracy = 4,
    kinetics = Arrhenius(
        A = (6.79, 'm^3/(mol*s)'),
        n = 2,
        Ea = (-5.82, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (298, 'K'),
        Tmax = (500, 'K'),
    ),
    reference = Article(
        authors = ["Cohen, N."],
        title = u'Are reaction rate coefficients additive? Revised transition state theory calculations for OH + alkane reactions',
        journal = "Int. J. Chem. Kinet.",
        volume = "23",
        pages = """397-417""",
        year = "1991",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1991COH397-417:37",
    ),
    referenceType = "theory",
    shortDesc = u"""Transition state theory""",
    longDesc = 
u"""
PrIMe Reaction: r00006132
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00006132/rk00000001.xml
""",
)

entry(
    index = 1316,
    label = "C6H6O + C5H5 <=> C5H6 + C6H5O",
    degeneracy = 1,
    kinetics = Arrhenius(
        A = (2.67e+08, 'm^3/(mol*s)'),
        n = 0,
        Ea = (105.594, 'kJ/mol'),
        T0 = (1, 'K'),
        Tmin = (1060, 'K'),
        Tmax = (1160, 'K'),
        Pmin = (101000, 'Pa'),
        Pmax = (101000, 'Pa'),
    ),
    reference = Article(
        authors = ["Lovell, A.B.", "Brezinsky, K.", "Glassman, I."],
        title = u'The gas phase pyrolysis of phenol',
        journal = "Int. J. Chem. Kinet.",
        volume = "21",
        pages = """547-560""",
        year = "1989",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1989LOV/BRE547-560:3",
    ),
    referenceType = "theory",
    shortDesc = u"""Estimated: thermochemical, kinetic, or other""",
    longDesc = 
u"""
PrIMe Reaction: r00005225
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00005225/rk00000001.xml
""",
)

entry(
    index = 1317,
    label = "C6H12 + C6H5 <=> C6H6 + C6H11",
    degeneracy = 12,
    kinetics = Arrhenius(
        A = (4.79e+06, 'm^3/(mol*s)', '*|/', 1.74),
        n = 0,
        Ea = (15.881, 'kJ/mol', '+|-', 1.588),
        T0 = (1, 'K'),
        Tmin = (297, 'K'),
        Tmax = (523, 'K'),
        Pmin = (3866, 'Pa'),
        Pmax = (7999, 'Pa'),
    ),
    reference = Article(
        authors = ["Yu, T.", "Lin, M.C."],
        title = u'Kinetics of phenyl radical reactions with selected cycloalkanes and carbon tetrachloride',
        journal = "J. Phys. Chem.",
        volume = "99",
        pages = """8599-8603""",
        year = "1995",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1995YU/LIN8599-8603:2",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00005486
Uncertainty: 1.74
Bath gas: Ar
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Vis-UV absorption
""",
)

entry(
    index = 1318,
    label = "C8H18-8 + C6H5 <=> C6H6 + C8H17-8",
    degeneracy = 2,
    kinetics = Arrhenius(
        A = (680000, 'm^3/(mol*s)', '+|-', 240000),
        n = 0,
        Ea = (3.559, 'kJ/mol', '+|-', 0.898),
        T0 = (1, 'K'),
        Tmin = (291, 'K'),
        Tmax = (496, 'K'),
        Pmin = (5333, 'Pa'),
        Pmax = (5333, 'Pa'),
    ),
    reference = Article(
        authors = ["Park, J.", "Gheyas, S.I.", "Lin, M.C."],
        title = u'Kinetics of C6H5 Radical Reactions with 2-Methylpropane, 2,3-Dimethylbutane and 2,3,4-Trimethylpentane',
        journal = "Int J. Chem. Kinet.",
        volume = "31",
        pages = """645-653""",
        year = "1999",
        url = "http://kinetics.nist.gov/kinetics/Detail?id=1999PAR/GHE645-653:3",
    ),
    referenceType = "experiment",
    shortDesc = u"""Absolute value measured directly""",
    longDesc = 
u"""
PrIMe Reaction: r00007664
PrIMe Kinetics: http://warehouse.primekinetics.org/depository/reactions/data/r00007664/rk00000001.xml
Experimental procedure: Static or low flow - Data taken vs time
Excitation technique: Flash photolysis (laser or conventional)
Time resolution: In real time
Analytical technique: Mass spectrometry
""",
)

