#!/usr/bin/env python
# encoding: utf-8

name = "H_Abstraction/rules"
shortDesc = u""
longDesc = u"""
General comments go at the top of the file,

or in a section(s) titled 'General'

.. the ID must match those in the rateLibrary AS A STRING (ie. '2' is different from '02')


.. [MRHCBSQB3RRHO] M.R. Harper (mrharper_at_mit_dot_edu or michael.harper.jr_at_gmail_dot_com)
The geometries of all reactants, products, and the transition state were optimized using the CBS-QB3 calculations.  The zero-point
energy is that computed by the CBS-QB3 calculations.  The frequencies were computed with B3LYP/CBSB7.
In computing k(T), an asymmetric tunneling correction was employed, the calculated frequencies were scaled by 0.99, and the 
temperatures used were: 300, 331, 370, 419, 482, 568, 692, 885, 1227, 2000 (evenly spaced on inverse temperature scale).

.. [Tsang1990] W. Tsang; "Chemical kinetic database for combustion chemistry. Part IV. Isobutane" J. Phys. Chem. Ref. Data 19 (1990) 1-68

.. [Tsang1991] W. Tsang; "Chemical kinetic database for combustion chemistry. Part V. Propene" J. Phys. Chem. Ref. Data 20 (1991) 221-273
"""
entry(
    index = 0,
    label = "X_H_or_Xrad_H_Xbirad_H_Xtrirad_H;Y_rad_birad_trirad_quadrad",
    kinetics = ArrheniusEP(
        A = (100000, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 0,
    shortDesc = u"""Default""",
    longDesc = 
u"""
If a biradical CH2JJ can abstract from RCH4 to make RCH3J and CH3J 
then a Y_rad CH3J should be able to abstract from RCH3J which means X_H needs 
to include Xrad_H. I.e. you can abstract from a radical. To make this possible
a head node has been created X_H_or_Xrad_H which is a union of X_H and Xrad_H.
The kinetics for it have just been copied from X_H and are only defined for 
abstraction by Y_rad_birad. I.e. the top level very approximate guess.

Do better kinetics for this exist? Do we in fact use the reverse kinetics anyway?
""",
)

entry(
    index = 1,
    label = "X_H;Y_rad_birad_trirad_quadrad",
    kinetics = ArrheniusEP(
        A = (100000, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 0,
    shortDesc = u"""Default""",
)

entry(
    index = 2,
    label = "X_H;H_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0.65,
        E0 = (9.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Dean, A. M. [118]""",
    longDesc = 
u"""
[118] Dean, A.M. Development and application of Detailed Kinetic Mechanisms for Free Radical Systems.
""",
)

entry(
    index = 3,
    label = "X_H;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0.75,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Dean, A. M. [118]""",
    longDesc = 
u"""
[118] Dean, A.M. Development and application of Detailed Kinetic Mechanisms for Free Radical Systems.
""",
)

entry(
    index = 4,
    label = "X_H;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0.5,
        E0 = (10.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Dean, A. M. [118]""",
    longDesc = 
u"""
[118] Dean, A.M. Development and application of Detailed Kinetic Mechanisms for Free Radical Systems.
""",
)

entry(
    index = 5,
    label = "X_H;O_sec_rad",
    kinetics = ArrheniusEP(
        A = (14000, 'cm^3/(mol*s)'),
        n = 2.69,
        alpha = 0.6,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Dean, A. M. [118]""",
    longDesc = 
u"""
[118] Dean, A.M. Development and application of Detailed Kinetic Mechanisms for Free Radical Systems.
""",
)

entry(
    index = 6,
    label = "X_H;C_methyl",
    kinetics = ArrheniusEP(
        A = (810000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0.65,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Dean, A. M. [118]""",
    longDesc = 
u"""
[118] Dean, A.M. Development and application of Detailed Kinetic Mechanisms for Free Radical Systems.
""",
)

entry(
    index = 7,
    label = "X_H;O2b",
    kinetics = ArrheniusEP(
        A = (5e+10, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 1,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Estimate [W.H. Green]""",
    longDesc = 
u"""
Sumathy CBS-Q calculations. Rate expression per H atom.
""",
)

entry(
    index = 8,
    label = "O/H/NonDeC;O2b",
    kinetics = ArrheniusEP(
        A = (5e+10, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 1,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Estimate [W.H. Green]""",
    longDesc = 
u"""
Sumathy CBS-Q calculations. Rate expression per H atom.
""",
)

entry(
    index = 142,
    label = "C/H3/Cs;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (5.93e+06, 'cm^3/(mol*s)'),
        n = 1.8,
        alpha = 0,
        E0 = (1.431, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. Fixed by RWest (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253. http://dx.doi.org/10.1016/S0010-2180(01)00373-X

Rate expressions for H atom abstraction from fuels. 
pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:OH, Site: primary (a)
Verified by Karma James

**HOWEVER** This entry should probably use the numbers for primary(d) not primary(a).
Primary(a) is for a primary on neopentane; primary(d) is for a primary on propane.
Richard West. (Updated accordingly).

These numbers reported by Curran et al. were apparently taken from
N. Cohen, *Intl. J. Chem. Kinet.* 14 (1982), p. 1339 http://dx.doi.org/10.1002/kin.550141206

Rate expression is changed to per H.(divided by 3)
Yushi Suzuki
""",
)

entry(
    index = 143,
    label = "C/H2/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (450000, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-1.133, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
http://dx.doi.org/10.1016/S0010-2180(01)00373-X

Rate expressions for H atom abstraction from fuels. 
pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:OH, Site: secondary (b)

Verified by Karma James

These numbers reported by Curran et al. were apparently taken from
N. Cohen, *Intl. J. Chem. Kinet.* 14 (1982), p. 1339 http://dx.doi.org/10.1002/kin.550141206


Rate expression is changed to per H.(divided by 2)
Yushi Suzuki
""",
)

entry(
    index = 144,
    label = "C/H/Cs3;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.7e+06, 'cm^3/(mol*s)'),
        n = 1.9,
        alpha = 0,
        E0 = (-1.451, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels.""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
http://dx.doi.org/10.1016/S0010-2180(01)00373-X

Rate expressions for H atom abstraction from fuels.
pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:OH, Site: tertiary (c)

Verified by Karma James

These numbers reported by Curran et al. were apparently taken from
N. Cohen, *Intl. J. Chem. Kinet.* 14 (1982), p. 1339 http://dx.doi.org/10.1002/kin.550141206
""",
)

entry(
    index = 145,
    label = "C/H3/Cs;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (950, 'cm^3/(mol*s)'),
        n = 3.05,
        alpha = 0,
        E0 = (3.123, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:O, Site: primary (a)

Verified by Karma James

Rate expression is changed to per H.(divided by 9)
Yushi Suzuki
""",
)

entry(
    index = 146,
    label = "C/H2/NonDeC;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (23900, 'cm^3/(mol*s)'),
        n = 2.71,
        alpha = 0,
        E0 = (2.106, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:O, Site: secondary (b)

Verified by Karma James


Rate expression is changed to per H.(divided by 2)
Yushi Suzuki
""",
)

entry(
    index = 147,
    label = "C/H/Cs3;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (383000, 'cm^3/(mol*s)'),
        n = 2.41,
        alpha = 0,
        E0 = (1.14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels.""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:O, Site: tertiary (c)

Verified by Karma James


This rate parameter actually comes from following new mechanism for PRF.

https://www-pls.llnl.gov/data/docs/science_and_technology/chemistry/combustion/prf_2d_mech.txt

Yushi Suzuki
""",
)

entry(
    index = 148,
    label = "C/H3/Cs;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (2.8e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (20.435, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Walker, R. W. Reactions of HO 2 radicals in combustion chemistry.""",
    longDesc = 
u"""
Walker, R. W. Symposium (International) on Combustion. Vol. 22. No. 1. Elsevier, 1989.
Reactions of HO 2 radicals in combustion chemistry.

Cited as source in:
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:HO2, Site: primary (a)
Verified by Karma James

Rate expression is changed to per H.(divided by 9)
Yushi Suzuki
""",
)

entry(
    index = 149,
    label = "C/H2/NonDeC;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (2.8e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (17.686, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:HO2, Site: secondary (b)

Verified by Karma James

Rate expression is changed to per H.(divided by 2)
Yushi Suzuki
""",
)

entry(
    index = 150,
    label = "C/H/Cs3;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (2.8e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (16.013, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels.""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:HO2, Site: tertiary (c)

Verified by Karma James
""",
)

entry(
    index = 151,
    label = "C/H3/Cs;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (5.27e+10, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:CH3O, Site: primary (a)

Verified by Karma James

Rate expression is changed to per H.(divided by 9)
Yushi Suzuki
""",
)

entry(
    index = 152,
    label = "C/H2/NonDeC;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (5.5e+10, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:CH3O, Site: secondary (b)

Verified by Karma James

Rate expression is changed to per H.(divided by 2)
Yushi Suzuki
""",
)

entry(
    index = 153,
    label = "C/H/Cs3;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (1.9e+10, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels.""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:CH3O, Site: tertiary (c)

Verified by Karma James
""",
)

entry(
    index = 154,
    label = "C/H3/Cs;O2b",
    kinetics = ArrheniusEP(
        A = (7e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (50.76, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:O2, Site: primary (a)

Verified by Karma James

Rate expression is changed to per H.(divided by 9)
Yushi Suzuki
""",
)

entry(
    index = 155,
    label = "C/H2/NonDeC;O2b",
    kinetics = ArrheniusEP(
        A = (7e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (48.21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels. (changed to per H)""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:O2, Site: secondary (b)

Verified by Karma James

Rate expression is changed to per H.(divided by 2)
Yushi Suzuki
""",
)

entry(
    index = 156,
    label = "C/H/Cs3;O2b",
    kinetics = ArrheniusEP(
        A = (7e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (46.06, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Curran et al. [8] Rate expressions for H atom abstraction from fuels.""",
    longDesc = 
u"""
[8] Curran, H.J.; Gaffuri, P.; Pit z, W.J.; Westbrook, C.K. Combust. Flame 2002, 129, 253.
Rate expressions for H atom abstraction from fuels.

pg 257 A Comprehensive Modelling Study of iso-Octane Oxidation, Table 1. Radical:O2, Site: tertiary (c)

Verified by Karma James
""",
)

entry(
    index = 157,
    label = "H2;O2b",
    kinetics = ArrheniusEP(
        A = (7.25e+13, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (56.64, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (800, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
H2 + O2 --> H + HO2 C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 1091, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 3,2.

Verified by Karma James

pg. 1109: Discussion of evaluated data

Recommended value computed using reverse rate and thermodynamics

MRH 28-Aug-2009
""",
)

entry(
    index = 158,
    label = "H2;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (4730, 'cm^3/(mol*s)'),
        n = 2.56,
        alpha = 0,
        E0 = (5.03, 'kcal/mol'),
        Tmin = (200, 'K'),
        Tmax = (3000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Knyazev et al. [119] Transition state theory.""",
    longDesc = 
u"""
[119] Knyazev, V.D; Bencsura, A.; Stoliarov, S.I.; Slagle, I.R. J. Phys. Chem. 1996, 100, 11346.
H2 + C2H3 --> H + C2H4 C.D.W divided original rate expression by 2 ( from A = 9.45E+03), to get rate expression per H atom.
""",
)

entry(
    index = 159,
    label = "H2;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (11100, 'cm^3/(mol*s)'),
        n = 2.48,
        alpha = 0,
        E0 = (7.13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (3500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Mebel et al. [120] Transition state theory.""",
    longDesc = 
u"""
[120] Mebel, A.M.; Morokuma, K.; Lin, M.C. J Chem. Phys. 1995, 103, 3440.
H2 + C2H3 --> H + C2H4 C.D.W divided original rate expression by 2, to get rate expression per H atom.
""",
)

entry(
    index = 160,
    label = "H2;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.58e+09, 'cm^3/(mol*s)'),
        n = 0.7,
        alpha = 0,
        E0 = (5.11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Weissman et al. [121] Transition state theory.""",
    longDesc = 
u"""
[121] Weissman, M.A.; Benson, S.W. J. Phys. Chem. 1988, 92, 4080.
H2 + C2H3 --> H + C2H4 C.D.W divided original rate expression by 2 ( from A = 3.15E+09), to get rate expression per H atom.
""",
)

entry(
    index = 161,
    label = "H2;Ct_rad",
    kinetics = ArrheniusEP(
        A = (5.4e+12, 'cm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        alpha = 0,
        E0 = (2.17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [94] literature review.""",
    longDesc = 
u"""
[94] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Frank, P.; Hayman, G,; Just, T.; Kerr, J.A.; Murrells, T.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1994, 23, 847.

H2 + C2H --> H + C2H2 C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 863 Evaluated Kinetic Data for Combustion Modelling Supplement 1, Table 1. Bimolecular reactions - C2H Radical Reactions.

Verified by Karma James

pg.1013-1014: Discussion on evaluated data

C2H+H2-->C2H2+H: Recommended rate coefficient is that reported by Koshi et al.  Rate

coefficient was computed for low temperatures, but extrapolation to higher temperatures
fits other reported data reasonably well.
MRH 31-Aug-2009
""",
)

entry(
    index = 162,
    label = "H2;Cb_rad",
    kinetics = ArrheniusEP(
        A = (28600, 'cm^3/(mol*s)'),
        n = 2.43,
        alpha = 0,
        E0 = (6.28, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (5000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Mebel et al. [122] Transition state theory.""",
    longDesc = 
u"""
[122] Mebel, A.M.; Lin, M.C.; Yu, T.; Morokuma, K. J. Phys. Chem. A. 1997, 101, 3189.
H2 + phenyl --> H + benzene C.D.W divided original rate expression by 2 ( from A = 5.71E+04), to get rate expression per H atom.
""",
)

entry(
    index = 163,
    label = "H2;CO_pri_rad",
    kinetics = ArrheniusEP(
        A = (900000, 'cm^3/(mol*s)', '*|/', 5),
        n = 2,
        alpha = 0,
        E0 = (17.83, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
H2 + HCO --> H + CH2O C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 1094, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 15,2.

Verified by Karma James

pg. 1147: Discussion of evaluated data

Recommended value computed using reverse rate and thermodynamics

MRH 28-Aug-2009
""",
)

entry(
    index = 164,
    label = "H2;CO_rad/NonDe",
    kinetics = ArrheniusEP(
        A = (2.06e+06, 'cm^3/(mol*s)', '*|/', 3),
        n = 1.82,
        alpha = 0,
        E0 = (17.61, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
H2 + CH3CO --> H + CH3CHO C.D.W divided original rate expression by 2, to get rate expression per H atom.

//WAS UNABLE TO VERIFY DATA!!! DATA NOT FOUND IN REFERENCE.

pg. 1229: Discussion on evaluated data

No experimental data for forward rxn, at the time

Reviewers noticed that k(H+HCHO=H2+HCO) / k(H+CH3CHO=H2+CH3CO) ~ 2, due to double the number of H atoms available

Used 0.5*k(H+HCHO=H2+HCO) and equilibrium constant to compute recommended rate expression

Verified by MRH on 10Aug2009
""",
)

entry(
    index = 165,
    label = "H2;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (9.1e+08, 'cm^3/(mol*s)'),
        n = 1.21,
        alpha = 0,
        E0 = (4.71, 'kcal/mol'),
        Tmin = (200, 'K'),
        Tmax = (2400, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Isaacson [123] Transition state theory.""",
    longDesc = 
u"""
[123] Isaacson, A.D. J. Chem. Phys. 1997, 107, 3832.
H2 + O2 --> H + H2O C.D.W divided original rate expression by 2, to get rate expression per H atom.

166. [100] Jodkowski, J.T.; Rauez, M.-T.; Rayez, J.-C. J. Phys. Chem. A. 1999, 103, 3750.

H2 + CH3O --> H + CH3OH The calculated reverse rate constants are in good agreement with experiment. (This is -R1 in the paper)

C.D.W divided original rate expression by 2, to get rate expression per H atom.

Verified by Greg Magoon; maximum error of fitted expression from tabular data for forward rate constant, kr1 is 15% (cf. p. 3758)
""",
)

entry(
    index = 166,
    label = "H2;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.0632, 'cm^3/(mol*s)'),
        n = 4,
        alpha = 0,
        E0 = (4.91, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Jodkowski et al. [100] ab initio calculations.""",
)

entry(
    index = 167,
    label = "C_methane;O2b",
    kinetics = ArrheniusEP(
        A = (9.925e+12, 'cm^3/(mol*s)', '*|/', 10),
        n = 0,
        alpha = 0,
        E0 = (56.83, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

CH4 + O2 --> CH3 + HO2 C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 417 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - O2 Reactions.

Verified by Karma James

pg.483: Discussion on evaluated data

O2+CH4 --> HO2+CH3: Recommended data based on experimental value for CH2O + O2 -->

HO2 + HCO.  Assumes equal A factor per C-H bond and Ea = deltaH.
MRH 31-Aug-2009
""",
)

entry(
    index = 168,
    label = "C_methane;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.0216, 'cm^3/(mol*s)', '*|/', 2),
        n = 4.14,
        alpha = 0,
        E0 = (12.56, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH4 + C2H5 --> CH3 + C2H6 C.D.W divided original rate expression by 4, to get rate expression per H atom.

//WAS UNABLE TO VERIFY DATA!!! DATA NOT FOUND IN REFERENCE.

pg. 1177: Discussion on evaluated data

No experimental data for forward rxn, at the time

Recommended data from reverse rate and equilibrium constant

Verified by MRH on 10Aug2009
""",
)

entry(
    index = 169,
    label = "C_methane;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000181, 'cm^3/(mol*s)', '*|/', 2),
        n = 4.4,
        alpha = 0,
        E0 = (10.79, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
CH4 + iso-C3H7 --> CH3 + C3H8 C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 894, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 42,10.

Verified by Karma James

pg. 935: Discussion on evaluated data

Entry 42,10: No data available at the time.  Author recommends rate coefficient

expression based on reverse rate and equilibrium constant.
MRH 30-Aug-2009
""",
)

entry(
    index = 170,
    label = "C_methane;Ct_rad",
    kinetics = ArrheniusEP(
        A = (4.53e+11, 'cm^3/(mol*s)', '*|/', 10),
        n = 0,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH4 + C2H --> CH3 + C2H2 C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 1101, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 21,10.

Verified by Karma James

pg. 1220: Discussion of evaluated data

Recommended data is expression given by Brown and Laufer (1981).

They computed the pre-exponential factor by the bond energy-bond order (BEBO) method

and combined that with experimental k at room temperature to yield Arrhenius expression
MRH 28-Aug-2009
""",
)

entry(
    index = 171,
    label = "C_methane;Cb_rad",
    kinetics = ArrheniusEP(
        A = (5e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (560, 'K'),
        Tmax = (1410, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Heckmann et al. [124]""",
    longDesc = 
u"""
[124] Heckmann, E.; Hippler, H. Troe, J. Sypm. Int. Combust. Proc. 1996, 26, 543.
Absolute value measured directly (excitation technique: thermal, analytical technique: vis-UV absorption) CH4 + phenyl --> benzene

C.D.W divided original rate expression by 4, to get rate expression per H atom.
""",
)

entry(
    index = 172,
    label = "C_methane;CO_pri_rad",
    kinetics = ArrheniusEP(
        A = (1820, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.85,
        alpha = 0,
        E0 = (22.46, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH4 + HCO --> CH3 + CH2O C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 1094, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 15,10.

Verified by Karma James

pg. 1150: Discussion on evaluated data

Recommended data computed using reverse rate and equilibrium constant

MRH 28-Aug-2009
""",
)

entry(
    index = 173,
    label = "C_methane;CO_rad/NonDe",
    kinetics = ArrheniusEP(
        A = (543, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.88,
        alpha = 0,
        E0 = (21.46, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH4 + CH3CO --> CH3 + CH3CHO C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 1102, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 22,10.

Verified by Karma James

pg. 1231: Discussion on evaluated data

Recommended number computed from reverse rate and equilibrium constant

MRH 28-Aug-2009
""",
)

entry(
    index = 174,
    label = "C_methane;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.385, 'cm^3/(mol*s)'),
        n = 3.95,
        alpha = 0,
        E0 = (0.55, 'kcal/mol'),
        Tmin = (223, 'K'),
        Tmax = (2400, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Melissas and Truhlar [125] Transition state theory.""",
    longDesc = 
u"""
[125] Melissas, V.S.; Truhlar, D.G. J. Chem. Phys. 1993,99,1010.
CH4 + OH --> CH3 + H2O C.D.W divided original rate expression by 4, to get rate expression per H atom.
""",
)

entry(
    index = 175,
    label = "C_methane;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (3.93e+06, 'cm^3/(mol*s)', '*|/', 1.41),
        n = 1.83,
        alpha = 0,
        E0 = (2.78, 'kcal/mol'),
        Tmin = (240, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

CH4 + OH --> CH3 + H2O C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 419 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - OH Radical Reactions.

Verified by Karma James

pg.571-572: Discussion on evaluated data

OH+CH4 --> H2O+CH3: "The preferred value of k is that obtained experimentally by

Madronich and Felder which predicts very precisely the data obtained between
240 and 2000K."
MRH 31-Aug-2009
""",
)

entry(
    index = 176,
    label = "C_methane;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.55e+07, 'cm^3/(mol*s)'),
        n = 1.6,
        alpha = 0,
        E0 = (3.12, 'kcal/mol'),
        Tmin = (298, 'K'),
        Tmax = (1510, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Cohen et al. [101] Transition state theory.""",
    longDesc = 
u"""
[101] Cohen, N. Int. J. Chem. Kinet. 1991, 23, 397.
CH4 + OH --> CH3 + H2O C.D.W divided original rate expression by 4, to get rate expression per H atom.
""",
)

entry(
    index = 177,
    label = "C_methane;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000155, 'cm^3/(mol*s)'),
        n = 5,
        alpha = 0,
        E0 = (5.58, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Jodkowski et al. [100] ab initio calculations.""",
    longDesc = 
u"""
[100] Jodkowski, J.T.; Rauez, M.-T.; Rayez, J.-C. J. Phys. Chem. A. 1999, 103, 3750.
CH4 + CH3O --> CH3 + CH3OH The calculated reverse rate constants are in good agreement with experiment. (Rxn. -R3 in paper)

C.D.W divided original rate expression by 4 ( from A= 1.51E+09), to get rate expression per H atom.

Verified by Greg Magoon; cf. reverse reaction, #261, below
""",
)

entry(
    index = 178,
    label = "C_methane;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (4.53e+10, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (18.58, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH4 + HO2 --> CH3 + H2O2 C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 1093, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 10,7.

Verified by Karma James

pg. 1131: Discussion on evaluated data

Recommended data is based on expression for HO2 attach on alkanes (Walker)

MRH 28-Aug-2009
""",
)

entry(
    index = 179,
    label = "C/H3/Cs;O2b",
    kinetics = ArrheniusEP(
        A = (1.005e+13, 'cm^3/(mol*s)', '*|/', 10),
        n = 0,
        alpha = 0,
        E0 = (51.87, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

C2H6 + O2 --> C2H5 + HO2 C.D.W divided original rate expression by 6, to get rate expression per H atom.

pg 417 Evaluated Kinetic Data for Combustion Modelling  Table 1. Bimolecular reactions - O2 Reactions. (The value for E0 does not 

match the value in the reference, E0 RMG = 1.87; E0 Reference = 51.86)

Verified by Karma James

pg.484: Discussion on evaluated data

O2+C2H6 --> HO2+C2H5: "The value given in the Walker review has been modified slightly

to allow for the higher heat of formation of the C2H5 radical now recommended
and for an assumed equal A factor per C-H bond in CH2O+O2 and C2H6+O2."
*** NOTE: MRH agrees with KJ on discrepancy in RMG-stored E0.  MRH is changing the value

of E0 in RMG from 1.87 kcal/mol to 51.87 kcal/mol. ***
MRH 31-Aug-2009
""",
)

entry(
    index = 180,
    label = "C/H3/Cs;Ct_rad",
    kinetics = ArrheniusEP(
        A = (6.02e+11, 'cm^3/(mol*s)', '*|/', 3),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
C2H6 + C2H --> C2H5 + C2H2 C.D.W divided original rate expression by 6, to get rate expression per H atom.

pg 1101, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 21,11.

Verified by Karma James

pg. 1221: Discussion on evaluated data

Recommended data is based on expression given by Brown and Laufer (1981).

Brown and Laufer calculated pre-exponential factor by BEBO method and
combined calculation with experimental measurement of k at room temperature.
MRH 28-Aug-2009
""",
)

entry(
    index = 181,
    label = "C/H3/Cs;Cb_rad",
    kinetics = ArrheniusEP(
        A = (3.48e+10, 'cm^3/(mol*s)', '*|/', 2.35),
        n = 0,
        alpha = 0,
        E0 = (4.44, 'kcal/mol', '+|-', 0.18),
        Tmin = (565, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Park et al. [126]""",
    longDesc = 
u"""
[126] Park, J.; Gheyas, S.; Lin, M.C. Int. J. Chem. Kinet. 2001, 33, 64.
Absolute value measured directly. Static or low flow, flash photolysis excitation, Vis-UV absoprtion analysis. 

Phenyl radicals are produced from 193 nm photolysis of C6H5COCH3. The cavity ringdown spectroscopy and/or mass spectroscopy

have been used to monitor reactant and/or products. C2H6 + phenyl --> C2H5 + benzene.

C.D.W divided original rate expression by 6 ( from A= 2.09E+11), to get rate expression per H atom. Original delta A = 2.0E+10.
""",
)

entry(
    index = 182,
    label = "C/H3/Cs;CO_pri_rad",
    kinetics = ArrheniusEP(
        A = (7820, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.72,
        alpha = 0,
        E0 = (18.24, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
C2H6 + HCO --> C2H5 + CH2O C.D.W divided original rate expression by 6(from A = 4.69E+04), to get rate expression per H atom.

pg 1094, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 15,11.

Verified by Karma James

pg. 1150: Discussion on evaluated data

Recommended data computed from reverse rate and equilibrium constant

MRH 28-Aug-2009
""",
)

entry(
    index = 183,
    label = "C/H3/Cs;CO_rad/NonDe",
    kinetics = ArrheniusEP(
        A = (3020, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.75,
        alpha = 0,
        E0 = (17.53, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang et al. [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
C2H6 + CH3CO --> C2H5 + CH3CHO C.D.W divided original rate expression by 6(from A = 1.81E+04), to get rate expression per H atom.

pg 1102, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 22,11.

Verified by Karma James

pg. 1231: Discussion on evaluated data

Recommended data computed using rate of C2H5+CH2O divided by 2 (since only one O=C-H

hydrogen is present in CH3CHO) and equilibrium constant
MRH 28-Aug-2009
""",
)

entry(
    index = 184,
    label = "C/H3/Cs;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)', '*|/', 1.41),
        n = 2,
        alpha = 0,
        E0 = (0.86, 'kcal/mol'),
        Tmin = (250, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

C2H6 + OH --> C2H5 + H2O C.D.W divided original rate expression by 6, to get rate expression per H atom.

pg 420 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - OH Radical Reactions.

Verified by Karma James

pg.589-590: Discussion on evaluated data

OH+C2H6 --> H2O+C2H5: "The preferred value of k is almost indistinguishable from the

value obtained by Cohen from transition state calculations carried out for
temperatures between 300 and 2000K."
MRH 31-Aug-2009
""",
)

entry(
    index = 185,
    label = "C/H3/CO;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (517000, 'cm^3/(mol*s)'),
        n = 2.2,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (295, 'K'),
        Tmax = (600, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Taylor et al. [127] Transition state theory.""",
    longDesc = 
u"""
[127] Taylor, P.H.; Rahman, M.S.; Arif, M.; Dellinger, B.; Marshall, P. Sypm. Int. Combust. Proc. 1996, 26, 497.
CH3CHO + OH --> CH2CHO + H2O Rate constant is high pressure limit (pressure 0.13-0.97atm?) 

C.D.W divided original rate expression by 3(from A = 1.55E+06), to get rate expression per H atom.
""",
)

entry(
    index = 186,
    label = "C/H3/O;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.000205, 'cm^3/(mol*s)'),
        n = 4.9,
        alpha = 0,
        E0 = (6.72, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Jodkowski et al. [100] ab initio calculations.""",
    longDesc = 
u"""
[100] Jodkowski, J.T.; Rauez, M.-T.; Rayez, J.-C. J. Phys. Chem. A. 1999, 103, 3750.
CH3OH + CH3 --> CH2OH + CH4 The calculated rate constants are in good agreement with experiment. (Rxn. R4 in paper)

C.D.W divided original rate expression by 3 ( from A= 8.43E+08), to get rate expression per H atom.

Verified by Greg Magoon
""",
)

entry(
    index = 187,
    label = "C/H3/O;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (8140, 'cm^3/(mol*s)'),
        n = 2.8,
        alpha = 0,
        E0 = (-0.42, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Jodkowski et al. [100] ab initio calculations.""",
    longDesc = 
u"""
[100] Jodkowski, J.T.; Rauez, M.-T.; Rayez, J.-C. J. Phys. Chem. A. 1999, 103, 3750.
CH3OH + OH --> CH2OH + H2O The calculated rate constants are in good agreement with experiment. (Rxn. R6 in paper)

C.D.W divided original rate expression by 3 ( from A= 2.11E+11), to get rate expression per H atom.

Verified by Greg Magoon
**Note that R2 from this paper appears to be missing from the RMG library, so I have added it as 1001**
""",
)

entry(
    index = 188,
    label = "C/H2/NonDeC;O2b",
    kinetics = ArrheniusEP(
        A = (1.985e+13, 'cm^3/(mol*s)', '*|/', 10),
        n = 0,
        alpha = 0,
        E0 = (47.69, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + O2 --> iso-C3H7 + HO2  C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 891, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 40,3.

//NOTE: For A value, Database value = 1.985E+13 and Reference value = 1.65E+13

Verified by Karma James

NOTE: MRH computed Reference A value of 1.99E+13 (11Aug2009)

pg. 899: Discussion on evaluated data

Entry 40,3 (b): No data available at the time.  The author "estimates" the rate

coefficient expressions (no indication of how).
MRH 30-Aug-2009
""",
)

entry(
    index = 189,
    label = "C/H2/NonDeC;CH2_triplet",
    kinetics = ArrheniusEP(
        A = (0.755, 'cm^3/(mol*s)', '*|/', 10),
        n = 3.46,
        alpha = 0,
        E0 = (7.47, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + CH2 --> iso-C3H7 + CH3  C.D.W divided original rate expression by 2(from A = 1.51), to get rate expression per H atom.

pg 892, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 40,26.
Verified by Karma James

pg. 910: Discussion on evaluated data

Entry 40,26 (b): No data available at the time.  Author estimates the rate coefficient

expression as that of CH3+C3H8=i-C3H7+CH4.
MRH 30-Aug-2009
""",
)

entry(
    index = 190,
    label = "C/H2/NonDeC;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (23900, 'cm^3/(mol*s)', '*|/', 2),
        n = 2.71,
        alpha = 0,
        E0 = (2.11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + O --> iso-C3H7 + OH  C.D.W divided original rate expression by 2(from A = 4.77E+04), to get rate expression per H atom.

pg 891, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 40,5.

Verified by Karma James

pg. 901: Discussion on evaluated data

Entry 40,5 (b): The author notes "considerable scatter" among the existing data.  The

author computed Arrhenius A and n parameters using a BEBO calculation and performed
a "fit" on the data reported by Herron and Huie to obtain the Arrhenius E.  This
rate coefficient expression is stated to fit 3 (of the 5) raw data reported.
MRH 30-Aug-2009
""",
)

entry(
    index = 191,
    label = "C/H2/NonDeC;C_rad/H2/O",
    kinetics = ArrheniusEP(
        A = (30.2, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.95,
        alpha = 0,
        E0 = (11.98, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + CH2OH --> iso-C3H7 + CH3OH  C.D.W divided original rate expression by 2(from A = 6.03E+01), to get rate expression per H atom.

//WAS UNABLE TO VERIFY DATA!!! DATA NOT FOUND IN REFERENCE.

pg. 910: Discussion on evaluated data

Entry 40,39 (b)

No experimental data, at the time

Recommended value for C3H8+CH2OH-->n-C3H7+CH3OH comes from rate for C2H6+CH2OH-->C2H5+CH3OH

No discussion on where rate for C3H8+CH2OH-->i-C3H7+CH3OH comes from:

A is ~ factor of 3 smaller (6 hydrogens vs 2 ... seems reasonable to MRH)
E is 1 kcal/mol smaller (more stable to form secondary radical than primary)
Verified by MRH on 10Aug2009

MRH 30-Aug-2009
""",
)

entry(
    index = 192,
    label = "C/H2/NonDeC;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (510, 'cm^3/(mol*s)', '*|/', 10),
        n = 3.1,
        alpha = 0,
        E0 = (8.82, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + C2H3 --> iso-C3H7 + C2H4  C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 891, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 40,19.

Verified by Karma James

pg. 906: Discussion on evaluated data

Entry 40,19 (b): No data available at the time.  The author recommends the rate coefficient

expression of C2H3+C2H6=C2H5+C2H4 for the rxn C2H3+C3H8=n-C3H7+C2H4.  The author
assumes the ratio of secondary-to-primary H-atom abstraction for the rxn CH3+C3H8
to obtain the recommended rate coefficient expression.
MRH 30-Aug-2009
""",
)

entry(
    index = 193,
    label = "C/H2/NonDeC;Ct_rad",
    kinetics = ArrheniusEP(
        A = (6.05e+11, 'cm^3/(mol*s)', '*|/', 3),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + C2H --> iso-C3H7 + C2H2  C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 891, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 40,21.

Verified by Karma James

pg. 906-907: Discussion on evaluated data

Entry 40,21 (b): No data available at the time.  The author recommends the rate coefficient

of C2H6+C2H=C2H2+C2H5 for the rxn C3H8+C2H=C2H2+n-C3H7.  Due to the high exothermicity
of the rxn, the author assumes the H-atom abstraction rxn is limited to the number
of H-atoms available, thus recommedning a rate coefficient equal to one-third that
recommended for C3H8+C2H=C2H2+n-C3H7.
MRH 30-Aug-2009
""",
)

entry(
    index = 194,
    label = "C/H2/NonDeC;CO_pri_rad",
    kinetics = ArrheniusEP(
        A = (5.4e+06, 'cm^3/(mol*s)', '*|/', 3),
        n = 1.9,
        alpha = 0,
        E0 = (17.01, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + HCO --> iso-C3H7 + CH2O  C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 891, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 40,15.

Verified by Karma James

pg. 904: Discussion on evaluated data

Entry 40,15 (b): No data available at the time.  The author recommends a rate coefficient

expression based on the reverse rxn (note: the author uses the rate of the rxn
n-C3H7+CH2O=HCO+C3H8 instead of i-C3H7+CH2O=HCO+C3H8) and equilibrium constant.
MRH 30-Aug-2009
""",
)

entry(
    index = 195,
    label = "C/H2/NonDeC;CO_rad/NonDe",
    kinetics = ArrheniusEP(
        A = (2.65e+06, 'cm^3/(mol*s)', '*|/', 3),
        n = 2,
        alpha = 0,
        E0 = (16.24, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + CH3CO --> iso-C3H7 + CH3CHO  C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 891, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 40,22.

Verified by Karma James

pg. 907: Discussion on evaluated data

Entry 40,22 (b): No data available at the time.  The author recommends a rate coefficient

expression based on the equilibrium constant and the reverse rate (note: the author
estimates this reverse rate using the suggestions of Kerr, J.A. and Trotman-Dickenson, A.F.).
MRH 30-Aug-2009
""",
)

entry(
    index = 196,
    label = "C/H2/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (3.95e+06, 'cm^3/(mol*s)'),
        n = 1.9,
        alpha = 0,
        E0 = (0.16, 'kcal/mol'),
        Tmin = (295, 'K'),
        Tmax = (1220, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Cohen et al. [101] Transition state theory.""",
    longDesc = 
u"""
[101] Cohen, N. Int. J. Chem. Kinet. 1991, 23, 397.
C3H8 + OH --> iso-C3H7 + H20  C.D.W divided original rate expression by 2, to get rate expression per H atom.

Not yet checked
""",
)

entry(
    index = 197,
    label = "C/H2/NonDeC;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (7.25e+10, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (4.57, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
C3H8 + CH3O --> iso-C3H7 + CH3OH  C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 891, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 40,24.

Verified by Karma James

pg. 908: Discussion on evaluated data

Entry 40,24 (b): The author assumes the Arrhenius A parameter should follow:

A(C3H8+CH3O=CH3OH+n-C3H7) / A(C3H8+CH3O=CH3OH+i-C3H7) = 3
The author also demands that the recommended data fit both sets of experiments
reported.  These assumptions (plus one unwritten one, as we still have 3
unknown parameters [A1, E1, E2 ... A2=f(A1)]) produce the reported rate
coefficient expression.
MRH 30-Aug-2009
""",
)

entry(
    index = 198,
    label = "C/H/Cs3;O2b",
    kinetics = ArrheniusEP(
        A = (3.97e+13, 'cm^3/(mol*s)', '*|/', 3),
        n = 0,
        alpha = 0,
        E0 = (43.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
Iso-C4H10 + O2 --> tert-C4H9 + HO2

pg 5, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 43,3.

Verified by Karma James

pg.14: Discussion on evaluated data

Entry 43,3(b): No direct measurements at the time.  A review article reported a rate

coefficient expression for iC4H10+O2-->tC4H9+HO2.  An experiment performed by
Baldwin, Drewery, and Walker reported a rate coefficient expression for O2 abstracting
a tertiary H-atom from 2,3-dimethylbutane.  The experiment's value matched well
with the review's value, so Tsang recommended the review's value.
MRH 31-Aug-2009
""",
)

entry(
    index = 199,
    label = "C/H/Cs3;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (157000, 'cm^3/(mol*s)', '*|/', 2),
        n = 2.5,
        alpha = 0,
        E0 = (1.11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
Iso-C4H10 + O --> tert-C4H9 + OH

pg 5, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 43,5.

Verified by Karma James

pg.15: Discussion on evaluated data

Entry 43,5(b): Michael et al. reported the rate coefficient expression for iC4H10+O=OH+C4H9 isomer.

Tsang subtracted from this expression the contributions from iC4H10+O=OH+iC4H9 (What
rate expression was used?  The one recommended here?) to obtain an expression for
iC4H10+O=OH+tC4H9.  Tsang then adjusted the rate expression such that the A-factor's
temperature dependence was 2.5 (was this 2.5 based on the review by Cohen and Westberg?).
MRH 31-Aug-2009
""",
)

entry(
    index = 200,
    label = "C/H/Cs3;CH2_triplet",
    kinetics = ArrheniusEP(
        A = (1.09e+12, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (4.91, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
Iso-C4H10 + CH2 --> tert-C4H9 + CH3

pg 6, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 43,25.

Verified by Karma James

pg.23-24: Discussion on evaluated data

Entry 43,25(b): Tsang recommends the rate coefficient expression reported by Bohland et al.

Tsang notes that the rate for CH2_triplet abstracting a H-atom is faster than
the recommended value for CH3 abstracting a H-atom.
MRH 31-Aug-2009
""",
)

entry(
    index = 201,
    label = "C/H/Cs3;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.904, 'cm^3/(mol*s)', '*|/', 5),
        n = 3.46,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
Iso-C4H10 + C2H3 --> tert-C4H9 + C2H4

pg 5, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 43,19.

Verified by Karma James

pg.20: Discussion on evaluated data

Entry 43,19(b): No data available at the time.  Author recommends rate coefficient expression

based on the rxn CH3+iC4H10=CH4+tC4H9: same Arrhenius A and n parameters, Ea decreased
by 8.5 kJ/mol.
MRH 31-Aug-2009
""",
)

entry(
    index = 202,
    label = "C/H/Cs3;Ct_rad",
    kinetics = ArrheniusEP(
        A = (6.62e+11, 'cm^3/(mol*s)', '*|/', 3),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
Iso-C4H10 + C2H --> tert-C4H9 + C2H2

pg 5, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 43,21.

Verified by Karma James

pg.21: Discussion on evaluated data

Entry 43,21(b): No data available at the time.  For the rxn iC4H10+C2H=C2H2+iC4H9, author

recommends 1.5x the rate of the rxn C2H6+C2H=C2H2+C2H5 (9 vs. 6 primary H-atoms).
The author then recommends a rate coefficient for iC4H10+C2H=C2H2+tC4H9 that appears
to be 1/9 the rate of iC4H10+C2H=C2H2+iC4H9 (9 vs. 1 H-atom).
MRH 31-Aug-2009
""",
)

entry(
    index = 203,
    label = "C/H/Cs3;CO_pri_rad",
    kinetics = ArrheniusEP(
        A = (34300, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.5,
        alpha = 0,
        E0 = (13.51, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
Iso-C4H10 + HCO --> tert-C4H9 + CH2O

pg 5, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 43,15.

Verified by Karma James

pg.18: Discussion on evaluated data

Entry 43,15(b): No data available at the time.  For the rxn iC4H10+HCO=CH2O+iC4H9, author

recommends 1.5x the rate of the rxn C3H8+HCO+CH2O+nC3H7 (9 vs. 6 primary H-atoms).
The author then recommends the rate coefficient for iC4H10+HCO=CH2O+tC4H9 to be the 
rate coefficient of iC4H10+HCO=CH2O+iC4H9, with the A factor divided by 9 (9 vs. 1
H-atoms) and the Ea decreased by 20 kJ/mol.
MRH 31-Aug-2009
""",
)

entry(
    index = 204,
    label = "C/H/Cs3;CO_rad/NonDe",
    kinetics = ArrheniusEP(
        A = (34300, 'cm^3/(mol*s)', '*|/', 10),
        n = 2.5,
        alpha = 0,
        E0 = (13.51, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
Iso-C4H10 + CH3CO --> tert-C4H9 + CH3CHO

pg 5, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 43,22.

Verified by Karma James

pg.21: Discussion on evaluated data

Entry 43,22(b): No data available at the time.  Author recommends rate coefficient expression

based on the rxn iC4H10+HCO=CH2O+tC4H9.
MRH 31-Aug-2009
""",
)

entry(
    index = 205,
    label = "C/H/Cs3;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.57e+06, 'cm^3/(mol*s)'),
        n = 1.9,
        alpha = 0,
        E0 = (-1.45, 'kcal/mol'),
        Tmin = (298, 'K'),
        Tmax = (1150, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Cohen et al. [101] Transition state theory.""",
    longDesc = 
u"""
[101] Cohen, N. Int. J. Chem. Kinet. 1991, 23, 397.
Iso-C4H10 + OH --> tert-C4H9 + H2O

Not yet checked
""",
)

entry(
    index = 206,
    label = "C/H/Cs3;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (2.29e+10, 'cm^3/(mol*s)', '*|/', 10),
        n = 0,
        alpha = 0,
        E0 = (2.88, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
Iso-C4H10 + CH3O --> tert-C4H9 + CH3OH

pg 6, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 43,24.

Verified by Karma James

pg.22: Discussion on evaluated data

Entry 43,24(b): A study by Berces and Trotman-Dickenson reported a rate coefficient

for the rxn iC4H10+CH3O=CH3OH+C4H9 isomer.  Tsang used the rate coefficient for
the rxn CH3O+C(CH3)4=CH3OH+H2C*-C(CH3)3 determined by Shaw and Trotman-Dickenson
as a characteristic for CH3O+primary H-atom abstraction to recommend a rate coefficient
for iC4H10+CH3O=CH3OH+iC4H9.  This rate expression was subtracted from the rate
coefficient reported by Berces and Trotman-Dickenson to yield the rate coefficient
for iC4H10+CH3O=CH3OH+tC4H9.  Lastly, the pre-exponential factor was cut in half,
due to Tsang's correcting an arithmetic error by Kerr and Parsonage (perhaps this
work was referenced in the Berces and Trotman-Dickenson study?)
MRH 31-Aug-2009
""",
)

entry(
    index = 207,
    label = "Cd_pri;O2b",
    kinetics = ArrheniusEP(
        A = (1.792e+13, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (60.01, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Hua, Ruscic, and Wang 2005, transition state theory.""",
    longDesc = 
u"""
FORMER RATES
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
C2H4 + O2 --> C2H3 + HO2 C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 1097, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 18,3.

Verified by Karma James

pg. 1184: Discussion on evaluated data

Recommended data follows Walker's estimates for O2+alkane

Note: The authors note that a lower lying channel, involving addition and
rearrangement prior to decomposition, may exist.
MRH 28-Aug-2009


CURRENT RATES
Hua, H.; B. Ruscic; B. Wang.  Chemical Physics 2005, 311, 335-341.
C2H4 + O2 --> C2H3 + HO2.

Divided rate expression by 4 to get the rate expression per H atom.  See page 338.
Overall, this agrees with the earlier rate that we used.
JDM 15-Jun-2010.
""",
)

entry(
    index = 209,
    label = "Cd_pri;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.78e+06, 'cm^3/(mol*s)'),
        n = 1.91,
        alpha = 0,
        E0 = (3.74, 'kcal/mol'),
        Tmin = (290, 'K'),
        Tmax = (1510, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Mahmud et al. [128] Transition state theory""",
    longDesc = 
u"""
[128] Mahmud, K.; Marshall, P.; Fontijn, A. J Phys. Chem. 1987, 91, `568.
C2H4 + O --> C2H3 + OH C.D.W divided original rate expression by 4(from A= 1.51E+07), to get rate expression per H atom.
""",
)

entry(
    index = 210,
    label = "Cd_pri;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (158, 'cm^3/(mol*s)', '*|/', 10),
        n = 3.13,
        alpha = 0,
        E0 = (18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
C2H4 + C2H5 --> C2H3 + C2H6 C.D.W divided original rate expression by 4, to get rate expression per H atom.

pg 1098, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 18,17.

Verified by Karma James

pgs. 1191-1192: Discussion on evaluated data

Recommended data based on study performed by Halstead and Quinn

Tsang fit the data against BEBO calculations (to attain the Arrhenius A, n)
and manually adjusted the E.
MRH 28-Aug-2009
""",
)

entry(
    index = 211,
    label = "Cd_pri;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (5.13e+12, 'cm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        alpha = 0,
        E0 = (5.94, 'kcal/mol'),
        Tmin = (650, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

C2H4 + OH --> C2H3 + H2O C.D.W divided original rate expression by 4(from A= 2.05E+13), to get rate expression per H atom.

pg 420 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - OH Radical Reactions.

Verified by Karma James

pg.586-587: Discussion on evaluated data

OH+C2H4 --> H2O+C2H3: Recommended rate taken from expression reported by Tully (1988).

MRH 31-Aug-2009
""",
)

entry(
    index = 212,
    label = "Cd/H/NonDeC;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (6.02e+10, 'cm^3/(mol*s)', '*|/', 3),
        n = 0.7,
        alpha = 0,
        E0 = (7.63, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [93] literature review.""",
    longDesc = 
u"""
[93] Tsang, W. J. Phys. Chem. Ref. Data 1991, 20, 221.
CH3CH=CH2 + O --> CH3C=CH2 + OH

pg 233-234: Discussion on evaluated data

Verified by MRH on 6Aug2009

Entry 46,5(f): No measurements on H-atom abstraction rxns. Recommended rate coefficient

is computed as follows:

The rate of O + C3H6 --> OH + H2C=CH-*CH2 is computed using the expression:
[k(O+C2H6-->C2H5+HO)/k(OH+C2H6-->C2H5+H2O)] * k(OH+C3H6-->H2C=CH-*CH2+H2O).
The author uses this expression because he notes that OH and O H-atom abstraction
rxns generally follow the same trend.  The O+C2H6, OH+C2H6, and OH+C3H6
are from other Tsang review articles.
The rate of O+C3H6 --> OH+CH3C=CH2 is computed by adjusting the O+C3H6 --> OH+H2C=CH-*CH2
rate coefficient: increasing the Ea/R by 880 Kelvin and multiplying the A
by ~0.345; these values come from the relative difference between the rxns
OH+C3H6 --> H2O+H2C=CH-*CH2 and OH+C3H6 --> H2O+CH3C=CH2
MRH 31-Aug-2009
""",
)

entry(
    index = 213,
    label = "Cd/H/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (409000, 'cm^3/(mol*s)', '*|/', 4),
        n = 2.5,
        alpha = 0,
        E0 = (9.79, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [93] literature review.""",
    longDesc = 
u"""
[93] Tsang, W. J. Phys. Chem. Ref. Data 1991, 20, 221.
CH3CH=CH2 + H --> CH3C=CH2 + H2

pg 231: Discussion on evaluated data

Previous modified Arrhenius parameters were for RELATIVE rate (kc/ka)

Multipled kc/ka by ka to get kc (only one H to abstract, so no division necessary)

Certified by MRH on 6Aug2009

Entry 46,4(c): No data available for H-atom abstraction rxns.  The recommended rate

coefficient is based on the author's assumption that methyl substitution has the
same influence in olefins as in alkanes.
MRH 31-Aug-2009
""",
)

entry(
    index = 214,
    label = "Cd/H/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.842, 'cm^3/(mol*s)', '*|/', 6),
        n = 3.5,
        alpha = 0,
        E0 = (11.66, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [93] literature review.""",
    longDesc = 
u"""
[93] Tsang, W. J. Phys. Chem. Ref. Data 1991, 20, 221.
CH3CH=CH2 + CH3 --> CH3C=CH2 + CH4

pg 237-239

Previous modified Arrhenius parameters were for RELATIVE rate (ke/kc)

Multiplied ke/kc by kc to get ke (only one H to abstract, so no division necessary)

Certified by MRH on 6Aug2009

Entry 46,16(e): Recommended rate coefficient is based on the author's assumption

that methyl substitution has the same influence in olefins as in alkanes.
MRH 31-Aug-2009
""",
)

entry(
    index = 215,
    label = "Cd/H/NonDeC;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.842, 'cm^3/(mol*s)', '*|/', 6),
        n = 3.5,
        alpha = 0,
        E0 = (9.67, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [93] literature review.""",
    longDesc = 
u"""
[93] Tsang, W. J. Phys. Chem. Ref. Data 1991, 20, 221.
CH3CH=CH2 + C2H3 --> CH3C=CH2 + C2H4

pg 240-241

Previous modified Arrhenius parameters were for RELATIVE rate (kc/ka)

Multiplied kc/ka by ka to get kc (only one H to abstract, so no division necessary)

Certified by MRH on 6Aug2009

Entry 46,19(c): No data available at the time.  The recommended rate coefficient

is based on the rate expressions for CH3 abstracting a H-atom from C3H6; all of
the Ea's have been decreased by 4kJ/mol.
MRH 31-Aug-2009
""",
)

entry(
    index = 216,
    label = "Cd/H/NonDeC;Ct_rad",
    kinetics = ArrheniusEP(
        A = (1.21e+12, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [93] literature review.""",
    longDesc = 
u"""
[93] Tsang, W. J. Phys. Chem. Ref. Data 1991, 20, 221.
CH3CH=CH2 + C2H --> CH3C=CH2 + C2H2 

pg 241

Verified by MRH on 6Aug2009

Entry 46,21(e): No data available at the time.  Recommended rate expression is "somewhat

smaller" than the rate of rxn C3H6+C2H --> C2H2+H2C=CH-*CH2.  The rate of this rxn
is assumed to be the rate of the rxn C2H+C2H6 --> C2H2+C2H5.
MRH 31-Aug-2009
""",
)

entry(
    index = 217,
    label = "Cd/H/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.11e+06, 'cm^3/(mol*s)', '*|/', 2),
        n = 2,
        alpha = 0,
        E0 = (1.45, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [93] literature review.""",
    longDesc = 
u"""
[93] Tsang, W. J. Phys. Chem. Ref. Data 1991, 20, 221.
CH3CH=CH2 + OH --> CH3C=CH2 + H2O

pg 235-236

Valid T range in reference suggested 700-2500K

Uncertainty stated in reference was *2.0

Verified by MRH on 6Aug2009

Entry 46,6(d): No direct measurements of H-atom abstraction rxns.  The recommended

H-atom abstraction rxns are based on "the results of Tully (1988) for the rxn
of OH + C2H4 and the rate constant ratio of OH + primary Hydrogens in ethane by
Tully et al. (1986) to OH + secondary Hydrogens by Droege and Tully (1986)".  The
author has also introduced a T^2 dependence in the A-factor.
MRH 31-Aug-2009
""",
)

entry(
    index = 218,
    label = "Ct_H;O2b",
    kinetics = ArrheniusEP(
        A = (6.05e+12, 'cm^3/(mol*s)', '*|/', 10),
        n = 0,
        alpha = 0,
        E0 = (74.52, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
C2H2 + O2 --> C2H + HO2 C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 1100, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 20,3.

Verified by Karma James

pg. 1209: Discussion on evaluated data

Recommended data based on report by Walker

NOTE: Authors note that a lower-lying channel of O2 addition, rearrangement,
and decomposition may exist.
MRH 28-Aug-2009
""",
)

entry(
    index = 220,
    label = "Ct_H;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (1.36e+11, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (23.45, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
C2H2 + C2H5 --> C2H + C2H6 C.D.W divided original rate expression by 2 (from A= 2.71E+11), to get rate expression per H atom.

pg 1100, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 20,17.

Verified by Karma James

pg. 1215: Discussion on evaluated data

Recommended data based on reverse rate and equilibrium constant

MRH 28-Aug-2009
""",
)

entry(
    index = 221,
    label = "Ct_H;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (7250, 'cm^3/(mol*s)', '*|/', 10),
        n = 2.68,
        alpha = 0,
        E0 = (12.04, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
C2H2 + OH --> C2H + H2O C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 1100, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 20,6.

Verified by Karma James

pg. 1213: Discussion on evaluated data

Recommended data is derived from BEBO method calculation

MRH 28-Aug-2009
""",
)

entry(
    index = 222,
    label = "Cb_H;O2b",
    kinetics = ArrheniusEP(
        A = (1.052e+13, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (60.01, 'kcal/mol'),
        Tmin = (1200, 'K'),
        Tmax = (1700, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Asaba et al. [129]. Data are estimated.""",
    longDesc = 
u"""
[129] Asaba, T.; Fujii, N.; Proc. Int. Symp. Shock Tubes Waves 1971, 8, 1.
Benzene + O2 --> phenyl + HO2 C.D.W divided original rate expression by 6(from A = 6.31E+13), to get rate expression per H atom.
""",
)

entry(
    index = 223,
    label = "Cb_H;H_rad",
    kinetics = ArrheniusEP(
        A = (1e+08, 'cm^3/(mol*s)'),
        n = 1.8,
        alpha = 0,
        E0 = (16.35, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (800, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Mebel et al. [122] RRK(M) extrapolation.""",
    longDesc = 
u"""
[122] Mebel, A.M.; Lin, M.C.; Yu, T.; Morokuma, K. J. Phys. Chem. A. 1997, 101, 3189.
Rate constant is high pressure limit. Benzene + H --> phenyl + H2

C.D.W divided original rate expression by 6(from A = 6.02E+08), to get rate expression per H atom.
""",
)

entry(
    index = 224,
    label = "Cb_H;H_rad",
    kinetics = ArrheniusEP(
        A = (5.02e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (8.11, 'kcal/mol'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Nicovich et al. [130]""",
    longDesc = 
u"""
[130] Nicovich, J.M.; Ravishankara, A.R. J. Phys. Chem. 1984, 88, 2534.
Pressure 0.01-0.26 atm Excitation: flash photolysis, analysis: resonance fluorescence. Benzene + H --> phenyl + H2

C.D.W divided original rate expression by 6(from A = 3.01E+12), to get rate expression per H atom.
""",
)

entry(
    index = 225,
    label = "Cb_H;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (1.05e+11, 'cm^3/(mol*s)', '*|/', 2),
        n = 0,
        alpha = 0,
        E0 = (14.86, 'kcal/mol', '+|-', 1.19),
        Tmin = (650, 'K'),
        Tmax = (770, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Zhang et al. [131]""",
    longDesc = 
u"""
[131] Zhang, H.X.; Ahonkhai, S.I. Back, H.M. Can. J. Chem. 1989, 67, 1541.
Pressure 0.30-0.50 atm Excitation: thermal, analysis: GC. Benzene + C2H5 --> phenyl + C2H6

C.D.W divided original rate expression by 6(from A = 6.31E+11), to get rate expression per H atom.
""",
)

entry(
    index = 226,
    label = "Cb_H;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.72e+07, 'cm^3/(mol*s)', '*|/', 2),
        n = 1.42,
        alpha = 0,
        E0 = (1.45, 'kcal/mol'),
        Tmin = (400, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

Benzene + OH --> phenyl + H2O  C.D.W divided original rate expression by 6(from A = 1.63E+08), to get rate expression per H atom.

pg 420 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - OH Radical Reactions.

Verified by Karma James

pg.595-597: Discussion on evaluated data

OH+C6H6 --> H2O+C6H5: Authors note that this rxn should be dominant at temperatures

above 500K.  No other comment on where the recommended rate expression comes from
(although MRH believes it is a best-fit to the available data, based on graph).
MRH 31-Aug-2009
""",
)

entry(
    index = 227,
    label = "CO_pri;O2b",
    kinetics = ArrheniusEP(
        A = (2.34e+07, 'cm^3/(mol*s)'),
        n = 2.05,
        alpha = 0,
        E0 = (37.93, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2200, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Michael et al. [132] Transition state theory.""",
    longDesc = 
u"""
[132] Michael, J.V.; Kumaran, S.S.; Su, M.-C. J. Phys. Chem. A. 1999, 103, 5942.
CH2O + O2 --> HCO + HO2 C.D.W divided original rate expression by 2, to get rate expression per H atom.
""",
)

entry(
    index = 228,
    label = "CO_pri;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (2.08e+11, 'cm^3/(mol*s)', '*|/', 2),
        n = 0.57,
        alpha = 0,
        E0 = (2.76, 'kcal/mol'),
        Tmin = (250, 'K'),
        Tmax = (2200, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

CH2O + O --> HCO + OH C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 416 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - O Atom Reactions.

Verified by Karma James

pg.449-450: Discussion on evaluated data

O+CH2O --> OH+HCO: "The preferred values are based on the low temperature data which are

all in good agreement, and on the higher temperature value of Bowman."
MRH 31-Aug-2009
""",
)

entry(
    index = 229,
    label = "CO_pri;CH2_triplet",
    kinetics = ArrheniusEP(
        A = (3.02e+09, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
Rate constant is an upper limit. CH2O + CH2 --> HCO + CH3

C.D.W divided original rate expression by 2 (from A= 6.03E+09), to get rate expression per H atom.

pg 1106, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 26,12.

Verified by Karma James

pg. 1267: Discussion on evaluated data

Recommended data based on triplet methylene's general lack of reactivity in H-atom abstractions

NOTE: Rate coefficient is an upper limit
MRH 28-Aug-2009
""",
)

entry(
    index = 230,
    label = "CO_pri;C_methyl",
    kinetics = ArrheniusEP(
        A = (3.89e-08, 'cm^3/(mol*s)', '*|/', 1.58),
        n = 6.1,
        alpha = 0,
        E0 = (1.97, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [94] literature review.""",
    longDesc = 
u"""
[94] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Frank, P.; Hayman, G,; Just, T.; Kerr, J.A.; Murrells, T.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1994, 23, 847.

CH2O + CH3 --> HCO + CH4 C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 862 Evaluated Kinetic Data for Combustion Modelling Supplement 1, Table 1. Bimolecular reactions - CH3 Radical Reactions.

Verified by Karma James

pg.989-990: Discussion on evaluated data

CH3+HCHO --> CH4+HCO: The recommended value is a "best fit to the data of Choudhury et al.,

the reworked data from Anastasi, together with those at lower temperatures from
Refs. 4, 5, and 7."
MRH 31-Aug-2009
""",
)

entry(
    index = 231,
    label = "CO_pri;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (2750, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.81,
        alpha = 0,
        E0 = (5.86, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH2O + C2H5 --> HCO + C2H6 C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 1096, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 17,12.

Verified by Karma James

pg. 1178: Discussion on evaluated data

Recommended data is the rate of CH2O+CH3-->HCO+CH4.

Authors note that rate coefficients for alkyl radicals w/aldehydic H-atoms are
similar (as noted by Kerr, J.A. and Trotman-Dickenson, A.F.
MRH 28-Aug-2009
""",
)

entry(
    index = 232,
    label = "CO_pri;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (5.4e+10, 'cm^3/(mol*s)', '*|/', 2.5),
        n = 0,
        alpha = 0,
        E0 = (6.96, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
CH2O + iso-C3H7 --> HCO + C3H8 C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 894, Chemical Kinetic Database For Combustion Chemistry, Part 3. Index of Reactions and Summary of Recommended Rate Expressions. No. 42,12.

Verified by Karma James

pg. 936: Discussion on evaluated data

Entry 42,12: No data available at the time.  The author recommends a rate coefficient

expression that is twice that of the rxn i-C3H7+(CH3)2CHCHO, taken from a study
by Kerr, J.A. and Trotman-Dickenson, A.F. (1959).  The author states that a correction
was made to the 1959 report, taking the recommended rate of i-C3H7 recombination
(reported by Tsang) into consideration.
MRH 30-Aug-2009
""",
)

entry(
    index = 233,
    label = "CO_pri;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (1.63e+09, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (3.56, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
CH2O + tert-C4H9 --> HCO + iso-C4H10 C.D.W divided original rate expression by 2 (from A= 3.25E+09), to get rate expression per H atom.

pg 7, Chemical Kinetic Database For Combustion Chemistry, Part 4 - Isobutane. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 44,12.

Verified by Karma James

pg.35: Discussion on evaluated data

Entry 44,12: No data available at the time.  The author recommends 2x the rate coefficient

of the rxn tC4H9+tC4H9-CHO=iC4H10+tC4H9-CO (2 vs. 1 aldehydic H-atoms); this value
was reported by Birrell and Trotman-Dickenson.  The author also notes that he has
taken into account tC4H9 combination (perhaps meaning he used a geometric mean rule
to derive the final form of the expression?)
MRH 31-Aug-2009
""",
)

entry(
    index = 234,
    label = "CO_pri;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (2710, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.81,
        alpha = 0,
        E0 = (5.86, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH2O + C2H3 --> HCO + C2H4 C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 1099, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 19,12.

Verified by Karma James

pg. 1197: Discussion on evaluated data

Recommended data is the rate of CH2O+CH3-->HCO+CH4.

Authors note that rate coefficients for alkyl radicals w/aldehydic H-atoms are
similar (as noted by Kerr, J.A. and Trotman-Dickenson, A.F.
MRH 28-Aug-2009
""",
)

entry(
    index = 235,
    label = "CO_pri;CO_rad/NonDe",
    kinetics = ArrheniusEP(
        A = (9.05e+10, 'cm^3/(mol*s)', '*|/', 10),
        n = 0,
        alpha = 0,
        E0 = (12.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH2O + CH3CO --> HCO + CH3CHO C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 1102, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 22,12.

Verified by Karma James

pg. 1231: Discussion on evaluated data

Recommended data based on "analogous systems"

MRH 28-Aug-2009
""",
)

entry(
    index = 236,
    label = "CO_pri;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.72e+09, 'cm^3/(mol*s)', '*|/', 5),
        n = 1.18,
        alpha = 0,
        E0 = (-0.45, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (3000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

CH2O + OH --> HCO + H2O C.D.W divided original rate expression by 2 (from A= 3.43E+09), to get rate expression per H atom.

pg 419 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - OH Radical Reactions.

Verified by Karma James

pg.575-576: Discussion on evaluated data

OH+CH2O --> H2O+HCO: The recommended rate coefficient is the value reported by Tsang

and Hampson.
MRH 31-Aug-2009
""",
)

entry(
    index = 237,
    label = "CO_pri;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (5.1e+10, 'cm^3/(mol*s)', '*|/', 3),
        n = 0,
        alpha = 0,
        E0 = (2.98, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
CH2O + CH3O --> HCO + CH3OH C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 1104, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 24,12.

Verified by Karma James

pg. 1245: Discussion on evaluated data

Recommended data based on review by Gray, based on experiments performed by Hoare and Wellington.

Authors note that experimental conditions were such that rxn of interest was
in competition with the disproportionation of two CH3O radicals (CH3O+CH3O-->CH3OH+CH2O)
MRH 28-Aug-2009
""",
)

entry(
    index = 238,
    label = "CO_pri;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (20600, 'cm^3/(mol*s)'),
        n = 2.5,
        alpha = 0,
        E0 = (10.21, 'kcal/mol'),
        Tmin = (641, 'K'),
        Tmax = (1600, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Eiteneer et al. [133] literature review.""",
    longDesc = 
u"""
[133] Eiteneer, B.; Yu, C.-L.; Goldenberg, M.; Frenklach, M. J. Phys. Chem. A. 1998, 102, 5196.
CH2O + HO2 --> HCO + H2O2 C.D.W divided original rate expression by 2 (from A= 4.11E+04), to get rate expression per H atom.
""",
)

entry(
    index = 239,
    label = "CO/H/NonDe;O2b",
    kinetics = ArrheniusEP(
        A = (3.01e+13, 'cm^3/(mol*s)', '*|/', 10),
        n = 0,
        alpha = 0,
        E0 = (39.15, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (1100, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

CH3CHO + O2 --> CH3CO + HO2

pg 417 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - O2 Reactions.

Verified by Karma James

pg.485: Discussion on evaluated data

O2+CH3CHO --> HO2+CH3CO: "For this evaluation we prefer the approach of Walker and

the recommended value is based on the best current deltaH298 value (=163.8 kJ/mol
using deltaHf(CH3CO)=11.0 kJ/mol and deltaHf(HO2)=14.6 kJ/mol) and A=5.0x10^-11
cm3/molecule/s."
MRH 31-Aug-2009
""",
)

entry(
    index = 240,
    label = "CO/H/NonDe;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (5e+12, 'cm^3/(mol*s)', '*|/', 2),
        n = 0,
        alpha = 0,
        E0 = (1.79, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Warnatz [134] literature review""",
    longDesc = 
u"""
[134] Warnatz, J. Rate coefficeints in the C/H/O system. In Combustion Chemistry, 1984; pp 197.
CH3CHO + O --> CH3CO + OH
""",
)

entry(
    index = 241,
    label = "CO/H/NonDe;H_rad",
    kinetics = ArrheniusEP(
        A = (4e+13, 'cm^3/(mol*s)', '*|/', 2),
        n = 0,
        alpha = 0,
        E0 = (4.21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Warnatz [134] literature review""",
    longDesc = 
u"""
[134] Warnatz, J. Rate coefficeints in the C/H/O system. In Combustion Chemistry, 1984; pp 197.
CH3CHO + H --> CH3CO + H2
""",
)

entry(
    index = 242,
    label = "CO/H/NonDe;C_methyl",
    kinetics = ArrheniusEP(
        A = (1.99e-06, 'cm^3/(mol*s)', '*|/', 2),
        n = 5.64,
        alpha = 0,
        E0 = (2.46, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1250, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

CH3CHO + CH3 --> CH3CO + CH4

pg 423 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - CH3 Radical Reactions.

Verified by Karma James

pg.671: Discussion on evaluated data

CH3+CH3CHO --> CH4+CH3CO: "There are no direct studies of the kinetics of this reaction

and all of the k values are relative to methyl recombination ... The preferred values
are based on a line constructed through the mean of the low temperature data and the
data of Liu and Laidler and Colket et al."
MRH 31-Aug-2009
""",
)

entry(
    index = 243,
    label = "CO/H/NonDe;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (3.8e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (7.21, 'kcal/mol'),
        Tmin = (790, 'K'),
        Tmax = (810, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Loser et al. [135] bond strength-bond length method.""",
    longDesc = 
u"""
[135] Loser, U.; Scherzer, K.; Weber, K. Z. Phys. Chem. (Leipzig) 1989, 270, 237.
CH3CHO + CH2CH=CH2 --> CH3CO + CH3CH=CH2
""",
)

entry(
    index = 244,
    label = "CO/H/NonDe;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (8.13e+10, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (3.68, 'kcal/mol'),
        Tmin = (480, 'K'),
        Tmax = (520, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Scherzer et al. [136] bond energy-bond order method.""",
    longDesc = 
u"""
[136] Scherzer, K.; Loser, U.; Stiller, W. Z. Phys. Chem. 1987, 27, 300.
CH3CHO + C2H3 --> CH3CO + C2H4
""",
)

entry(
    index = 245,
    label = "CO/H/NonDe;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2e+06, 'cm^3/(mol*s)'),
        n = 1.8,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (295, 'K'),
        Tmax = (600, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Taylor et al. [127] Transition state theory.""",
    longDesc = 
u"""
[127] Taylor, P.H.; Rahman, M.S.; Arif, M.; Dellinger, B.; Marshall, P. Sypm. Int. Combust. Proc. 1996, 26, 497.
CH3CHO + OH --> CH3CO + H2O Pressure 0.13-0.97 atm. Rate constant is high pressure limit.

pg 501, Table 1, k2 = 2.00x10^6 T^1.8 exp(1300/RT)

Previous modified Arrhenius parameters had E=1.3 kcal/mol; it should be E=-1.3 kcal/mol

Certified by MRH on 6Aug2009
""",
)

entry(
    index = 246,
    label = "CO/H/NonDe;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1e+13, 'cm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Warnatz [134] literature review""",
    longDesc = 
u"""
[134] Warnatz, J. Rate coefficeints in the C/H/O system. In Combustion Chemistry, 1984; pp 197.
CH3CHO + OH --> CH3CO + H2O
""",
)

entry(
    index = 247,
    label = "CO/H/NonDe;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (3.01e+12, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (11.92, 'kcal/mol'),
        Tmin = (900, 'K'),
        Tmax = (1200, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

CH3CHO + HO2 --> CH3CO + H2O2

pg 421 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - HO2 Radical Reactions.

Verified by Karma James

pg.614-615: Discussion on evaluated data

HO2+CH3CHO --> CH3CO+H2O2: "The preferred expression is based on a value of 1.7x10^-14

cm3/molecule/s at 1050K from a study performed by Colket et al. and an assumed A
factor of 5.0x10^-12 cm3/molecule/s."
MRH 31-Aug-2009
""",
)

entry(
    index = 248,
    label = "O_pri;O2b",
    kinetics = ArrheniusEP(
        A = (2.325e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (74.12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Mayer et al. [137] Bond energy-bond order.""",
    longDesc = 
u"""
[137] Mayer, S.W.; Schieler, L. J. Phys. Chem. 1968, 72, 2628.
http://dx.doi.org/10.1021/j100853a066

H2O + O2 --> OH + HO2. 
C.D.W divided original rate expression by 2, to get rate expression per H atom.
""",
)

entry(
    index = 249,
    label = "O_pri;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (2.63e+09, 'cm^3/(mol*s)'),
        n = 1.2,
        alpha = 0,
        E0 = (17.83, 'kcal/mol'),
        Tmin = (298, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Karach et al. [138] Transition state theory.""",
    longDesc = 
u"""
[138] Karach, S.P.; Oscherov, V.I. J. Phys. Chem. 1999, 110, 11918.
H2O + O --> OH + OH. C.D.W divided original rate expression by 2 (from A= 2.95E+39), to get rate expression per H atom.
""",
)

entry(
    index = 250,
    label = "O_pri;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (74000, 'cm^3/(mol*s)'),
        n = 2.6,
        alpha = 0,
        E0 = (15.18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Harding et al. [139] Transition state theory.""",
    longDesc = 
u"""
[139] Harding, L.B.; Wagner, A.F. Symp. Int. Combust. proc. 1989, 22, 983.
H2O + O --> OH + OH. C.D.W divided original rate expression by 2 (from A= 1.48E+05), to get rate expression per H atom.
""",
)

entry(
    index = 251,
    label = "O_pri;H_rad",
    kinetics = ArrheniusEP(
        A = (2.26e+08, 'cm^3/(mol*s)', '*|/', 1.6),
        n = 1.6,
        alpha = 0,
        E0 = (19.32, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Baulch et al. [95] literature review.""",
    longDesc = 
u"""
[95] Baulch, D.L.; Cobos, C.J.; Cox, R.A.; Esser, C.; Frank, P.; Just, T.; Kerr, J.A.; Pilling, M.J.; 
Troe, J.; Walker, R.W.; Warnatz, J. J. Phys. Chem. Ref. Data 1992, 21, 411.

H2O + H --> OH + H2. C.D.W divided original rate expression by 2, to get rate expression per H atom.

pg 418 Evaluated Kinetic Data for Combustion Modelling, Table 1. Bimolecular reactions - H Atom Reactions.

NOTE: E0 Rference = 18.4, E0 RMG database = 19.32

Verified by Karma James

pg.504: Discussion on evaluated data

H+H2O --> OH+H2: "The recommended rate coefficient is based on the spare high temperature

measurements and rate data of the reverse rxn combined with the equilibrium constant."
MRH agrees with Karma.  However, the discrepancy is small and NIST's online database Webbook

has an E = 19.32 kcal/mol.
MRH 31-Aug-2009
""",
)

entry(
    index = 252,
    label = "O_pri;C_methyl",
    kinetics = ArrheniusEP(
        A = (3.2, 'cm^3/(mol*s)'),
        n = 3.31,
        alpha = 0,
        E0 = (12.56, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Ma et al. [140] Transition state theory.""",
    longDesc = 
u"""
[140] Ma, S.; Liu, R.; Sci. China Ser. S: 1996, 39, 37.
H2O + CH3 --> OH + CH4. C.D.W divided original rate expression by 2 (from A= 6.39), to get rate expression per H atom.
""",
)

entry(
    index = 253,
    label = "O_pri;C_methyl",
    kinetics = ArrheniusEP(
        A = (242, 'cm^3/(mol*s)', '*|/', 1.6),
        n = 2.9,
        alpha = 0,
        E0 = (14.86, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
H2O + CH3 --> OH + CH4. C.D.W divided original rate expression by 2 (from A= 4.83E+02), to get rate expression per H atom.

pg 1095, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 16,9.

Verified by Karma James

pg. 1163: Discussion on evaluated data

Recommended data based on reverse rate and equilibrium constant

MRH 28-Aug-2009
""",
)

entry(
    index = 254,
    label = "O_pri;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (1.7e+06, 'cm^3/(mol*s)', '*|/', 2),
        n = 1.44,
        alpha = 0,
        E0 = (20.27, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
H2O + C2H5 --> OH + C2H6. C.D.W divided original rate expression by 2 (from A= 3.39E+06), to get rate expression per H atom.

pg 1096, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 17,9.

Verified by Karma James

pg. 1177: Discussion on evaluated data

Recommended data based on reverse rate and equilibrium constant

MRH 28-Aug-2009
""",
)

entry(
    index = 255,
    label = "O_pri;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (242, 'cm^3/(mol*s)', '*|/', 5),
        n = 2.9,
        alpha = 0,
        E0 = (14.86, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
H2O + C2H3 --> OH + C2H4. C.D.W divided original rate expression by 2 (from A= 4.83E+02), to get rate expression per H atom.

pg 1098, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 19,9.

Verified by Karma James

pg. 1196: Discussion on evaluated data

Recommended data based on expression for CH3+H2O=CH4+OH

MRH 28-Aug-2009
""",
)

entry(
    index = 256,
    label = "O_pri;CO_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.18e+08, 'cm^3/(mol*s)', '*|/', 5),
        n = 1.35,
        alpha = 0,
        E0 = (26.03, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [89] literature review.""",
    longDesc = 
u"""
[89] Tsang, W.; Hampson, R.F. J. Phys. Chem. Ref. Data 1986, 15, 1087.
H2O + HCO --> OH + CH2O. C.D.W divided original rate expression by 2 (from A= 2.35E+08), to get rate expression per H atom.

pg 1094, Chemical Kinetic Database For Combustion Chemistry, 2. Index of Reactions and Summary of Recommended Rate Expressions. No. 15,9.

Verified by Karma James

pg. 1150: Discussion on evaluated data

Recommended data based on reverse rate and equilibrium constant

MRH 28-Aug-2009
""",
)

entry(
    index = 257,
    label = "O_pri;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.417e-07, 'cm^3/(mol*s)'),
        n = 5.48,
        alpha = 0,
        E0 = (0.274, 'kcal/mol'),
        Tmin = (200, 'K'),
        Tmax = (700, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Masgrau et al. [141] Transition state theory.""",
    longDesc = 
u"""
[141] Masgrau, L.; Gonzalez-Lafont, A.; Lluch, J.M. J. Phys. Chem. A. 1999, 103, 1044.
H2O + OH --> OH + H2O . C.D.W refitted their k(T) to get A, n, and Ea, and divided original rate expression by 2, to get rate expression per H atom.

pg 1050, Table 4, Section: HO + HOH = HOH + OH(1), Column k_ab_CVT/SCT

MRH computed modified Arrhenius parameters using least-squares regression: ln(k) = ln(A) + n*ln(T) - (E/R)*(1/T)

E: Multiplied (E/R) expression by 1.987e-3

A: exp(ln(A)), multiplied by 6.02e23 (to convert /molecule to /mol) and divided by 2 (to get rate per H atom)

Certified by MRH on 7Aug2009
""",
)

entry(
    index = 258,
    label = "O_pri;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.174, 'cm^3/(mol*s)'),
        n = 3.8,
        alpha = 0,
        E0 = (11.49, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Jodkowski et al. [100] ab initio calculations.""",
    longDesc = 
u"""
[100] Jodkowski, J.T.; Rauez, M.-T.; Rayez, J.-C. J. Phys. Chem. A. 1999, 103, 3750.
H2O + CH3O --> OH + CH3OH C.D.W divided original rate expression by 2 (from A= 9.03E+08), to get rate expression per H atom.; This is Rxn. -R5 from mpaper

Verified by Greg Magoon: note that this reaction is endothermic; the reverse (R5), appears as #267, below
""",
)

entry(
    index = 259,
    label = "O/H/NonDeC;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1e+13, 'cm^3/(mol*s)', '*|/', 2.51),
        n = 0,
        alpha = 0,
        E0 = (4.69, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Warnatz [134] literature review""",
    longDesc = 
u"""
[134] Warnatz, J. Rate coefficeints in the C/H/O system. In Combustion Chemistry, 1984; pp 197.
CH3OH + O --> CH3O + OH
""",
)

entry(
    index = 260,
    label = "O/H/NonDeC;CH2_triplet",
    kinetics = ArrheniusEP(
        A = (14.4, 'cm^3/(mol*s)', '*|/', 3),
        n = 3.1,
        alpha = 0,
        E0 = (6.94, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [90] literature review.""",
    longDesc = 
u"""
[90] Tsang, W. J. Phys. Chem. Ref. Data 1987, 16, 471.
CH3OH + CH2 --> CH3O + CH3

pg 475, Chemical Kinetic Database For Combustion Chemistry, Part 2 - Methanol. 

//Index of Reactions and Summary of Recommended Rate Expressions. No. 38,25.

Verified by Karma James

Data for Rate Expression 38,26 (pg. 493)

Stated uncertainty factor is 3

Verified by MRH on 11Aug2009

Entry 38,26 (b): No data available at the time.  Author suggests the rate coefficient

expression for CH3+CH3OH=CH4+CH3O
MRH 30-Aug-2009
""",
)

entry(
    index = 261,
    label = "O/H/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00037, 'cm^3/(mol*s)'),
        n = 4.7,
        alpha = 0,
        E0 = (5.78, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Jodkowski et al. [100] ab initio calculations.""",
    longDesc = 
u"""
[100] Jodkowski, J.T.; Rauez, M.-T.; Rayez, J.-C. J. Phys. Chem. A. 1999, 103, 3750.
The calculated rate constants are in good agreement with experiment. CH3OH + CH3 --> CH3O + CH4 (Rxn. R3 from paper)

Verified by Greg Magoon: I changed upper temperature to 2000 K (was 2500) in line with other reactions from same paper; note that according to the paper, this reaction is very slightly endothermic; the exothermic reverse (-R3) is included above as #177
""",
)

entry(
    index = 262,
    label = "O/H/NonDeC;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (14.4, 'cm^3/(mol*s)', '*|/', 3),
        n = 3.1,
        alpha = 0,
        E0 = (8.94, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [90] literature review.""",
    longDesc = 
u"""
[90] Tsang, W. J. Phys. Chem. Ref. Data 1987, 16, 471.
CH3OH + C2H5 --> CH3O + C2H6

pg 475, Chemical Kinetic Database For Combustion Chemistry, Part 2 - Methanol. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 38,17.

Verified by Karma James

pg. 489: Discussion on evaluated data

Entry 38,17 (b): No data available at the time.  Author notes ethyl radicals are known

to be considerably less reactive than methyl.  Author recommends the rate coefficient
expression of CH3+CH3OH=CH4+CH3O, with a slight adjustment (based on the observed
trends in methyl vs. ethyl radical reactivity with hydrocarbons).
MRH 30-Aug-2009

//263: [90] Tsang, W. J. Phys. Chem. Ref. Data 1987, 16, 471.
""",
)

entry(
    index = 263,
    label = "O/H/NonDeC;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (14.5, 'cm^3/(mol*s)', '*|/', 5),
        n = 3.1,
        alpha = 0,
        E0 = (10.33, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [91] literature review.""",
    longDesc = 
u"""
[91] Tsang, W. J. Phys. Chem. Ref. Data 1988, 17, 887.
CH3OH + iso-C3H7 --> CH3O + C3H8

//WAS UNABLE TO VERIFY DATA!!! DATA NOT FOUND IN REFERENCE.

Ref[90] was incorrect; rate matches that reported in Ref[91].

pg. 944: Discussion on evaluated data

Entry 42,38 (b)

No experimental data, at the time

Recommended rate is based on C2H5+CH3OH=C2H6+CH3O

Verified by MRH on 10Aug2009

MRH 30-Aug-2009

//264: [90] Tsang, W. J. Phys. Chem. Ref. Data 1987, 16, 471.
""",
)

entry(
    index = 264,
    label = "O/H/NonDeC;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (1510, 'cm^3/(mol*s)', '*|/', 10),
        n = 1.8,
        alpha = 0,
        E0 = (9.36, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [92] literature review.""",
    longDesc = 
u"""
[92] Tsang, W. J. Phys. Chem. Ref. Data 1990, 19, 1.
CH3OH + tert-C4H9 --> CH3O + iso-C4H10

//WAS UNABLE TO VERIFY DATA!!! DATA NOT FOUND IN REFERENCE.

Ref[90] was incorrect; rate matches that reported in Ref[92].

pg.44: Discussion on evaluated data

Entry 44,38(b)

Reference reports reaction as: t-C4H9+CH3OH=t-C4H10+CH3O

This is a typo: no t-C4H10 molecule exists (should be i-C4H10)
No experimental data, at the time

Recommended rate is based on reverse rxn and equilibrium constant

Verified by MRH on 10Aug2009
""",
)

entry(
    index = 265,
    label = "O/H/NonDeC;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (14.4, 'cm^3/(mol*s)', '*|/', 10),
        n = 3.1,
        alpha = 0,
        E0 = (6.94, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [90] literature review.""",
    longDesc = 
u"""
[90] Tsang, W. J. Phys. Chem. Ref. Data 1987, 16, 471.
CH3OH + C2H3 --> CH3O + C2H4

pg 475, Chemical Kinetic Database For Combustion Chemistry, Part 2 - Methanol. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 38,19.

Verified by Karma James

pg. 489: Discussion on evaluated data

Entry 38,19 (b): No data available at the time.  Author recommends the rate coefficient

expression for CH3+CH3OH=CH4+CH3O.
MRH 30-Aug-2009
""",
)

entry(
    index = 266,
    label = "O/H/NonDeC;Ct_rad",
    kinetics = ArrheniusEP(
        A = (1.21e+12, 'cm^3/(mol*s)', '*|/', 5),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Tsang [90] literature review.""",
    longDesc = 
u"""
[90] Tsang, W. J. Phys. Chem. Ref. Data 1987, 16, 471.
CH3OH + C2H --> CH3O + C2H2

pg 475, Chemical Kinetic Database For Combustion Chemistry, Part 2 - Methanol. 

Index of Reactions and Summary of Recommended Rate Expressions. No. 38,21.

Verified by Karma James

pg. 490: Discussion on evaluated data

Entry 38,21 (b): No data available at the time.  Author recommends a rate coefficient

expression based on measurements of C2H+CH4 and C2H+C2H6 rxns
MRH 30-Aug-2009
""",
)

entry(
    index = 267,
    label = "O/H/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (17.3, 'cm^3/(mol*s)'),
        n = 3.4,
        alpha = 0,
        E0 = (-1.14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Jodkowski et al. [100] ab initio calculations.""",
    longDesc = 
u"""
[100] Jodkowski, J.T.; Rauez, M.-T.; Rayez, J.-C. J. Phys. Chem. A. 1999, 103, 3750.
The calculated rate constants are in good agreement with experiment. CH3OH + OH --> CH3O + H2O (Rxn. R5 from paper)

Verified by Greg Magoon (cf. reverse, #258, above)
""",
)

entry(
    index = 268,
    label = "O/H/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1e+13, 'cm^3/(mol*s)', '*|/', 3.16),
        n = 0,
        alpha = 0,
        E0 = (1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Warnatz [134] literature review""",
    longDesc = 
u"""
[134] Warnatz, J. Rate coefficeints in the C/H/O system. In Combustion Chemistry, 1984; pp 197.
CH3OH + OH --> CH3O + H2O
""",
)

entry(
    index = 301,
    label = "H2O2;C_rad/H2/Cs\H2\Cs|Cs#O",
    kinetics = ArrheniusEP(
        A = (2.88, 'cm^3/(mol*s)'),
        n = 3.16,
        alpha = 0,
        E0 = (0.75, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + *CH2CH2CH2CH2OH = nButanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.

For nButanol+HO2=H2O2+*CH2CH2CH2CH2OH:
Moc et al. (AIP Conference Proceedings (2009) 1148 161-164 "The Unimolecular Decomposition
and H Abstraction Reactions by HO and HO2 from n-Butanol") report reaction barriers and
enthalpies(0 K); our CBS-QB3 calculations are shown in comparison (all units are kcal/mol).
				G3		CCSD(T)/cc-pVTZ		CBS-QB3
Barrier:		18.8		19.62			17.57
Enthalpy:		14.25		14.66			13.70
""",
)

entry(
    index = 302,
    label = "H2O2;C_rad/H/Cs\H2\Cs|O/Cs",
    kinetics = ArrheniusEP(
        A = (0.675, 'cm^3/(mol*s)'),
        n = 3.42,
        alpha = 0,
        E0 = (1.43, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + CH3*CHCH2CH2OH = nButanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.

For nButanol+HO2=H2O2+CH3*CHCH2CH2OH:
Moc et al. (AIP Conference Proceedings (2009) 1148 161-164 "The Unimolecular Decomposition
and H Abstraction Reactions by HO and HO2 from n-Butanol") report reaction barriers and
enthalpies(0 K); our CBS-QB3 calculations are shown in comparison (all units are kcal/mol).
				G3		CCSD(T)/cc-pVTZ		CBS-QB3
Barrier:		14.64		15.47			14.72
Enthalpy:		11.05		12.41			10.11
""",
)

entry(
    index = 303,
    label = "H2O2;C_rad/H/Cs\H2\Cs/Cs\H2\O",
    kinetics = ArrheniusEP(
        A = (0.3145, 'cm^3/(mol*s)'),
        n = 3.52,
        alpha = 0,
        E0 = (1.61, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + CH3CH2*CHCH2OH = nButanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.

For nButanol+HO2=H2O2+CH3CH2*CHCH2OH:
Moc et al. (AIP Conference Proceedings (2009) 1148 161-164 "The Unimolecular Decomposition
and H Abstraction Reactions by HO and HO2 from n-Butanol") report reaction barriers and
enthalpies(0 K); our CBS-QB3 calculations are shown in comparison (all units are kcal/mol).
				G3		CCSD(T)/cc-pVTZ		CBS-QB3
Barrier:		15.43		16.37			16.33
Enthalpy:		13.53		14.02			11.48
""",
)

entry(
    index = 304,
    label = "H2O2;C_rad/H/Cs\H2\Cs|H2|Cs/O",
    kinetics = ArrheniusEP(
        A = (1.485, 'cm^3/(mol*s)'),
        n = 3.39,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + CH3CH2CH2*CHOH = nButanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.

For nButanol+HO2=H2O2+CH3CH2CH2*CHOH:
Moc et al. (AIP Conference Proceedings (2009) 1148 161-164 "The Unimolecular Decomposition
and H Abstraction Reactions by HO and HO2 from n-Butanol") report reaction barriers and
enthalpies(0 K); our CBS-QB3 calculations are shown in comparison (all units are kcal/mol).
				G3		CCSD(T)/cc-pVTZ		CBS-QB3
Barrier:		12.62		13.23			11.74
Enthalpy:		 8.35		 8.63			 7.17
""",
)

entry(
    index = 305,
    label = "H2O2;C_rad/H2/Cs\H2\Cs|Cs|O",
    kinetics = ArrheniusEP(
        A = (5.75, 'cm^3/(mol*s)'),
        n = 2.94,
        alpha = 0,
        E0 = (0.46, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + *CH2CH2CH[OH]CH3 = 2-Butanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.
""",
)

entry(
    index = 306,
    label = "H2O2;C_rad/H/Cs\H\Cs\O/Cs",
    kinetics = ArrheniusEP(
        A = (0.875, 'cm^3/(mol*s)'),
        n = 2.91,
        alpha = 0,
        E0 = (-0.41, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + CH3*CHCH[OH]CH3 = 2-Butanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.
""",
)

entry(
    index = 307,
    label = "H2O2;C_rad/O/Cs/Cs\Cs",
    kinetics = ArrheniusEP(
        A = (17.3, 'cm^3/(mol*s)'),
        n = 3.05,
        alpha = 0,
        E0 = (1.02, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + CH3CH2*C[OH]CH3 = 2-Butanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.
""",
)

entry(
    index = 308,
    label = "H2O2;C_rad/H2/Cs\H\Cs\Cs|O",
    kinetics = ArrheniusEP(
        A = (0.3055, 'cm^3/(mol*s)'),
        n = 3.53,
        alpha = 0,
        E0 = (1.52, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + CH3CH2CH[OH]*CH2 = 2-Butanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.
""",
)

entry(
    index = 309,
    label = "H2O2;C_rad/H2/Cs\Cs2\O",
    kinetics = ArrheniusEP(
        A = (0.21, 'cm^3/(mol*s)'),
        n = 3.53,
        alpha = 0,
        E0 = (1.56, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
H2O2 + HOC[*CH2][CH3][CH3] = tert-Butanol + HO2

CBS-QB3 method was used to calculate electronic energy of reactants, products, and TS; frequencies were
calculated using B3LYP/CBSB7 method.  Arrhenius expression was computed using CanTherm: an asymmetric Eckart
tunneling correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomery et al.
J.Chem.Phys. 110 (1999) 2822-2827).  The external symmetry number for H2O2 was 2; the external symmetry number
for the remaining species and TS were set to 1.  The rate coefficient was computed at 600-2000K (in 200 K increments).
The computed pre-exponential factor was divided by 2 and this is the reported value.
""",
)

entry(
    index = 486,
    label = "Orad_O_H;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (1.75e+10, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (-3.275, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[8] Curran's estimation in reaction type 13, RO2 + HO2 --> RO2H + O2""",
)

entry(
    index = 487,
    label = "C/H2/NonDeC;O2b",
    kinetics = ArrheniusEP(
        A = (3.16e+14, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (43.3, 'kcal/mol'),
        Tmin = (378, 'K'),
        Tmax = (433, 'K'),
    ),
    rank = 4,
    shortDesc = u"""ET Denisov, LN Denisova. Int J Chem Kinet 8:123-130, 1975 for BuCH2(CH-H)Me in benzene""",
)

entry(
    index = 500,
    label = "CO_pri;C_rad/H2/Cd\Cs_Cd\H2",
    kinetics = ArrheniusEP(
        A = (0.03065, 'cm^3/(mol*s)'),
        n = 3.95,
        alpha = 0,
        E0 = (12.22, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/o HR corrections
CH2O + H2C=C[*CH2][CH3] = HCO + H2C=C[CH3]2

Geometries and energies of reactants, products, and TS were computed using the CBS-QB3 methodology; frequencies
were calculated at B3LYP/CBSB7.  Arrhenius expression was computed using CanTherm; an asymmetric Eckart tunneling
correction was employed and the frequencies were scaled by 0.99 (as suggested by Montgomergy et al.; J. Chem. Phys.
110 (1999) 2822-2827).  The Arrhenius fit was based on k(T) at T=600, 800, 1000, 1200, 1400, 1600, 1800, and 2000K.
The external symmetry number for CH2O and iso-butene was 2; the external symmetry for all others was 1.  The
electronic spin multiplicity was 1 for CH2O and iso-butene; the electronic spin multiplicity for all others was 2.
The computed pre-exponential factor was divided by 2 (symmetry of CH2O), from 6.13e-02 to 3.065e-02.

There are no rate coefficients for this reaction in the literature (based on MRH's limited search).
   Tsang {J. Phys. Chem. Ref. Data 20 (1991) 221-273} recommends the following for the reaction of 
   CH2O + H2C=CH-*CH2 = HCO + H2C=CH-CH3: k(T) = 1.26e+08 * T^1.9 * exp(-18.184 kcal/mol / RT) cm3 mol-1 s-1.
   This rate coefficient is 25-85x faster than MRH's calculation over the range 600-2000K.
   
   The previous estimate by RMG for this reaction was: k(T) = 5.500e+03 * T^2.81 * exp(-5.86 kcal/mol / RT) cm3 mol-1 s-1.
   This rate coefficient is 80-13,000x faster than MRH's calculation over the range 600-2000K.
""",
)

entry(
    index = 501,
    label = "C/H2/Cs\H3/Cs\H3;C_rad/Cs2/Cs\O",
    kinetics = ArrheniusEP(
        A = (9.11e-07, 'cm^3/(mol*s)'),
        n = 5.11,
        alpha = 0,
        E0 = (5.69, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 2 to get per-H value.

InChI=1/C3H8/c1-3-2/h3H2,1-2H3 (external symmetry number = 2, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C3H7/c1-3-2/h3H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 502,
    label = "C/H2/Cs\Cs2/O;C_rad/H/Cs\H3/Cs\H3",
    kinetics = ArrheniusEP(
        A = (1.06e-06, 'cm^3/(mol*s)'),
        n = 5.06,
        alpha = 0,
        E0 = (4.89, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 2 to get per-H value.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C3H7/c1-3-2/h3H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h3-5H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C3H8/c1-3-2/h3H2,1-2H3 (external symmetry number = 2, spin multiplicity = 1)
""",
)

entry(
    index = 503,
    label = "C/H3/Cd\Cs_Cd\H2;C_rad/H2/Cs\H\Cs\Cs|O",
    kinetics = ArrheniusEP(
        A = (8.39e-06, 'cm^3/(mol*s)'),
        n = 4.89,
        alpha = 0,
        E0 = (4.32, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C4H8/c1-4(2)3/h1H2,2-3H3 (external symmetry number = 2, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h4-5H,1,3H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H7/c1-4(2)3/h1-2H2,3H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 504,
    label = "C/H3/Cd\Cs_Cd\H2;C_rad/Cs2/Cs\O",
    kinetics = ArrheniusEP(
        A = (1.44e-05, 'cm^3/(mol*s)'),
        n = 4.52,
        alpha = 0,
        E0 = (1.46, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C4H8/c1-4(2)3/h1H2,2-3H3 (external symmetry number = 2, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H7/c1-4(2)3/h1-2H2,3H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 505,
    label = "C/H3/Cd\Cs_Cd\H2;C_rad/H/Cs\H\Cs2/O",
    kinetics = ArrheniusEP(
        A = (4.91e-06, 'cm^3/(mol*s)'),
        n = 5.07,
        alpha = 0,
        E0 = (3.66, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C4H8/c1-4(2)3/h1H2,2-3H3 (external symmetry number = 2, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h3-5H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H7/c1-4(2)3/h1-2H2,3H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 506,
    label = "C/H3/Cd\Cs_Cd\H2;O_rad/Cs\H2\Cs|H|Cs2",
    kinetics = ArrheniusEP(
        A = (0.583, 'cm^3/(mol*s)'),
        n = 3.74,
        alpha = 0,
        E0 = (1.45, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C4H8/c1-4(2)3/h1H2,2-3H3 (external symmetry number = 2, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h4H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H7/c1-4(2)3/h1-2H2,3H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 507,
    label = "C/H3/Cd\H_Cd\H2;C_rad/H2/Cs\H\Cs\Cs|O",
    kinetics = ArrheniusEP(
        A = (3.36e-05, 'cm^3/(mol*s)'),
        n = 4.75,
        alpha = 0,
        E0 = (4.13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 3 to get per-H value.

InChI=1/C3H6/c1-3-2/h3H,1H2,2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h4-5H,1,3H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C3H5/c1-3-2/h3H,1-2H2 (external symmetry number = 2, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)

Tsang [Tsang1991]_ recommends k(T) = 2.23e+00 * (T/K)^3.5 * exp(-6.64 kcal/mol /RT) cm3 mol-1 s-1
for the reaction C3H6 + iso-C4H9 = iso-C4H10 + C3H5.  The new rate coefficient expression is
in good agreement with this expression (within 10% over most of the valid temperature range).
""",
)

entry(
    index = 508,
    label = "C/H3/Cd\H_Cd\H2;C_rad/Cs2/Cs\O",
    kinetics = ArrheniusEP(
        A = (1.64e-06, 'cm^3/(mol*s)'),
        n = 4.98,
        alpha = 0,
        E0 = (3.18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 3 to get per-H value.

InChI=1/C3H6/c1-3-2/h3H,1H2,2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C3H5/c1-3-2/h3H,1-2H2 (external symmetry number = 2, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)

Tsang [Tsang1991]_ recommends k(T) = 3.01e-05 * (T/K)^4.9 * exp(-7.95 kcal/mol /RT) cm3 mol-1 s-1
for the reaction C3H6 + tert-C4H9 = iso-C4H10 + C3H5.  The new rate coefficient expression is faster
by as much as 10x over of the valid temperature range.
""",
)

entry(
    index = 509,
    label = "C/H3/Cd\H_Cd\H2;C_rad/H/Cs\H\Cs2/O",
    kinetics = ArrheniusEP(
        A = (3.11e-06, 'cm^3/(mol*s)'),
        n = 4.97,
        alpha = 0,
        E0 = (3.64, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 3 to get per-H value.

InChI=1/C3H6/c1-3-2/h3H,1H2,2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h3-5H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C3H5/c1-3-2/h3H,1-2H2 (external symmetry number = 2, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 510,
    label = "C/H3/Cd\H_Cd\H2;O_rad/Cs\H2\Cs|H|Cs2",
    kinetics = ArrheniusEP(
        A = (0.119, 'cm^3/(mol*s)'),
        n = 3.9,
        alpha = 0,
        E0 = (1.81, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 3 to get per-H value.

InChI=1/C3H6/c1-3-2/h3H,1H2,2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h4H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C3H5/c1-3-2/h3H,1-2H2 (external symmetry number = 2, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 511,
    label = "C/H3/Cs\H3;C_rad/H2/Cs\H\Cs\Cs|O",
    kinetics = ArrheniusEP(
        A = (3.21e-06, 'cm^3/(mol*s)'),
        n = 5.28,
        alpha = 0,
        E0 = (7.78, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C2H6/c1-2/h1-2H3 (external symmetry number = 6, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h4-5H,1,3H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C2H5/c1-2/h1H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)

Tsang [Tsang1990]_ recommends k(T) = 2.894e-01 * (T/K)^3.7 * exp(-9.78 kcal/mol /RT) cm3 mol-1 s-1
for the reaction C2H6 + iso-C4H9 = iso-C4H10 + C2H5.  The new rate coefficient expression is faster
by 10-100x over of the valid temperature range.
""",
)

entry(
    index = 512,
    label = "C/H/Cs2/Cs\O;C_rad/H2/Cs\H3",
    kinetics = ArrheniusEP(
        A = (1.41e-05, 'cm^3/(mol*s)'),
        n = 4.83,
        alpha = 0,
        E0 = (4.37, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C2H5/c1-2/h1H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C2H6/c1-2/h1-2H3 (external symmetry number = 6, spin multiplicity = 1)

Tsang [Tsang1990]_ recommends k(T) = 5.41e-01 * (T/K)^3.46 * exp(-5.96 kcal/mol /RT) cm3 mol-1 s-1
for the reaction iso-C4H10 + C2H5 = C2H6 + tert-C4H9.  The new rate coefficient expression is
in good agreement with this expression (within a factor of 1.6 over the valid temperature range).
""",
)

entry(
    index = 513,
    label = "C/H2/Cs\Cs2/O;C_rad/H2/Cs\H3",
    kinetics = ArrheniusEP(
        A = (4.25e-06, 'cm^3/(mol*s)'),
        n = 5.01,
        alpha = 0,
        E0 = (5.01, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 2 to get per-H value.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C2H5/c1-2/h1H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h3-5H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C2H6/c1-2/h1-2H3 (external symmetry number = 6, spin multiplicity = 1)
""",
)

entry(
    index = 514,
    label = "C/H3/Cs\H3;O_rad/Cs\H2\Cs|H|Cs2",
    kinetics = ArrheniusEP(
        A = (0.00507, 'cm^3/(mol*s)'),
        n = 4.52,
        alpha = 0,
        E0 = (2.34, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C2H6/c1-2/h1-2H3 (external symmetry number = 6, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h4H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C2H5/c1-2/h1H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 515,
    label = "C/H/Cs2/Cs\O;Cd_Cd\H2_pri_rad",
    kinetics = ArrheniusEP(
        A = (5.49, 'cm^3/(mol*s)'),
        n = 3.33,
        alpha = 0,
        E0 = (0.63, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C2H3/c1-2/h1H,2H2 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C2H4/c1-2/h1-2H2 (external symmetry number = 4, spin multiplicity = 1)

Tsang [Tsang1990]_ recommends k(T) = 9.04e-01 * (T/K)^3.46 * exp(-2.60 kcal/mol /RT) cm3 mol-1 s-1
for the reaction iso-C4H10 + C2H3 = C2H4 + tert-C4H9.  The new rate coefficient is faster by 4-10x
over the valid temperature range.
""",
)

entry(
    index = 516,
    label = "C/H3/Cs\H2\Cs|O;Cd_Cd\H2_rad/Cs",
    kinetics = ArrheniusEP(
        A = (3.11e-05, 'cm^3/(mol*s)'),
        n = 4.87,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C3H5/c1-3-2/h1H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h4-5H,1,3H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C3H6/c1-3-2/h3H,1H2,2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 517,
    label = "C/H2/Cs\Cs2/O;Cd_Cd\H2_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0128, 'cm^3/(mol*s)'),
        n = 4.09,
        alpha = 0,
        E0 = (1.31, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 2 to get per-H value.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C3H5/c1-3-2/h1H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h3-5H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C3H6/c1-3-2/h3H,1H2,2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 518,
    label = "C/H2/CO\H/Cs\H3;C_rad/H2/Cs\H\Cs\Cs|O",
    kinetics = ArrheniusEP(
        A = (0.000156, 'cm^3/(mol*s)'),
        n = 4.31,
        alpha = 0,
        E0 = (3.39, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 2 to get per-H value.

InChI=1/C3H6O/c1-2-3-4/h3H,2H2,1H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C4H9O/c1-4(2)3-5/h4-5H,1,3H2,2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C3H5O/c1-2-3-4/h2-3H,1H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 519,
    label = "C/H/Cs2/Cs\O;C_rad/H/CO\H/Cs\H3",
    kinetics = ArrheniusEP(
        A = (0.000485, 'cm^3/(mol*s)'),
        n = 4.37,
        alpha = 0,
        E0 = (9.66, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C3H5O/c1-2-3-4/h2-3H,1H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C3H6O/c1-2-3-4/h3H,2H2,1H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 520,
    label = "C/H2/Cs\Cs2/O;C_rad/H/CO\H/Cs\H3",
    kinetics = ArrheniusEP(
        A = (0.00184, 'cm^3/(mol*s)'),
        n = 4.02,
        alpha = 0,
        E0 = (7.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 2 to get per-H value.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C3H5O/c1-2-3-4/h2-3H,1H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h3-5H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C3H6O/c1-2-3-4/h3H,2H2,1H3 (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 521,
    label = "C/H/Cs2CO;H_rad",
    kinetics = ArrheniusEP(
        A = (2.08e+07, 'cm^3/(mol*s)'),
        n = 1.84,
        alpha = 0,
        E0 = (3.03, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.

InChI=1/C4H8O/c1-4(2)3-5/h3-4H,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/H (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H7O/c1-4(2)3-5/h3H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/H2/h1H (external symmetry number = 2, spin multiplicity = 1)
""",
)

entry(
    index = 522,
    label = "C/H3/Cd\Cs_Cd\H2;O_rad/Cd\H_Cd\H\Cs",
    kinetics = ArrheniusEP(
        A = (7.52e-08, 'cm^3/(mol*s)'),
        n = 5.77,
        alpha = 0,
        E0 = (12.04, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C4H8/c1-4(2)3/h1H2,2-3H3 (external symmetry number = 2, spin multiplicity = 1)
 +
InChI=1/C3H5O/c1-2-3-4/h2-3H,1H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H7/c1-4(2)3/h1-2H2,3H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C3H6O/c1-2-3-4/h2-4H,1H3/ (external symmetry number = 1, spin multiplicity = 1)
""",
)

entry(
    index = 524,
    label = "C/H3/Cd;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (0.00057833, 'cm^3/(mol*s)'),
        n = 4.65,
        alpha = 0,
        E0 = (9.78, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM due to lack of better value ref rate rule 525""",
    longDesc = 
u"""
This rate rules matches C=C-CH3 + HO-O* <=> C=C-CH2* + H2O2

Due to lack of better estimate SSM has given this node the value obtained from 2-Butene + HO2 calculations (Rate rule 525)
The rate was calculated using CBS-QB3 w/o hindered rotors and is valid in a range of temperature from 300 -2000 K.
The Wigner tunneling currection that was used to account for tunneling.
""",
)

entry(
    index = 525,
    label = "C/H3/Cd\H_Cd\H\Cs;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (0.00057833, 'cm^3/(mol*s)'),
        n = 4.65,
        alpha = 0,
        E0 = (9.78, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
SSM CBS-QB3 calculations w/RRHO .  Pre-exponential was divided by 6 to get per-H value.

InChI=1/C4H8/c1-3-4-2/h3-4H,1-2H3/b4-3+ (external symmetry number = 2, spin multiplicity = 1)
 +
HO2 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H7/c1-3-4-2/h3-4H,1H2,2H3  (external symmetry number = 1, spin multiplicity = 2)
 +
H2O2 (external symmetry number = 2, spin multiplicity = 1)
""",
)

entry(
    index = 526,
    label = "H2O2;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.4375, 'cm^3/(mol*s)'),
        n = 3.59,
        alpha = 0,
        E0 = (-4.03, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM due to lack of better value ref rate rule 527""",
    longDesc = 
u"""
This rate rules matches C=C*-C + H2O2 <=> C=C-C + HO-O*

Due to lack of better estimate SSM has given this node the value obtained from 2-Butene + HO2 calculations (Rate rule 527)
The rate was calculated using CBS-QB3 w/o hindered rotors and is valid in a range of temperature from 300 -2000 K.
The Wigner tunneling currection that was used to account for tunneling.
""",
)

entry(
    index = 527,
    label = "H2O2;Cd_Cd\H\Cs_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.4375, 'cm^3/(mol*s)'),
        n = 3.59,
        alpha = 0,
        E0 = (-4.03, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
SSM CBS-QB3 calculations w/RRHO .  Pre-exponential was divided by 2 to account for summetry of H2O2
The rate rule is valid in a range of temperature from 300 -2000 K.
The Wigner tunneling currection that was used to account for tunneling.

InChI=1/C4H7/c1-3-4-2/h3H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
H2O2 (external symmetry number = 2, spin multiplicity = 1)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H8/c1-3-4-2/h3-4H,1-2H3/b4-3+  (external symmetry number = 2, spin multiplicity = 1)
 +
HO2 (external symmetry number = 1, spin multiplicity = 2)
""",
)

entry(
    index = 528,
    label = "C/H2/OneDeC;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (0.000254, 'cm^3/(mol*s)'),
        n = 4.59,
        alpha = 0,
        E0 = (7.16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM due to lack of better value ref rate rule 529""",
    longDesc = 
u"""
This rate rules matches Cs-CH2-C=C + HO-O* <=> Cs-CH*-C=C + H2O2

Due to lack of better estimate SSM has given this node the value obtained from 1-Butene + HO2 calculations (Rate rule 529)
The rate was calculated using CBS-QB3 w/o hindered rotors and is valid in a range of temperature from 300 -2000 K.
The Wigner tunneling currection that was used to account for tunneling.

NY added CS to the definition of 'C/H2/OneDeC'. This rule could be over-generalizing now. Be sure to double check
this when doing training reaction conversions.
""",
)

entry(
    index = 529,
    label = "C/H2/Cd\H_Cd\H2/Cs\H3;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (0.000254, 'cm^3/(mol*s)'),
        n = 4.59,
        alpha = 0,
        E0 = (7.16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
SSM CBS-QB3 calculations w/RRHO .  Pre-exponential was divided by 2 to get per-H value.
The rate rule is valid in a range of temperature from 300 -2000 K.
The Wigner tunneling currection that was used to account for tunneling.

InChI=1/C4H8/c1-3-4-2/h3H,1,4H2,2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
HO2 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H7/c1-3-4-2/h3-4H,1H2,2H3   (external symmetry number = 1, spin multiplicity = 2)
 +
H2O2 (external symmetry number = 2, spin multiplicity = 1)
""",
)

entry(
    index = 530,
    label = "H2O2;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (1, 'cm^3/(mol*s)'),
        n = 3.52,
        alpha = 0,
        E0 = (-7.48, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM due to lack of better value ref rate rule 531""",
    longDesc = 
u"""
This rate rules matches C-HC=CH* + H2O2 <=> C-HC=CH2 + HO=O*

Due to lack of better estimate SSM has given this node the value obtained from 1-Butene + HO2 calculations (Rate rule 531)
The rate was calculated using CBS-QB3 w/o hindered rotors and is valid in a range of temperature from 300 -2000 K.
The Wigner tunneling currection that was used to account for tunneling.
""",
)

entry(
    index = 531,
    label = "H2O2;Cd_Cd\H\Cs|H2|Cs_pri_rad",
    kinetics = ArrheniusEP(
        A = (1, 'cm^3/(mol*s)'),
        n = 3.52,
        alpha = 0,
        E0 = (-7.48, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
SSM CBS-QB3 calculations w/RRHO .  Pre-exponential was divided by 2 to account for summetry of H2O2
The rate rule is valid in a range of temperature from 300 -2000 K.
The Wigner tunneling currection that was used to account for tunneling.

InChI=1/C4H7/c1-3-4-2/h1,3H,4H2,2H3  (external symmetry number = 1, spin multiplicity = 2)
 +
H2O2 (external symmetry number = 2, spin multiplicity = 1)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H8/c1-3-4-2/h3H,1,4H2,2H3  (external symmetry number = 1, spin multiplicity = 1)
 +
HO2 (external symmetry number = 1, spin multiplicity = 2)
""",
)

entry(
    index = 533,
    label = "C_methane;C2b",
    kinetics = ArrheniusEP(
        A = (7.5e+12, 'cm^3/(mol*s)', '+|-', 1.6e+12),
        n = 0,
        alpha = 0,
        E0 = (1.05, 'kcal/mol', '+|-', 0.12),
        Tmin = (294, 'K'),
        Tmax = (376, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Matsugi et al 10.1021/jp1012494""",
    longDesc = 
u"""
For CH4 + C2 = CH3 + C2H

J. Phys. Chem. A 2010, 114, 4580-4585
http://dx.doi.org/10.1021/jp1012494

Rate Constants and Kinetic Isotope Effects on the Reaction of C2($X^1\Sigma_g^+$) with CH4 and CD4.
Akira Matsugi, Kohsuke Suma, and Akira Miyoshi

It was measured at pretty low temperatures (294-376), but also calculated ab initio. The calculated
rates are plotted but the expression is not reported.

    k = (10.0 +- 2.1)E-11 exp[-(4.4+-0.5 kJ mol)/RT] cm3 molecule-1 s-1
which gives 
    A = 6e13+-1.3e13 cm3/mole/s
    n = 0
    Ea = 1.05+-0.12  kcal/mol
The degeneracy of this reaction is 8 though, so per-site A is:
    A = 7.5e12+-1.6e12
    
(See also  doi:10.1063/1.3480395  for reactions of C2, but that may be the wrong electronic state.)
""",
)

entry(
    index = 534,
    label = "H2O2;O_rad/Cd\H_Cd\H\Cs",
    kinetics = ArrheniusEP(
        A = (0.03495, 'cm^3/(mol*s)', '*|/', 3),
        n = 3.75,
        alpha = 0,
        E0 = (10.89, 'kcal/mol', '+|-', 2),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MHS CBS-QB3 w/1dHR calculations""",
    longDesc = 
u"""
Exact reaction: HOOH + *O-CH=CH-C2H5 <=> HO-CH=CH-C2H5 + HOO*
Rxn family nodes: H2O2 + InChI=1/C4H7O/c1-2-3-4-5/h3-4H,2H2,1H3

MHS computed rate coefficient using CBS-QB3 method, see _[MRHCBSQB3RRHO] for general algorithm
employed.  Two differences::
	1) the k(T) was calculated from 600 to 2000 K, in 200 K increments.
	2) Low-frequency torsional modes were treated as 1-d separable hindered rotors.  The scans
		were performed at the B3LYP/6-31G(d) level.

MHS computed the fitted Arrhenius expression to be: k(T) = 6.99e-2 (T/1K)^3.75 exp(-10.89 kcal mol-1 / RT) cm3 mol-1 s-1.
The pre-exponential was divided by 2 to get the per-H event.  The uncertainty in the E0
was estimated to be 2 kcal mol-1 (general accuracy of CBS-QB3 calculations) and the uncertainty
in the A parameter was MRH guess.

RMG previously estimated the kinetics of the titled reaction to be ~10^3 times faster
than calculations of MHS.
""",
)

entry(
    index = 535,
    label = "H2O2;O_rad/OneDe",
    kinetics = ArrheniusEP(
        A = (0.03495, 'cm^3/(mol*s)', '*|/', 3),
        n = 3.75,
        alpha = 0,
        E0 = (10.89, 'kcal/mol', '+|-', 2),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MHS CBS-QB3 w/1dHR calculations, see node 534.""",
    longDesc = 
u"""
Rxn family nodes: H2O2 + O_rad/OneDeC

The rate coefficient for this node was taken from node 534 (H2O2 + InChI=1/C4H7O/c1-2-3-4-5/h3-4H,2H2,1H3)
by analogy: HOOH + *O-C=R.  Discussed with MRH.
""",
)

entry(
    index = 536,
    label = "H2O2;OOC",
    kinetics = ArrheniusEP(
        A = (0.092, 'cm^3/(mol*s)', '*|/', 3),
        n = 3.96,
        alpha = 0,
        E0 = (6.63, 'kcal/mol', '+|-', 2),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MHS CBS-QB3 w/1dHR calculations""",
    longDesc = 
u"""
Exact reaction: HOOH + *O-O-CH3 <=> HO-O-CH3 + HOO*
Rxn family nodes: H2O2 + OOCH3

MHS computed rate coefficient using CBS-QB3 method, see _[MRHCBSQB3RRHO] for general algorithm
employed.  Two differences::
	1) the k(T) was calculated from 600 to 2000 K, in 200 K increments.
	2) Low-frequency torsional modes were treated as 1-d separable hindered rotors.  The scans
		were performed at the B3LYP/6-31G(d) level.

MHS computed the fitted Arrhenius expression to be: k(T) = 1.84e-1 (T/1K)^3.96 exp(-6.63 kcal mol-1 / RT) cm3 mol-1 s-1.
The pre-exponential was divided by 2 to get the per-H event.  The uncertainty in the E0
was estimated to be 2 kcal mol-1 (general accuracy of CBS-QB3 calculations) and the uncertainty
in the A parameter was MRH guess.

RMG previously estimated the kinetics of the titled reaction to be 1-3 orders of magnitude faster
than calculations of MHS.
""",
)

entry(
    index = 537,
    label = "H2O2;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (0.092, 'cm^3/(mol*s)', '*|/', 3),
        n = 3.96,
        alpha = 0,
        E0 = (6.63, 'kcal/mol', '+|-', 2),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MHS CBS-QB3 w/1dHR calculations, see node 536.""",
    longDesc = 
u"""
Rxn family nodes: H2O2 + O_rad/NonDeO

The rate coefficient for this node was taken from node 536 (H2O2 + OOCH3)
by analogy: HOOH + *O-O-R.  Discussed with MRH.
""",
)

entry(
    index = 538,
    label = "C/H2/Cd\H_Cd\H2/Cs\H3;OOC",
    kinetics = ArrheniusEP(
        A = (0.00741, 'cm^3/(mol*s)', '*|/', 3),
        n = 4.313,
        alpha = 0,
        E0 = (8.016, 'kcal/mol', '+|-', 2),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations, w/1dHR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/1d hindered rotor corrections
Exact reaction: CH3CH2CH=CH2 + OOCH3 = HOOCH3 + CH3CHCH=CH2

This reaction was of interest to MRH/MHS because the butanol model was sensitive to its kinetics
(in particular, the C4H8-1 predicted concentration for 10-atm JSR simulations between 800-1000 K).
The original mechanism had an estimate that was much faster than these new calculations (the RMG old
k(T) was 50-100x faster than these calculations between 800-1000 K).

MRH computed these kinetics using the CBS-QB3 method.  Hindered rotor corrections were accounted for in all species:
	CH3CH2CH=CH2: -CH3 and -CH2CH3 rotor
	OOCH3: -CH3 rotor
	TS: -CH3 and -CH=CH2 rotor of react1, -CH3 and -OCH3 of react2, and -OOCH3 between react1 and react2
	HOOCH3: -CH3 and -OCH3 rotor
	CH3CHCH=CH2: -CH3 and -CH=CH2 rotor
External symmetry number of all speces was 1.  k(T) was computed from 600 - 2000 K, in 200 K intervals.  An
asymmetric Eckart tunneling correction was used.

The computed k(T) was 1.482e-02 * (T/1K)^4.313 * exp(-8.016 kcal/mol / RT) cm3 mol-1 s-1.
MRH divided the pre-exponential by 2 to account for the reaction path degeneracy.

NOTE: Running PopulateReactions before and after this number produced results that differed by less than a factor
of three.  New numbers in the RMG database thus lead to an improvement in the RMG estimate (RMG works!).  Also,
this computed rate coefficient is a factor of 10 faster than Tsang's recommendation for C3H6 + OOCH3 = HOOCH3 + allyl;
his stated uncertainty is a factor of ten.  However, one would expect abstraction from the secondary carbon of
1-butane to be faster than the primary carbon of propene, because the C-H bond strength should be weaker.  So,
this calculation is in reasonable agreement with the literature.
""",
)

entry(
    index = 539,
    label = "H2O2;C_rad/H2/Cd\H_Cd\H2",
    kinetics = ArrheniusEP(
        A = (0.01755, 'cm^3/(mol*s)', '*|/', 3),
        n = 4.22,
        alpha = 0,
        E0 = (9.86, 'kcal/mol', '+|-', 2),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MHS CBS-QB3 w/1dHR calculations""",
    longDesc = 
u"""
MHS CBS-QB3 calculations w/1d hindered rotor corrections
Exact reaction: *CH2-CH=CH2 + H2O2 = CH3-CH=CH2 + HO2

MHS computed rate coefficient using CBS-QB3 method, see _[MRHCBSQB3RRHO] for general algorithm
employed.  Two differences::
	1) the k(T) was calculated from 600 to 2000 K, in 200 K increments.
	2) Low-frequency torsional modes were treated as 1-d separable hindered rotors.  The scans
		were performed at the B3LYP/6-31G(d) level.

MHS computed the fitted Arrhenius expression to be: k(T) = 3.51e-2 (T/1K)^4.22 exp(-9.86 kcal mol-1 / RT) cm3 mol-1 s-1.
The pre-exponential was divided by 2 to get the per-H event.  The uncertainty in the E0
was estimated to be 2 kcal mol-1 (general accuracy of CBS-QB3 calculations) and the uncertainty
in the A parameter was MRH guess.

RMG previously estimated the kinetics of the titled reaction to be ~2 orders of magnitude faster
than calculations of MHS.
""",
)

entry(
    index = 540,
    label = "CO/H/Cs\Cs|Cs;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (0.000191, 'cm^3/(mol*s)', '*|/', 3),
        n = 4.25,
        alpha = 0,
        E0 = (0.81, 'kcal/mol', '+|-', 2),
        Tmin = (600, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MHS CBS-QB3 w/o 1dHR calculations""",
    longDesc = 
u"""
MHS CBS-QB3 calculations without 1d hindered rotor correction (due to presence of hydrogen bond interactions)
Exact reaction: HO2 + CH3-CH2-CH2-CH=O = H2O2 + CH3-CH2-CH2-C*=O

MHS computed rate coefficient using CBS-QB3 method, see _[MRHCBSQB3RRHO] for general algorithm
employed.  With the difference that the k(T) was calculated from 600 to 2000 K, in 200 K increments.

MHS computed the fitted Arrhenius expression to be: k(T) = 1.91e-4 (T/1K)^4.25 exp(-0.81 kcal mol-1 / RT) cm3 mol-1 s-1.
The uncertainty in the E0 was estimated to be 2 kcal mol-1 (general accuracy of CBS-QB3 calculations) and the uncertainty
in the A parameter was MRH guess.
""",
)

entry(
    index = 541,
    label = "C/H3/Cb;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (4.2e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (2.59, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Tully et al. experimental data (changed to per H)""",
)

entry(
    index = 542,
    label = "C/H2/Cb;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (4.2e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (2.59, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Tully et al. experimental data (changed to per H)""",
)

entry(
    index = 543,
    label = "C/H/Cb;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (4.2e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (2.59, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Tully et al. experimental data (changed to per H)""",
)

entry(
    index = 544,
    label = "C/H3/Cb;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (1.32e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (14.08, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Baulch et al. literature review (value for HO2 + toluene) (changed to per H)""",
)

entry(
    index = 545,
    label = "C/H2/Cb;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (1.33e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Baulch et al. literature review (value for HO2 + ethylbenzene) (changed to per H)""",
)

entry(
    index = 546,
    label = "C/H/Cb;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (1.33e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (600, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Baulch et al. literature review (value for HO2 + ethylbenzene) (changed to per H)""",
)

entry(
    index = 547,
    label = "C/H3/Cb;O2b",
    kinetics = ArrheniusEP(
        A = (6e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (39.71, 'kcal/mol'),
        Tmin = (700, 'K'),
        Tmax = (1200, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Baulch et al. literature review (value for HO2 + toluene entered here) (changed to per H)""",
)

entry(
    index = 548,
    label = "C/H2/Cb;O2b",
    kinetics = ArrheniusEP(
        A = (6e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (39.71, 'kcal/mol'),
        Tmin = (700, 'K'),
        Tmax = (1200, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Baulch et al. literature review (value for HO2 + toluene entered here) (changed to per H)""",
)

entry(
    index = 549,
    label = "C/H/Cb;O2b",
    kinetics = ArrheniusEP(
        A = (6e+11, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (39.71, 'kcal/mol'),
        Tmin = (700, 'K'),
        Tmax = (1200, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Baulch et al. literature review (value for HO2 + toluene entered here) (changed to per H)""",
)

entry(
    index = 550,
    label = "ROOH_pri;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (2.51e-11, 'cm^3/(mol*s)'),
        n = 6.77,
        alpha = 0,
        E0 = (-8.6, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[AJ]Assumed to be same as for ROOH_sec""",
)

entry(
    index = 551,
    label = "ROOH_sec;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (2.51e-11, 'cm^3/(mol*s)'),
        n = 6.77,
        alpha = 0,
        E0 = (-8.6, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""[AJ]CBS-QB3 calculations with 1DHR corrections, reverse rates computed using DFT_QCI_thermo""",
)

entry(
    index = 552,
    label = "ROOH_pri;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (2.51e-11, 'cm^3/(mol*s)'),
        n = 6.77,
        alpha = 0,
        E0 = (-8.6, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[AJ]Assumed to be same as for C_rad/H/NonDeC""",
)

entry(
    index = 553,
    label = "ROOH_sec;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (2.51e-11, 'cm^3/(mol*s)'),
        n = 6.77,
        alpha = 0,
        E0 = (-8.6, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[AJ]Assumed to be same as for C_rad/H/NonDeC""",
)

entry(
    index = 554,
    label = "ROOH_pri;C_rad/OOH/Cs/Cs",
    kinetics = ArrheniusEP(
        A = (5.066e-14, 'cm^3/(mol*s)'),
        n = 7.18,
        alpha = 0,
        E0 = (-5.27, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[AJ] Assumed to be same as for ROOH_sec""",
)

entry(
    index = 555,
    label = "ROOH_sec;C_rad/OOH/Cs/Cs",
    kinetics = ArrheniusEP(
        A = (5.066e-14, 'cm^3/(mol*s)'),
        n = 7.18,
        alpha = 0,
        E0 = (-5.27, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""[AJ] CBS-QB3 calculations with 1DHR corrections""",
)

entry(
    index = 556,
    label = "ROOH_pri;CO_rad/NonDe",
    kinetics = ArrheniusEP(
        A = (0.0009569, 'cm^3/(mol*s)'),
        n = 4.45,
        alpha = 0,
        E0 = (0.54, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[AJ] Assumed to be same as for ROOH_sec""",
)

entry(
    index = 557,
    label = "ROOH_sec;CO_rad/NonDe",
    kinetics = ArrheniusEP(
        A = (0.0009569, 'cm^3/(mol*s)'),
        n = 4.45,
        alpha = 0,
        E0 = (0.54, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""[AJ] CBS-QB3 calculations with 1DHR corrections""",
)

entry(
    index = 558,
    label = "ROOH_pri;C_rad/H/CO/Cs",
    kinetics = ArrheniusEP(
        A = (1.73e-10, 'cm^3/(mol*s)'),
        n = 6.3,
        alpha = 0,
        E0 = (-2.14, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[AJ] Assumed to be same as for ROOH_sec""",
)

entry(
    index = 559,
    label = "ROOH_sec;C_rad/H/CO/Cs",
    kinetics = ArrheniusEP(
        A = (1.73e-10, 'cm^3/(mol*s)'),
        n = 6.3,
        alpha = 0,
        E0 = (-2.14, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[AJ] Assumed to be same as for C_rad/H2/CO""",
)

entry(
    index = 560,
    label = "ROOH_pri;C_rad/H2/CO",
    kinetics = ArrheniusEP(
        A = (1.73e-10, 'cm^3/(mol*s)'),
        n = 6.3,
        alpha = 0,
        E0 = (-2.14, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""[AJ] Assumed to be same as for ROOH_sec""",
)

entry(
    index = 561,
    label = "ROOH_sec;C_rad/H2/CO",
    kinetics = ArrheniusEP(
        A = (1.73e-10, 'cm^3/(mol*s)'),
        n = 6.3,
        alpha = 0,
        E0 = (-2.14, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (1000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""[AJ] CBS-QB3 calculations with 1DHR corrections""",
)

entry(
    index = 562,
    label = "CS/H/NonDeC;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (4.36e-10, 'cm^3/(mol*s)'),
        n = 4.56,
        alpha = 0,
        E0 = (4.77, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CAC CBS-QB3 calc, 1dhr""",
)

entry(
    index = 563,
    label = "CS/H/NonDeC;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.377, 'cm^3/(mol*s)'),
        n = 3.63,
        alpha = 0,
        E0 = (3.98, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CAC CBS-QB3 calc, 1dhr""",
)

entry(
    index = 565,
    label = "C/H2/CSCs;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (96.1, 'cm^3/(mol*s)'),
        n = 3.34,
        alpha = 0,
        E0 = (-0.27, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CAC CBS-QB3 1dhr""",
)

entry(
    index = 566,
    label = "C/H2/CSCs;Cs_rad",
    kinetics = ArrheniusEP(
        A = (12.1, 'cm^3/(mol*s)'),
        n = 3.35,
        alpha = 0,
        E0 = (3.49, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CAC CBS-QB3 1dhr""",
)

entry(
    index = 567,
    label = "C/H2/CdS;S_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.0188, 'cm^3/(mol*s)'),
        n = 4.57,
        alpha = 0,
        E0 = (4.06, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""CAC CBS-QB3, HO approx""",
)

entry(
    index = 1001,
    label = "C/H3/O;H_rad",
    kinetics = ArrheniusEP(
        A = (451, 'cm^3/(mol*s)'),
        n = 3.2,
        alpha = 0,
        E0 = (3.49, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""Jodkowski et al. [100] ab initio calculations. added by Greg Magoon 08/25/09""",
    longDesc = 
u"""
[100] Jodkowski, J.T.; Rauez, M.-T.; Rayez, J.-C. J. Phys. Chem. A. 1999, 103, 3750.

CH3OH + H --> CH2OH + H2 (Rxn. R2 in paper)

divided original rate expression by 3 to get rate expression per H atom.

Created by Greg Magoon; maximum error of fitted expression from tabular data for kr2 is 20% (cf. p. 3758); rank of 2 assigned based on rank for other values reported in the paper in the rateLibrary (also 2)
""",
)

entry(
    index = 1002,
    label = "C/H/Cs2/Cs\O;C_rad/H/Cs\H3/Cs\H3",
    kinetics = ArrheniusEP(
        A = (2.35e-06, 'cm^3/(mol*s)'),
        n = 4.84,
        alpha = 0,
        E0 = (4.27, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 calculations w/o HR corrections""",
    longDesc = 
u"""
MRH CBS-QB3 calculations w/RRHO [MRHCBSQB3RRHO]_.

InChI=1/C4H10O/c1-4(2)3-5/h4-5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 1)
 +
InChI=1/C3H7/c1-3-2/h3H,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 <=> (TS: external symmetry number = 1, spin multiplicity = 2)
InChI=1/C4H9O/c1-4(2)3-5/h5H,3H2,1-2H3 (external symmetry number = 1, spin multiplicity = 2)
 +
InChI=1/C3H8/c1-3-2/h3H2,1-2H3 (external symmetry number = 2, spin multiplicity = 1)

Tsang [Tsang1990]_ recommends k(T) = 1.51e-03 * (T/K)^4.2 * exp(-5.96 kcal/mol /RT) cm3 mol-1 s-1
for the reaction iso-C4H10 + iso-C3H7 = C3H8 + tert-C4H9.  The new rate coefficient expression is
in good agreement with this expression (within a factor of 3.5 over the valid temperature range).
""",
)

entry(
    index = 1184,
    label = "S/H/NonDeC;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (395, 'cm^3/(mol*s)'),
        n = 3.17,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs""",
)

entry(
    index = 1185,
    label = "CS_pri;C_methyl",
    kinetics = ArrheniusEP(
        A = (83200, 'cm^3/(mol*s)'),
        n = 2.3,
        alpha = 0,
        E0 = (-0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs""",
)

entry(
    index = 1192,
    label = "S_pri;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (6.3e+07, 'cm^3/(mol*s)'),
        n = 1.71,
        alpha = 0,
        E0 = (-0.67, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1193,
    label = "S/H/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (203000, 'cm^3/(mol*s)'),
        n = 2.41,
        alpha = 0,
        E0 = (-4.19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1194,
    label = "S/H/NonDeC;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (1.32e+06, 'cm^3/(mol*s)'),
        n = 2.09,
        alpha = 0,
        E0 = (-0.47, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1195,
    label = "S_pri;O_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (20900, 'cm^3/(mol*s)'),
        n = 2.44,
        alpha = 0,
        E0 = (1.19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1196,
    label = "CO/H/NonDe;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000194, 'cm^3/(mol*s)'),
        n = 4.68,
        alpha = 0,
        E0 = (6.31, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1197,
    label = "C/H/CsOS;Cs_rad",
    kinetics = ArrheniusEP(
        A = (0.512, 'cm^3/(mol*s)'),
        n = 3.74,
        alpha = 0,
        E0 = (3.72, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr""",
)

entry(
    index = 1198,
    label = "S/H/CO;Cs_rad",
    kinetics = ArrheniusEP(
        A = (1.34, 'cm^3/(mol*s)'),
        n = 3.51,
        alpha = 0,
        E0 = (-0.85, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1199,
    label = "C/H/CsOS;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (111000, 'cm^3/(mol*s)'),
        n = 2.47,
        alpha = 0,
        E0 = (0.74, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1200,
    label = "CO/H/NonDe;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (11900, 'cm^3/(mol*s)'),
        n = 2.9,
        alpha = 0,
        E0 = (0.18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1201,
    label = "O/H/OneDe;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0204, 'cm^3/(mol*s)'),
        n = 4.42,
        alpha = 0,
        E0 = (6.65, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 1202,
    label = "O/H/OneDe;S_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (2.95e-06, 'cm^3/(mol*s)'),
        n = 5.63,
        alpha = 0,
        E0 = (11.75, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CAC calculation CBS-QB3 1dhr, F12a energy""",
)

entry(
    index = 2000,
    label = "C_pri;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0.23,
        E0 = (8.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Added by Beat Buesser from 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli""",
)

entry(
    index = 2001,
    label = "C/H2/NonDeC_5ring_fused6_1;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0127, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2001,
    label = "C_sec;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0.23,
        E0 = (8.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Dean and Bozzelli chapter 2, estimation same as C_pri;NH2_rad""",
)

entry(
    index = 2002,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00147, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2002,
    label = "C_ter;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0.23,
        E0 = (8.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Dean and Bozzelli chapter 2, estimation same as C_pri;NH2_rad""",
)

entry(
    index = 2003,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00221, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2003,
    label = "N3s_H;H_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0.21,
        E0 = (10.402, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Added by Beat Buesser from 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli""",
)

entry(
    index = 2004,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00066, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2004,
    label = "N3s_H;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0.15,
        E0 = (6.544, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Added by Beat Buesser from 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli""",
)

entry(
    index = 2005,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0126, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2005,
    label = "N3s_H;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0.05,
        E0 = (1.329, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Added by Beat Buesser from 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli""",
)

entry(
    index = 2006,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00567, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2006,
    label = "N3s_H;C_methyl",
    kinetics = ArrheniusEP(
        A = (810000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0.15,
        E0 = (9.42, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Added by Beat Buesser from 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli""",
)

entry(
    index = 2007,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000881, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2007,
    label = "C/H3/Cs;InChI=1S/NO3/c2-1(3)4",
    kinetics = ArrheniusEP(
        A = (2.03e-12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (8.31, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser from 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli""",
)

entry(
    index = 2008,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.019, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (24.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2008,
    label = "C/H3/Ct;InChI=1S/NO3/c2-1(3)4",
    kinetics = ArrheniusEP(
        A = (810000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0.15,
        E0 = (9.42, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser from 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli""",
)

entry(
    index = 2009,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000961, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (24.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2010,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00575, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2011,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00136, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2012,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000549, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2013,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00577, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2014,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000161, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2015,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0123, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2016,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00361, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2017,
    label = "C/H2/NonDeC_5ring_fused6_1;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (9.77e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2018,
    label = "C/H2/NonDeC_5ring_fused6_1;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0119, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2019,
    label = "C/H2/NonDeC_5ring_fused6_1;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00672, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2020,
    label = "C/H2/NonDeC_5ring_fused6_1;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00564, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2021,
    label = "C/H2/NonDeC_5ring_fused6_1;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0142, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2022,
    label = "C/H2/NonDeC_5ring_fused6_1;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00121, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2024,
    label = "C/H/Cs3_5ring_fused6;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0183, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2025,
    label = "C/H/Cs3_5ring_fused6;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.0016, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2026,
    label = "C/H/Cs3_5ring_fused6;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00181, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2027,
    label = "C/H/Cs3_5ring_fused6;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000408, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2028,
    label = "C/H/Cs3_5ring_fused6;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0125, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (17.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2029,
    label = "C/H/Cs3_5ring_fused6;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00424, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2030,
    label = "C/H/Cs3_5ring_fused6;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000498, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2031,
    label = "C/H/Cs3_5ring_fused6;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.013, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (24.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2032,
    label = "C/H/Cs3_5ring_fused6;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000495, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (24.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2033,
    label = "C/H/Cs3_5ring_fused6;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0057, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (13.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2034,
    label = "C/H/Cs3_5ring_fused6;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00102, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2035,
    label = "C/H/Cs3_5ring_fused6;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00031, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2036,
    label = "C/H/Cs3_5ring_fused6;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00394, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2037,
    label = "C/H/Cs3_5ring_fused6;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (8.32e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (19.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2038,
    label = "C/H/Cs3_5ring_fused6;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0122, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2039,
    label = "C/H/Cs3_5ring_fused6;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0027, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2040,
    label = "C/H/Cs3_5ring_fused6;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (5.52e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2041,
    label = "C/H/Cs3_5ring_fused6;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0172, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2042,
    label = "C/H/Cs3_5ring_fused6;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.0073, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2043,
    label = "C/H/Cs3_5ring_fused6;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00813, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2044,
    label = "C/H/Cs3_5ring_fused6;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0205, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2045,
    label = "C/H/Cs3_5ring_fused6;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00174, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2047,
    label = "C/H2/NonDeC_5ring_fused6_2;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00726, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2048,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000842, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2049,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00127, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2050,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000378, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2051,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00724, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2052,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00325, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (20, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2053,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000505, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (20.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2054,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0109, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (26.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2055,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00055, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (26.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2056,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00329, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2057,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000779, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2058,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000314, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2059,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00331, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2060,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (9.25e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (21.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2061,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00706, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2062,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00206, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2063,
    label = "C/H2/NonDeC_5ring_fused6_2;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (5.6e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2064,
    label = "C/H2/NonDeC_5ring_fused6_2;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00684, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2065,
    label = "C/H2/NonDeC_5ring_fused6_2;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00385, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2066,
    label = "C/H2/NonDeC_5ring_fused6_2;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00323, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2067,
    label = "C/H2/NonDeC_5ring_fused6_2;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00813, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2068,
    label = "C/H2/NonDeC_5ring_fused6_2;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000693, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2070,
    label = "C/H/Cs3_5ring_adj5;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00665, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2071,
    label = "C/H/Cs3_5ring_adj5;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000582, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2072,
    label = "C/H/Cs3_5ring_adj5;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00066, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2073,
    label = "C/H/Cs3_5ring_adj5;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000149, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2074,
    label = "C/H/Cs3_5ring_adj5;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00457, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2075,
    label = "C/H/Cs3_5ring_adj5;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00154, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2076,
    label = "C/H/Cs3_5ring_adj5;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000181, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2077,
    label = "C/H/Cs3_5ring_adj5;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00473, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (22.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2078,
    label = "C/H/Cs3_5ring_adj5;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00018, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (22.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2079,
    label = "C/H/Cs3_5ring_adj5;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00208, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (11.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2080,
    label = "C/H/Cs3_5ring_adj5;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000371, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2081,
    label = "C/H/Cs3_5ring_adj5;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000113, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2082,
    label = "C/H/Cs3_5ring_adj5;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00144, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2083,
    label = "C/H/Cs3_5ring_adj5;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (3.03e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2084,
    label = "C/H/Cs3_5ring_adj5;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00446, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2085,
    label = "C/H/Cs3_5ring_adj5;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000983, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (13.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2086,
    label = "C/H/Cs3_5ring_adj5;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.01e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2087,
    label = "C/H/Cs3_5ring_adj5;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00627, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2088,
    label = "C/H/Cs3_5ring_adj5;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00266, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2089,
    label = "C/H/Cs3_5ring_adj5;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00296, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2090,
    label = "C/H/Cs3_5ring_adj5;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00745, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (-1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2091,
    label = "C/H/Cs3_5ring_adj5;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000635, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2093,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0104, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2094,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00121, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2095,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00182, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2096,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000543, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2097,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0104, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (17.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2098,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00466, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2099,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000724, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2100,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0156, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (25.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2101,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000789, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (25.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2102,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00472, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2103,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00112, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2104,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000451, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2105,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00474, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (19.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2106,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000133, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (20.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2107,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0101, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2108,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00296, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2109,
    label = "C/H2/NonDeC_5ring_alpha6ring;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (8.03e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2110,
    label = "C/H2/NonDeC_5ring_alpha6ring;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00981, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2111,
    label = "C/H2/NonDeC_5ring_alpha6ring;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00552, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2112,
    label = "C/H2/NonDeC_5ring_alpha6ring;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00463, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (9.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2113,
    label = "C/H2/NonDeC_5ring_alpha6ring;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0117, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (-1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2114,
    label = "C/H2/NonDeC_5ring_alpha6ring;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000994, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2116,
    label = "C/H2/NonDeC_5ring_beta6ring;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0151, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2117,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00175, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2118,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00263, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2119,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000787, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2120,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0151, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (16.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2121,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00675, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2122,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00105, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (18.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2123,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0226, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (24.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2124,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00114, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (24.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2125,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00685, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2126,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00162, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2127,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000654, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2128,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00688, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (19.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2129,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000192, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (19.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2130,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0147, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2131,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0043, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (15.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2132,
    label = "C/H2/NonDeC_5ring_beta6ring;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000116, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2133,
    label = "C/H2/NonDeC_5ring_beta6ring;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0142, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2134,
    label = "C/H2/NonDeC_5ring_beta6ring;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.008, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2135,
    label = "C/H2/NonDeC_5ring_beta6ring;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00672, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2136,
    label = "C/H2/NonDeC_5ring_beta6ring;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0169, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 2137,
    label = "C/H2/NonDeC_5ring_beta6ring;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00144, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte GAVs BMK/6-311G(2,d,p)""",
)

entry(
    index = 3000,
    label = "NH3;H_rad",
    kinetics = ArrheniusEP(
        A = (540000, 'cm^3/(mol*s)'),
        n = 2.4,
        alpha = 0,
        E0 = (9.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH3 + H = NH2 + H2 (B&D #6) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH3;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (5e+07, 'cm^3/(mol*s)'),
        n = 1.6,
        alpha = 0,
        E0 = (0.95, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH3 + OH = NH2 + H2O (B&D #7) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH3;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (9.4e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (6.46, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH3 + O = NH2 + OH (B&D #8) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH2_rad_H;H_rad",
    kinetics = ArrheniusEP(
        A = (4.8e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (7.94, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2 + H = NH + H2 (B&D #9) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH2_rad_H;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (7e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2 + O = NH + OH (B&D #15d2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH2_rad_H;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (0.05, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2 + OH = NH + H2O (B&D #16b) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH2_rad_H;NH2_rad",
    kinetics = ArrheniusEP(
        A = (5e+13, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (9.94, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2 + NH2 = NH3 + NH (B&D #17e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH2_rad_H;C_methyl",
    kinetics = ArrheniusEP(
        A = (2.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (9.21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3 + NH2 = CH4 + NH (B&D #21e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "CH3_rad_H;NH2_rad",
    kinetics = ArrheniusEP(
        A = (1.6e+06, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (7.57, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3 + NH2 = CH2 + NH3 (B&D #21f) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "OH_rad_H;N_atom_quartet",
    kinetics = ArrheniusEP(
        A = (6.4e+12, 'cm^3/(mol*s)'),
        n = 0.1,
        alpha = 0,
        E0 = (21.26, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N + OH = NH + O (B&D #26b) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH_triplet_H;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (2.44, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH + NH2 = NH3 + N (B&D #27b2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH_triplet_H;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.49, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH + OH = N + H2O (B&D #27c2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH_triplet_H;H_rad",
    kinetics = ArrheniusEP(
        A = (3.5e+13, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (1.73, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH + H = N + H2 (B&D #27d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH_triplet_H;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (3.37, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH + O = N + OH (B&D #27e2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH_triplet_H;C_methyl",
    kinetics = ArrheniusEP(
        A = (820000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (5.85, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH + CH3 = CH4 + N (B&D #27f2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (4.8e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (1.58, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H2 + H = NNH + H2 (B&D #29c1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.3e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H2 + O = NNH + OH (B&D #29c2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-1.19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H2 + OH = NNH + H2O (B&D #29c3) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (1.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (-1.15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H2 + NH2 = NNH + NH3 (B&D #29c4) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (1.6e+06, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (2.97, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H2 + CH3 = NNH + CH4 (B&D #29c5) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeN;NH_triplet",
    kinetics = ArrheniusEP(
        A = (2.4e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-1.19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H2 + NH = NNH + NH2 (B&D #29d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s_rad_H/H/NonDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (3e+13, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H3 + OH = H2NN + H2O (B&D #31d2)  in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s_rad_H/H/NonDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (3e+13, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H3 + CH3 = H2NN + CH4 (B&D #31e2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s_rad_H/H/NonDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (3e+13, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H3 + NH2 = H2NN + NH3 (B&D #31f2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (9.6e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (4.84, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H4 + H = N2H3 + H2 (B&D #32a) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (4.8e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (-0.89, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2NNHO + H = HNNHO + H2 (B&D #63b) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (6.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (2.85, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H4 + O = N2H3 + OH (B&D #32b) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.3e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (-0.89, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2NNHO + O = HNNHO + OH (B&D #63c) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (4.8e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.65, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H4 + OH = N2H3 + H2O (B&D #32c) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-1.19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2NNHO + OH = HNNHO + H2O (B&D #63d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (3.3e+06, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (5.33, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H4 + CH3 = N2H3 + CH4 (B&D #32d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (1.6e+06, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (0.38, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2NNHO + CH3 = HNNHO + CH4 (B&D #63e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (3.7e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (1.63, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: N2H4 + NH2 = N2H3 + NH3 (B&D #32e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (1.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (-1.15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2NNHO + NH2 = HNNHO + NH3 (B&D #63f) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeO;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.3e+07, 'cm^3/(mol*s)'),
        n = 1.88,
        alpha = 0,
        E0 = (-0.95, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO + OH = NO + H2O (B&D #36c) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeO;H_rad",
    kinetics = ArrheniusEP(
        A = (4.5e+11, 'cm^3/(mol*s)'),
        n = 0.72,
        alpha = 0,
        E0 = (0.66, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO + H = H2 + NO (B&D #36d1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeO;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (4.5e+11, 'cm^3/(mol*s)'),
        n = 0.72,
        alpha = 0,
        E0 = (0.66, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO + O = OH + NO (B&D #36e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeO;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (-1.15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO + NH2 = NH3 + NO (B&D #36f) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeO;O2b",
    kinetics = ArrheniusEP(
        A = (2e+13, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (15.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO + O2 = NO + HO2 (B&D #36h) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeO;C_methyl",
    kinetics = ArrheniusEP(
        A = (820000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (0.95, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO + CH3 = NO + CH4 (B&D #36i) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (2e+08, 'cm^3/(mol*s)'),
        n = 1.55,
        alpha = 0,
        E0 = (6.62, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HONO + H = H2 + NO2 (B&D #40b1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (3.03, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HONO + O = OH + NO2 (B&D #40c) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HONO + OH = H2O + NO2 (B&D #40d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (810000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HONO + CH3 = NO2 + CH4 (B&D #40e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (1.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HONO + NH2 = NO2 + NH3 (B&D #40f) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N5d/H/NonDeOO;H_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (4.16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO2 + H = H2 + NO2 (B&D #41a) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N5d/H/NonDeOO;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (2.36, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO2 + O = OH + NO2 (B&D #41b) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N5d/H/NonDeOO;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.79, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO2 + OH = H2O + NO2 (B&D #41c) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N5d/H/NonDeOO;C_methyl",
    kinetics = ArrheniusEP(
        A = (810000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (4.84, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO2 + CH3 = NO2 + CH4 (B&D #41d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N5d/H/NonDeOO;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (0.87, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNO2 + NH2 = NH3 + NO2 (B&D #41e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Ct/H/NonDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (3.9e+06, 'cm^3/(mol*s)'),
        n = 1.83,
        alpha = 0,
        E0 = (10.29, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HCN + OH = CN + H2O (B&D #42a) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Ct/H/NonDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (4.2e+10, 'cm^3/(mol*s)'),
        n = 1.83,
        alpha = 0,
        E0 = (20.67, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HCN + O = CN + OH (B&D #42c3) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "H2;Ct_rad/N",
    kinetics = ArrheniusEP(
        A = (3.6e+08, 'cm^3/(mol*s)'),
        n = 1.55,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CN + H2 = HCN + H (B&D #44a) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O_pri;Ct_rad/N",
    kinetics = ArrheniusEP(
        A = (7.8e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (7.45, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CN + H2O = HCN + OH (B&D #44b) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "C_methane;Ct_rad/N",
    kinetics = ArrheniusEP(
        A = (120000, 'cm^3/(mol*s)'),
        n = 2.64,
        alpha = 0,
        E0 = (-0.16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CN + CH4 = HCN + CH3 (B&D #44i) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH3;Ct_rad/N",
    kinetics = ArrheniusEP(
        A = (9.2e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (-0.36, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CN + NH3 = HCN + NH2 (B&D #44j) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (7.32, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + H = H2CN + H2 (B&D #48a1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeC;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (4.63, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + O = H2CN + OH (B&D #48a2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.09, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + OH = H2CN + H2O (B&D #48a3) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (820000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (7.12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + CH3 = H2CN + CH4 (B&D #48a4) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/NonDeC;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (4.44, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + NH2 = H2CN + NH3 (B&D #48a5) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cd/H2/NonDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (3e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (6.13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + H = HCNH + H2 (B&D #48b1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cd/H2/NonDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (2.2e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + O = HCNH + OH (B&D #48b2)  in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cd/H2/NonDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (0.46, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + OH = HCNH + H2O (B&D #48b3) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cd/H2/NonDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (530000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (9.69, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + CH3 = HCNH + CH4 (B&D #48b4) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cd/H2/NonDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (1.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (6.09, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2CNH + NH2 = HCNH + NH3 (B&D #48b5)  in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/NonDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (5.6e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (5.46, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + H = CH2NH2 + H2 (B&D #51a1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/NonDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (4e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + O = CH2NH2 + OH (B&D #51a2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/NonDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (3.6e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (0.24, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + OH = CH2NH2 + H2O (B&D #51a3) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/NonDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (1.5e+06, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (9.17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + CH3 = CH2NH2 + CH4 (B&D #51a4) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/NonDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (2.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (5.49, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + NH2 = CH2NH2 + NH3 (B&D #51a5) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (4.8e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (9.71, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + H = CH3NH + H2 (B&D #51b1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeC;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.3e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (6.35, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + O = CH3NH + OH (B&D #51b2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (0.45, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + OH = CH3NH + H2O (B&D #51b3) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (1.6e+06, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (8.84, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + CH3 = CH3NH + CH4 (B&D #51b4) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeC;NH2_rad",
    kinetics = ArrheniusEP(
        A = (1.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (7.14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NH2 + NH2 = CH3NH + NH3 (B&D #51b5) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "H2;N3d_rad/OneDeCdd_O",
    kinetics = ArrheniusEP(
        A = (760, 'cm^3/(mol*s)'),
        n = 3,
        alpha = 0,
        E0 = (3.97, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NCO + H2 = HNCO + H (B&D #53c) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "C_methane;N3d_rad/OneDeCdd_O",
    kinetics = ArrheniusEP(
        A = (9.8e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (8.13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NCO + CH4 = HNCO + CH3 (B&D #53i) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "NH3;N3d_rad/OneDeCdd_O",
    kinetics = ArrheniusEP(
        A = (28000, 'cm^3/(mol*s)'),
        n = 2.48,
        alpha = 0,
        E0 = (0.98, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NCO + NH3 = HNCO + NH2 (B&D #53j) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (6.62, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HOCN + H = H2 + NCO (B&D #55d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeC;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (4.13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HOCN + O = OH + NCO (B&D #55e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.25, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HOCN + OH = H2O + NCO (B&D #55f) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (820000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (6.62, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HOCN + CH3 = CH4 + NCO (B&D #55g) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/OneDeC;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (3.65, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HOCN + NH2 = NH3 + NCO (B&D #55h) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/OneDeCO;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (5.2e+10, 'cm^3/(mol*s)'),
        n = -0.03,
        alpha = 0,
        E0 = (17.57, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNCO + OH = NCO + H2O (B&D #56d2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/OneDeCO;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (3.6e+07, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNCO + OH = NCO + H2O (B&D #56g) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/OneDeCO;H_rad",
    kinetics = ArrheniusEP(
        A = (180000, 'cm^3/(mol*s)'),
        n = 2.4,
        alpha = 0,
        E0 = (9.92, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNCO + H = NCO + H2 (B&D #56e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/OneDeCO;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.1e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (6.46, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNCO + O = NCO + OH (B&D #56f) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/OneDeCO;C_methyl",
    kinetics = ArrheniusEP(
        A = (1e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (9.94, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNCO + CH3 = NCO + CH4 (B&D #56h) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3d/H/OneDeCO;NH2_rad",
    kinetics = ArrheniusEP(
        A = (1e+12, 'cm^3/(mol*s)'),
        n = 0,
        alpha = 0,
        E0 = (8.94, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: HNCO + NH2 = NCO + NH3 (B&D #56i) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H2/OneDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.3e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (-0.89, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH2NO + O = HCNO + OH (B&D #57d2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/OneDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (4.4e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (0.38, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NO + H = CH2NO + H2 (B&D #58a) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/OneDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.3e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (3.62, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NO + O = CH2NO + OH (B&D #58b) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/OneDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (3.6e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-1.19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NO + OH = CH2NO + H2O (B&D #58c) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/OneDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (790000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (5.41, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NO + CH3 = CH2NO + CH4 (B&D #58d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "Cs/H3/OneDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (2.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (1.07, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: CH3NO + NH2 = CH2NO + NH3 (B&D #58e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeO;H_rad",
    kinetics = ArrheniusEP(
        A = (4.8e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (6.25, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + H = HNOH + H2 (B&D #61b1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeO;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.3e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (3.86, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + O = HNOH + OH (B&D #61c1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeO;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.33, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + OH = HNOH + H2O (B&D #61d1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeO;C_methyl",
    kinetics = ArrheniusEP(
        A = (1.6e+06, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (6.35, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + CH3 = HNOH + CH4 (B&D #61e1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeO;NH2_rad",
    kinetics = ArrheniusEP(
        A = (1.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (3.23, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + NH2 = HNOH + NH3 (B&D #61f1)  in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeO;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (29000, 'cm^3/(mol*s)'),
        n = 2.69,
        alpha = 0,
        E0 = (9.56, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + HO2 = HNOH + H2O2 (B&D #61g1) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/NonDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (5.07, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + H = NH2O + H2 (B&D #61b2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/NonDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (1.7e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (3.01, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + O = NH2O + OH (B&D #61c2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/NonDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (1.2e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + OH = NH2O + H2O (B&D #61d2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/NonDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (820000, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (5.49, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + CH3 = NH2O + CH4 (B&D #61e2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/NonDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (920000, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (1.89, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + NH2 = NH2O + NH3 (B&D #61f2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "O/H/NonDeN;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (14000, 'cm^3/(mol*s)'),
        n = 2.69,
        alpha = 0,
        E0 = (6.42, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2OH + HO2 = NH2O + H2O2 (B&D #61g2) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/OneDeN;H_rad",
    kinetics = ArrheniusEP(
        A = (4.8e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (7.41, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2NO + H = HNNO + H2 (B&D #62b) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/OneDeN;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (3.3e+08, 'cm^3/(mol*s)'),
        n = 1.5,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2NO + O = HNNO + OH (B&D #62c) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/OneDeN;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.4e+06, 'cm^3/(mol*s)'),
        n = 2,
        alpha = 0,
        E0 = (-0.07, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2NO + OH = HNNO + H2O (B&D #62d) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/OneDeN;C_methyl",
    kinetics = ArrheniusEP(
        A = (1.6e+06, 'cm^3/(mol*s)'),
        n = 1.87,
        alpha = 0,
        E0 = (7.18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2NO + CH3 = HNNO + CH4 (B&D #62e) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/OneDeN;NH2_rad",
    kinetics = ArrheniusEP(
        A = (1.8e+06, 'cm^3/(mol*s)'),
        n = 1.94,
        alpha = 0,
        E0 = (4.54, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2NO + NH2 = HNNO + NH3 (B&D #62f) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/OneDeN;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (29000, 'cm^3/(mol*s)'),
        n = 2.69,
        alpha = 0,
        E0 = (12.63, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: NH2NO + HO2 = HNNO + H2O2 (B&D #62g) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3000,
    label = "N3s/H2/NonDeN;O_rad/NonDeO",
    kinetics = ArrheniusEP(
        A = (29000, 'cm^3/(mol*s)'),
        n = 2.69,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 1,
    shortDesc = u"""Added by Beat Buesser""",
    longDesc = 
u"""
Added by Beat Buesser, value for reaction: H2NNHO + HO2 = HNNHO + H2O2 (B&D #63g) in 'Gas-Phase Combustion Chemistry' (ISBN: 978-1-4612-7088-1), chapter 2, 'Combustion Chemistry of Nitrogen', Anthony M. Dean, Joseph W. Bozzelli",
""",
)

entry(
    index = 3021,
    label = "C/H2/NonDeC_5ring_fused6_1;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (86100, 'cm^3/(mol*s)'),
        n = 2.38,
        alpha = 0,
        E0 = (-1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) OH + JP10""",
)

entry(
    index = 3022,
    label = "C/H/Cs3_5ring_fused6;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (278000, 'cm^3/(mol*s)'),
        n = 2.38,
        alpha = 0,
        E0 = (-1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) OH + JP10""",
)

entry(
    index = 3023,
    label = "C/H2/NonDeC_5ring_fused6_2;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (84400, 'cm^3/(mol*s)'),
        n = 2.38,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) OH + JP10""",
)

entry(
    index = 3024,
    label = "C/H/Cs3_5ring_adj5;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (56700, 'cm^3/(mol*s)'),
        n = 2.38,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) OH + JP10""",
)

entry(
    index = 3025,
    label = "C/H2/NonDeC_5ring_alpha6ring;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (68800, 'cm^3/(mol*s)'),
        n = 2.38,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) OH + JP10""",
)

entry(
    index = 3026,
    label = "C/H2/NonDeC_5ring_beta6ring;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (151000, 'cm^3/(mol*s)'),
        n = 2.38,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) OH + JP10""",
)

entry(
    index = 3030,
    label = "C/H2/NonDeC_5ring_fused6_1;H_rad",
    kinetics = ArrheniusEP(
        A = (2870, 'cm^3/(mol*s)'),
        n = 3.02,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) H + JP10""",
)

entry(
    index = 3031,
    label = "C/H/Cs3_5ring_fused6;H_rad",
    kinetics = ArrheniusEP(
        A = (4520, 'cm^3/(mol*s)'),
        n = 3.02,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) H + JP10""",
)

entry(
    index = 3032,
    label = "C/H2/NonDeC_5ring_fused6_2;H_rad",
    kinetics = ArrheniusEP(
        A = (3180, 'cm^3/(mol*s)'),
        n = 3.02,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) H + JP10""",
)

entry(
    index = 3033,
    label = "C/H/Cs3_5ring_adj5;H_rad",
    kinetics = ArrheniusEP(
        A = (3840, 'cm^3/(mol*s)'),
        n = 3.02,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) H + JP10""",
)

entry(
    index = 3034,
    label = "C/H2/NonDeC_5ring_alpha6ring;H_rad",
    kinetics = ArrheniusEP(
        A = (2220, 'cm^3/(mol*s)'),
        n = 3.02,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) H + JP10""",
)

entry(
    index = 3035,
    label = "C/H2/NonDeC_5ring_beta6ring;H_rad",
    kinetics = ArrheniusEP(
        A = (4020, 'cm^3/(mol*s)'),
        n = 3.02,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK/6-311G(2,d,p) H + JP10""",
)

entry(
    index = 3040,
    label = "C/H3/Cd;C_rad/H/NonDeC_5ring_fused6_1",
    kinetics = ArrheniusEP(
        A = (0.000814, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK""",
)

entry(
    index = 3041,
    label = "C/H3/Cd;C_rad/Cs3_5ring_adj5",
    kinetics = ArrheniusEP(
        A = (0.000441, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK""",
)

entry(
    index = 3042,
    label = "C/H3/Cd;C_rad/H/NonDeC_5ring_alpha6ring",
    kinetics = ArrheniusEP(
        A = (0.000316, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK""",
)

entry(
    index = 3043,
    label = "C/H3/Cd;C_rad/H/NonDeC_5ring_beta6ring",
    kinetics = ArrheniusEP(
        A = (9.67e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK""",
)

entry(
    index = 3044,
    label = "C/H3/Cd;C_rad/H/NonDeC_5ring_fused6_2",
    kinetics = ArrheniusEP(
        A = (0.000441, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK""",
)

entry(
    index = 3045,
    label = "C/H3/Cd;C_rad/Cs3_5ring_fused6",
    kinetics = ArrheniusEP(
        A = (0.000441, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Aaron Vandeputte BMK""",
)

entry(
    index = 3046,
    label = "C/H2/CdCd;C_rad/H/NonDeC_5ring_fused6_1",
    kinetics = ArrheniusEP(
        A = (0.000814, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Estimated value""",
)

entry(
    index = 3047,
    label = "C/H2/CdCd;C_rad/Cs3_5ring_adj5",
    kinetics = ArrheniusEP(
        A = (0.000441, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Estimated value""",
)

entry(
    index = 3048,
    label = "C/H2/CdCd;C_rad/H/NonDeC_5ring_alpha6ring",
    kinetics = ArrheniusEP(
        A = (0.000316, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Estimated value""",
)

entry(
    index = 3049,
    label = "C/H2/CdCd;C_rad/H/NonDeC_5ring_beta6ring",
    kinetics = ArrheniusEP(
        A = (9.67e-05, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Estimated value""",
)

entry(
    index = 3050,
    label = "C/H2/CdCd;C_rad/Cs3_5ring_fused6",
    kinetics = ArrheniusEP(
        A = (0.000441, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Estimated value""",
)

entry(
    index = 3050,
    label = "C/H2/CdCd;C_rad/H/NonDeC_5ring_fused6_2",
    kinetics = ArrheniusEP(
        A = (0.000441, 'cm^3/(mol*s)'),
        n = 4.24,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Estimated value""",
)

entry(
    index = 3064,
    label = "C/H3/Cs\H\Cs\O;H_rad",
    kinetics = ArrheniusEP(
        A = (1.89e+06, 'cm^3/(mol*s)'),
        n = 2.21,
        alpha = 0,
        E0 = (7.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3065,
    label = "C/H/Cs2O;H_rad",
    kinetics = ArrheniusEP(
        A = (414000, 'cm^3/(mol*s)'),
        n = 2.34,
        alpha = 0,
        E0 = (2.68, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3066,
    label = "C/H3/Cs\H\Cs\O;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.473, 'cm^3/(mol*s)'),
        n = 3.6,
        alpha = 0,
        E0 = (11.05, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3067,
    label = "C/H/Cs2O;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.389, 'cm^3/(mol*s)'),
        n = 3.53,
        alpha = 0,
        E0 = (4.01, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3068,
    label = "C/H2/CdCs;H_rad",
    kinetics = ArrheniusEP(
        A = (22500, 'cm^3/(mol*s)'),
        n = 2.67,
        alpha = 0,
        E0 = (3.48, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3069,
    label = "C/H2/CdCs;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.102, 'cm^3/(mol*s)'),
        n = 3.99,
        alpha = 0,
        E0 = (6.27, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3070,
    label = "C/H3/Cd\H_Cd\H2;H_rad",
    kinetics = ArrheniusEP(
        A = (1120, 'cm^3/(mol*s)'),
        n = 3.14,
        alpha = 0,
        E0 = (4.29, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""same as rule 3072. ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3071,
    label = "C/H3/Cd\H_Cd\H\Cs;H_rad",
    kinetics = ArrheniusEP(
        A = (1120, 'cm^3/(mol*s)'),
        n = 3.14,
        alpha = 0,
        E0 = (4.29, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3072,
    label = "C/H3/Cd\H_Cd\H2;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.024, 'cm^3/(mol*s)'),
        n = 4.25,
        alpha = 0,
        E0 = (7.53, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""same as rule 3072. ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3073,
    label = "C/H3/Cd\H_Cd\H\Cs;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.024, 'cm^3/(mol*s)'),
        n = 4.25,
        alpha = 0,
        E0 = (7.53, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3074,
    label = "C/H3/Cd\Cs_Cd\H2;H_rad",
    kinetics = ArrheniusEP(
        A = (838, 'cm^3/(mol*s)'),
        n = 3.18,
        alpha = 0,
        E0 = (4.37, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3075,
    label = "C/H3/Cd\Cs_Cd\H2;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0198, 'cm^3/(mol*s)'),
        n = 4.26,
        alpha = 0,
        E0 = (7.55, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""MRH CBS-QB3 with 1-dHR corrections ref: doi: 10.1021/ie1005349""",
)

entry(
    index = 3076,
    label = "Cd/H/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (0.386, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Aaron Vandeputte GAVs CBS-QB3""",
)

entry(
    index = 3077,
    label = "Cd/H/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00915, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Aaron Vandeputte GAVs CBS-QB3""",
)

entry(
    index = 3078,
    label = "Cd/H/NonDeC;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Aaron Vandeputte GAVs CBS-QB3""",
)

entry(
    index = 3079,
    label = "Cd/H/NonDeC;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Aaron Vandeputte GAVs CBS-QB3""",
)

entry(
    index = 3080,
    label = "Cd/H/NonDeC;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""Aaron Vandeputte GAVs CBS-QB3""",
)

entry(
    index = 3081,
    label = "C/H2/CsO;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.16e+06, 'cm^3/(mol*s)'),
        n = 2.002,
        alpha = 0,
        E0 = (-0.113, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH + OH (communication from truhlar group) refitted to arrhenius form""",
)

entry(
    index = 3083,
    label = "C/H/Cs2/Cs\O;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (34760, 'cm^3/(mol*s)'),
        n = 2.458,
        alpha = 0,
        E0 = (-0.155, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH + OH (communication from truhlar group) refitted to arrhenius form""",
)

entry(
    index = 3085,
    label = "C/H3/Cs;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.3e+08, 'cm^3/(mol*s)'),
        n = 1.225,
        alpha = 0,
        E0 = (-0.467, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH + OH (communication from truhlar group) refitted to arrhenius form""",
)

entry(
    index = 3087,
    label = "O/H/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (33500, 'cm^3/(mol*s)'),
        n = 2.378,
        alpha = 0,
        E0 = (-0.881, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH + OH (communication from truhlar group) refitted to arrhenius form""",
)

entry(
    index = 3088,
    label = "O/H/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (0.293, 'cm^3/(mol*s)'),
        n = 4.14,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH AG Vandeputte CBS-QB3 1dHR """,
)

entry(
    index = 3090,
    label = "C/H2/CsO;H_rad",
    kinetics = ArrheniusEP(
        A = (2610, 'cm^3/(mol*s)'),
        n = 3.04,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH AG Vandeputte CBS-QB3 1dHR """,
)

entry(
    index = 3092,
    label = "C/H/Cs2/Cs\O;H_rad",
    kinetics = ArrheniusEP(
        A = (5760, 'cm^3/(mol*s)'),
        n = 3.02,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH AG Vandeputte CBS-QB3 1dHR """,
)

entry(
    index = 3094,
    label = "C/H3/Cs;H_rad",
    kinetics = ArrheniusEP(
        A = (1030, 'cm^3/(mol*s)'),
        n = 3.24,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH AG Vandeputte CBS-QB3 1dHR """,
)

entry(
    index = 3095,
    label = "C/H3/Cs;C_methyl",
    kinetics = ArrheniusEP(
        A = (7.48e-06, 'cm^3/(mol*s)'),
        n = 4.99,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH & iPtOH AG Vandeputte CBS-QB3 1dHR""",
)

entry(
    index = 3097,
    label = "C/H/Cs2/Cs\O;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0146, 'cm^3/(mol*s)'),
        n = 4.47,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH & iPtOH AG Vandeputte CBS-QB3 1dHR""",
)

entry(
    index = 3098,
    label = "C/H/Cs2/Cs\Cs|O;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0719, 'cm^3/(mol*s)'),
        n = 3.96,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH & iPtOH AG Vandeputte CBS-QB3 1dHR""",
    longDesc = u"""Value for ipentanol, x3 lower mainly because of gamma O restricting rotation of abstracting methyl""",
)

entry(
    index = 3099,
    label = "C/H2/CsO;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00124, 'cm^3/(mol*s)'),
        n = 4.44,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH & iPtOH AG Vandeputte CBS-QB3 1dHR""",
)

entry(
    index = 3101,
    label = "O/H/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00297, 'cm^3/(mol*s)'),
        n = 4.35,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""iBuOH & iPtOH AG Vandeputte CBS-QB3 1dHR""",
)

entry(
    index = 3102,
    label = "C/H3/Cs;Cd_Cd\H2_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00018, 'cm^3/(mol*s)'),
        n = 4.55,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""SSM CBS-QB3 with 1-dHR corrections""",
)

entry(
    index = 3104,
    label = "C/H/Cs2/Cs\O;Cd_Cd\H2_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.027, 'cm^3/(mol*s)'),
        n = 3.9,
        alpha = 0,
        E0 = (0.684, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""SSM CBS-QB3 with 1-dHR corrections""",
)

entry(
    index = 3106,
    label = "C/H2/CsO;Cd_Cd\H2_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.026, 'cm^3/(mol*s)'),
        n = 3.9,
        alpha = 0,
        E0 = (0.86, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 3,
    shortDesc = u"""SSM CBS-QB3 with 1-dHR corrections""",
)

entry(
    index = 3108,
    label = "C/H3/Cs;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (323, 'cm^3/(mol*s)'),
        n = 3.23,
        alpha = 0,
        E0 = (4.66, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""C2H5OH+O=OH+CH2CH2OH""",
    longDesc = """
iBuOH+O SSM estimates		 
Values for -alpha,-gamma,-O come from C2H5OH+O TST calculations:
C. W. Wu, Y. P. Lee, S. C. Xu, M. C. Lin, J. Phys. Chem. A 111 (2007) 6693-6703. 		 //!	C. W. Wu, Y. P. Lee, S. C. Xu, M. C. Lin, J. Phys. Chem. A 111 (2007) 6693-6703. 
-alpha is 2*k(C2H5OH+O=OH+CH2CH2OH)		
""",
)

entry(
    index = 3110,
    label = "C/H/Cs2/Cs\O;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (78000, 'cm^3/(mol*s)'),
        n = 2.5,
        alpha = 0,
        E0 = (1.11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""iso-butane + O = OH + tert-C4H9""",
)

entry(
    index = 3112,
    label = "C/H2/Cs\Cs2/O;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (72500, 'cm^3/(mol*s)'),
        n = 2.47,
        alpha = 0,
        E0 = (0.88, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""C2H5OH+O=OH+CH3CHOH""",
)

entry(
    index = 3114,
    label = "O/H/NonDeC;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (0.00146, 'cm^3/(mol*s)'),
        n = 4.73,
        alpha = 0,
        E0 = (1.73, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""C2H5OH+O=OH+CH3CH2O""",
)

entry(
    index = 3115,
    label = "H2O2;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (1.5, 'cm^3/(mol*s)'),
        n = 3.28,
        alpha = 0,
        E0 = (1.05, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM CBS-QB3 without 1-dHR corrections""",
)

entry(
    index = 3117,
    label = "H2O2;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (1.5, 'cm^3/(mol*s)'),
        n = 3.28,
        alpha = 0,
        E0 = (1.05, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""same as 3116""",
)

entry(
    index = 3119,
    label = "H2O2;C_rad/Cs2/Cs\O",
    kinetics = ArrheniusEP(
        A = (1.455, 'cm^3/(mol*s)'),
        n = 3.31,
        alpha = 0,
        E0 = (1.41, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM CBS-QB3 without 1-dHR corrections""",
)

entry(
    index = 3121,
    label = "H2O2;C_rad/H/CsO",
    kinetics = ArrheniusEP(
        A = (28.5, 'cm^3/(mol*s)'),
        n = 3.04,
        alpha = 0,
        E0 = (1.21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""SSM CBS-QB3 without 1-dHR corrections""",
)

entry(
    index = 3122,
    label = "O/H/NonDeC;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0395, 'cm^3/(mol*s)'),
        n = 4.19,
        alpha = 0,
        E0 = (-2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CCSD(T)-F12a/pVTZ with MS-VTST treatment for rotors""",
    longDesc = """Seal, Prasenjit Oyedepo, Gbenga Truhlar, Donald G
doi: 10.1021/jp310910f""",
)

entry(
    index = 3123,
    label = "C/H2/CsO;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (21550, 'cm^3/(mol*s)'),
        n = 2.6,
        alpha = 0,
        E0 = (-1.738, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CCSD(T)-F12a/pVTZ with MS-VTST treatment for rotors""",
    longDesc = """Seal, Prasenjit Oyedepo, Gbenga Truhlar, Donald G
doi: 10.1021/jp310910f""",
)

entry(
    index = 3124,
    label = "C/H2/Cs/Cs\O;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (84.5, 'cm^3/(mol*s)'),
        n = 3.43,
        alpha = 0,
        E0 = (1.74, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
)

entry(
    index = 3124,
    label = "C/H2/Cs/Cs\O;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (14.35, 'cm^3/(mol*s)'),
        n = 3.42,
        alpha = 0,
        E0 = (-1.255, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CCSD(T)-F12a/pVTZ with MS-VTST treatment for rotors""",
    longDesc = """Seal, Prasenjit Oyedepo, Gbenga Truhlar, Donald G
doi: 10.1021/jp310910f""",
)

entry(
    index = 3125,
    label = "C/H2/Cs/Cs\Cs|O;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (13, 'cm^3/(mol*s)'),
        n = 3.44,
        alpha = 0,
        E0 = (-2.442, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CCSD(T)-F12a/pVTZ with MS-VTST treatment for rotors""",
    longDesc = """Seal, Prasenjit Oyedepo, Gbenga Truhlar, Donald G
doi: 10.1021/jp310910f""",
)

entry(
    index = 3125,
    label = "C/H2/Cs/Cs\Cs|O;O_atom_triplet",
    kinetics = ArrheniusEP(
        A = (84.5, 'cm^3/(mol*s)'),
        n = 3.43,
        alpha = 0,
        E0 = (1.74, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
)

entry(
    index = 3126,
    label = "C/H3/Cs;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (4.77e+08, 'cm^3/(mol*s)'),
        n = 1.152,
        alpha = 0,
        E0 = (2.68, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CCSD(T)-F12a/pVTZ with MS-VTST treatment for rotors""",
)

entry(
    index = 4000,
    label = "H2;H_rad",
    kinetics = ArrheniusEP(
        A = (0.472, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4001,
    label = "H2;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4002,
    label = "H2;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00192, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4003,
    label = "H2;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00271, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4004,
    label = "H2;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00332, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4005,
    label = "H2;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0303, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4006,
    label = "H2;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4007,
    label = "H2;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00435, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4008,
    label = "H2;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0914, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (30.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4009,
    label = "H2;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.005, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (30.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4010,
    label = "H2;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4011,
    label = "H2;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00621, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4012,
    label = "H2;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00285, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4013,
    label = "H2;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0278, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4014,
    label = "H2;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.00136, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4015,
    label = "H2;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0281, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4016,
    label = "H2;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0145, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4017,
    label = "H2;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000865, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4018,
    label = "H2;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0121, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4019,
    label = "H2;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00832, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4020,
    label = "H2;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00557, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4021,
    label = "H2;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0154, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4022,
    label = "H2;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0343, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4023,
    label = "H2;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00131, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4023,
    label = "H2;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00448, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4024,
    label = "H2;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.0153, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4025,
    label = "H2;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0108, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4026,
    label = "H2;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0366, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4027,
    label = "H2;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0694, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4028,
    label = "H2;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.039, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4029,
    label = "H2;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0288, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4030,
    label = "H2;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0482, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4031,
    label = "H2;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0724, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4032,
    label = "H2;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.0113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4033,
    label = "H2;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.569, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (33.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4034,
    label = "H2;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.184, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (34.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4035,
    label = "H2;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0367, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4036,
    label = "H2;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0176, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4037,
    label = "H2;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0173, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4038,
    label = "H2;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00763, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4039,
    label = "H2;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0416, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4040,
    label = "H2;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0323, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4041,
    label = "H2;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0496, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4042,
    label = "H2;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0174, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4043,
    label = "H2;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0487, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 1,
        E0 = (20.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4044,
    label = "C_methane;H_rad",
    kinetics = ArrheniusEP(
        A = (0.219, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4045,
    label = "C_methane;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00518, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4046,
    label = "C_methane;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000889, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4047,
    label = "C_methane;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00125, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4048,
    label = "C_methane;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00154, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4049,
    label = "C_methane;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4050,
    label = "C_methane;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4051,
    label = "C_methane;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00201, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4052,
    label = "C_methane;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0423, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (33.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4053,
    label = "C_methane;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00231, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (33.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4054,
    label = "C_methane;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00716, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4055,
    label = "C_methane;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00287, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4056,
    label = "C_methane;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00132, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4057,
    label = "C_methane;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4058,
    label = "C_methane;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000631, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4059,
    label = "C_methane;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4060,
    label = "C_methane;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00669, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4061,
    label = "C_methane;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.0004, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4062,
    label = "C_methane;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00559, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4063,
    label = "C_methane;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00385, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4064,
    label = "C_methane;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4065,
    label = "C_methane;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00711, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4066,
    label = "C_methane;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0159, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4068,
    label = "C_methane;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000605, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4067,
    label = "C_methane;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00207, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4068,
    label = "C_methane;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00708, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4069,
    label = "C_methane;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00501, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4070,
    label = "C_methane;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0169, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4071,
    label = "C_methane;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4072,
    label = "C_methane;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0181, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (31.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4073,
    label = "C_methane;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0133, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4074,
    label = "C_methane;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0223, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4075,
    label = "C_methane;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0335, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4076,
    label = "C_methane;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00525, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4077,
    label = "C_methane;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.263, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (36.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4078,
    label = "C_methane;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0853, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (37.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4079,
    label = "C_methane;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.017, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4080,
    label = "C_methane;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00815, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4081,
    label = "C_methane;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00803, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4082,
    label = "C_methane;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00353, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4083,
    label = "C_methane;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0192, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4084,
    label = "C_methane;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.015, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4085,
    label = "C_methane;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4086,
    label = "C_methane;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00806, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4087,
    label = "C_methane;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0225, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4088,
    label = "C/H3/Cs;H_rad",
    kinetics = ArrheniusEP(
        A = (0.277, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4089,
    label = "C/H3/Cs;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00656, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4090,
    label = "C/H3/Cs;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00092, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4091,
    label = "C/H3/Cs;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4092,
    label = "C/H3/Cs;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4093,
    label = "C/H3/Cs;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0146, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4094,
    label = "C/H3/Cs;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.009, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4095,
    label = "C/H3/Cs;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.0014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4096,
    label = "C/H3/Cs;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0361, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4097,
    label = "C/H3/Cs;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00161, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4098,
    label = "C/H3/Cs;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00744, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4099,
    label = "C/H3/Cs;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00244, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4100,
    label = "C/H3/Cs;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000915, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4101,
    label = "C/H3/Cs;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.011, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4102,
    label = "C/H3/Cs;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.00044, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4103,
    label = "C/H3/Cs;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4104,
    label = "C/H3/Cs;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00568, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4105,
    label = "C/H3/Cs;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000278, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4106,
    label = "C/H3/Cs;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00708, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4107,
    label = "C/H3/Cs;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00398, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4108,
    label = "C/H3/Cs;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00327, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4109,
    label = "C/H3/Cs;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.009, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4112,
    label = "C/H3/Cs;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0165, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4110,
    label = "C/H3/Cs;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000767, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4111,
    label = "C/H3/Cs;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00253, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4112,
    label = "C/H3/Cs;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00706, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4113,
    label = "C/H3/Cs;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00408, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4114,
    label = "C/H3/Cs;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0147, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4115,
    label = "C/H3/Cs;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0227, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4116,
    label = "C/H3/Cs;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0104, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4117,
    label = "C/H3/Cs;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0115, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4118,
    label = "C/H3/Cs;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0283, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4119,
    label = "C/H3/Cs;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0336, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4120,
    label = "C/H3/Cs;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.0043, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4121,
    label = "C/H3/Cs;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.22, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (31.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4122,
    label = "C/H3/Cs;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0582, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (32.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4123,
    label = "C/H3/Cs;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.017, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4124,
    label = "C/H3/Cs;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00667, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4125,
    label = "C/H3/Cs;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00804, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4126,
    label = "C/H3/Cs;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00289, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4127,
    label = "C/H3/Cs;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0244, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4128,
    label = "C/H3/Cs;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4129,
    label = "C/H3/Cs;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.028, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4130,
    label = "C/H3/Cs;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0102, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4131,
    label = "C/H3/Cs;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0286, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4132,
    label = "C/H2/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (0.339, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4133,
    label = "C/H2/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00803, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4134,
    label = "C/H2/NonDeC;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00092, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4135,
    label = "C/H2/NonDeC;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000865, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4136,
    label = "C/H2/NonDeC;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000708, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4137,
    label = "C/H2/NonDeC;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0146, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4138,
    label = "C/H2/NonDeC;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00738, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4139,
    label = "C/H2/NonDeC;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000935, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4140,
    label = "C/H2/NonDeC;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0297, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4141,
    label = "C/H2/NonDeC;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00108, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4142,
    label = "C/H2/NonDeC;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00747, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4143,
    label = "C/H2/NonDeC;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.002, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4144,
    label = "C/H2/NonDeC;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000613, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4145,
    label = "C/H2/NonDeC;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00902, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4146,
    label = "C/H2/NonDeC;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000296, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4147,
    label = "C/H2/NonDeC;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0136, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4148,
    label = "C/H2/NonDeC;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00466, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4149,
    label = "C/H2/NonDeC;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000186, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4150,
    label = "C/H2/NonDeC;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00866, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4151,
    label = "C/H2/NonDeC;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00398, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4152,
    label = "C/H2/NonDeC;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.004, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4153,
    label = "C/H2/NonDeC;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.011, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4157,
    label = "C/H2/NonDeC;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0166, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4154,
    label = "C/H2/NonDeC;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000939, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4155,
    label = "C/H2/NonDeC;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00298, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4156,
    label = "C/H2/NonDeC;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00681, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4157,
    label = "C/H2/NonDeC;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4158,
    label = "C/H2/NonDeC;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0123, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4159,
    label = "C/H2/NonDeC;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4160,
    label = "C/H2/NonDeC;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00582, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4161,
    label = "C/H2/NonDeC;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00965, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4162,
    label = "C/H2/NonDeC;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0346, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4163,
    label = "C/H2/NonDeC;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0325, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4164,
    label = "C/H2/NonDeC;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.0034, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4165,
    label = "C/H2/NonDeC;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.177, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4166,
    label = "C/H2/NonDeC;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0383, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4167,
    label = "C/H2/NonDeC;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0165, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4168,
    label = "C/H2/NonDeC;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00528, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4169,
    label = "C/H2/NonDeC;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00778, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4170,
    label = "C/H2/NonDeC;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4171,
    label = "C/H2/NonDeC;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0298, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4172,
    label = "C/H2/NonDeC;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4173,
    label = "C/H2/NonDeC;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.033, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4174,
    label = "C/H2/NonDeC;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0125, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4175,
    label = "C/H2/NonDeC;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.035, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4176,
    label = "C/H/Cs3;H_rad",
    kinetics = ArrheniusEP(
        A = (0.476, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4177,
    label = "C/H/Cs3;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4178,
    label = "C/H/Cs3;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4179,
    label = "C/H/Cs3;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000811, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4180,
    label = "C/H/Cs3;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000542, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4181,
    label = "C/H/Cs3;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0169, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4182,
    label = "C/H/Cs3;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00695, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4183,
    label = "C/H/Cs3;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000719, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4184,
    label = "C/H/Cs3;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0281, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4185,
    label = "C/H/Cs3;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000837, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4186,
    label = "C/H/Cs3;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00862, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4187,
    label = "C/H/Cs3;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00189, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4188,
    label = "C/H/Cs3;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000471, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4189,
    label = "C/H/Cs3;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00854, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4190,
    label = "C/H/Cs3;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4191,
    label = "C/H/Cs3;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0157, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4192,
    label = "C/H/Cs3;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00439, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4193,
    label = "C/H/Cs3;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000143, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4194,
    label = "C/H/Cs3;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0122, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4195,
    label = "C/H/Cs3;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00457, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4196,
    label = "C/H/Cs3;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00562, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4197,
    label = "C/H/Cs3;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4202,
    label = "C/H/Cs3;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0191, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4198,
    label = "C/H/Cs3;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00132, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4199,
    label = "C/H/Cs3;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00404, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4200,
    label = "C/H/Cs3;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00753, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4201,
    label = "C/H/Cs3;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0029, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4202,
    label = "C/H/Cs3;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4203,
    label = "C/H/Cs3;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0122, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4204,
    label = "C/H/Cs3;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00373, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4205,
    label = "C/H/Cs3;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00927, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4206,
    label = "C/H/Cs3;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0487, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4207,
    label = "C/H/Cs3;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0361, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4208,
    label = "C/H/Cs3;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00308, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4209,
    label = "C/H/Cs3;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.164, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4210,
    label = "C/H/Cs3;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.029, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4211,
    label = "C/H/Cs3;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0183, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4212,
    label = "C/H/Cs3;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00479, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4213,
    label = "C/H/Cs3;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00865, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4214,
    label = "C/H/Cs3;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00207, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4215,
    label = "C/H/Cs3;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0419, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4216,
    label = "C/H/Cs3;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0178, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4217,
    label = "C/H/Cs3;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0448, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4218,
    label = "C/H/Cs3;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0176, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4219,
    label = "C/H/Cs3;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0492, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4220,
    label = "C/H3/Cd;H_rad",
    kinetics = ArrheniusEP(
        A = (0.0869, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4221,
    label = "C/H3/Cd;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00206, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4222,
    label = "C/H3/Cd;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00029, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4223,
    label = "C/H3/Cd;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000336, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4224,
    label = "C/H3/Cd;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000338, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4225,
    label = "C/H3/Cd;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00145, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4226,
    label = "C/H3/Cd;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000897, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4227,
    label = "C/H3/Cd;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4228,
    label = "C/H3/Cd;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4229,
    label = "C/H3/Cd;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (5.07e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4230,
    label = "C/H3/Cd;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000739, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4231,
    label = "C/H3/Cd;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000243, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4232,
    label = "C/H3/Cd;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (9.16e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4233,
    label = "C/H3/Cd;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000344, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4234,
    label = "C/H3/Cd;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.39e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4235,
    label = "C/H3/Cd;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00134, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4236,
    label = "C/H3/Cd;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000566, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4237,
    label = "C/H3/Cd;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.78e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4238,
    label = "C/H3/Cd;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00222, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4239,
    label = "C/H3/Cd;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00126, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4240,
    label = "C/H3/Cd;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00103, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4241,
    label = "C/H3/Cd;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00283, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4247,
    label = "C/H3/Cd;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00164, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4242,
    label = "C/H3/Cd;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000241, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4243,
    label = "C/H3/Cd;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000652, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4244,
    label = "C/H3/Cd;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00183, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4245,
    label = "C/H3/Cd;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4246,
    label = "C/H3/Cd;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00104, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4247,
    label = "C/H3/Cd;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00162, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4248,
    label = "C/H3/Cd;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000747, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4249,
    label = "C/H3/Cd;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000818, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4250,
    label = "C/H3/Cd;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.00888, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4251,
    label = "C/H3/Cd;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00273, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4252,
    label = "C/H3/Cd;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000351, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4253,
    label = "C/H3/Cd;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4254,
    label = "C/H3/Cd;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0034, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4255,
    label = "C/H3/Cd;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4256,
    label = "C/H3/Cd;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000546, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4257,
    label = "C/H3/Cd;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000655, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4258,
    label = "C/H3/Cd;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000236, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4259,
    label = "C/H3/Cd;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00765, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4260,
    label = "C/H3/Cd;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00488, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4261,
    label = "C/H3/Cd;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00722, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4262,
    label = "C/H3/Cd;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4263,
    label = "C/H3/Cd;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00897, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4264,
    label = "C/H2/CdCs;H_rad",
    kinetics = ArrheniusEP(
        A = (0.331, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4265,
    label = "C/H2/CdCs;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00785, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4266,
    label = "C/H2/CdCs;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000903, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4267,
    label = "C/H2/CdCs;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000853, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4268,
    label = "C/H2/CdCs;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000701, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4269,
    label = "C/H2/CdCs;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00452, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4270,
    label = "C/H2/CdCs;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4271,
    label = "C/H2/CdCs;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000291, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4272,
    label = "C/H2/CdCs;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0029, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4273,
    label = "C/H2/CdCs;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4274,
    label = "C/H2/CdCs;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00231, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4275,
    label = "C/H2/CdCs;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000621, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4276,
    label = "C/H2/CdCs;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000191, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4277,
    label = "C/H2/CdCs;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000881, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4278,
    label = "C/H2/CdCs;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (2.9e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4279,
    label = "C/H2/CdCs;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00419, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4280,
    label = "C/H2/CdCs;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00144, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4281,
    label = "C/H2/CdCs;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (5.8e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4282,
    label = "C/H2/CdCs;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00846, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4283,
    label = "C/H2/CdCs;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00391, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4284,
    label = "C/H2/CdCs;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00391, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4285,
    label = "C/H2/CdCs;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0108, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4292,
    label = "C/H2/CdCs;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00512, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4286,
    label = "C/H2/CdCs;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000917, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4287,
    label = "C/H2/CdCs;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00239, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4288,
    label = "C/H2/CdCs;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00548, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4289,
    label = "C/H2/CdCs;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0026, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4290,
    label = "C/H2/CdCs;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00271, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4291,
    label = "C/H2/CdCs;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00344, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4292,
    label = "C/H2/CdCs;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4293,
    label = "C/H2/CdCs;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00213, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4294,
    label = "C/H2/CdCs;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0338, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4295,
    label = "C/H2/CdCs;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00823, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4296,
    label = "C/H2/CdCs;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000865, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4297,
    label = "C/H2/CdCs;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4298,
    label = "C/H2/CdCs;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00697, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4299,
    label = "C/H2/CdCs;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00418, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4300,
    label = "C/H2/CdCs;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00134, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4301,
    label = "C/H2/CdCs;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00197, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4302,
    label = "C/H2/CdCs;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000582, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4303,
    label = "C/H2/CdCs;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0292, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4304,
    label = "C/H2/CdCs;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0152, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4305,
    label = "C/H2/CdCs;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0265, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4306,
    label = "C/H2/CdCs;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0122, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4307,
    label = "C/H2/CdCs;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0342, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4308,
    label = "C/H/Cs2Cd;H_rad",
    kinetics = ArrheniusEP(
        A = (0.248, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4309,
    label = "C/H/Cs2Cd;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00587, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4310,
    label = "C/H/Cs2Cd;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000552, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4311,
    label = "C/H/Cs2Cd;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000426, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4312,
    label = "C/H/Cs2Cd;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000286, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4313,
    label = "C/H/Cs2Cd;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00278, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4314,
    label = "C/H/Cs2Cd;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00115, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4315,
    label = "C/H/Cs2Cd;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000119, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4316,
    label = "C/H/Cs2Cd;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00146, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4317,
    label = "C/H/Cs2Cd;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (4.37e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4318,
    label = "C/H/Cs2Cd;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00142, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4319,
    label = "C/H/Cs2Cd;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000311, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4320,
    label = "C/H/Cs2Cd;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (7.82e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4321,
    label = "C/H/Cs2Cd;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000444, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4322,
    label = "C/H/Cs2Cd;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.19e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4323,
    label = "C/H/Cs2Cd;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4324,
    label = "C/H/Cs2Cd;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000724, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4325,
    label = "C/H/Cs2Cd;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.37e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4326,
    label = "C/H/Cs2Cd;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00633, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4327,
    label = "C/H/Cs2Cd;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00239, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4328,
    label = "C/H/Cs2Cd;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00292, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4329,
    label = "C/H/Cs2Cd;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00806, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4330,
    label = "C/H/Cs2Cd;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00314, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4338,
    label = "C/H/Cs2Cd;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000686, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4331,
    label = "C/H/Cs2Cd;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00173, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4332,
    label = "C/H/Cs2Cd;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00323, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4333,
    label = "C/H/Cs2Cd;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00125, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4334,
    label = "C/H/Cs2Cd;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4335,
    label = "C/H/Cs2Cd;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00144, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4336,
    label = "C/H/Cs2Cd;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000443, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4337,
    label = "C/H/Cs2Cd;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4338,
    label = "C/H/Cs2Cd;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0253, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4339,
    label = "C/H/Cs2Cd;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00487, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4340,
    label = "C/H/Cs2Cd;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000418, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4341,
    label = "C/H/Cs2Cd;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0158, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4342,
    label = "C/H/Cs2Cd;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00281, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4343,
    label = "C/H/Cs2Cd;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00247, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4344,
    label = "C/H/Cs2Cd;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000649, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4345,
    label = "C/H/Cs2Cd;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00117, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4346,
    label = "C/H/Cs2Cd;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000281, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4347,
    label = "C/H/Cs2Cd;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0218, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4348,
    label = "C/H/Cs2Cd;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00929, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4349,
    label = "C/H/Cs2Cd;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0191, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4350,
    label = "C/H/Cs2Cd;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00914, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4351,
    label = "C/H/Cs2Cd;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0256, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4352,
    label = "C/H2/CdCd;H_rad",
    kinetics = ArrheniusEP(
        A = (0.447, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4353,
    label = "C/H2/CdCd;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4354,
    label = "C/H2/CdCd;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00122, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4355,
    label = "C/H2/CdCd;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00116, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4356,
    label = "C/H2/CdCd;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000958, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4357,
    label = "C/H2/CdCd;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00193, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4358,
    label = "C/H2/CdCd;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000981, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4359,
    label = "C/H2/CdCd;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000125, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4360,
    label = "C/H2/CdCd;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000391, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4361,
    label = "C/H2/CdCd;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (1.44e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4362,
    label = "C/H2/CdCd;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000984, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4363,
    label = "C/H2/CdCd;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000266, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4364,
    label = "C/H2/CdCd;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (8.22e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4365,
    label = "C/H2/CdCd;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000119, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4366,
    label = "C/H2/CdCd;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (3.93e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4367,
    label = "C/H2/CdCd;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00179, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4368,
    label = "C/H2/CdCd;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000619, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4369,
    label = "C/H2/CdCd;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.49e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4370,
    label = "C/H2/CdCd;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0114, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4371,
    label = "C/H2/CdCd;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.0053, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4372,
    label = "C/H2/CdCd;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00527, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4373,
    label = "C/H2/CdCd;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0145, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4382,
    label = "C/H2/CdCd;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00218, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4374,
    label = "C/H2/CdCd;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00124, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4375,
    label = "C/H2/CdCd;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00265, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4376,
    label = "C/H2/CdCd;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00609, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4377,
    label = "C/H2/CdCd;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0029, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4378,
    label = "C/H2/CdCd;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000825, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4379,
    label = "C/H2/CdCd;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4380,
    label = "C/H2/CdCd;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000399, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4381,
    label = "C/H2/CdCd;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000649, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4382,
    label = "C/H2/CdCd;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0456, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4383,
    label = "C/H2/CdCd;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00288, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4384,
    label = "C/H2/CdCd;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000304, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4385,
    label = "C/H2/CdCd;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00803, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4386,
    label = "C/H2/CdCd;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00175, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4387,
    label = "C/H2/CdCd;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00146, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4388,
    label = "C/H2/CdCd;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000472, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4389,
    label = "C/H2/CdCd;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00069, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4390,
    label = "C/H2/CdCd;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000205, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4391,
    label = "C/H2/CdCd;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0393, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4392,
    label = "C/H2/CdCd;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0206, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4393,
    label = "C/H2/CdCd;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0293, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4394,
    label = "C/H2/CdCd;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0165, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4395,
    label = "C/H2/CdCd;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0461, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4396,
    label = "C/H/CdCd;H_rad",
    kinetics = ArrheniusEP(
        A = (0.221, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4397,
    label = "C/H/CdCd;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00524, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4398,
    label = "C/H/CdCd;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000495, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4399,
    label = "C/H/CdCd;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000384, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4400,
    label = "C/H/CdCd;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000259, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4401,
    label = "C/H/CdCd;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.000784, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4402,
    label = "C/H/CdCd;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000326, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4403,
    label = "C/H/CdCd;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (3.4e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4404,
    label = "C/H/CdCd;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4405,
    label = "C/H/CdCd;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (3.92e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4406,
    label = "C/H/CdCd;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0004, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4407,
    label = "C/H/CdCd;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (8.83e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4408,
    label = "C/H/CdCd;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (2.23e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4409,
    label = "C/H/CdCd;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (3.96e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4410,
    label = "C/H/CdCd;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.07e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4411,
    label = "C/H/CdCd;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.000727, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4412,
    label = "C/H/CdCd;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000205, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4413,
    label = "C/H/CdCd;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (6.76e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4414,
    label = "C/H/CdCd;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00565, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4415,
    label = "C/H/CdCd;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00214, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4416,
    label = "C/H/CdCd;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00261, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4417,
    label = "C/H/CdCd;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00719, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4427,
    label = "C/H/CdCd;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.000887, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4418,
    label = "C/H/CdCd;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000613, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4419,
    label = "C/H/CdCd;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00126, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4420,
    label = "C/H/CdCd;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00238, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4421,
    label = "C/H/CdCd;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000924, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4422,
    label = "C/H/CdCd;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00028, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4423,
    label = "C/H/CdCd;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000291, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4424,
    label = "C/H/CdCd;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (9.01e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4425,
    label = "C/H/CdCd;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00022, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-16.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4426,
    label = "C/H/CdCd;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0226, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4427,
    label = "C/H/CdCd;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4428,
    label = "C/H/CdCd;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (9.72e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4429,
    label = "C/H/CdCd;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00262, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4430,
    label = "C/H/CdCd;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.000467, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4431,
    label = "C/H/CdCd;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000573, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4432,
    label = "C/H/CdCd;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000151, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4433,
    label = "C/H/CdCd;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00027, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4434,
    label = "C/H/CdCd;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (6.54e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4435,
    label = "C/H/CdCd;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0195, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4436,
    label = "C/H/CdCd;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00833, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4437,
    label = "C/H/CdCd;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4438,
    label = "C/H/CdCd;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00816, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4439,
    label = "C/H/CdCd;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0228, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4440,
    label = "C/H3/Ct;H_rad",
    kinetics = ArrheniusEP(
        A = (0.271, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4441,
    label = "C/H3/Ct;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00641, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4442,
    label = "C/H3/Ct;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000903, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4443,
    label = "C/H3/Ct;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4444,
    label = "C/H3/Ct;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4445,
    label = "C/H3/Ct;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00451, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4446,
    label = "C/H3/Ct;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00279, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4447,
    label = "C/H3/Ct;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000435, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4448,
    label = "C/H3/Ct;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00352, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4449,
    label = "C/H3/Ct;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000158, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4450,
    label = "C/H3/Ct;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00571, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4451,
    label = "C/H3/Ct;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00188, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4452,
    label = "C/H3/Ct;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000708, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4453,
    label = "C/H3/Ct;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00659, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4454,
    label = "C/H3/Ct;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000266, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4455,
    label = "C/H3/Ct;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00418, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4456,
    label = "C/H3/Ct;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00176, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4457,
    label = "C/H3/Ct;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (8.65e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4458,
    label = "C/H3/Ct;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00692, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4459,
    label = "C/H3/Ct;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00391, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4460,
    label = "C/H3/Ct;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00319, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4461,
    label = "C/H3/Ct;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0088, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4472,
    label = "C/H3/Ct;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0051, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4462,
    label = "C/H3/Ct;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00075, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4463,
    label = "C/H3/Ct;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00203, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4464,
    label = "C/H3/Ct;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00569, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4465,
    label = "C/H3/Ct;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0033, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4466,
    label = "C/H3/Ct;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00445, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4467,
    label = "C/H3/Ct;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00692, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4468,
    label = "C/H3/Ct;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00319, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4469,
    label = "C/H3/Ct;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0035, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4470,
    label = "C/H3/Ct;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0276, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4471,
    label = "C/H3/Ct;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00851, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4472,
    label = "C/H3/Ct;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4473,
    label = "C/H3/Ct;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0547, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4474,
    label = "C/H3/Ct;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0145, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4475,
    label = "C/H3/Ct;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0107, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4476,
    label = "C/H3/Ct;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00422, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4477,
    label = "C/H3/Ct;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00204, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4478,
    label = "C/H3/Ct;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000736, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4479,
    label = "C/H3/Ct;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0238, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4480,
    label = "C/H3/Ct;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0152, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4481,
    label = "C/H3/Ct;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0225, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4482,
    label = "C/H3/Ct;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00998, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4483,
    label = "C/H3/Ct;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0279, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4484,
    label = "C/H2/CtCs;H_rad",
    kinetics = ArrheniusEP(
        A = (0.358, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4485,
    label = "C/H2/CtCs;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00847, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4486,
    label = "C/H2/CtCs;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000975, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4487,
    label = "C/H2/CtCs;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000921, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4488,
    label = "C/H2/CtCs;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000757, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4489,
    label = "C/H2/CtCs;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00488, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4490,
    label = "C/H2/CtCs;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00247, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4491,
    label = "C/H2/CtCs;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000314, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4492,
    label = "C/H2/CtCs;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00313, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4493,
    label = "C/H2/CtCs;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000115, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4494,
    label = "C/H2/CtCs;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00619, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4495,
    label = "C/H2/CtCs;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00166, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4496,
    label = "C/H2/CtCs;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000512, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4497,
    label = "C/H2/CtCs;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00586, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4498,
    label = "C/H2/CtCs;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000193, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4499,
    label = "C/H2/CtCs;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00453, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4500,
    label = "C/H2/CtCs;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00156, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4501,
    label = "C/H2/CtCs;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (6.26e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4502,
    label = "C/H2/CtCs;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00914, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4503,
    label = "C/H2/CtCs;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00422, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4504,
    label = "C/H2/CtCs;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00422, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4505,
    label = "C/H2/CtCs;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0116, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4517,
    label = "C/H2/CtCs;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00552, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4506,
    label = "C/H2/CtCs;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00099, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4507,
    label = "C/H2/CtCs;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4508,
    label = "C/H2/CtCs;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00592, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4509,
    label = "C/H2/CtCs;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0028, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4510,
    label = "C/H2/CtCs;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00402, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4511,
    label = "C/H2/CtCs;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00511, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4512,
    label = "C/H2/CtCs;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00192, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4513,
    label = "C/H2/CtCs;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00316, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4514,
    label = "C/H2/CtCs;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0365, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4515,
    label = "C/H2/CtCs;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00889, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4516,
    label = "C/H2/CtCs;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000934, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4517,
    label = "C/H2/CtCs;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0476, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4518,
    label = "C/H2/CtCs;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0103, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4519,
    label = "C/H2/CtCs;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4520,
    label = "C/H2/CtCs;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0036, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4521,
    label = "C/H2/CtCs;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00213, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4522,
    label = "C/H2/CtCs;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000628, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4523,
    label = "C/H2/CtCs;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0315, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4524,
    label = "C/H2/CtCs;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0164, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4525,
    label = "C/H2/CtCs;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0286, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4526,
    label = "C/H2/CtCs;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0132, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4527,
    label = "C/H2/CtCs;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0369, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4528,
    label = "C/H/Cs2Ct;H_rad",
    kinetics = ArrheniusEP(
        A = (0.414, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4529,
    label = "C/H/Cs2Ct;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0098, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4530,
    label = "C/H/Cs2Ct;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000921, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4531,
    label = "C/H/Cs2Ct;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000711, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4532,
    label = "C/H/Cs2Ct;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000477, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4533,
    label = "C/H/Cs2Ct;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00463, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4534,
    label = "C/H/Cs2Ct;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00192, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4535,
    label = "C/H/Cs2Ct;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000199, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4536,
    label = "C/H/Cs2Ct;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00244, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4537,
    label = "C/H/Cs2Ct;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (7.3e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4538,
    label = "C/H/Cs2Ct;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00587, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4539,
    label = "C/H/Cs2Ct;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00129, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4540,
    label = "C/H/Cs2Ct;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000324, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4541,
    label = "C/H/Cs2Ct;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00456, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4542,
    label = "C/H/Cs2Ct;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000123, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4543,
    label = "C/H/Cs2Ct;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0043, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4544,
    label = "C/H/Cs2Ct;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00121, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4545,
    label = "C/H/Cs2Ct;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (3.96e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4546,
    label = "C/H/Cs2Ct;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4547,
    label = "C/H/Cs2Ct;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00399, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4548,
    label = "C/H/Cs2Ct;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00488, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4549,
    label = "C/H/Cs2Ct;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0134, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4562,
    label = "C/H/Cs2Ct;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00524, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4550,
    label = "C/H/Cs2Ct;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00115, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4551,
    label = "C/H/Cs2Ct;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00288, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4552,
    label = "C/H/Cs2Ct;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00539, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4553,
    label = "C/H/Cs2Ct;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00209, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4554,
    label = "C/H/Cs2Ct;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00318, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4555,
    label = "C/H/Cs2Ct;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0033, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4556,
    label = "C/H/Cs2Ct;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00101, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4557,
    label = "C/H/Cs2Ct;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0025, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4558,
    label = "C/H/Cs2Ct;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0422, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4559,
    label = "C/H/Cs2Ct;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00813, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4560,
    label = "C/H/Cs2Ct;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000697, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4561,
    label = "C/H/Cs2Ct;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0363, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4562,
    label = "C/H/Cs2Ct;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00643, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4563,
    label = "C/H/Cs2Ct;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0102, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4564,
    label = "C/H/Cs2Ct;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00269, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4565,
    label = "C/H/Cs2Ct;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00195, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4566,
    label = "C/H/Cs2Ct;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000469, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4567,
    label = "C/H/Cs2Ct;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0364, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4568,
    label = "C/H/Cs2Ct;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4569,
    label = "C/H/Cs2Ct;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0319, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4570,
    label = "C/H/Cs2Ct;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0153, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4571,
    label = "C/H/Cs2Ct;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0427, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4572,
    label = "C/H2/CtCt;H_rad",
    kinetics = ArrheniusEP(
        A = (0.399, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4573,
    label = "C/H2/CtCt;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00946, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4574,
    label = "C/H2/CtCt;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4575,
    label = "C/H2/CtCt;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00104, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4576,
    label = "C/H2/CtCt;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000857, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4577,
    label = "C/H2/CtCt;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00172, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4578,
    label = "C/H2/CtCt;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000877, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4579,
    label = "C/H2/CtCt;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4580,
    label = "C/H2/CtCt;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00035, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4581,
    label = "C/H2/CtCt;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (1.29e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4582,
    label = "C/H2/CtCt;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00542, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4583,
    label = "C/H2/CtCt;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00147, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4584,
    label = "C/H2/CtCt;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000453, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4585,
    label = "C/H2/CtCt;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00403, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4586,
    label = "C/H2/CtCt;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000134, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4587,
    label = "C/H2/CtCt;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0016, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4588,
    label = "C/H2/CtCt;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000553, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4589,
    label = "C/H2/CtCt;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.23e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4590,
    label = "C/H2/CtCt;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0102, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4591,
    label = "C/H2/CtCt;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00473, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4592,
    label = "C/H2/CtCt;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00471, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4593,
    label = "C/H2/CtCt;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4607,
    label = "C/H2/CtCt;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00195, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4594,
    label = "C/H2/CtCt;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00111, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4595,
    label = "C/H2/CtCt;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00237, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4596,
    label = "C/H2/CtCt;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00545, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4597,
    label = "C/H2/CtCt;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00259, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4598,
    label = "C/H2/CtCt;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4599,
    label = "C/H2/CtCt;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00178, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4600,
    label = "C/H2/CtCt;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000672, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4601,
    label = "C/H2/CtCt;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-9.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4602,
    label = "C/H2/CtCt;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0408, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4603,
    label = "C/H2/CtCt;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4604,
    label = "C/H2/CtCt;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000272, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4605,
    label = "C/H2/CtCt;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4606,
    label = "C/H2/CtCt;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00295, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4607,
    label = "C/H2/CtCt;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00806, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4608,
    label = "C/H2/CtCt;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0026, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4609,
    label = "C/H2/CtCt;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000617, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4610,
    label = "C/H2/CtCt;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000183, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4611,
    label = "C/H2/CtCt;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0352, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4612,
    label = "C/H2/CtCt;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0184, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4613,
    label = "C/H2/CtCt;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0262, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4614,
    label = "C/H2/CtCt;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0147, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4615,
    label = "C/H2/CtCt;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0412, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4616,
    label = "C/H/CtCt;H_rad",
    kinetics = ArrheniusEP(
        A = (0.44, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4617,
    label = "C/H/CtCt;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0104, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4618,
    label = "C/H/CtCt;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000985, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4619,
    label = "C/H/CtCt;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000764, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4620,
    label = "C/H/CtCt;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000515, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4621,
    label = "C/H/CtCt;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00156, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4622,
    label = "C/H/CtCt;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000648, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4623,
    label = "C/H/CtCt;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (6.76e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4624,
    label = "C/H/CtCt;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00026, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4625,
    label = "C/H/CtCt;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (7.8e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4626,
    label = "C/H/CtCt;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00491, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4627,
    label = "C/H/CtCt;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00108, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4628,
    label = "C/H/CtCt;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000273, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4629,
    label = "C/H/CtCt;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00299, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4630,
    label = "C/H/CtCt;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (8.1e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4631,
    label = "C/H/CtCt;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00145, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4632,
    label = "C/H/CtCt;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000409, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4633,
    label = "C/H/CtCt;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (1.35e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4634,
    label = "C/H/CtCt;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4635,
    label = "C/H/CtCt;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00426, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4636,
    label = "C/H/CtCt;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00519, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4637,
    label = "C/H/CtCt;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0143, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-6.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4652,
    label = "C/H/CtCt;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00177, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4638,
    label = "C/H/CtCt;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00122, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4639,
    label = "C/H/CtCt;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00252, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4640,
    label = "C/H/CtCt;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00473, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4641,
    label = "C/H/CtCt;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00184, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4642,
    label = "C/H/CtCt;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4643,
    label = "C/H/CtCt;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4644,
    label = "C/H/CtCt;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000338, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4645,
    label = "C/H/CtCt;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000825, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4646,
    label = "C/H/CtCt;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.045, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4647,
    label = "C/H/CtCt;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00225, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4648,
    label = "C/H/CtCt;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000194, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4649,
    label = "C/H/CtCt;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00985, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4650,
    label = "C/H/CtCt;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00175, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4651,
    label = "C/H/CtCt;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00703, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4652,
    label = "C/H/CtCt;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00185, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4653,
    label = "C/H/CtCt;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000538, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4654,
    label = "C/H/CtCt;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4655,
    label = "C/H/CtCt;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0388, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4656,
    label = "C/H/CtCt;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0166, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4657,
    label = "C/H/CtCt;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0279, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4658,
    label = "C/H/CtCt;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0162, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4659,
    label = "C/H/CtCt;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0454, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4660,
    label = "C/H3/Cb;H_rad",
    kinetics = ArrheniusEP(
        A = (0.0738, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4661,
    label = "C/H3/Cb;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00175, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4662,
    label = "C/H3/Cb;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000246, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4663,
    label = "C/H3/Cb;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000285, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4664,
    label = "C/H3/Cb;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000287, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4665,
    label = "C/H3/Cb;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00123, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4666,
    label = "C/H3/Cb;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000761, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4667,
    label = "C/H3/Cb;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000119, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4668,
    label = "C/H3/Cb;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00096, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4669,
    label = "C/H3/Cb;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (4.31e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4670,
    label = "C/H3/Cb;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000627, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4671,
    label = "C/H3/Cb;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000206, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4672,
    label = "C/H3/Cb;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (7.77e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4673,
    label = "C/H3/Cb;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000292, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4674,
    label = "C/H3/Cb;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.18e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4675,
    label = "C/H3/Cb;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00114, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4676,
    label = "C/H3/Cb;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00048, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4677,
    label = "C/H3/Cb;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.36e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4678,
    label = "C/H3/Cb;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00188, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4679,
    label = "C/H3/Cb;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00107, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4680,
    label = "C/H3/Cb;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00087, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4681,
    label = "C/H3/Cb;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0024, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4697,
    label = "C/H3/Cb;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4682,
    label = "C/H3/Cb;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000204, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4683,
    label = "C/H3/Cb;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000553, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4684,
    label = "C/H3/Cb;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4685,
    label = "C/H3/Cb;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0009, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4686,
    label = "C/H3/Cb;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000883, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4687,
    label = "C/H3/Cb;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00137, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4688,
    label = "C/H3/Cb;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000633, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4689,
    label = "C/H3/Cb;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000694, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4690,
    label = "C/H3/Cb;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.00753, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4691,
    label = "C/H3/Cb;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00232, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4692,
    label = "C/H3/Cb;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000298, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4693,
    label = "C/H3/Cb;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4694,
    label = "C/H3/Cb;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00288, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4695,
    label = "C/H3/Cb;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4696,
    label = "C/H3/Cb;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000463, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4697,
    label = "C/H3/Cb;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000556, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4698,
    label = "C/H3/Cb;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000201, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4699,
    label = "C/H3/Cb;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00649, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4700,
    label = "C/H3/Cb;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00414, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4701,
    label = "C/H3/Cb;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00612, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4702,
    label = "C/H3/Cb;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00272, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4703,
    label = "C/H3/Cb;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00761, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4704,
    label = "C/H2/CbCs;H_rad",
    kinetics = ArrheniusEP(
        A = (0.109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4705,
    label = "C/H2/CbCs;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4706,
    label = "C/H2/CbCs;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000297, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4707,
    label = "C/H2/CbCs;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000281, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4708,
    label = "C/H2/CbCs;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00023, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4709,
    label = "C/H2/CbCs;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00149, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4710,
    label = "C/H2/CbCs;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000753, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4711,
    label = "C/H2/CbCs;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (9.58e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4712,
    label = "C/H2/CbCs;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000954, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4713,
    label = "C/H2/CbCs;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (3.49e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4714,
    label = "C/H2/CbCs;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000759, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4715,
    label = "C/H2/CbCs;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000204, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4716,
    label = "C/H2/CbCs;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (6.28e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4717,
    label = "C/H2/CbCs;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00029, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4718,
    label = "C/H2/CbCs;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (9.55e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4719,
    label = "C/H2/CbCs;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00138, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4720,
    label = "C/H2/CbCs;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000475, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4721,
    label = "C/H2/CbCs;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (1.91e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4722,
    label = "C/H2/CbCs;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00278, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4723,
    label = "C/H2/CbCs;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00129, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4724,
    label = "C/H2/CbCs;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4725,
    label = "C/H2/CbCs;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00354, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4742,
    label = "C/H2/CbCs;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00168, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4726,
    label = "C/H2/CbCs;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000302, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4727,
    label = "C/H2/CbCs;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000787, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4728,
    label = "C/H2/CbCs;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.0018, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4729,
    label = "C/H2/CbCs;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000854, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4730,
    label = "C/H2/CbCs;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000891, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4731,
    label = "C/H2/CbCs;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4732,
    label = "C/H2/CbCs;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000426, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4733,
    label = "C/H2/CbCs;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0007, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4734,
    label = "C/H2/CbCs;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0111, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4735,
    label = "C/H2/CbCs;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00271, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4736,
    label = "C/H2/CbCs;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000284, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4737,
    label = "C/H2/CbCs;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4738,
    label = "C/H2/CbCs;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4739,
    label = "C/H2/CbCs;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00137, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4740,
    label = "C/H2/CbCs;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000442, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4741,
    label = "C/H2/CbCs;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000649, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4742,
    label = "C/H2/CbCs;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000191, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4743,
    label = "C/H2/CbCs;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00959, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4744,
    label = "C/H2/CbCs;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.005, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4745,
    label = "C/H2/CbCs;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00871, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4746,
    label = "C/H2/CbCs;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00402, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4747,
    label = "C/H2/CbCs;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4748,
    label = "C/H/Cs2Cb;H_rad",
    kinetics = ArrheniusEP(
        A = (0.0948, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4749,
    label = "C/H/Cs2Cb;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00225, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4750,
    label = "C/H/Cs2Cb;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000211, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4751,
    label = "C/H/Cs2Cb;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000163, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4752,
    label = "C/H/Cs2Cb;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4753,
    label = "C/H/Cs2Cb;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4754,
    label = "C/H/Cs2Cb;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000439, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4755,
    label = "C/H/Cs2Cb;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (4.56e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4756,
    label = "C/H/Cs2Cb;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000559, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4757,
    label = "C/H/Cs2Cb;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (1.67e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4758,
    label = "C/H/Cs2Cb;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000542, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4759,
    label = "C/H/Cs2Cb;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000119, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4760,
    label = "C/H/Cs2Cb;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (2.99e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4761,
    label = "C/H/Cs2Cb;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00017, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4762,
    label = "C/H/Cs2Cb;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (4.57e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4763,
    label = "C/H/Cs2Cb;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.000985, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4764,
    label = "C/H/Cs2Cb;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000277, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4765,
    label = "C/H/Cs2Cb;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (9.08e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4766,
    label = "C/H/Cs2Cb;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00242, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4767,
    label = "C/H/Cs2Cb;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000914, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4768,
    label = "C/H/Cs2Cb;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4769,
    label = "C/H/Cs2Cb;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00308, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4770,
    label = "C/H/Cs2Cb;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0012, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4788,
    label = "C/H/Cs2Cb;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000263, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4771,
    label = "C/H/Cs2Cb;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00066, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4772,
    label = "C/H/Cs2Cb;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00124, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4773,
    label = "C/H/Cs2Cb;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000478, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4774,
    label = "C/H/Cs2Cb;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00053, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4775,
    label = "C/H/Cs2Cb;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000551, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4776,
    label = "C/H/Cs2Cb;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000169, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4777,
    label = "C/H/Cs2Cb;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000417, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-8.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4778,
    label = "C/H/Cs2Cb;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.00968, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4779,
    label = "C/H/Cs2Cb;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00186, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4780,
    label = "C/H/Cs2Cb;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00016, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4781,
    label = "C/H/Cs2Cb;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00606, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4782,
    label = "C/H/Cs2Cb;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00107, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4783,
    label = "C/H/Cs2Cb;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000946, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4784,
    label = "C/H/Cs2Cb;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000248, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4785,
    label = "C/H/Cs2Cb;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000447, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4786,
    label = "C/H/Cs2Cb;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000108, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4787,
    label = "C/H/Cs2Cb;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00835, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4788,
    label = "C/H/Cs2Cb;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00355, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4789,
    label = "C/H/Cs2Cb;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00731, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4790,
    label = "C/H/Cs2Cb;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0035, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4791,
    label = "C/H/Cs2Cb;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00978, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4792,
    label = "Cd_pri;H_rad",
    kinetics = ArrheniusEP(
        A = (0.362, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4793,
    label = "Cd_pri;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00858, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4794,
    label = "Cd_pri;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00147, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4795,
    label = "Cd_pri;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00208, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4796,
    label = "Cd_pri;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00254, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4797,
    label = "Cd_pri;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0232, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4798,
    label = "Cd_pri;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0175, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4799,
    label = "Cd_pri;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00333, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4800,
    label = "Cd_pri;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.07, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (33.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4801,
    label = "Cd_pri;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00383, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (34, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4802,
    label = "Cd_pri;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4803,
    label = "Cd_pri;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00476, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4804,
    label = "Cd_pri;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00218, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4805,
    label = "Cd_pri;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0213, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4806,
    label = "Cd_pri;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.00105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4807,
    label = "Cd_pri;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0215, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4808,
    label = "Cd_pri;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0111, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4809,
    label = "Cd_pri;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000663, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4810,
    label = "Cd_pri;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00925, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4811,
    label = "Cd_pri;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00637, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4812,
    label = "Cd_pri;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00427, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4813,
    label = "Cd_pri;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4814,
    label = "Cd_pri;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0263, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4833,
    label = "Cd_pri;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.001, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4815,
    label = "Cd_pri;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00343, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4816,
    label = "Cd_pri;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.0117, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4817,
    label = "Cd_pri;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00829, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4818,
    label = "Cd_pri;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.028, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4819,
    label = "Cd_pri;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0532, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4820,
    label = "Cd_pri;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0299, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (32.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4821,
    label = "Cd_pri;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.022, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4822,
    label = "Cd_pri;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.037, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4823,
    label = "Cd_pri;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0554, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4824,
    label = "Cd_pri;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00869, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4825,
    label = "Cd_pri;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.436, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (36.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4826,
    label = "Cd_pri;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.141, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (38, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4827,
    label = "Cd_pri;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0281, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4828,
    label = "Cd_pri;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4829,
    label = "Cd_pri;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0133, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4830,
    label = "Cd_pri;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00585, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4831,
    label = "Cd_pri;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0319, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4832,
    label = "Cd_pri;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0248, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4833,
    label = "Cd_pri;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.038, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4834,
    label = "Cd_pri;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0133, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4835,
    label = "Cd_pri;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0373, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4836,
    label = "Cd/H/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (0.386, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4837,
    label = "Cd/H/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00915, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4838,
    label = "Cd/H/NonDeC;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4839,
    label = "Cd/H/NonDeC;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4840,
    label = "Cd/H/NonDeC;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4841,
    label = "Cd/H/NonDeC;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0203, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4842,
    label = "Cd/H/NonDeC;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0126, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4843,
    label = "Cd/H/NonDeC;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00195, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4844,
    label = "Cd/H/NonDeC;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0503, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4845,
    label = "Cd/H/NonDeC;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00225, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4846,
    label = "Cd/H/NonDeC;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0104, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4847,
    label = "Cd/H/NonDeC;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.0034, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4848,
    label = "Cd/H/NonDeC;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4849,
    label = "Cd/H/NonDeC;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0153, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4850,
    label = "Cd/H/NonDeC;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000613, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4851,
    label = "Cd/H/NonDeC;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0189, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4852,
    label = "Cd/H/NonDeC;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00792, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4853,
    label = "Cd/H/NonDeC;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000387, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4854,
    label = "Cd/H/NonDeC;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00987, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4855,
    label = "Cd/H/NonDeC;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00556, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4856,
    label = "Cd/H/NonDeC;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00455, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4857,
    label = "Cd/H/NonDeC;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0126, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4877,
    label = "Cd/H/NonDeC;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.023, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4858,
    label = "Cd/H/NonDeC;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00107, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4859,
    label = "Cd/H/NonDeC;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00353, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4860,
    label = "Cd/H/NonDeC;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00985, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4861,
    label = "Cd/H/NonDeC;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00569, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4862,
    label = "Cd/H/NonDeC;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0205, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4863,
    label = "Cd/H/NonDeC;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0317, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4864,
    label = "Cd/H/NonDeC;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0146, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4865,
    label = "Cd/H/NonDeC;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0161, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4866,
    label = "Cd/H/NonDeC;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0394, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4867,
    label = "Cd/H/NonDeC;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0468, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4868,
    label = "Cd/H/NonDeC;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00599, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4869,
    label = "Cd/H/NonDeC;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.307, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (32, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4870,
    label = "Cd/H/NonDeC;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0811, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (33.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4871,
    label = "Cd/H/NonDeC;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0238, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4872,
    label = "Cd/H/NonDeC;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00931, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4873,
    label = "Cd/H/NonDeC;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4874,
    label = "Cd/H/NonDeC;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00403, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4875,
    label = "Cd/H/NonDeC;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.034, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4876,
    label = "Cd/H/NonDeC;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0216, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4877,
    label = "Cd/H/NonDeC;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0391, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4878,
    label = "Cd/H/NonDeC;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0142, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4879,
    label = "Cd/H/NonDeC;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0398, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4880,
    label = "Cd/H/Cd;H_rad",
    kinetics = ArrheniusEP(
        A = (0.365, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4881,
    label = "Cd/H/Cd;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00864, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4882,
    label = "Cd/H/Cd;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4883,
    label = "Cd/H/Cd;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00209, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4884,
    label = "Cd/H/Cd;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00257, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4885,
    label = "Cd/H/Cd;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0234, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4886,
    label = "Cd/H/Cd;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0177, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4887,
    label = "Cd/H/Cd;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00336, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4888,
    label = "Cd/H/Cd;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0706, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (31.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4889,
    label = "Cd/H/Cd;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00386, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (31.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4890,
    label = "Cd/H/Cd;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0119, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4891,
    label = "Cd/H/Cd;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.0048, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4892,
    label = "Cd/H/Cd;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.0022, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4893,
    label = "Cd/H/Cd;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0214, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4894,
    label = "Cd/H/Cd;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.00105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4895,
    label = "Cd/H/Cd;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0217, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4896,
    label = "Cd/H/Cd;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4897,
    label = "Cd/H/Cd;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000668, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4898,
    label = "Cd/H/Cd;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00932, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4899,
    label = "Cd/H/Cd;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00642, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4900,
    label = "Cd/H/Cd;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0043, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4901,
    label = "Cd/H/Cd;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0119, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4922,
    label = "Cd/H/Cd;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0265, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4902,
    label = "Cd/H/Cd;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00101, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4903,
    label = "Cd/H/Cd;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00346, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4904,
    label = "Cd/H/Cd;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.0118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4905,
    label = "Cd/H/Cd;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00836, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4906,
    label = "Cd/H/Cd;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0283, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4907,
    label = "Cd/H/Cd;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0536, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4908,
    label = "Cd/H/Cd;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0301, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4909,
    label = "Cd/H/Cd;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0222, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4910,
    label = "Cd/H/Cd;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0372, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4911,
    label = "Cd/H/Cd;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0559, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4912,
    label = "Cd/H/Cd;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00876, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4913,
    label = "Cd/H/Cd;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.44, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (34.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4914,
    label = "Cd/H/Cd;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.142, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (35.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4915,
    label = "Cd/H/Cd;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0284, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4916,
    label = "Cd/H/Cd;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0136, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4917,
    label = "Cd/H/Cd;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0134, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4918,
    label = "Cd/H/Cd;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00589, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4919,
    label = "Cd/H/Cd;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4920,
    label = "Cd/H/Cd;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.025, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4921,
    label = "Cd/H/Cd;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0383, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4922,
    label = "Cd/H/Cd;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4923,
    label = "Cd/H/Cd;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0376, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4924,
    label = "Cb_H;H_rad",
    kinetics = ArrheniusEP(
        A = (0.443, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4925,
    label = "Cb_H;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4926,
    label = "Cb_H;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.0018, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4927,
    label = "Cb_H;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00254, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4928,
    label = "Cb_H;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00311, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4929,
    label = "Cb_H;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0284, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4930,
    label = "Cb_H;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0215, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4931,
    label = "Cb_H;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00407, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4932,
    label = "Cb_H;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0857, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (35.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4933,
    label = "Cb_H;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00468, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (35.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4934,
    label = "Cb_H;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0145, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4935,
    label = "Cb_H;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00582, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4936,
    label = "Cb_H;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00267, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4937,
    label = "Cb_H;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.026, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4938,
    label = "Cb_H;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.00128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (30.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4939,
    label = "Cb_H;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0263, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4940,
    label = "Cb_H;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4941,
    label = "Cb_H;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000811, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4942,
    label = "Cb_H;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4943,
    label = "Cb_H;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.0078, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4944,
    label = "Cb_H;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00522, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4945,
    label = "Cb_H;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0144, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4946,
    label = "Cb_H;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4968,
    label = "Cb_H;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00123, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4947,
    label = "Cb_H;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00419, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4948,
    label = "Cb_H;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.0143, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4949,
    label = "Cb_H;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0101, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4950,
    label = "Cb_H;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0343, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4951,
    label = "Cb_H;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0651, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (31.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4952,
    label = "Cb_H;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0366, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (34.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4953,
    label = "Cb_H;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.027, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4954,
    label = "Cb_H;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0452, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4955,
    label = "Cb_H;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0678, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4956,
    label = "Cb_H;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.0106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4957,
    label = "Cb_H;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.534, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (38.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4958,
    label = "Cb_H;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.173, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (39.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4959,
    label = "Cb_H;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0344, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4960,
    label = "Cb_H;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0165, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4961,
    label = "Cb_H;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0163, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4962,
    label = "Cb_H;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00715, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4963,
    label = "Cb_H;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.039, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4964,
    label = "Cb_H;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0303, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4965,
    label = "Cb_H;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0464, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4966,
    label = "Cb_H;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0163, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4967,
    label = "Cb_H;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0457, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4968,
    label = "Cd_Cdd/H2;H_rad",
    kinetics = ArrheniusEP(
        A = (1.63, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4991,
    label = "Cd_Cdd/H2;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0387, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4992,
    label = "Cd_Cdd/H2;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00545, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4993,
    label = "Cd_Cdd/H2;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00631, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4994,
    label = "Cd_Cdd/H2;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00635, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4995,
    label = "Cd_Cdd/H2;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0272, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4996,
    label = "Cd_Cdd/H2;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0169, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4997,
    label = "Cd_Cdd/H2;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00263, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4998,
    label = "Cd_Cdd/H2;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0213, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4999,
    label = "Cd_Cdd/H2;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000953, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5000,
    label = "Cd_Cdd/H2;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5001,
    label = "Cd_Cdd/H2;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00457, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5002,
    label = "Cd_Cdd/H2;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00172, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5003,
    label = "Cd_Cdd/H2;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00646, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5004,
    label = "Cd_Cdd/H2;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.00026, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5005,
    label = "Cd_Cdd/H2;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0252, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5006,
    label = "Cd_Cdd/H2;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5007,
    label = "Cd_Cdd/H2;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000522, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5008,
    label = "Cd_Cdd/H2;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0417, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5009,
    label = "Cd_Cdd/H2;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.0236, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5010,
    label = "Cd_Cdd/H2;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0193, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5011,
    label = "Cd_Cdd/H2;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0531, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5012,
    label = "Cd_Cdd/H2;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0308, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5013,
    label = "Cd_Cdd/H2;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00452, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5014,
    label = "Cd_Cdd/H2;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.0122, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5015,
    label = "Cd_Cdd/H2;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.0343, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5016,
    label = "Cd_Cdd/H2;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0199, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5017,
    label = "Cd_Cdd/H2;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0195, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5018,
    label = "Cd_Cdd/H2;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0304, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5019,
    label = "Cd_Cdd/H2;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5020,
    label = "Cd_Cdd/H2;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0154, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5021,
    label = "Cd_Cdd/H2;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.167, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5022,
    label = "Cd_Cdd/H2;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0514, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5023,
    label = "Cd_Cdd/H2;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.0066, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5024,
    label = "Cd_Cdd/H2;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.241, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5025,
    label = "Cd_Cdd/H2;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0639, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5026,
    label = "Cd_Cdd/H2;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0261, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5027,
    label = "Cd_Cdd/H2;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0103, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5028,
    label = "Cd_Cdd/H2;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0123, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5029,
    label = "Cd_Cdd/H2;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00444, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5030,
    label = "Cd_Cdd/H2;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.144, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5031,
    label = "Cd_Cdd/H2;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0918, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5032,
    label = "Cd_Cdd/H2;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.136, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5033,
    label = "Cd_Cdd/H2;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0603, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5034,
    label = "Cd_Cdd/H2;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.169, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5035,
    label = "Cd/H/Ct;H_rad",
    kinetics = ArrheniusEP(
        A = (0.295, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4969,
    label = "Cd/H/Ct;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00698, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4970,
    label = "Cd/H/Ct;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.0012, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4971,
    label = "Cd/H/Ct;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00169, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4972,
    label = "Cd/H/Ct;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00207, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4973,
    label = "Cd/H/Ct;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0189, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4974,
    label = "Cd/H/Ct;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0143, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4975,
    label = "Cd/H/Ct;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00271, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4976,
    label = "Cd/H/Ct;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.057, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4977,
    label = "Cd/H/Ct;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00312, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4978,
    label = "Cd/H/Ct;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00965, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4979,
    label = "Cd/H/Ct;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00388, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4980,
    label = "Cd/H/Ct;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00178, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4981,
    label = "Cd/H/Ct;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0173, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4982,
    label = "Cd/H/Ct;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000851, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4983,
    label = "Cd/H/Ct;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0175, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4984,
    label = "Cd/H/Ct;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00901, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4985,
    label = "Cd/H/Ct;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.00054, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4986,
    label = "Cd/H/Ct;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00753, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4987,
    label = "Cd/H/Ct;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00519, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4988,
    label = "Cd/H/Ct;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00347, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4989,
    label = "Cd/H/Ct;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00958, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4990,
    label = "Cd/H/Ct;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0214, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5058,
    label = "Cd/H/Ct;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000816, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4991,
    label = "Cd/H/Ct;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00279, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4992,
    label = "Cd/H/Ct;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00955, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4993,
    label = "Cd/H/Ct;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00675, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4994,
    label = "Cd/H/Ct;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0228, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4995,
    label = "Cd/H/Ct;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0433, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4996,
    label = "Cd/H/Ct;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0243, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4997,
    label = "Cd/H/Ct;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0179, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4998,
    label = "Cd/H/Ct;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0301, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 4999,
    label = "Cd/H/Ct;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0452, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5000,
    label = "Cd/H/Ct;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00708, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5001,
    label = "Cd/H/Ct;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.355, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (31.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5002,
    label = "Cd/H/Ct;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.115, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (33.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5003,
    label = "Cd/H/Ct;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5004,
    label = "Cd/H/Ct;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.011, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5005,
    label = "Cd/H/Ct;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0108, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5006,
    label = "Cd/H/Ct;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00476, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5007,
    label = "Cd/H/Ct;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0259, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5008,
    label = "Cd/H/Ct;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0202, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5009,
    label = "Cd/H/Ct;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0309, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5010,
    label = "Cd/H/Ct;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5011,
    label = "Cd/H/Ct;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0304, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5012,
    label = "C/H3/S;H_rad",
    kinetics = ArrheniusEP(
        A = (0.0556, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5013,
    label = "C/H3/S;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00132, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5014,
    label = "C/H3/S;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000218, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5015,
    label = "C/H3/S;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000296, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5016,
    label = "C/H3/S;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00035, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5017,
    label = "C/H3/S;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00282, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5018,
    label = "C/H3/S;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00206, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5019,
    label = "C/H3/S;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000376, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5020,
    label = "C/H3/S;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00673, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5021,
    label = "C/H3/S;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000355, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5022,
    label = "C/H3/S;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00144, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5023,
    label = "C/H3/S;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000558, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5024,
    label = "C/H3/S;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000247, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5025,
    label = "C/H3/S;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00204, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5026,
    label = "C/H3/S;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (9.69e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5027,
    label = "C/H3/S;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00262, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5028,
    label = "C/H3/S;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5029,
    label = "C/H3/S;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (7.48e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5030,
    label = "C/H3/S;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00142, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5031,
    label = "C/H3/S;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000944, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5032,
    label = "C/H3/S;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.000656, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5033,
    label = "C/H3/S;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00181, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5034,
    label = "C/H3/S;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00319, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5103,
    label = "C/H3/S;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000154, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5035,
    label = "C/H3/S;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5036,
    label = "C/H3/S;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000457, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5037,
    label = "C/H3/S;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000311, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5038,
    label = "C/H3/S;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00103, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5039,
    label = "C/H3/S;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00188, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5040,
    label = "C/H3/S;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00102, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5041,
    label = "C/H3/S;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000807, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5042,
    label = "C/H3/S;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.00568, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5043,
    label = "C/H3/S;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00177, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5044,
    label = "C/H3/S;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000268, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5045,
    label = "C/H3/S;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0042, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5046,
    label = "C/H3/S;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00131, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5047,
    label = "C/H3/S;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000899, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5048,
    label = "C/H3/S;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000416, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5049,
    label = "C/H3/S;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000425, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5050,
    label = "C/H3/S;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00018, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5051,
    label = "C/H3/S;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00489, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5052,
    label = "C/H3/S;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00367, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5053,
    label = "C/H3/S;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00153, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5054,
    label = "C/H3/S;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00205, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5055,
    label = "C/H3/S;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00574, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5056,
    label = "C/H2/CsS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.131, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5057,
    label = "C/H2/CsS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00309, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5058,
    label = "C/H2/CsS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000418, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5059,
    label = "C/H2/CsS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000464, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5060,
    label = "C/H2/CsS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000448, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5061,
    label = "C/H2/CsS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00544, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5062,
    label = "C/H2/CsS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00323, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5063,
    label = "C/H2/CsS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000483, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5064,
    label = "C/H2/CsS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5065,
    label = "C/H2/CsS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000458, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5066,
    label = "C/H2/CsS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00277, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5067,
    label = "C/H2/CsS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000877, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5068,
    label = "C/H2/CsS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000317, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5069,
    label = "C/H2/CsS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00323, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5070,
    label = "C/H2/CsS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000125, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5071,
    label = "C/H2/CsS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00504, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5072,
    label = "C/H2/CsS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00204, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5073,
    label = "C/H2/CsS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (9.61e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5074,
    label = "C/H2/CsS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00333, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5075,
    label = "C/H2/CsS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00181, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5076,
    label = "C/H2/CsS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00154, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5077,
    label = "C/H2/CsS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00424, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5078,
    label = "C/H2/CsS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00615, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5148,
    label = "C/H2/CsS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000361, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5079,
    label = "C/H2/CsS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000313, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5080,
    label = "C/H2/CsS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000844, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5081,
    label = "C/H2/CsS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00047, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5082,
    label = "C/H2/CsS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00165, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5083,
    label = "C/H2/CsS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00246, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5084,
    label = "C/H2/CsS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5085,
    label = "C/H2/CsS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5086,
    label = "C/H2/CsS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0133, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5087,
    label = "C/H2/CsS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00329, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5088,
    label = "C/H2/CsS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000406, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5089,
    label = "C/H2/CsS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0065, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5090,
    label = "C/H2/CsS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00166, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5091,
    label = "C/H2/CsS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00167, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5092,
    label = "C/H2/CsS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00063, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5093,
    label = "C/H2/CsS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000788, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5094,
    label = "C/H2/CsS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000273, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5095,
    label = "C/H2/CsS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0115, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5096,
    label = "C/H2/CsS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00703, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5097,
    label = "C/H2/CsS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00347, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5098,
    label = "C/H2/CsS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00481, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5099,
    label = "C/H2/CsS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5100,
    label = "C/H/Cs2S;H_rad",
    kinetics = ArrheniusEP(
        A = (0.0699, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5101,
    label = "C/H/Cs2S;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00166, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5102,
    label = "C/H/Cs2S;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000183, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5103,
    label = "C/H/Cs2S;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000166, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5104,
    label = "C/H/Cs2S;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000131, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5105,
    label = "C/H/Cs2S;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00239, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5106,
    label = "C/H/Cs2S;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00116, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5107,
    label = "C/H/Cs2S;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000142, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5108,
    label = "C/H/Cs2S;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00383, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5109,
    label = "C/H/Cs2S;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.000135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5110,
    label = "C/H/Cs2S;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00122, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5111,
    label = "C/H/Cs2S;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000315, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5112,
    label = "C/H/Cs2S;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (9.28e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5113,
    label = "C/H/Cs2S;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00116, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5114,
    label = "C/H/Cs2S;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (3.68e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5115,
    label = "C/H/Cs2S;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00221, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5116,
    label = "C/H/Cs2S;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000732, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5117,
    label = "C/H/Cs2S;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.82e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5118,
    label = "C/H/Cs2S;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00179, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5119,
    label = "C/H/Cs2S;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000791, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5120,
    label = "C/H/Cs2S;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.000824, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5121,
    label = "C/H/Cs2S;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00227, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5122,
    label = "C/H/Cs2S;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0027, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5193,
    label = "C/H/Cs2S;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000193, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5123,
    label = "C/H/Cs2S;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000162, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5124,
    label = "C/H/Cs2S;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000356, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5125,
    label = "C/H/Cs2S;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000162, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5126,
    label = "C/H/Cs2S;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000603, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5127,
    label = "C/H/Cs2S;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000736, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5128,
    label = "C/H/Cs2S;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000266, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5129,
    label = "C/H/Cs2S;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000474, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5130,
    label = "C/H/Cs2S;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.00713, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5131,
    label = "C/H/Cs2S;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5132,
    label = "C/H/Cs2S;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5133,
    label = "C/H/Cs2S;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5134,
    label = "C/H/Cs2S;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.000477, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5135,
    label = "C/H/Cs2S;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000707, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5136,
    label = "C/H/Cs2S;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000218, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5137,
    label = "C/H/Cs2S;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000334, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5138,
    label = "C/H/Cs2S;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (9.44e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5139,
    label = "C/H/Cs2S;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00615, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5140,
    label = "C/H/Cs2S;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00308, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5141,
    label = "C/H/Cs2S;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00179, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5142,
    label = "C/H/Cs2S;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5143,
    label = "C/H/Cs2S;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00721, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5144,
    label = "C/H3/CS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5145,
    label = "C/H3/CS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0033, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5146,
    label = "C/H3/CS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000387, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5147,
    label = "C/H3/CS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000374, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5148,
    label = "C/H3/CS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000313, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5149,
    label = "C/H3/CS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00138, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5150,
    label = "C/H3/CS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000713, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5151,
    label = "C/H3/CS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (9.26e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5152,
    label = "C/H3/CS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000643, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5153,
    label = "C/H3/CS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (2.4e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5154,
    label = "C/H3/CS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000968, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5155,
    label = "C/H3/CS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000266, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5156,
    label = "C/H3/CS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (8.34e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5157,
    label = "C/H3/CS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000368, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5158,
    label = "C/H3/CS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.24e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5159,
    label = "C/H3/CS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5160,
    label = "C/H3/CS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00045, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5161,
    label = "C/H3/CS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (1.84e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5162,
    label = "C/H3/CS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00356, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5163,
    label = "C/H3/CS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00168, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5164,
    label = "C/H3/CS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00164, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5165,
    label = "C/H3/CS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00453, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5166,
    label = "C/H3/CS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00156, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5238,
    label = "C/H3/CS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000386, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5167,
    label = "C/H3/CS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000315, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5168,
    label = "C/H3/CS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000736, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5169,
    label = "C/H3/CS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000356, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5170,
    label = "C/H3/CS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00281, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5171,
    label = "C/H3/CS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00365, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5172,
    label = "C/H3/CS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5173,
    label = "C/H3/CS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00221, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5174,
    label = "C/H3/CS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0142, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5175,
    label = "C/H3/CS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000786, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5176,
    label = "C/H3/CS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (8.42e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5177,
    label = "C/H3/CS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0104, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5178,
    label = "C/H3/CS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00231, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (30.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5179,
    label = "C/H3/CS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000548, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5180,
    label = "C/H3/CS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00018, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5181,
    label = "C/H3/CS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000188, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5182,
    label = "C/H3/CS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (5.67e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5183,
    label = "C/H3/CS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0123, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5184,
    label = "C/H3/CS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00652, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5185,
    label = "C/H3/CS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00348, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5186,
    label = "C/H3/CS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00514, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5187,
    label = "C/H3/CS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0144, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5188,
    label = "C/H2/CSCs;H_rad",
    kinetics = ArrheniusEP(
        A = (0.198, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5189,
    label = "C/H2/CSCs;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00469, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5190,
    label = "C/H2/CSCs;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00045, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5191,
    label = "C/H2/CSCs;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000354, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5192,
    label = "C/H2/CSCs;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000242, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5193,
    label = "C/H2/CSCs;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00161, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5194,
    label = "C/H2/CSCs;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000679, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5195,
    label = "C/H2/CSCs;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (7.2e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5196,
    label = "C/H2/CSCs;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000615, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5197,
    label = "C/H2/CSCs;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (1.88e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5198,
    label = "C/H2/CSCs;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5199,
    label = "C/H2/CSCs;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000253, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5200,
    label = "C/H2/CSCs;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (6.48e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5201,
    label = "C/H2/CSCs;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000352, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5202,
    label = "C/H2/CSCs;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (9.67e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5203,
    label = "C/H2/CSCs;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00149, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5204,
    label = "C/H2/CSCs;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000429, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5205,
    label = "C/H2/CSCs;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (1.43e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5206,
    label = "C/H2/CSCs;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00506, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5207,
    label = "C/H2/CSCs;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00195, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5208,
    label = "C/H2/CSCs;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00233, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5209,
    label = "C/H2/CSCs;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00644, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5210,
    label = "C/H2/CSCs;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00182, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5283,
    label = "C/H2/CSCs;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000548, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5211,
    label = "C/H2/CSCs;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000431, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5212,
    label = "C/H2/CSCs;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000823, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5213,
    label = "C/H2/CSCs;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000325, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5214,
    label = "C/H2/CSCs;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00273, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5215,
    label = "C/H2/CSCs;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00289, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5216,
    label = "C/H2/CSCs;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000908, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5217,
    label = "C/H2/CSCs;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00215, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5218,
    label = "C/H2/CSCs;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0202, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5219,
    label = "C/H2/CSCs;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000883, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5220,
    label = "C/H2/CSCs;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (7.73e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5221,
    label = "C/H2/CSCs;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00977, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5222,
    label = "C/H2/CSCs;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00177, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5223,
    label = "C/H2/CSCs;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000616, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5224,
    label = "C/H2/CSCs;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000165, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5225,
    label = "C/H2/CSCs;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000212, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5226,
    label = "C/H2/CSCs;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (5.2e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5227,
    label = "C/H2/CSCs;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0174, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5228,
    label = "C/H2/CSCs;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00757, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5229,
    label = "C/H2/CSCs;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00477, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5230,
    label = "C/H2/CSCs;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0073, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5231,
    label = "C/H2/CSCs;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0204, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5232,
    label = "C/H/Cs2CS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.131, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5233,
    label = "C/H/Cs2CS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0031, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5234,
    label = "C/H/Cs2CS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000242, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5235,
    label = "C/H/Cs2CS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000156, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5236,
    label = "C/H/Cs2CS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (8.72e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5237,
    label = "C/H/Cs2CS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.000872, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5238,
    label = "C/H/Cs2CS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0003, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5239,
    label = "C/H/Cs2CS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (2.6e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5240,
    label = "C/H/Cs2CS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000273, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5241,
    label = "C/H/Cs2CS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (6.81e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5242,
    label = "C/H/Cs2CS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000611, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5243,
    label = "C/H/Cs2CS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5244,
    label = "C/H/Cs2CS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (2.34e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5245,
    label = "C/H/Cs2CS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000156, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5246,
    label = "C/H/Cs2CS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (3.51e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5247,
    label = "C/H/Cs2CS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.000808, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5248,
    label = "C/H/Cs2CS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00019, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5249,
    label = "C/H/Cs2CS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (5.17e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5250,
    label = "C/H/Cs2CS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00334, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5251,
    label = "C/H/Cs2CS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5252,
    label = "C/H/Cs2CS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00154, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5253,
    label = "C/H/Cs2CS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00425, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5254,
    label = "C/H/Cs2CS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.000986, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5328,
    label = "C/H/Cs2CS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000362, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5255,
    label = "C/H/Cs2CS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000274, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5256,
    label = "C/H/Cs2CS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000428, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5257,
    label = "C/H/Cs2CS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000138, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5258,
    label = "C/H/Cs2CS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00123, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5259,
    label = "C/H/Cs2CS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00107, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5260,
    label = "C/H/Cs2CS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000273, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5261,
    label = "C/H/Cs2CS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000969, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5262,
    label = "C/H/Cs2CS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0133, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5263,
    label = "C/H/Cs2CS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000461, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5264,
    label = "C/H/Cs2CS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (3.3e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5265,
    label = "C/H/Cs2CS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00425, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5266,
    label = "C/H/Cs2CS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.000627, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5267,
    label = "C/H/Cs2CS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5268,
    label = "C/H/Cs2CS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (7.03e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5269,
    label = "C/H/Cs2CS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00011, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5270,
    label = "C/H/Cs2CS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (2.22e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5271,
    label = "C/H/Cs2CS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0115, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5272,
    label = "C/H/Cs2CS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00408, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5273,
    label = "C/H/Cs2CS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00304, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5274,
    label = "C/H/Cs2CS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00482, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5275,
    label = "C/H/Cs2CS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5276,
    label = "Cd/H/NonDeS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.187, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5277,
    label = "Cd/H/NonDeS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00444, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5278,
    label = "Cd/H/NonDeS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000521, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5279,
    label = "Cd/H/NonDeS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000502, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5280,
    label = "Cd/H/NonDeS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000421, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5281,
    label = "Cd/H/NonDeS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00186, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5282,
    label = "Cd/H/NonDeS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000959, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5283,
    label = "Cd/H/NonDeS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000124, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5284,
    label = "Cd/H/NonDeS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000864, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5285,
    label = "Cd/H/NonDeS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (3.23e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5286,
    label = "Cd/H/NonDeS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5287,
    label = "Cd/H/NonDeS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000357, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5288,
    label = "Cd/H/NonDeS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5289,
    label = "Cd/H/NonDeS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000495, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5290,
    label = "Cd/H/NonDeS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.66e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5291,
    label = "Cd/H/NonDeS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00172, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5292,
    label = "Cd/H/NonDeS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000605, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5293,
    label = "Cd/H/NonDeS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.47e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5294,
    label = "Cd/H/NonDeS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00478, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5295,
    label = "Cd/H/NonDeS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00225, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5296,
    label = "Cd/H/NonDeS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00221, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5297,
    label = "Cd/H/NonDeS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00609, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5298,
    label = "Cd/H/NonDeS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0021, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5373,
    label = "Cd/H/NonDeS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000518, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5299,
    label = "Cd/H/NonDeS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000423, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5300,
    label = "Cd/H/NonDeS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000989, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5301,
    label = "Cd/H/NonDeS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000478, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5302,
    label = "Cd/H/NonDeS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00378, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5303,
    label = "Cd/H/NonDeS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0049, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5304,
    label = "Cd/H/NonDeS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00188, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5305,
    label = "Cd/H/NonDeS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00297, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5306,
    label = "Cd/H/NonDeS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0191, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5307,
    label = "Cd/H/NonDeS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5308,
    label = "Cd/H/NonDeS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5309,
    label = "Cd/H/NonDeS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5310,
    label = "Cd/H/NonDeS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0031, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5311,
    label = "Cd/H/NonDeS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000736, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5312,
    label = "Cd/H/NonDeS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000241, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5313,
    label = "Cd/H/NonDeS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000253, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5314,
    label = "Cd/H/NonDeS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (7.61e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5315,
    label = "Cd/H/NonDeS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0165, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5316,
    label = "Cd/H/NonDeS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00876, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5317,
    label = "Cd/H/NonDeS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00468, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5318,
    label = "Cd/H/NonDeS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00691, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5319,
    label = "Cd/H/NonDeS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0193, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5320,
    label = "Cd/H/CS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.5, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5321,
    label = "Cd/H/CS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5322,
    label = "Cd/H/CS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00203, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5323,
    label = "Cd/H/CS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00287, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5324,
    label = "Cd/H/CS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00351, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5325,
    label = "Cd/H/CS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5326,
    label = "Cd/H/CS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0242, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5327,
    label = "Cd/H/CS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.0046, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5328,
    label = "Cd/H/CS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0966, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (32.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5329,
    label = "Cd/H/CS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00528, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (32.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5330,
    label = "Cd/H/CS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0164, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5331,
    label = "Cd/H/CS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00657, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5332,
    label = "Cd/H/CS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00301, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5333,
    label = "Cd/H/CS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0293, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5334,
    label = "Cd/H/CS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.00144, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5335,
    label = "Cd/H/CS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0297, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5336,
    label = "Cd/H/CS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0153, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5337,
    label = "Cd/H/CS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000915, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5338,
    label = "Cd/H/CS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5339,
    label = "Cd/H/CS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.0088, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5340,
    label = "Cd/H/CS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00589, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5341,
    label = "Cd/H/CS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0162, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5342,
    label = "Cd/H/CS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0363, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5418,
    label = "Cd/H/CS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00138, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5343,
    label = "Cd/H/CS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00473, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5344,
    label = "Cd/H/CS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.0162, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5345,
    label = "Cd/H/CS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0114, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5346,
    label = "Cd/H/CS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0387, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5347,
    label = "Cd/H/CS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0734, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5348,
    label = "Cd/H/CS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0413, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (30.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5349,
    label = "Cd/H/CS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0304, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5350,
    label = "Cd/H/CS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.051, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5351,
    label = "Cd/H/CS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0765, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5352,
    label = "Cd/H/CS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.012, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5353,
    label = "Cd/H/CS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.602, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (35.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5354,
    label = "Cd/H/CS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.195, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (36.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5355,
    label = "Cd/H/CS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0388, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5356,
    label = "Cd/H/CS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0186, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5357,
    label = "Cd/H/CS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0183, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5358,
    label = "Cd/H/CS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00807, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5359,
    label = "Cd/H/CS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.044, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5360,
    label = "Cd/H/CS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0342, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5361,
    label = "Cd/H/CS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0524, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5362,
    label = "Cd/H/CS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0184, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5363,
    label = "Cd/H/CS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0515, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5364,
    label = "C/H2/CdS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.205, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5365,
    label = "C/H2/CdS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00485, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5366,
    label = "C/H2/CdS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000659, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5367,
    label = "C/H2/CdS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000735, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5368,
    label = "C/H2/CdS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000712, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5369,
    label = "C/H2/CdS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0027, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5370,
    label = "C/H2/CdS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00161, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5371,
    label = "C/H2/CdS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000242, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5372,
    label = "C/H2/CdS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00167, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5373,
    label = "C/H2/CdS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (7.21e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5374,
    label = "C/H2/CdS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00138, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5375,
    label = "C/H2/CdS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000437, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5376,
    label = "C/H2/CdS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000159, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5377,
    label = "C/H2/CdS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000506, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5378,
    label = "C/H2/CdS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.97e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5379,
    label = "C/H2/CdS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0025, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5380,
    label = "C/H2/CdS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00102, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5381,
    label = "C/H2/CdS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (4.81e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5382,
    label = "C/H2/CdS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00523, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5383,
    label = "C/H2/CdS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00285, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5384,
    label = "C/H2/CdS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00241, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5385,
    label = "C/H2/CdS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00666, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5386,
    label = "C/H2/CdS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00305, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5463,
    label = "C/H2/CdS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000567, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5387,
    label = "C/H2/CdS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000404, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5388,
    label = "C/H2/CdS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5389,
    label = "C/H2/CdS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00061, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5390,
    label = "C/H2/CdS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000584, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5391,
    label = "C/H2/CdS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000876, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5392,
    label = "C/H2/CdS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000389, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5393,
    label = "C/H2/CdS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000459, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-9.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5394,
    label = "C/H2/CdS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0209, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5395,
    label = "C/H2/CdS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00134, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5396,
    label = "C/H2/CdS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000166, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5397,
    label = "C/H2/CdS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00189, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5398,
    label = "C/H2/CdS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.000484, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5399,
    label = "C/H2/CdS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00068, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5400,
    label = "C/H2/CdS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5401,
    label = "C/H2/CdS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5402,
    label = "C/H2/CdS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000112, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5403,
    label = "C/H2/CdS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.018, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5404,
    label = "C/H2/CdS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0111, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5405,
    label = "C/H2/CdS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00447, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5406,
    label = "C/H2/CdS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00755, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5407,
    label = "C/H2/CdS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0211, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5408,
    label = "C/H/CSCsS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.137, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5409,
    label = "C/H/CSCsS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00324, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5410,
    label = "C/H/CSCsS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00036, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5411,
    label = "C/H/CSCsS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000328, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5412,
    label = "C/H/CSCsS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000259, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5413,
    label = "C/H/CSCsS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5414,
    label = "C/H/CSCsS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000721, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5415,
    label = "C/H/CSCsS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (8.84e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5416,
    label = "C/H/CSCsS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00075, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5417,
    label = "C/H/CSCsS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (2.65e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5418,
    label = "C/H/CSCsS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000754, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5419,
    label = "C/H/CSCsS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000196, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5420,
    label = "C/H/CSCsS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (5.8e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5421,
    label = "C/H/CSCsS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000228, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5422,
    label = "C/H/CSCsS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (7.23e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5423,
    label = "C/H/CSCsS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00137, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5424,
    label = "C/H/CSCsS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000455, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5425,
    label = "C/H/CSCsS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (1.76e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5426,
    label = "C/H/CSCsS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0035, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5427,
    label = "C/H/CSCsS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00156, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5428,
    label = "C/H/CSCsS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00161, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5429,
    label = "C/H/CSCsS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00445, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5430,
    label = "C/H/CSCsS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00167, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5508,
    label = "C/H/CSCsS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000379, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5431,
    label = "C/H/CSCsS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00026, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5432,
    label = "C/H/CSCsS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000574, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5433,
    label = "C/H/CSCsS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000262, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5434,
    label = "C/H/CSCsS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000267, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5435,
    label = "C/H/CSCsS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000327, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5436,
    label = "C/H/CSCsS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000119, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5437,
    label = "C/H/CSCsS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00021, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-12.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5438,
    label = "C/H/CSCsS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5439,
    label = "C/H/CSCsS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000708, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5440,
    label = "C/H/CSCsS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (7.16e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5441,
    label = "C/H/CSCsS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.000832, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5442,
    label = "C/H/CSCsS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.000174, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5443,
    label = "C/H/CSCsS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000359, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5444,
    label = "C/H/CSCsS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000111, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5445,
    label = "C/H/CSCsS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00017, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5446,
    label = "C/H/CSCsS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (4.82e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5447,
    label = "C/H/CSCsS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.012, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5448,
    label = "C/H/CSCsS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00605, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5449,
    label = "C/H/CSCsS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00288, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5450,
    label = "C/H/CSCsS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00505, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5451,
    label = "C/H/CSCsS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0141, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5452,
    label = "C/H2/CSS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.309, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5453,
    label = "C/H2/CSS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00733, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5454,
    label = "C/H2/CSS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000829, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5455,
    label = "C/H2/CSS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00077, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5456,
    label = "C/H2/CSS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000622, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5457,
    label = "C/H2/CSS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00242, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5458,
    label = "C/H2/CSS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00121, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5459,
    label = "C/H2/CSS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000151, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5460,
    label = "C/H2/CSS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000892, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5461,
    label = "C/H2/CSS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (3.21e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5462,
    label = "C/H2/CSS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0017, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5463,
    label = "C/H2/CSS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000449, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5464,
    label = "C/H2/CSS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000136, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5465,
    label = "C/H2/CSS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000511, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5466,
    label = "C/H2/CSS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.66e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5467,
    label = "C/H2/CSS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00225, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5468,
    label = "C/H2/CSS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000761, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5469,
    label = "C/H2/CSS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (3e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5470,
    label = "C/H2/CSS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0079, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5471,
    label = "C/H2/CSS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00359, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5472,
    label = "C/H2/CSS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00365, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5473,
    label = "C/H2/CSS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.01, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5474,
    label = "C/H2/CSS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00274, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5553,
    label = "C/H2/CSS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000856, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5475,
    label = "C/H2/CSS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000184, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5476,
    label = "C/H2/CSS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000414, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5477,
    label = "C/H2/CSS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000193, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5478,
    label = "C/H2/CSS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00149, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5479,
    label = "C/H2/CSS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00186, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5480,
    label = "C/H2/CSS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000689, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5481,
    label = "C/H2/CSS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00117, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5482,
    label = "C/H2/CSS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0316, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5483,
    label = "C/H2/CSS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000363, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5484,
    label = "C/H2/CSS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (3.75e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5485,
    label = "C/H2/CSS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00145, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5486,
    label = "C/H2/CSS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00031, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5487,
    label = "C/H2/CSS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000253, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5488,
    label = "C/H2/CSS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (7.99e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5489,
    label = "C/H2/CSS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (8.69e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5490,
    label = "C/H2/CSS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (2.52e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5491,
    label = "C/H2/CSS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0272, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5492,
    label = "C/H2/CSS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5493,
    label = "C/H2/CSS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00203, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5494,
    label = "C/H2/CSS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0114, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5495,
    label = "C/H2/CSS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0319, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5496,
    label = "C/H/CSCsS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.266, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5497,
    label = "C/H/CSCsS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00629, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5498,
    label = "C/H/CSCsS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000581, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5499,
    label = "C/H/CSCsS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000441, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5500,
    label = "C/H/CSCsS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000291, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5501,
    label = "C/H/CSCsS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00171, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5502,
    label = "C/H/CSCsS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000695, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5503,
    label = "C/H/CSCsS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (7.1e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5504,
    label = "C/H/CSCsS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000516, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5505,
    label = "C/H/CSCsS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (1.52e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5506,
    label = "C/H/CSCsS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0012, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5507,
    label = "C/H/CSCsS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000259, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5508,
    label = "C/H/CSCsS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (6.39e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5509,
    label = "C/H/CSCsS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000296, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5510,
    label = "C/H/CSCsS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (7.82e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5511,
    label = "C/H/CSCsS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00158, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5512,
    label = "C/H/CSCsS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000438, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5513,
    label = "C/H/CSCsS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (1.41e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5514,
    label = "C/H/CSCsS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00679, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5515,
    label = "C/H/CSCsS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00252, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5516,
    label = "C/H/CSCsS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00313, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5517,
    label = "C/H/CSCsS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00863, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5518,
    label = "C/H/CSCsS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00193, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5598,
    label = "C/H/CSCsS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000735, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5519,
    label = "C/H/CSCsS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000152, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5520,
    label = "C/H/CSCsS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00028, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5521,
    label = "C/H/CSCsS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000107, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5522,
    label = "C/H/CSCsS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000874, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5523,
    label = "C/H/CSCsS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000892, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5524,
    label = "C/H/CSCsS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00027, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5525,
    label = "C/H/CSCsS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000687, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-14.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5526,
    label = "C/H/CSCsS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0271, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5527,
    label = "C/H/CSCsS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000247, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5528,
    label = "C/H/CSCsS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (2.08e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5529,
    label = "C/H/CSCsS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.000822, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5530,
    label = "C/H/CSCsS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.000143, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5531,
    label = "C/H/CSCsS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000172, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5532,
    label = "C/H/CSCsS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (4.44e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5533,
    label = "C/H/CSCsS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (5.91e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5534,
    label = "C/H/CSCsS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (1.4e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5535,
    label = "C/H/CSCsS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0234, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5536,
    label = "C/H/CSCsS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00979, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5537,
    label = "C/H/CSCsS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00168, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5538,
    label = "C/H/CSCsS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0098, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5539,
    label = "C/H/CSCsS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0274, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5540,
    label = "C/H2/CtS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.143, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5541,
    label = "C/H2/CtS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00339, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5542,
    label = "C/H2/CtS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000461, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5543,
    label = "C/H2/CtS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000514, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5544,
    label = "C/H2/CtS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000498, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5545,
    label = "C/H2/CtS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00189, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5546,
    label = "C/H2/CtS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5547,
    label = "C/H2/CtS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000169, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5548,
    label = "C/H2/CtS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00117, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5549,
    label = "C/H2/CtS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (5.04e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5550,
    label = "C/H2/CtS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00239, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5551,
    label = "C/H2/CtS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000759, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5552,
    label = "C/H2/CtS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000275, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5553,
    label = "C/H2/CtS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00218, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5554,
    label = "C/H2/CtS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (8.49e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5555,
    label = "C/H2/CtS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00175, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5556,
    label = "C/H2/CtS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000711, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5557,
    label = "C/H2/CtS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (3.36e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5558,
    label = "C/H2/CtS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00366, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5559,
    label = "C/H2/CtS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00199, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5560,
    label = "C/H2/CtS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00169, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5561,
    label = "C/H2/CtS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00466, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5562,
    label = "C/H2/CtS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00213, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5643,
    label = "C/H2/CtS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000397, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5563,
    label = "C/H2/CtS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000282, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5564,
    label = "C/H2/CtS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000763, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5565,
    label = "C/H2/CtS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000427, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5566,
    label = "C/H2/CtS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000561, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5567,
    label = "C/H2/CtS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000842, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5568,
    label = "C/H2/CtS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000374, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5569,
    label = "C/H2/CtS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000441, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-8.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5570,
    label = "C/H2/CtS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0146, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5571,
    label = "C/H2/CtS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000936, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5572,
    label = "C/H2/CtS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.000116, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5573,
    label = "C/H2/CtS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00182, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5574,
    label = "C/H2/CtS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.000465, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5575,
    label = "C/H2/CtS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5576,
    label = "C/H2/CtS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000448, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5577,
    label = "C/H2/CtS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000224, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5578,
    label = "C/H2/CtS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (7.81e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5579,
    label = "C/H2/CtS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0126, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5580,
    label = "C/H2/CtS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00775, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5581,
    label = "C/H2/CtS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00312, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5582,
    label = "C/H2/CtS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00528, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5583,
    label = "C/H2/CtS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5584,
    label = "C/H/CtCsS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.175, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5585,
    label = "C/H/CtCsS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00416, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5586,
    label = "C/H/CtCsS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000461, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5587,
    label = "C/H/CtCsS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00042, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5588,
    label = "C/H/CtCsS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000332, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5589,
    label = "C/H/CtCsS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00189, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5590,
    label = "C/H/CtCsS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000924, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5591,
    label = "C/H/CtCsS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.000113, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5592,
    label = "C/H/CtCsS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.000961, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5593,
    label = "C/H/CtCsS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (3.39e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5594,
    label = "C/H/CtCsS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0024, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5595,
    label = "C/H/CtCsS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000622, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5596,
    label = "C/H/CtCsS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000184, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5597,
    label = "C/H/CtCsS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0018, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5598,
    label = "C/H/CtCsS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (5.71e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5599,
    label = "C/H/CtCsS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00176, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5600,
    label = "C/H/CtCsS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000583, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5601,
    label = "C/H/CtCsS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (2.25e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5602,
    label = "C/H/CtCsS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00448, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5603,
    label = "C/H/CtCsS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00199, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5604,
    label = "C/H/CtCsS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00207, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5605,
    label = "C/H/CtCsS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0057, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5606,
    label = "C/H/CtCsS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00214, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5688,
    label = "C/H/CtCsS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000486, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5607,
    label = "C/H/CtCsS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000333, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5608,
    label = "C/H/CtCsS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000736, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5609,
    label = "C/H/CtCsS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000336, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5610,
    label = "C/H/CtCsS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00047, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5611,
    label = "C/H/CtCsS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000575, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5612,
    label = "C/H/CtCsS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000209, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5613,
    label = "C/H/CtCsS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000369, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-11.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5614,
    label = "C/H/CtCsS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0179, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5615,
    label = "C/H/CtCsS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000907, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5616,
    label = "C/H/CtCsS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (9.18e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5617,
    label = "C/H/CtCsS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00146, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5618,
    label = "C/H/CtCsS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.000306, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5619,
    label = "C/H/CtCsS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00114, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5620,
    label = "C/H/CtCsS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.000354, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5621,
    label = "C/H/CtCsS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000217, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5622,
    label = "C/H/CtCsS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (6.18e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5623,
    label = "C/H/CtCsS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0154, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5624,
    label = "C/H/CtCsS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00775, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5625,
    label = "C/H/CtCsS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00369, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5626,
    label = "C/H/CtCsS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00647, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5627,
    label = "C/H/CtCsS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0181, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5628,
    label = "C/H2/CbS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.135, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5629,
    label = "C/H2/CbS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00321, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5630,
    label = "C/H2/CbS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000436, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5631,
    label = "C/H2/CbS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000486, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5632,
    label = "C/H2/CbS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000471, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5633,
    label = "C/H2/CbS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.00178, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5634,
    label = "C/H2/CbS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00107, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5635,
    label = "C/H2/CbS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00016, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5636,
    label = "C/H2/CbS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0011, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5637,
    label = "C/H2/CbS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (4.77e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5638,
    label = "C/H2/CbS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00091, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5639,
    label = "C/H2/CbS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.000289, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5640,
    label = "C/H2/CbS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5641,
    label = "C/H2/CbS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000335, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5642,
    label = "C/H2/CbS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (1.3e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5643,
    label = "C/H2/CbS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.00165, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5644,
    label = "C/H2/CbS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000672, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5645,
    label = "C/H2/CbS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (3.18e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5646,
    label = "C/H2/CbS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00346, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5647,
    label = "C/H2/CbS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00189, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5648,
    label = "C/H2/CbS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0016, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5649,
    label = "C/H2/CbS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0044, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5650,
    label = "C/H2/CbS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.00202, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5733,
    label = "C/H2/CbS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000375, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5651,
    label = "C/H2/CbS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000267, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5652,
    label = "C/H2/CbS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000722, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5653,
    label = "C/H2/CbS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000404, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5654,
    label = "C/H2/CbS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.000386, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5655,
    label = "C/H2/CbS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000579, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5656,
    label = "C/H2/CbS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.000258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5657,
    label = "C/H2/CbS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000304, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5658,
    label = "C/H2/CbS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0138, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5659,
    label = "C/H2/CbS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000886, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5660,
    label = "C/H2/CbS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00011, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5661,
    label = "C/H2/CbS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.00125, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5662,
    label = "C/H2/CbS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00032, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5663,
    label = "C/H2/CbS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000449, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5664,
    label = "C/H2/CbS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00017, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5665,
    label = "C/H2/CbS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.000212, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5666,
    label = "C/H2/CbS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (7.38e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5667,
    label = "C/H2/CbS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0119, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5668,
    label = "C/H2/CbS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00733, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5669,
    label = "C/H2/CbS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00296, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5670,
    label = "C/H2/CbS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00499, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5671,
    label = "C/H2/CbS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.014, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5672,
    label = "C/H/CbCsS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.0766, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5673,
    label = "C/H/CbCsS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00182, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5674,
    label = "C/H/CbCsS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000201, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5675,
    label = "C/H/CbCsS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000183, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5676,
    label = "C/H/CbCsS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000145, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5677,
    label = "C/H/CbCsS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.000828, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5678,
    label = "C/H/CbCsS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.000404, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5679,
    label = "C/H/CbCsS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (4.95e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5680,
    label = "C/H/CbCsS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.00042, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5681,
    label = "C/H/CbCsS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (1.48e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5682,
    label = "C/H/CbCsS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.000423, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5683,
    label = "C/H/CbCsS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00011, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5684,
    label = "C/H/CbCsS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (3.25e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5685,
    label = "C/H/CbCsS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.000128, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5686,
    label = "C/H/CbCsS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (4.05e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5687,
    label = "C/H/CbCsS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.000768, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5688,
    label = "C/H/CbCsS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.000255, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5689,
    label = "C/H/CbCsS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (9.86e-06, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5690,
    label = "C/H/CbCsS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00196, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5691,
    label = "C/H/CbCsS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000872, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5692,
    label = "C/H/CbCsS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.000904, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5693,
    label = "C/H/CbCsS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00249, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5694,
    label = "C/H/CbCsS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.000937, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5778,
    label = "C/H/CbCsS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000212, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5695,
    label = "C/H/CbCsS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000146, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5696,
    label = "C/H/CbCsS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.000322, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5697,
    label = "C/H/CbCsS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.000147, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5698,
    label = "C/H/CbCsS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00015, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5699,
    label = "C/H/CbCsS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.000183, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5700,
    label = "C/H/CbCsS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (6.65e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5701,
    label = "C/H/CbCsS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.000118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-11.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5702,
    label = "C/H/CbCsS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.00783, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5703,
    label = "C/H/CbCsS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.000396, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5704,
    label = "C/H/CbCsS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (4.01e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5705,
    label = "C/H/CbCsS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.000466, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5706,
    label = "C/H/CbCsS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (9.75e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5707,
    label = "C/H/CbCsS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.000201, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5708,
    label = "C/H/CbCsS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (6.23e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5709,
    label = "C/H/CbCsS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (9.5e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5710,
    label = "C/H/CbCsS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (2.7e-05, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5711,
    label = "C/H/CbCsS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00675, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5712,
    label = "C/H/CbCsS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.00339, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5713,
    label = "C/H/CbCsS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00161, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5714,
    label = "C/H/CbCsS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00283, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5715,
    label = "C/H/CbCsS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00791, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5716,
    label = "CS_pri;H_rad",
    kinetics = ArrheniusEP(
        A = (0.623, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5717,
    label = "CS_pri;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.0148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5718,
    label = "CS_pri;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00253, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5719,
    label = "CS_pri;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00357, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5720,
    label = "CS_pri;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00438, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5721,
    label = "CS_pri;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.04, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5722,
    label = "CS_pri;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0302, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5723,
    label = "CS_pri;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00573, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5724,
    label = "CS_pri;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.121, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5725,
    label = "CS_pri;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00659, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5726,
    label = "CS_pri;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0204, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5727,
    label = "CS_pri;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00819, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5728,
    label = "CS_pri;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00376, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5729,
    label = "CS_pri;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0366, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5730,
    label = "CS_pri;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.0018, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5731,
    label = "CS_pri;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0371, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5732,
    label = "CS_pri;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.0191, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5733,
    label = "CS_pri;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.00114, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5734,
    label = "CS_pri;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0159, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5735,
    label = "CS_pri;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.011, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5736,
    label = "CS_pri;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00734, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5737,
    label = "CS_pri;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0203, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5738,
    label = "CS_pri;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0452, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5823,
    label = "CS_pri;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00172, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5739,
    label = "CS_pri;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.0059, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5740,
    label = "CS_pri;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.0202, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5741,
    label = "CS_pri;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.0143, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5742,
    label = "CS_pri;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0483, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5743,
    label = "CS_pri;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0915, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5744,
    label = "CS_pri;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0514, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5745,
    label = "CS_pri;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0379, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5746,
    label = "CS_pri;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0636, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5747,
    label = "CS_pri;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0954, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5748,
    label = "CS_pri;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.015, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5749,
    label = "CS_pri;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.751, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5750,
    label = "CS_pri;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.243, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (31.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5751,
    label = "CS_pri;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0484, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5752,
    label = "CS_pri;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.0232, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5753,
    label = "CS_pri;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.0229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5754,
    label = "CS_pri;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.0101, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5755,
    label = "CS_pri;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0548, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5756,
    label = "CS_pri;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0426, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5757,
    label = "CS_pri;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0653, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5758,
    label = "CS_pri;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.023, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5759,
    label = "CS_pri;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0643, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5760,
    label = "CS/H/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (0.252, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5761,
    label = "CS/H/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00598, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5762,
    label = "CS/H/NonDeC;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000838, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5763,
    label = "CS/H/NonDeC;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.000966, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5764,
    label = "CS/H/NonDeC;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.000967, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5765,
    label = "CS/H/NonDeC;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0133, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5766,
    label = "CS/H/NonDeC;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0082, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5767,
    label = "CS/H/NonDeC;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00127, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5768,
    label = "CS/H/NonDeC;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0329, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (23.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5769,
    label = "CS/H/NonDeC;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00147, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5770,
    label = "CS/H/NonDeC;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00678, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5771,
    label = "CS/H/NonDeC;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00222, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5772,
    label = "CS/H/NonDeC;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.000833, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5773,
    label = "CS/H/NonDeC;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00998, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5774,
    label = "CS/H/NonDeC;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000401, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5775,
    label = "CS/H/NonDeC;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0123, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5776,
    label = "CS/H/NonDeC;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00517, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5777,
    label = "CS/H/NonDeC;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000253, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5778,
    label = "CS/H/NonDeC;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00645, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5779,
    label = "CS/H/NonDeC;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00363, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5780,
    label = "CS/H/NonDeC;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00298, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5781,
    label = "CS/H/NonDeC;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.0082, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5782,
    label = "CS/H/NonDeC;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.015, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5868,
    label = "CS/H/NonDeC;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000699, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5783,
    label = "CS/H/NonDeC;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.0023, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5784,
    label = "CS/H/NonDeC;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00643, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5785,
    label = "CS/H/NonDeC;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00372, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5786,
    label = "CS/H/NonDeC;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0134, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5787,
    label = "CS/H/NonDeC;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0207, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5788,
    label = "CS/H/NonDeC;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00951, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5789,
    label = "CS/H/NonDeC;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5790,
    label = "CS/H/NonDeC;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0258, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5791,
    label = "CS/H/NonDeC;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0306, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5792,
    label = "CS/H/NonDeC;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00391, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5793,
    label = "CS/H/NonDeC;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.2, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5794,
    label = "CS/H/NonDeC;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.053, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (27.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5795,
    label = "CS/H/NonDeC;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5796,
    label = "CS/H/NonDeC;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00608, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5797,
    label = "CS/H/NonDeC;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00733, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5798,
    label = "CS/H/NonDeC;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00263, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5799,
    label = "CS/H/NonDeC;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0222, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5800,
    label = "CS/H/NonDeC;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0141, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5801,
    label = "CS/H/NonDeC;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0255, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5802,
    label = "CS/H/NonDeC;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00931, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5803,
    label = "CS/H/NonDeC;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.026, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5804,
    label = "CS/H/NonDeS;H_rad",
    kinetics = ArrheniusEP(
        A = (0.246, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5805,
    label = "CS/H/NonDeS;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00582, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5806,
    label = "CS/H/NonDeS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000963, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5807,
    label = "CS/H/NonDeS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00131, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5808,
    label = "CS/H/NonDeS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5809,
    label = "CS/H/NonDeS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0125, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5810,
    label = "CS/H/NonDeS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.00908, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5811,
    label = "CS/H/NonDeS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00166, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5812,
    label = "CS/H/NonDeS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0297, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5813,
    label = "CS/H/NonDeS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00157, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5814,
    label = "CS/H/NonDeS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00636, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5815,
    label = "CS/H/NonDeS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00246, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5816,
    label = "CS/H/NonDeS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00109, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5817,
    label = "CS/H/NonDeS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.00902, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5818,
    label = "CS/H/NonDeS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000428, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5819,
    label = "CS/H/NonDeS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0116, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5820,
    label = "CS/H/NonDeS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00573, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5821,
    label = "CS/H/NonDeS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.00033, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5822,
    label = "CS/H/NonDeS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00627, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5823,
    label = "CS/H/NonDeS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00417, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5824,
    label = "CS/H/NonDeS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.0029, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5825,
    label = "CS/H/NonDeS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00798, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5826,
    label = "CS/H/NonDeS;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0141, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5913,
    label = "CS/H/NonDeS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.00068, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5827,
    label = "CS/H/NonDeS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.000612, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5828,
    label = "CS/H/NonDeS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00202, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5829,
    label = "CS/H/NonDeS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00137, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5830,
    label = "CS/H/NonDeS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.00454, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5831,
    label = "CS/H/NonDeS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.00829, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5832,
    label = "CS/H/NonDeS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.00449, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5833,
    label = "CS/H/NonDeS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.00357, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5834,
    label = "CS/H/NonDeS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0251, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5835,
    label = "CS/H/NonDeS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.00783, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5836,
    label = "CS/H/NonDeS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00118, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5837,
    label = "CS/H/NonDeS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.0186, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5838,
    label = "CS/H/NonDeS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.00579, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5839,
    label = "CS/H/NonDeS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.00397, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5840,
    label = "CS/H/NonDeS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00184, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5841,
    label = "CS/H/NonDeS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00188, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5842,
    label = "CS/H/NonDeS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.000795, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5843,
    label = "CS/H/NonDeS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0216, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5844,
    label = "CS/H/NonDeS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0162, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5845,
    label = "CS/H/NonDeS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.00677, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5846,
    label = "CS/H/NonDeS;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00906, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5847,
    label = "CS/H/NonDeS;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0253, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5848,
    label = "CS/H/Cd;H_rad",
    kinetics = ArrheniusEP(
        A = (0.216, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5849,
    label = "CS/H/Cd;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00512, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5850,
    label = "CS/H/Cd;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.000879, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5851,
    label = "CS/H/Cd;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00124, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5852,
    label = "CS/H/Cd;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00152, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5853,
    label = "CS/H/Cd;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0139, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5854,
    label = "CS/H/Cd;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0105, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5855,
    label = "CS/H/Cd;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00199, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5856,
    label = "CS/H/Cd;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0418, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5857,
    label = "CS/H/Cd;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00228, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (26.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5858,
    label = "CS/H/Cd;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.00707, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5859,
    label = "CS/H/Cd;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00284, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5860,
    label = "CS/H/Cd;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.0013, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5861,
    label = "CS/H/Cd;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0127, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5862,
    label = "CS/H/Cd;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.000624, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5863,
    label = "CS/H/Cd;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0129, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5864,
    label = "CS/H/Cd;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00661, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5865,
    label = "CS/H/Cd;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000395, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5866,
    label = "CS/H/Cd;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00552, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5867,
    label = "CS/H/Cd;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.0038, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5868,
    label = "CS/H/Cd;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00255, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5869,
    label = "CS/H/Cd;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00702, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5870,
    label = "CS/H/Cd;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0157, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5958,
    label = "CS/H/Cd;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000598, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5871,
    label = "CS/H/Cd;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00205, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5872,
    label = "CS/H/Cd;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.007, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5873,
    label = "CS/H/Cd;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00495, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5874,
    label = "CS/H/Cd;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0167, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5875,
    label = "CS/H/Cd;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0317, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (22.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5876,
    label = "CS/H/Cd;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0178, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5877,
    label = "CS/H/Cd;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0132, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5878,
    label = "CS/H/Cd;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0221, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5879,
    label = "CS/H/Cd;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0331, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5880,
    label = "CS/H/Cd;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00519, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5881,
    label = "CS/H/Cd;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.26, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5882,
    label = "CS/H/Cd;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.0843, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (30.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5883,
    label = "CS/H/Cd;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0168, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5884,
    label = "CS/H/Cd;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00806, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5885,
    label = "CS/H/Cd;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00793, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5886,
    label = "CS/H/Cd;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00349, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5887,
    label = "CS/H/Cd;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.019, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5888,
    label = "CS/H/Cd;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0148, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5889,
    label = "CS/H/Cd;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0227, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5890,
    label = "CS/H/Cd;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00797, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5891,
    label = "CS/H/Cd;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0223, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5892,
    label = "CS/H/Ct;H_rad",
    kinetics = ArrheniusEP(
        A = (0.26, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5893,
    label = "CS/H/Ct;C_methyl",
    kinetics = ArrheniusEP(
        A = (0.00615, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5894,
    label = "CS/H/Ct;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (0.00106, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5895,
    label = "CS/H/Ct;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00149, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5896,
    label = "CS/H/Ct;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (0.00183, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5897,
    label = "CS/H/Ct;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (0.0167, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5898,
    label = "CS/H/Ct;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (0.0126, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5899,
    label = "CS/H/Ct;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.00239, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5900,
    label = "CS/H/Ct;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (0.0502, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5901,
    label = "CS/H/Ct;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.00275, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (25.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5902,
    label = "CS/H/Ct;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0085, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5903,
    label = "CS/H/Ct;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (0.00341, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5904,
    label = "CS/H/Ct;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.00157, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5905,
    label = "CS/H/Ct;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.0153, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5906,
    label = "CS/H/Ct;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.00075, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (20.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5907,
    label = "CS/H/Ct;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (0.0155, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5908,
    label = "CS/H/Ct;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.00794, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (14.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5909,
    label = "CS/H/Ct;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.000475, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5910,
    label = "CS/H/Ct;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.00663, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5911,
    label = "CS/H/Ct;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (0.00457, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5912,
    label = "CS/H/Ct;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00306, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5913,
    label = "CS/H/Ct;Cb_rad",
    kinetics = ArrheniusEP(
        A = (0.00844, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (-4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5914,
    label = "CS/H/Ct;Cd_Cdd_rad/H",
    kinetics = ArrheniusEP(
        A = (0.0189, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 6003,
    label = "CS/H/Ct;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.000719, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5915,
    label = "CS/H/Ct;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (0.00246, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5916,
    label = "CS/H/Ct;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (0.00841, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5917,
    label = "CS/H/Ct;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (0.00595, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5918,
    label = "CS/H/Ct;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (0.0201, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (18.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5919,
    label = "CS/H/Ct;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (0.0381, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (21.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5920,
    label = "CS/H/Ct;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (0.0214, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (24.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5921,
    label = "CS/H/Ct;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (0.0158, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5922,
    label = "CS/H/Ct;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (0.0265, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (13.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5923,
    label = "CS/H/Ct;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.0398, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5924,
    label = "CS/H/Ct;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.00623, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (19, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5925,
    label = "CS/H/Ct;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (0.313, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (28.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5926,
    label = "CS/H/Ct;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.101, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (29.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5927,
    label = "CS/H/Ct;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (0.0202, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5928,
    label = "CS/H/Ct;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.00968, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (17.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5929,
    label = "CS/H/Ct;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.00953, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (16.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5930,
    label = "CS/H/Ct;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.00419, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5931,
    label = "CS/H/Ct;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (0.0229, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5932,
    label = "CS/H/Ct;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (0.0178, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5933,
    label = "CS/H/Ct;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (0.0272, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (11.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5934,
    label = "CS/H/Ct;CS_rad/Cd",
    kinetics = ArrheniusEP(
        A = (0.00958, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (12.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 5935,
    label = "CS/H/Ct;CS_rad/Ct",
    kinetics = ArrheniusEP(
        A = (0.0268, 'cm^3/(mol*s)'),
        n = 4.34,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--C abstractions, Aaron Vandeputte""",
)

entry(
    index = 6000,
    label = "S_pri;H_rad",
    kinetics = ArrheniusEP(
        A = (13000, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6001,
    label = "S_pri;C_methyl",
    kinetics = ArrheniusEP(
        A = (235, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6002,
    label = "S_pri;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (16.7, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6003,
    label = "S_pri;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (33.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6004,
    label = "S_pri;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (129, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6005,
    label = "S_pri;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (310, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6006,
    label = "S_pri;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (129, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6007,
    label = "S_pri;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (110, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6008,
    label = "S_pri;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (19.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6009,
    label = "S_pri;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (121, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6010,
    label = "S_pri;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (116, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6011,
    label = "S_pri;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (20.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6012,
    label = "S_pri;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (159, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (15.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6013,
    label = "S_pri;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (8.52, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6014,
    label = "S_pri;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (113, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6015,
    label = "S_pri;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (39.7, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6016,
    label = "S_pri;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (12.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6017,
    label = "S_pri;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (39.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6018,
    label = "S_pri;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (3.14, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (12.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6019,
    label = "S_pri;Cb_rad",
    kinetics = ArrheniusEP(
        A = (433, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6020,
    label = "S_pri;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (83.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6021,
    label = "S_pri;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (12.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6022,
    label = "S_pri;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (5.39, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6023,
    label = "S_pri;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (29.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6024,
    label = "S_pri;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (63.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6025,
    label = "S_pri;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (19.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6026,
    label = "S_pri;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (59.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (11.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6027,
    label = "S_pri;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (47.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (13.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6028,
    label = "S_pri;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (31.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (15.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6029,
    label = "S_pri;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (181, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6030,
    label = "S_pri;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (115, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6031,
    label = "S_pri;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (60.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6032,
    label = "S_pri;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (14.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (8.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6033,
    label = "S_pri;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (130, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (19.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6034,
    label = "S_pri;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (51.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (20.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6035,
    label = "S_pri;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (91.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (8.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6036,
    label = "S_pri;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (29.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6037,
    label = "S_pri;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (41.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6038,
    label = "S_pri;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (10.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6039,
    label = "S_pri;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (644, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6040,
    label = "S_pri;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (398, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6041,
    label = "S_pri;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (240, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6042,
    label = "S/H/NonDeC;H_rad",
    kinetics = ArrheniusEP(
        A = (17500, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6043,
    label = "S/H/NonDeC;C_methyl",
    kinetics = ArrheniusEP(
        A = (316, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6044,
    label = "S/H/NonDeC;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (20.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6045,
    label = "S/H/NonDeC;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (39.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6046,
    label = "S/H/NonDeC;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (138, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6047,
    label = "S/H/NonDeC;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (417, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6048,
    label = "S/H/NonDeC;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (161, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6049,
    label = "S/H/NonDeC;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (148, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6050,
    label = "S/H/NonDeC;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (26, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6051,
    label = "S/H/NonDeC;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (217, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6052,
    label = "S/H/NonDeC;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (193, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6053,
    label = "S/H/NonDeC;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (31, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6054,
    label = "S/H/NonDeC;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (381, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (12.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6055,
    label = "S/H/NonDeC;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (18.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (12.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6056,
    label = "S/H/NonDeC;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (189, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6057,
    label = "S/H/NonDeC;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (61.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6058,
    label = "S/H/NonDeC;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (18.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6059,
    label = "S/H/NonDeC;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (82.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6060,
    label = "S/H/NonDeC;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (6.02, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6061,
    label = "S/H/NonDeC;Cb_rad",
    kinetics = ArrheniusEP(
        A = (583, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6062,
    label = "S/H/NonDeC;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (150, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6063,
    label = "S/H/NonDeC;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (21.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6064,
    label = "S/H/NonDeC;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (8.33, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6065,
    label = "S/H/NonDeC;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (42.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6066,
    label = "S/H/NonDeC;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (85.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6067,
    label = "S/H/NonDeC;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (24.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6068,
    label = "S/H/NonDeC;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (232, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6069,
    label = "S/H/NonDeC;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (172, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (10.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6070,
    label = "S/H/NonDeC;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (105, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (12.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6071,
    label = "S/H/NonDeC;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (263, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6072,
    label = "S/H/NonDeC;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (155, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (8.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6073,
    label = "S/H/NonDeC;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (118, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6074,
    label = "S/H/NonDeC;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (25.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6075,
    label = "S/H/NonDeC;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (549, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (16.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6076,
    label = "S/H/NonDeC;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (200, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (17.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6077,
    label = "S/H/NonDeC;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (164, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6078,
    label = "S/H/NonDeC;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (49.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6079,
    label = "S/H/NonDeC;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (79.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6080,
    label = "S/H/NonDeC;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (19.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6081,
    label = "S/H/NonDeC;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (866, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6082,
    label = "S/H/NonDeC;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (497, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6083,
    label = "S/H/NonDeC;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (348, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6084,
    label = "S/H/Cd;H_rad",
    kinetics = ArrheniusEP(
        A = (24000, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6085,
    label = "S/H/Cd;C_methyl",
    kinetics = ArrheniusEP(
        A = (433, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6086,
    label = "S/H/Cd;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (28.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6087,
    label = "S/H/Cd;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (54.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6088,
    label = "S/H/Cd;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (197, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6089,
    label = "S/H/Cd;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (571, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6090,
    label = "S/H/Cd;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (224, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6091,
    label = "S/H/Cd;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (203, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6092,
    label = "S/H/Cd;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (35.7, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6093,
    label = "S/H/Cd;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (170, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6094,
    label = "S/H/Cd;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (152, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6095,
    label = "S/H/Cd;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (24.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6096,
    label = "S/H/Cd;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (170, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6097,
    label = "S/H/Cd;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (8.52, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6098,
    label = "S/H/Cd;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (227, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6099,
    label = "S/H/Cd;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (74.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6100,
    label = "S/H/Cd;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (22.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6101,
    label = "S/H/Cd;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (86.7, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6102,
    label = "S/H/Cd;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (6.41, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6103,
    label = "S/H/Cd;Cb_rad",
    kinetics = ArrheniusEP(
        A = (799, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6104,
    label = "S/H/Cd;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (118, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6105,
    label = "S/H/Cd;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (17, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6106,
    label = "S/H/Cd;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (6.66, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6107,
    label = "S/H/Cd;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (64.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6108,
    label = "S/H/Cd;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (131, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6109,
    label = "S/H/Cd;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (38.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6110,
    label = "S/H/Cd;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (109, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6111,
    label = "S/H/Cd;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (82, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6112,
    label = "S/H/Cd;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (50.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6113,
    label = "S/H/Cd;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (398, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6114,
    label = "S/H/Cd;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (212, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6115,
    label = "S/H/Cd;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (102, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6116,
    label = "S/H/Cd;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (22.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6117,
    label = "S/H/Cd;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (285, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (13.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6118,
    label = "S/H/Cd;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (105, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (14.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6119,
    label = "S/H/Cd;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (218, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6120,
    label = "S/H/Cd;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (66.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6121,
    label = "S/H/Cd;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (68.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6122,
    label = "S/H/Cd;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (17.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6123,
    label = "S/H/Cd;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (1190, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6124,
    label = "S/H/Cd;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (689, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6125,
    label = "S/H/Cd;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (527, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6126,
    label = "S/H/CS;H_rad",
    kinetics = ArrheniusEP(
        A = (10800, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6127,
    label = "S/H/CS;C_methyl",
    kinetics = ArrheniusEP(
        A = (195, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6128,
    label = "S/H/CS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (8.64, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6129,
    label = "S/H/CS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (10.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6130,
    label = "S/H/CS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (25.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6131,
    label = "S/H/CS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (258, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6132,
    label = "S/H/CS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (67, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6133,
    label = "S/H/CS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (91.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6134,
    label = "S/H/CS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (16.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6135,
    label = "S/H/CS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (9.36, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6136,
    label = "S/H/CS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (5.57, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6137,
    label = "S/H/CS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (0.602, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6138,
    label = "S/H/CS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (1.14, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (10.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6139,
    label = "S/H/CS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (0.0381, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (10.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6140,
    label = "S/H/CS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (10.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6141,
    label = "S/H/CS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (2.36, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6142,
    label = "S/H/CS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (0.475, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6143,
    label = "S/H/CS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (0.436, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (8.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6144,
    label = "S/H/CS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.0214, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (8.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6145,
    label = "S/H/CS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (360, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6146,
    label = "S/H/CS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (6.48, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6147,
    label = "S/H/CS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (0.621, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6148,
    label = "S/H/CS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (0.162, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6149,
    label = "S/H/CS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (4.42, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6150,
    label = "S/H/CS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (5.91, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6151,
    label = "S/H/CS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (1.15, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6152,
    label = "S/H/CS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (5.38, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6153,
    label = "S/H/CS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (2.69, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6154,
    label = "S/H/CS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (1.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (10.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6155,
    label = "S/H/CS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (27.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6156,
    label = "S/H/CS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (95.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6157,
    label = "S/H/CS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (0.845, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6158,
    label = "S/H/CS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (0.124, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6159,
    label = "S/H/CS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (2.12, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (14.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6160,
    label = "S/H/CS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (0.52, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (15.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6161,
    label = "S/H/CS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (1.57, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6162,
    label = "S/H/CS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (0.319, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6163,
    label = "S/H/CS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (0.571, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6164,
    label = "S/H/CS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (0.0945, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6165,
    label = "S/H/CS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (535, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6166,
    label = "S/H/CS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (206, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6167,
    label = "S/H/CS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (35.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6168,
    label = "S/H/Ct;H_rad",
    kinetics = ArrheniusEP(
        A = (24300, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6169,
    label = "S/H/Ct;C_methyl",
    kinetics = ArrheniusEP(
        A = (438, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6170,
    label = "S/H/Ct;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (21, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6171,
    label = "S/H/Ct;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (28.7, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6172,
    label = "S/H/Ct;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (74, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-7.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6173,
    label = "S/H/Ct;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (577, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6174,
    label = "S/H/Ct;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (163, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6175,
    label = "S/H/Ct;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (205, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6176,
    label = "S/H/Ct;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (36.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6177,
    label = "S/H/Ct;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (153, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6178,
    label = "S/H/Ct;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (98.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6179,
    label = "S/H/Ct;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (11.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6180,
    label = "S/H/Ct;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (135, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6181,
    label = "S/H/Ct;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (4.89, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6182,
    label = "S/H/Ct;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (82.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6183,
    label = "S/H/Ct;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (19.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6184,
    label = "S/H/Ct;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (4.26, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6185,
    label = "S/H/Ct;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (11.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6186,
    label = "S/H/Ct;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (0.603, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6187,
    label = "S/H/Ct;Cb_rad",
    kinetics = ArrheniusEP(
        A = (807, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6188,
    label = "S/H/Ct;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (106, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6189,
    label = "S/H/Ct;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (11, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6190,
    label = "S/H/Ct;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (3.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6191,
    label = "S/H/Ct;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (68.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6192,
    label = "S/H/Ct;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (99.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6193,
    label = "S/H/Ct;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (20.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6194,
    label = "S/H/Ct;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (31, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6195,
    label = "S/H/Ct;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (16.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6196,
    label = "S/H/Ct;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (7.45, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6197,
    label = "S/H/Ct;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (421, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6198,
    label = "S/H/Ct;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (214, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6199,
    label = "S/H/Cb;H_rad",
    kinetics = ArrheniusEP(
        A = (19300, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6200,
    label = "S/H/Cb;C_methyl",
    kinetics = ArrheniusEP(
        A = (348, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6201,
    label = "S/H/Cb;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (23.2, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6202,
    label = "S/H/Cb;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (44.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6203,
    label = "S/H/Cb;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (158, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6204,
    label = "S/H/Cb;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (458, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6205,
    label = "S/H/Cb;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (180, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6206,
    label = "S/H/Cb;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (163, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6207,
    label = "S/H/Cb;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (28.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6208,
    label = "S/H/Cb;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (136, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6209,
    label = "S/H/Cb;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (122, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6210,
    label = "S/H/Cb;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (19.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6211,
    label = "S/H/Cb;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (136, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (10.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6212,
    label = "S/H/Cb;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (6.83, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6213,
    label = "S/H/Cb;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (182, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6214,
    label = "S/H/Cb;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (59.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6215,
    label = "S/H/Cb;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (18.2, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6216,
    label = "S/H/Cb;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (69.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6217,
    label = "S/H/Cb;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (5.14, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6218,
    label = "S/H/Cb;Cb_rad",
    kinetics = ArrheniusEP(
        A = (641, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6219,
    label = "S/H/Cb;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (94.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6220,
    label = "S/H/Cb;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (13.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6221,
    label = "S/H/Cb;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (5.34, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6222,
    label = "S/H/Cb;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (52.1, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6223,
    label = "S/H/Cb;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (105, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6224,
    label = "S/H/Cb;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (30.7, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6225,
    label = "S/H/Cb;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (87.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6226,
    label = "S/H/Cb;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (65.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6227,
    label = "S/H/Cb;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (40.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6228,
    label = "S/H/Cb;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (320, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6229,
    label = "S/H/Cb;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (170, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (7.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6230,
    label = "S/H/Cb;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (81.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6231,
    label = "S/H/Cb;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (18, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6232,
    label = "S/H/Cb;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (229, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (13.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6233,
    label = "S/H/Cb;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (84.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (14.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6234,
    label = "S/H/Cb;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (175, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6235,
    label = "S/H/Cb;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (53.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6236,
    label = "S/H/Cb;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (55, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6237,
    label = "S/H/Cb;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (13.7, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6238,
    label = "S/H/Cb;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (953, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6239,
    label = "S/H/Cb;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (553, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6240,
    label = "S/H/Cb;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (423, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6241,
    label = "S/H/NonDeS;H_rad",
    kinetics = ArrheniusEP(
        A = (22200, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6242,
    label = "S/H/NonDeS;C_methyl",
    kinetics = ArrheniusEP(
        A = (400, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6243,
    label = "S/H/NonDeS;C_rad/H2/Cs",
    kinetics = ArrheniusEP(
        A = (36.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6244,
    label = "S/H/NonDeS;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (94.2, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6245,
    label = "S/H/NonDeS;C_rad/Cs3",
    kinetics = ArrheniusEP(
        A = (460, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-6.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6246,
    label = "S/H/NonDeS;Cd_pri_rad",
    kinetics = ArrheniusEP(
        A = (527, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6247,
    label = "S/H/NonDeS;Cd_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (282, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6248,
    label = "S/H/NonDeS;Cd_rad/Cd",
    kinetics = ArrheniusEP(
        A = (187, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6249,
    label = "S/H/NonDeS;Cd_rad/Ct",
    kinetics = ArrheniusEP(
        A = (32.9, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6250,
    label = "S/H/NonDeS;C_rad/H2/Cd",
    kinetics = ArrheniusEP(
        A = (144, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6251,
    label = "S/H/NonDeS;C_rad/H/CdCs",
    kinetics = ArrheniusEP(
        A = (176, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6252,
    label = "S/H/NonDeS;C_rad/CdCs2",
    kinetics = ArrheniusEP(
        A = (39, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6253,
    label = "S/H/NonDeS;C_rad/H/CdCd",
    kinetics = ArrheniusEP(
        A = (132, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6254,
    label = "S/H/NonDeS;C_rad/CdCdCs",
    kinetics = ArrheniusEP(
        A = (9.01, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6255,
    label = "S/H/NonDeS;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (239, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6256,
    label = "S/H/NonDeS;C_rad/H/CtCs",
    kinetics = ArrheniusEP(
        A = (107, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6257,
    label = "S/H/NonDeS;C_rad/CtCs2",
    kinetics = ArrheniusEP(
        A = (44.3, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6258,
    label = "S/H/NonDeS;C_rad/H/CtCt",
    kinetics = ArrheniusEP(
        A = (104, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6259,
    label = "S/H/NonDeS;C_rad/CtCtCs",
    kinetics = ArrheniusEP(
        A = (10.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6260,
    label = "S/H/NonDeS;Cb_rad",
    kinetics = ArrheniusEP(
        A = (737, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6261,
    label = "S/H/NonDeS;C_rad/H2/Cb",
    kinetics = ArrheniusEP(
        A = (99.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6262,
    label = "S/H/NonDeS;C_rad/H/CbCs",
    kinetics = ArrheniusEP(
        A = (19.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6263,
    label = "S/H/NonDeS;C_rad/CbCs2",
    kinetics = ArrheniusEP(
        A = (10.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-3.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6264,
    label = "S/H/NonDeS;C_rad/H2/S",
    kinetics = ArrheniusEP(
        A = (59.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6265,
    label = "S/H/NonDeS;C_rad/H/CsS",
    kinetics = ArrheniusEP(
        A = (164, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-4.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6266,
    label = "S/H/NonDeS;C_rad/Cs2S",
    kinetics = ArrheniusEP(
        A = (65.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-5.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6267,
    label = "S/H/NonDeS;C_rad/H2/CS",
    kinetics = ArrheniusEP(
        A = (89.5, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (3.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6268,
    label = "S/H/NonDeS;C_rad/H/CSCs",
    kinetics = ArrheniusEP(
        A = (91.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (4.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6269,
    label = "S/H/NonDeS;C_rad/CSCs2",
    kinetics = ArrheniusEP(
        A = (77.2, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (5.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6270,
    label = "S/H/NonDeS;Cd_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (366, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-6.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6271,
    label = "S/H/NonDeS;Cd_rad/CS",
    kinetics = ArrheniusEP(
        A = (195, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6272,
    label = "S/H/NonDeS;C_rad/H/CdS",
    kinetics = ArrheniusEP(
        A = (85.6, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6273,
    label = "S/H/NonDeS;C_rad/CdCsS",
    kinetics = ArrheniusEP(
        A = (25.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6274,
    label = "S/H/NonDeS;C_rad/H/CSS",
    kinetics = ArrheniusEP(
        A = (233, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (9.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6275,
    label = "S/H/NonDeS;C_rad/CSCsS",
    kinetics = ArrheniusEP(
        A = (117, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (10, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6276,
    label = "S/H/NonDeS;C_rad/H/CtS",
    kinetics = ArrheniusEP(
        A = (228, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6277,
    label = "S/H/NonDeS;C_rad/CtCsS",
    kinetics = ArrheniusEP(
        A = (95.4, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (1.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6278,
    label = "S/H/NonDeS;C_rad/H/CbS",
    kinetics = ArrheniusEP(
        A = (57.8, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6279,
    label = "S/H/NonDeS;C_rad/CbCsS",
    kinetics = ArrheniusEP(
        A = (19.7, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6280,
    label = "S/H/NonDeS;CS_pri_rad",
    kinetics = ArrheniusEP(
        A = (1100, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6281,
    label = "S/H/NonDeS;CS_rad/Cs",
    kinetics = ArrheniusEP(
        A = (867, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 6282,
    label = "S/H/NonDeS;CS_rad/S",
    kinetics = ArrheniusEP(
        A = (484, 'cm^3/(mol*s)'),
        n = 3.06,
        alpha = 0,
        E0 = (-2.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for C--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7000,
    label = "S_pri;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (301, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (4.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7001,
    label = "S_pri;S_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (955, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (10.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7002,
    label = "S_pri;S_rad/Cd",
    kinetics = ArrheniusEP(
        A = (366, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (14.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7003,
    label = "S_pri;S_rad/Ct",
    kinetics = ArrheniusEP(
        A = (1490, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (9.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7004,
    label = "S_pri;S_rad/Cb",
    kinetics = ArrheniusEP(
        A = (467, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (15.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7005,
    label = "S_pri;S_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (1370, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7006,
    label = "S/H/NonDeC;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (903, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7007,
    label = "S/H/NonDeC;S_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (668, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (1.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7008,
    label = "S/H/NonDeC;S_rad/Cd",
    kinetics = ArrheniusEP(
        A = (675, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (6.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7009,
    label = "S/H/NonDeC;S_rad/Ct",
    kinetics = ArrheniusEP(
        A = (716, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (9.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7010,
    label = "S/H/NonDeC;S_rad/Cb",
    kinetics = ArrheniusEP(
        A = (537, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (5.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7011,
    label = "S/H/NonDeC;S_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (557, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (11.1, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7012,
    label = "S/H/Cd;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (931, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7013,
    label = "S/H/Cd;S_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (1810, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-0.6, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7014,
    label = "S/H/Cd;S_rad/Cd",
    kinetics = ArrheniusEP(
        A = (789, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7015,
    label = "S/H/Cd;S_rad/Ct",
    kinetics = ArrheniusEP(
        A = (2110, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (4.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7016,
    label = "S/H/Cd;S_rad/Cb",
    kinetics = ArrheniusEP(
        A = (682, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (1.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7017,
    label = "S/H/Cd;S_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (459, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-1.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7018,
    label = "S/H/Ct;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (493, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7019,
    label = "S/H/Ct;S_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (250, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-0.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7020,
    label = "S/H/Ct;S_rad/Cd",
    kinetics = ArrheniusEP(
        A = (275, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7021,
    label = "S/H/Ct;S_rad/Ct",
    kinetics = ArrheniusEP(
        A = (4210, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7022,
    label = "S/H/Ct;S_rad/Cb",
    kinetics = ArrheniusEP(
        A = (964, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-0.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7023,
    label = "S/H/Ct;S_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (351, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7024,
    label = "S/H/Cb;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (199, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-1.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7025,
    label = "S/H/Cb;S_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (241, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-0.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7026,
    label = "S/H/Cb;S_rad/Cd",
    kinetics = ArrheniusEP(
        A = (114, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (2.5, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7027,
    label = "S/H/Cb;S_rad/Ct",
    kinetics = ArrheniusEP(
        A = (1240, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (3.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7028,
    label = "S/H/Cb;S_rad/Cb",
    kinetics = ArrheniusEP(
        A = (189, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7029,
    label = "S/H/Cb;S_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (384, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (5.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7030,
    label = "S/H/NonDeS;S_pri_rad",
    kinetics = ArrheniusEP(
        A = (1440, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-2.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7031,
    label = "S/H/NonDeS;S_rad/NonDeC",
    kinetics = ArrheniusEP(
        A = (617, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-2.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7032,
    label = "S/H/NonDeS;S_rad/Cd",
    kinetics = ArrheniusEP(
        A = (190, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7033,
    label = "S/H/NonDeS;S_rad/Ct",
    kinetics = ArrheniusEP(
        A = (1110, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-0.3, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7034,
    label = "S/H/NonDeS;S_rad/Cb",
    kinetics = ArrheniusEP(
        A = (948, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (-1.7, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7035,
    label = "S/H/NonDeS;S_rad/NonDeS",
    kinetics = ArrheniusEP(
        A = (113, 'cm^3/(mol*s)'),
        n = 3.15,
        alpha = 0,
        E0 = (0.4, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 4,
    shortDesc = u"""Group additivity method for S--H--S abstractions, Aaron Vandeputte""",
)

entry(
    index = 7036,
    label = "O/H/OneDe;C_rad/H2/Ct",
    kinetics = ArrheniusEP(
        A = (0.0065, 'cm^3/(mol*s)'),
        n = 4.245,
        alpha = 0,
        E0 = (7.2, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CBS-QB3 (RRHO), SSM""",
    longDesc = """SSM CBS-QB3 calculations for propargyl + vinylalcohol (RRHO approximation)""",
)

entry(
    index = 7037,
    label = "Cd_Cdd/H2;O_rad/Cd\H_Cd\H2",
    kinetics = ArrheniusEP(
        A = (0.0021, 'cm^3/(mol*s)'),
        n = 4.36,
        alpha = 0,
        E0 = (14.2, 'kcal/mol'),
        Tmin = (500, 'K'),
        Tmax = (2500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CBS-QB3 (RRHO), SSM""",
    longDesc = """SSM CBS-QB3 calculations for propargyl + vinylalcohol (RRHO approximation)""",
)

entry(
    index = 7038,
    label = "CO/H/Cs;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2e+06, 'cm^3/(mol*s)'),
        n = 1.8,
        alpha = 0,
        E0 = (-1.3, 'kcal/mol'),
        Tmin = (295, 'K'),
        Tmax = (600, 'K'),
    ),
    rank = 5,
    shortDesc = u"""NIST SSM""",
    longDesc = """
NIST CH3CHO + OH = CH3CO + H2O rate coefficient ref: DOI: 10.1016/S0082-0784(96)80252-9
Most estimates seem to be  ~ 3E+12 for 200-350 K range""",
)

entry(
    index = 7039,
    label = "H2O2;CO_rad/Cs",
    kinetics = ArrheniusEP(
        A = (4.33e-06, 'cm^3/(mol*s)'),
        n = 5.09,
        alpha = 0,
        E0 = (1.2, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CCSD(T)/CBS//M08-HX/maug-cc-pVTZ MSTOR""",
    longDesc = """
ref: Role of conformational structures and torsional anharmonicity in controlling chemical reaction rates and
relative yields: butanal + HO2 reactions
Refitted from four parameter fits to three parameters fits,  
""",
)

entry(
    index = 7040,
    label = "H2O2;C_rad/H/CO/Cs",
    kinetics = ArrheniusEP(
        A = (1.62e-11, 'cm^3/(mol*s)'),
        n = 6.525,
        alpha = 0,
        E0 = (2.9, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CCSD(T)/CBS//M08-HX/maug-cc-pVTZ MSTOR""",
    longDesc = """
ref: Role of conformational structures and torsional anharmonicity in controlling chemical reaction rates and
relative yields: butanal + HO2 reactions
Refitted from four parameter fits to three parameters fits,  
""",
)

entry(
    index = 7041,
    label = "H2O2;C_rad/H/Cs\H2\CO/Cs",
    kinetics = ArrheniusEP(
        A = (8.3e-08, 'cm^3/(mol*s)'),
        n = 5.407,
        alpha = 0,
        E0 = (0.04, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 2,
    shortDesc = u"""CCSD(T)/CBS//M08-HX/maug-cc-pVTZ MSTOR""",
    longDesc = """
ref: Role of conformational structures and torsional anharmonicity in controlling chemical reaction rates and
relative yields: butanal + HO2 reactions
Refitted from four parameter fits to three parameters fits,  
""",
)

entry(
    index = 7042,
    label = "H2O2;C_rad/H/NonDeC",
    kinetics = ArrheniusEP(
        A = (8.3e-08, 'cm^3/(mol*s)'),
        n = 5.407,
        alpha = 0,
        E0 = (0.04, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (2000, 'K'),
    ),
    rank = 5,
    shortDesc = u"""Same as C_rad/H/Cs\H2\CO/Cs H2O2""",
    longDesc = """
CCSD(T)/CBS//M08-HX/maug-cc-pVTZ MSTOR.
ref: Role of conformational structures and torsional anharmonicity in controlling chemical reaction rates and
relative yields: butanal + HO2 reactions
Refitted from four parameter fits to three parameters fits,  
""",
)

entry(
    index = 7043,
    label = "C/H2/CdCs;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (33.5, 'cm^3/(mol*s)'),
        n = 3.475,
        alpha = 0,
        E0 = (-2.8, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CCSD(T)/6-311++G(d,p)""",
    longDesc = """
Kinetics of Hydrogen Abstraction Reactions of Butene Isomers by OH Radical
s-allylic site from 1-Butene + OH ref: DOI: 10.1021/jp1062786""",
)

entry(
    index = 7044,
    label = "C/H3/Cd\H_Cd\H\Cs;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2.03, 'cm^3/(mol*s)'),
        n = 3.774,
        alpha = 0,
        E0 = (-1.49, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CCSD(T)/6-311++G(d,p)""",
    longDesc = """
Kinetics of Hydrogen Abstraction Reactions of Butene Isomers by OH Radical
p-allylic site of 2-butene ref: DOI: 10.1021/jp1062786""",
)

entry(
    index = 7045,
    label = "C/H3/Cd\Cs_Cd\H2;O_pri_rad",
    kinetics = ArrheniusEP(
        A = (2, 'cm^3/(mol*s)'),
        n = 3.594,
        alpha = 0,
        E0 = (-1.07, 'kcal/mol'),
        Tmin = (300, 'K'),
        Tmax = (1500, 'K'),
    ),
    rank = 3,
    shortDesc = u"""CCSD(T)/6-311++G(d,p)""",
    longDesc = """
Kinetics of Hydrogen Abstraction Reactions of Butene Isomers by OH Radical
p-allylic site of iso-butene ref: DOI: 10.1021/jp1062786""",
)

