#!/usr/bin/env python
# encoding: utf-8

name = "CHO"
shortDesc = u"Yaws' Critical Property Data for C H and O compounds"
longDesc = u"""
Yaws' Critical Property Data for Chemical Engineers and Chemists
Table 30. Heat Capacity of Gas - Organic Compounds
Table 38. Enthalpy of Formation of Gas - Organic Compounds
Table 46. Entropy of Gas - Organic Compounds

contains molecules only with carbon, hydrogen and oxygen
"""
entry(
    index = 1,
    label = "CH2O",
    molecule = 
"""
1 C u0 p0 c0 {2,D} {3,S} {4,S}
2 O u0 p2 c0 {1,D}
3 H u0 p0 c0 {1,S}
4 H u0 p0 c0 {1,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([8.473,9.391,10.454,11.514,13.37,14.806,17.005],'cal/(mol*K)'),
        H298 = (-25.955,'kcal/mol'),
        S298 = (52.227,'cal/(mol*K)'),
    ),
    shortDesc = u"""formaldehyde""",
    longDesc = 
u"""

""",
)

entry(
    index = 2,
    label = "CH2O2",
    molecule = 
"""
1 C u0 p0 c0 {2,D} {3,S} {4,S}
2 O u0 p2 c0 {1,D}
3 O u0 p2 c0 {1,S} {5,S}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([10.955,13.01,14.969,16.707,19.441,21.367,23.674],'cal/(mol*K)'),
        H298 = (-90.487,'kcal/mol'),
        S298 = (59.507,'cal/(mol*K)'),
    ),
    shortDesc = u"""formic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 3,
    label = "CH4O",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2 O u0 p2 c0 {1,S} {6,S}
3 H u0 p0 c0 {1,S}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {2,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([10.56,12.353,14.269,16.068,19.063,21.401,25.191],'cal/(mol*K)'),
        H298 = (-48.015,'kcal/mol'),
        S298 = (57.326,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 4,
    label = "C2H2O",
    molecule = 
"""
1 C u0 p0 c0 {2,D} {4,S} {5,S}
2 C u0 p0 c0 {1,D} {3,D}
3 O u0 p2 c0 {2,D}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {1,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([12.405,14.2,15.681,16.902,18.795,20.246,22.553],'cal/(mol*K)'),
        H298 = (-11.4,'kcal/mol'),
        S298 = (57.765,'cal/(mol*K)'),
    ),
    shortDesc = u"""ketene""",
    longDesc = 
u"""

""",
)

entry(
    index = 5,
    label = "C2H2O4",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {5,D} {6,S}
2 C u0 p0 c0 {1,S} {3,D} {4,S}
3 O u0 p2 c0 {2,D}
4 O u0 p2 c0 {2,S} {7,S}
5 O u0 p2 c0 {1,D}
6 O u0 p2 c0 {1,S} {8,S}
7 H u0 p0 c0 {4,S}
8 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([20.405,24.419,27.575,29.988,33.356,35.801,39.159],'cal/(mol*K)'),
        H298 = (-172.968,'kcal/mol'),
        S298 = (81.776,'cal/(mol*K)'),
    ),
    shortDesc = u"""oxalic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 6,
    label = "C2H4Oa",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2 C u0 p0 c0 {1,S} {6,D} {7,S}
3 H u0 p0 c0 {1,S}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {1,S}
6 O u0 p2 c0 {2,D}
7 H u0 p0 c0 {2,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([13.268,15.832,18.327,20.562,24.156,26.886,31.092],'cal/(mol*K)'),
        H298 = (-39.722,'kcal/mol'),
        S298 = (63.105,'cal/(mol*K)'),
    ),
    shortDesc = u"""acetaldehyde""",
    longDesc = 
u"""

""",
)

entry(
    index = 7,
    label = "C2H4Ob",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2 C u0 p0 c0 {1,S} {3,S} {6,S} {7,S}
3 O u0 p2 c0 {1,S} {2,S}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {2,S}
7 H u0 p0 c0 {2,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([11.456,14.831,18.026,20.71,24.62,27.488,31.833],'cal/(mol*K)'),
        H298 = (-12.57,'kcal/mol'),
        S298 = (58.136,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylene oxide""",
    longDesc = 
u"""

""",
)

entry(
    index = 8,
    label = "C2H4O2a",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2 C u0 p0 c0 {1,S} {3,S} {7,D}
3 O u0 p2 c0 {2,S} {8,S}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {1,S}
7 O u0 p2 c0 {2,D}
8 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([15.232,18.99,22.45,25.427,29.995,33.284,37.674],'cal/(mol*K)'),
        H298 = (-103.321,'kcal/mol'),
        S298 = (74.634,'cal/(mol*K)'),
    ),
    shortDesc = u"""acetic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 9,
    label = "C2H4O2b",
    molecule = 
"""
1 C u0 p0 c0 {3,S} {4,S} {5,S} {6,S}
2 C u0 p0 c0 {3,S} {7,D} {8,S}
3 O u0 p2 c0 {1,S} {2,S}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {1,S}
7 O u0 p2 c0 {2,D}
8 H u0 p0 c0 {2,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([15.967,19.479,22.6,25.198,29.099,32,35.729],'cal/(mol*K)'),
        H298 = (-83.579,'kcal/mol'),
        S298 = (72.069,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 10,
    label = "C2H6Oa",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2 C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3 O u0 p2 c0 {1,S} {9,S}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {2,S}
7 H u0 p0 c0 {2,S}
8 H u0 p0 c0 {2,S}
9 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([15.653,19.386,22.892,25.915,30.574,34.101,39.677],'cal/(mol*K)'),
        H298 = (-56.165,'kcal/mol'),
        S298 = (67.002,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 11,
    label = "C2H6Ob",
    molecule = 
"""
1 C u0 p0 c0 {3,S} {4,S} {5,S} {6,S}
2 C u0 p0 c0 {3,S} {7,S} {8,S} {9,S}
3 O u0 p2 c0 {1,S} {2,S}
4 H u0 p0 c0 {1,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {1,S}
7 H u0 p0 c0 {2,S}
8 H u0 p0 c0 {2,S}
9 H u0 p0 c0 {2,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([15.728,18.828,21.836,24.585,29.156,32.672,38.186],'cal/(mol*K)'),
        H298 = (-43.999,'kcal/mol'),
        S298 = (63.876,'cal/(mol*K)'),
    ),
    shortDesc = u"""dimethyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 12,
    label = "C2H6O2",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {3,S} {7,S} {8,S}
3  O u0 p2 c0 {2,S} {9,S}
4  O u0 p2 c0 {1,S} {10,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([19.851,24.409,28.537,32.015,37.261,41.085,45.871],'cal/(mol*K)'),
        H298 = (-92.613,'kcal/mol'),
        S298 = (72.598,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylene glycol""",
    longDesc = 
u"""

""",
)

entry(
    index = 13,
    label = "C3H4Oa",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {3,D} {4,S}
2 C u0 p0 c0 {1,S} {5,D} {6,S}
3 C u0 p0 c0 {1,D} {7,S} {8,S}
4 H u0 p0 c0 {1,S}
5 O u0 p2 c0 {2,D}
6 H u0 p0 c0 {2,S}
7 H u0 p0 c0 {3,S}
8 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([17.11,20.924,24.218,26.912,30.808,33.509,37.38],'cal/(mol*K)'),
        H298 = (-20.076,'kcal/mol'),
        S298 = (67.041,'cal/(mol*K)'),
    ),
    shortDesc = u"""acrolein""",
    longDesc = 
u"""

""",
)

entry(
    index = 14,
    label = "C3H4Ob",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2 C u0 p0 c0 {1,S} {4,T}
3 O u0 p2 c0 {1,S} {7,S}
4 C u0 p0 c0 {2,T} {8,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {1,S}
7 H u0 p0 c0 {3,S}
8 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([17.471,20.72,23.477,25.86,29.646,32.271,36.511],'cal/(mol*K)'),
        H298 = (10.087,'kcal/mol'),
        S298 = (70.087,'cal/(mol*K)'),
    ),
    shortDesc = u"""propargyl alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 15,
    label = "C3H4O2a",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {3,D} {5,S}
2 C u0 p0 c0 {1,S} {4,S} {6,D}
3 C u0 p0 c0 {1,D} {7,S} {8,S}
4 O u0 p2 c0 {2,S} {9,S}
5 H u0 p0 c0 {1,S}
6 O u0 p2 c0 {2,D}
7 H u0 p0 c0 {3,S}
8 H u0 p0 c0 {3,S}
9 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([19.639,24.13,27.88,30.832,34.924,37.782,42.017],'cal/(mol*K)'),
        H298 = (-77.317,'kcal/mol'),
        S298 = (73.519,'cal/(mol*K)'),
    ),
    shortDesc = u"""acrylic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 16,
    label = "C3H4O2b",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2 C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3 C u0 p0 c0 {1,S} {4,S} {9,D}
4 O u0 p2 c0 {2,S} {3,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {1,S}
7 H u0 p0 c0 {2,S}
8 H u0 p0 c0 {2,S}
9 O u0 p2 c0 {3,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([17.111,21.766,26.018,29.503,34.448,37.961,42.384],'cal/(mol*K)'),
        H298 = (-70.998,'kcal/mol'),
        S298 = (68.462,'cal/(mol*K)'),
    ),
    shortDesc = u"""propiolactone""",
    longDesc = 
u"""

""",
)

entry(
    index = 17,
    label = "C3H4O2c",
    molecule = 
"""
1 C u0 p0 c0 {2,D} {4,S} {5,S}
2 C u0 p0 c0 {1,D} {6,S} {7,S}
3 C u0 p0 c0 {4,S} {8,D} {9,S}
4 O u0 p2 c0 {1,S} {3,S}
5 H u0 p0 c0 {1,S}
6 H u0 p0 c0 {2,S}
7 H u0 p0 c0 {2,S}
8 O u0 p2 c0 {3,D}
9 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([17.633,22.21,26.167,29.32,33.777,37.099,42.057],'cal/(mol*K)'),
        H298 = (-62.618,'kcal/mol'),
        S298 = (73.119,'cal/(mol*K)'),
    ),
    shortDesc = u"""vinyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 18,
    label = "C3H4O3a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {4,S} {5,S} {10,D}
4  O u0 p2 c0 {1,S} {3,S}
5  O u0 p2 c0 {2,S} {3,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 O u0 p2 c0 {3,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([19.6,24.918,29.756,33.696,39.221,43.117,48.14],'cal/(mol*K)'),
        H298 = (-120.911,'kcal/mol'),
        S298 = (70.379,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylene carbonate""",
    longDesc = 
u"""

""",
)

entry(
    index = 19,
    label = "C3H4O3b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,D}
3  C u0 p0 c0 {2,S} {4,S} {9,D}
4  O u0 p2 c0 {3,S} {10,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  O u0 p2 c0 {2,D}
9  O u0 p2 c0 {3,D}
10 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([21.937,26.533,30.391,33.554,38.265,41.644,47.115],'cal/(mol*K)'),
        H298 = (-149.377,'kcal/mol'),
        S298 = (75.989,'cal/(mol*K)'),
    ),
    shortDesc = u"""pyruvic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 20,
    label = "C3H6Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {3,D} {7,S}
3  C u0 p0 c0 {2,D} {8,S} {9,S}
4  O u0 p2 c0 {1,S} {10,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {3,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([18.252,22.726,26.79,30.189,35.28,39.061,43.611],'cal/(mol*K)'),
        H298 = (-31.523,'kcal/mol'),
        S298 = (73.663,'cal/(mol*K)'),
    ),
    shortDesc = u"""allyl alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 21,
    label = "C3H6Ob",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {3,D} {4,S} {8,S}
3  C u0 p0 c0 {2,D} {9,S} {10,S}
4  O u0 p2 c0 {1,S} {2,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([18.493,22.423,26.208,29.548,34.863,38.968,44.859],'cal/(mol*K)'),
        H298 = (-25.811,'kcal/mol'),
        S298 = (73.663,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl vinyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 22,
    label = "C3H6Oc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,D} {10,S}
4  H u0 p0 c0 {1,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {2,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  O u0 p2 c0 {3,D}
10 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([19.366,23.202,26.984,30.626,37.094,42.137,50.598],'cal/(mol*K)'),
        H298 = (-44.453,'kcal/mol'),
        S298 = (72.781,'cal/(mol*K)'),
    ),
    shortDesc = u"""propionaldehyde""",
    longDesc = 
u"""

""",
)

entry(
    index = 23,
    label = "C3H6Od",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {3,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {2,S} {10,D}
4  H u0 p0 c0 {1,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 O u0 p2 c0 {3,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([17.886,21.945,25.779,29.184,34.639,38.731,45.041],'cal/(mol*K)'),
        H298 = (-51.886,'kcal/mol'),
        S298 = (70.617,'cal/(mol*K)'),
    ),
    shortDesc = u"""acetone""",
    longDesc = 
u"""

""",
)

entry(
    index = 24,
    label = "C3H6Oe",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {4,S} {6,S} {7,S}
3  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
4  O u0 p2 c0 {1,S} {2,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {2,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {3,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([17.439,21.606,25.832,29.779,36.169,40.485,47.99],'cal/(mol*K)'),
        H298 = (-22.168,'kcal/mol'),
        S298 = (68.621,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2-propylene oxide""",
    longDesc = 
u"""

""",
)

entry(
    index = 25,
    label = "C3H6Of",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
4  O u0 p2 c0 {2,S} {3,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([14.904,19.936,24.708,28.733,35.039,40.44,47.936],'cal/(mol*K)'),
        H298 = (-17.938,'kcal/mol'),
        S298 = (63.484,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,3-propylene oxide""",
    longDesc = 
u"""

""",
)

entry(
    index = 26,
    label = "C3H6O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {4,S} {10,D}
4  O u0 p2 c0 {3,S} {11,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 O u0 p2 c0 {3,D}
11 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([21.426,26.35,30.849,34.602,40.167,44.34,50.339],'cal/(mol*K)'),
        H298 = (-108.22,'kcal/mol'),
        S298 = (77.816,'cal/(mol*K)'),
    ),
    shortDesc = u"""propanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 27,
    label = "C3H6O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {4,S} {10,D} {11,S}
4  O u0 p2 c0 {1,S} {3,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 O u0 p2 c0 {3,D}
11 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([21.312,25.646,29.989,34,40.56,45.291,52.139],'cal/(mol*K)'),
        H298 = (-92.804,'kcal/mol'),
        S298 = (78.538,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 28,
    label = "C3H6O2c",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {4,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {4,S} {11,D}
4  O u0 p2 c0 {2,S} {3,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 O u0 p2 c0 {3,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([20.647,25.226,29.493,33.26,39.309,43.752,48.85],'cal/(mol*K)'),
        H298 = (-98.445,'kcal/mol'),
        S298 = (77.496,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 29,
    label = "C3H6O3a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {10,D}
4  O u0 p2 c0 {1,S} {11,S}
5  O u0 p2 c0 {3,S} {12,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 O u0 p2 c0 {3,D}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([25.089,30.56,35.236,39.111,44.899,48.994,55.431],'cal/(mol*K)'),
        H298 = (-148.421,'kcal/mol'),
        S298 = (87.18,'cal/(mol*K)'),
    ),
    shortDesc = u"""lactic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 30,
    label = "C3H6O3b",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {6,S} {7,S}
2  C u0 p0 c0 {4,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {5,S} {11,D}
4  O u0 p2 c0 {1,S} {2,S}
5  O u0 p2 c0 {3,S} {12,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 O u0 p2 c0 {3,D}
12 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.43,29.731,34.471,38.577,44.723,48.503,54.876],'cal/(mol*K)'),
        H298 = (-134.558,'kcal/mol'),
        S298 = (86.379,'cal/(mol*K)'),
    ),
    shortDesc = u"""methoxyacetic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 31,
    label = "C3H8Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  O u0 p2 c0 {2,S} {12,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([20.545,25.774,30.638,34.819,41.257,46.121,53.76],'cal/(mol*K)'),
        H298 = (-60.992,'kcal/mol'),
        S298 = (77.079,'cal/(mol*K)'),
    ),
    shortDesc = u"""propyl alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 32,
    label = "C3H8Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  O u0 p2 c0 {1,S} {12,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {2,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([21.449,26.794,31.539,35.489,41.358,45.643,52.283],'cal/(mol*K)'),
        H298 = (-65.175,'kcal/mol'),
        S298 = (73.872,'cal/(mol*K)'),
    ),
    shortDesc = u"""isopropyl alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 33,
    label = "C3H8Oc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {4,S} {10,S} {11,S} {12,S}
4  O u0 p2 c0 {1,S} {3,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([22.391,27.251,31.707,35.631,41.955,46.745,54.24],'cal/(mol*K)'),
        H298 = (-51.743,'kcal/mol'),
        S298 = (73.871,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl ethyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 34,
    label = "C3H8O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {4,S} {10,S} {11,S} {12,S}
4  O u0 p2 c0 {1,S} {3,S}
5  O u0 p2 c0 {2,S} {13,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.959,29.497,34.456,38.771,45.648,50.651,57.305],'cal/(mol*K)'),
        H298 = (-103.726,'kcal/mol'),
        S298 = (85.882,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methoxyethanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 35,
    label = "C3H8O2b",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {4,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {5,S} {11,S} {12,S} {13,S}
4  O u0 p2 c0 {1,S} {2,S}
5  O u0 p2 c0 {1,S} {3,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([21.923,27.974,33.409,37.954,44.766,49.763,56.301],'cal/(mol*K)'),
        H298 = (-83.219,'kcal/mol'),
        S298 = (80.359,'cal/(mol*K)'),
    ),
    shortDesc = u"""methylal""",
    longDesc = 
u"""

""",
)

entry(
    index = 36,
    label = "C3H8O2c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  O u0 p2 c0 {1,S} {12,S}
5  O u0 p2 c0 {2,S} {13,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.425,29.863,35.06,39.417,45.786,50.643,57.912],'cal/(mol*K)'),
        H298 = (-103.487,'kcal/mol'),
        S298 = (75.043,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2-propanediol (propylene glycol)""",
    longDesc = 
u"""

""",
)

entry(
    index = 37,
    label = "C3H8O2d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {4,S} {10,S} {11,S}
4  O u0 p2 c0 {3,S} {12,S}
5  O u0 p2 c0 {2,S} {13,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.923,29.399,34.634,38.997,45.258,49.936,57.104],'cal/(mol*K)'),
        H298 = (-97.751,'kcal/mol'),
        S298 = (72.398,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,3-propanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 38,
    label = "C3H8O3",
    molecule = 
"""
1  O u0 p2 c0 {2,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {4,S} {5,S} {10,S}
4  O u0 p2 c0 {3,S} {11,S}
5  C u0 p0 c0 {3,S} {6,S} {12,S} {13,S}
6  O u0 p2 c0 {5,S} {14,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.506,33.622,38.839,43.164,49.81,54.848,62.054],'cal/(mol*K)'),
        H298 = (-139.29,'kcal/mol'),
        S298 = (94.917,'cal/(mol*K)'),
    ),
    shortDesc = u"""glycerol""",
    longDesc = 
u"""

""",
)

entry(
    index = 39,
    label = "C4H2O3",
    molecule = 
"""
1 C u0 p0 c0 {2,S} {5,S} {7,D}
2 O u0 p2 c0 {1,S} {3,S}
3 C u0 p0 c0 {2,S} {4,S} {6,D}
4 C u0 p0 c0 {3,S} {5,D} {8,S}
5 C u0 p0 c0 {1,S} {4,D} {9,S}
6 O u0 p2 c0 {3,D}
7 O u0 p2 c0 {1,D}
8 H u0 p0 c0 {4,S}
9 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([26.829,32.344,36.578,39.64,43.56,46.586,52.706],'cal/(mol*K)'),
        H298 = (-95.196,'kcal/mol'),
        S298 = (75.545,'cal/(mol*K)'),
    ),
    shortDesc = u"""maleic anhydride""",
    longDesc = 
u"""

""",
)

entry(
    index = 40,
    label = "C4H4O",
    molecule = 
"""
1 O u0 p2 c0 {2,S} {8,S}
2 C u0 p0 c0 {1,S} {3,S} {4,D}
3 H u0 p0 c0 {2,S}
4 C u0 p0 c0 {2,D} {5,S} {6,S}
5 H u0 p0 c0 {4,S}
6 C u0 p0 c0 {4,S} {7,S} {8,D}
7 H u0 p0 c0 {6,S}
8 C u0 p0 c0 {1,S} {6,D} {9,S}
9 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([15.732,21.102,25.772,29.46,34.448,37.906,42.947],'cal/(mol*K)'),
        H298 = (-8.292,'kcal/mol'),
        S298 = (63.924,'cal/(mol*K)'),
    ),
    shortDesc = u"""furan""",
    longDesc = 
u"""

""",
)

entry(
    index = 41,
    label = "C4H4O2",
    molecule = 
"""
1  O u0 p2 c0 {2,D}
2  C u0 p0 c0 {1,D} {3,S} {5,S}
3  C u0 p0 c0 {2,S} {4,S} {7,S} {8,S}
4  C u0 p0 c0 {3,S} {5,S} {6,D}
5  O u0 p2 c0 {2,S} {4,S}
6  C u0 p0 c0 {4,D} {9,S} {10,S}
7  H u0 p0 c0 {3,S}
8  H u0 p0 c0 {3,S}
9  H u0 p0 c0 {6,S}
10 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([20.277,25.601,30.194,33.931,39.314,43.086,48.566],'cal/(mol*K)'),
        H298 = (-45.458,'kcal/mol'),
        S298 = (72.726,'cal/(mol*K)'),
    ),
    shortDesc = u"""diketene""",
    longDesc = 
u"""

""",
)

entry(
    index = 42,
    label = "C4H4O3",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {7,D}
2  O u0 p2 c0 {1,S} {3,S}
3  C u0 p0 c0 {2,S} {4,S} {6,D}
4  C u0 p0 c0 {3,S} {5,S} {8,S} {9,S}
5  C u0 p0 c0 {1,S} {4,S} {10,S} {11,S}
6  O u0 p2 c0 {3,D}
7  O u0 p2 c0 {1,D}
8  H u0 p0 c0 {4,S}
9  H u0 p0 c0 {4,S}
10 H u0 p0 c0 {5,S}
11 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.611,32.516,36.511,39.841,44.97,48.561,54.941],'cal/(mol*K)'),
        H298 = (-125.262,'kcal/mol'),
        S298 = (80.485,'cal/(mol*K)'),
    ),
    shortDesc = u"""succinic anhydride""",
    longDesc = 
u"""

""",
)

entry(
    index = 43,
    label = "C4H4O4a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,D} {8,S}
2  C u0 p0 c0 {1,S} {3,D} {9,S}
3  C u0 p0 c0 {2,D} {4,S} {10,S}
4  C u0 p0 c0 {3,S} {5,D} {6,S}
5  O u0 p2 c0 {4,D}
6  O u0 p2 c0 {4,S} {11,S}
7  O u0 p2 c0 {1,D}
8  O u0 p2 c0 {1,S} {12,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {6,S}
12 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.077,39.934,44.389,47.818,52.727,56.348,63.75],'cal/(mol*K)'),
        H298 = (-160.6,'kcal/mol'),
        S298 = (94.024,'cal/(mol*K)'),
    ),
    shortDesc = u"""fumaric acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 45,
    label = "C4H6Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,D} {8,S}
3  C u0 p0 c0 {2,D} {4,S} {9,S}
4  C u0 p0 c0 {3,S} {10,D} {11,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 O u0 p2 c0 {4,D}
11 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([22.539,27.313,31.592,35.276,41.061,45.363,51.864],'cal/(mol*K)'),
        H298 = (-24.855,'kcal/mol'),
        S298 = (77.838,'cal/(mol*K)'),
    ),
    shortDesc = u"""crotonaldehyde""",
    longDesc = 
u"""

""",
)

entry(
    index = 46,
    label = "C4H6Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {4,D}
3  C u0 p0 c0 {2,S} {8,D} {9,S}
4  C u0 p0 c0 {2,D} {10,S} {11,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  O u0 p2 c0 {3,D}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([22.539,27.313,31.592,35.276,41.061,45.363,51.864],'cal/(mol*K)'),
        H298 = (-26.767,'kcal/mol'),
        S298 = (80.085,'cal/(mol*K)'),
    ),
    shortDesc = u"""methacrolein""",
    longDesc = 
u"""

""",
)

entry(
    index = 47,
    label = "C4H6Oc",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {4,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {4,D} {10,S}
4  C u0 p0 c0 {2,S} {3,D} {11,S}
5  O u0 p2 c0 {1,S} {2,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([18.185,24.188,29.627,34.123,40.612,45.256,52.082],'cal/(mol*K)'),
        H298 = (-26.002,'kcal/mol'),
        S298 = (68.061,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,5-dihydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 48,
    label = "C4H6Od",
    molecule = 
"""
1  C u0 p0 c0 {3,D} {5,S} {6,S}
2  C u0 p0 c0 {4,D} {5,S} {7,S}
3  C u0 p0 c0 {1,D} {8,S} {9,S}
4  C u0 p0 c0 {2,D} {10,S} {11,S}
5  O u0 p2 c0 {1,S} {2,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {3,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([20.767,25.743,30.154,33.906,39.718,43.966,49.742],'cal/(mol*K)'),
        H298 = (-3.344,'kcal/mol'),
        S298 = (79.908,'cal/(mol*K)'),
    ),
    shortDesc = u"""divinyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 50,
    label = "C4H6O2a",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {4,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {4,T}
4  C u0 p0 c0 {2,S} {3,T}
5  O u0 p2 c0 {2,S} {11,S}
6  O u0 p2 c0 {1,S} {12,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([25.242,30.129,34.324,37.964,43.815,47.995,54.3],'cal/(mol*K)'),
        H298 = (-37.044,'kcal/mol'),
        S298 = (85.68,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-butyne-1,4-diol""",
    longDesc = 
u"""

""",
)

entry(
    index = 51,
    label = "C4H6O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {5,S} {12,D}
5  O u0 p2 c0 {3,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 O u0 p2 c0 {4,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([20.693,27.128,33.167,38.186,45.406,50.562,56.452],'cal/(mol*K)'),
        H298 = (-90.581,'kcal/mol'),
        S298 = (73.088,'cal/(mol*K)'),
    ),
    shortDesc = u"""?-butyrolactone""",
    longDesc = 
u"""

""",
)

entry(
    index = 52,
    label = "C4H6O2d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {3,D} {9,S}
3  C u0 p0 c0 {2,D} {4,S} {10,S}
4  C u0 p0 c0 {3,S} {5,S} {11,D}
5  O u0 p2 c0 {4,S} {12,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 O u0 p2 c0 {4,D}
12 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([25.995,31.662,36.52,40.527,46.511,50.86,57.433],'cal/(mol*K)'),
        H298 = (-90.343,'kcal/mol'),
        S298 = (80.87,'cal/(mol*K)'),
    ),
    shortDesc = u"""trans-2-butenoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 53,
    label = "C4H6O2e",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,D} {8,S}
3  C u0 p0 c0 {1,S} {5,S} {9,D}
4  C u0 p0 c0 {2,D} {10,S} {11,S}
5  O u0 p2 c0 {3,S} {12,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  O u0 p2 c0 {3,D}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.221,29.757,34.909,39.165,45.237,49.704,56.799],'cal/(mol*K)'),
        H298 = (-80.591,'kcal/mol'),
        S298 = (96.959,'cal/(mol*K)'),
    ),
    shortDesc = u"""vinylacetic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 54,
    label = "C4H6O2f",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {4,D}
3  C u0 p0 c0 {2,S} {5,S} {9,D}
4  C u0 p0 c0 {2,D} {10,S} {11,S}
5  O u0 p2 c0 {3,S} {12,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  O u0 p2 c0 {3,D}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.221,29.757,34.909,39.165,45.237,49.704,56.799],'cal/(mol*K)'),
        H298 = (-86.471,'kcal/mol'),
        S298 = (84.093,'cal/(mol*K)'),
    ),
    shortDesc = u"""methacrylic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 55,
    label = "C4H6O2g",
    molecule = 
"""
1  C u0 p0 c0 {5,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {3,S} {4,D} {9,S}
3  C u0 p0 c0 {2,S} {5,S} {10,D}
4  C u0 p0 c0 {2,D} {11,S} {12,S}
5  O u0 p2 c0 {1,S} {3,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 O u0 p2 c0 {3,D}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.872,29.494,34.479,38.659,44.829,49.044,55.598],'cal/(mol*K)'),
        H298 = (-79.587,'kcal/mol'),
        S298 = (87.54,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl acrylate""",
    longDesc = 
u"""

""",
)

entry(
    index = 56,
    label = "C4H6O2h",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,D}
3  C u0 p0 c0 {4,D} {5,S} {10,S}
4  C u0 p0 c0 {3,D} {11,S} {12,S}
5  O u0 p2 c0 {2,S} {3,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  O u0 p2 c0 {2,D}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.767,29.472,34.649,38.978,45.418,50.105,55.942],'cal/(mol*K)'),
        H298 = (-75.452,'kcal/mol'),
        S298 = (78.386,'cal/(mol*K)'),
    ),
    shortDesc = u"""vinyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 57,
    label = "C4H6O2i",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,D} {8,S}
3  C u0 p0 c0 {2,D} {9,S} {10,S}
4  C u0 p0 c0 {5,S} {11,D} {12,S}
5  O u0 p2 c0 {1,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 O u0 p2 c0 {4,D}
12 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.872,29.494,34.479,38.659,44.829,49.044,55.598],'cal/(mol*K)'),
        H298 = (-77.52,'kcal/mol'),
        S298 = (82.963,'cal/(mol*K)'),
    ),
    shortDesc = u"""allyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 58,
    label = "C4H6O2j",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {3,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {2,S} {9,S} {10,S}
4  C u0 p0 c0 {1,S} {5,S} {11,D}
5  O u0 p2 c0 {4,S} {12,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 O u0 p2 c0 {4,D}
12 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.221,29.757,34.909,39.165,45.237,49.704,56.799],'cal/(mol*K)'),
        H298 = (-85.533,'kcal/mol'),
        S298 = (87.4,'cal/(mol*K)'),
    ),
    shortDesc = u"""cyclopropanecarboxylic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 60,
    label = "C4H6O3",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,D} {4,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  O u0 p2 c0 {1,D}
4  O u0 p2 c0 {1,S} {5,S}
5  C u0 p0 c0 {4,S} {6,S} {7,D}
6  C u0 p0 c0 {5,S} {11,S} {12,S} {13,S}
7  O u0 p2 c0 {5,D}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {6,S}
12 H u0 p0 c0 {6,S}
13 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.658,30.827,36.482,41.407,49.026,54.246,61.373],'cal/(mol*K)'),
        H298 = (-137.598,'kcal/mol'),
        S298 = (93.33,'cal/(mol*K)'),
    ),
    shortDesc = u"""acetic anhydride""",
    longDesc = 
u"""

""",
)

entry(
    index = 61,
    label = "C4H6O4",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,D} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {4,S} {11,S} {12,S}
4  C u0 p0 c0 {3,S} {5,D} {6,S}
5  O u0 p2 c0 {4,D}
6  O u0 p2 c0 {4,S} {13,S}
7  O u0 p2 c0 {1,D}
8  O u0 p2 c0 {1,S} {14,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {6,S}
14 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.239,38.413,43.548,47.823,54.31,58.825,66.553],'cal/(mol*K)'),
        H298 = (-196.676,'kcal/mol'),
        S298 = (96.311,'cal/(mol*K)'),
    ),
    shortDesc = u"""succinic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 62,
    label = "C4H6O5a",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {8,S} {9,S}
2  C u0 p0 c0 {4,S} {5,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {7,S} {13,D}
4  C u0 p0 c0 {2,S} {6,S} {12,D}
5  O u0 p2 c0 {1,S} {2,S}
6  O u0 p2 c0 {4,S} {14,S}
7  O u0 p2 c0 {3,S} {15,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 O u0 p2 c0 {4,D}
13 O u0 p2 c0 {3,D}
14 H u0 p0 c0 {6,S}
15 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.217,40.454,46.565,51.525,58.658,63.555,71.905],'cal/(mol*K)'),
        H298 = (-225.858,'kcal/mol'),
        S298 = (105.515,'cal/(mol*K)'),
    ),
    shortDesc = u"""diglycolic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 63,
    label = "C4H6O5b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {7,S} {12,D}
4  C u0 p0 c0 {2,S} {6,S} {11,D}
5  O u0 p2 c0 {1,S} {13,S}
6  O u0 p2 c0 {4,S} {14,S}
7  O u0 p2 c0 {3,S} {15,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 O u0 p2 c0 {4,D}
12 O u0 p2 c0 {3,D}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {6,S}
15 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.082,42.023,47.735,52.348,59,63.519,71.864],'cal/(mol*K)'),
        H298 = (-236.614,'kcal/mol'),
        S298 = (107.919,'cal/(mol*K)'),
    ),
    shortDesc = u"""malic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 64,
    label = "C4H6O6",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {9,D} {10,S}
2  C u0 p0 c0 {1,S} {3,S} {4,S} {11,S}
3  O u0 p2 c0 {2,S} {12,S}
4  C u0 p0 c0 {2,S} {5,S} {6,S} {13,S}
5  O u0 p2 c0 {4,S} {14,S}
6  C u0 p0 c0 {4,S} {7,D} {8,S}
7  O u0 p2 c0 {6,D}
8  O u0 p2 c0 {6,S} {15,S}
9  O u0 p2 c0 {1,D}
10 O u0 p2 c0 {1,S} {16,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {8,S}
16 H u0 p0 c0 {10,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.831,45.518,51.809,56.79,63.715,68.345,77.324],'cal/(mol*K)'),
        H298 = (-277.245,'kcal/mol'),
        S298 = (116.402,'cal/(mol*K)'),
    ),
    shortDesc = u"""tartaric acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 65,
    label = "C4H8Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
4  C u0 p0 c0 {2,S} {11,S} {12,S} {13,S}
5  O u0 p2 c0 {1,S} {3,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.376,29.272,34.673,39.387,46.798,52.071,58.911],'cal/(mol*K)'),
        H298 = (-26.288,'kcal/mol'),
        S298 = (77.071,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2-epoxybutane""",
    longDesc = 
u"""

""",
)

entry(
    index = 66,
    label = "C4H8Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {4,D} {5,S} {11,S}
4  C u0 p0 c0 {3,D} {12,S} {13,S}
5  O u0 p2 c0 {1,S} {3,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.491,29.11,34.46,39.022,45.956,51.351,59.113],'cal/(mol*K)'),
        H298 = (-33.674,'kcal/mol'),
        S298 = (83.523,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl vinyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 67,
    label = "C4H8Oc",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {5,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {4,D} {11,S}
4  C u0 p0 c0 {3,D} {12,S} {13,S}
5  O u0 p2 c0 {1,S} {2,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.864,30.985,36.42,40.685,46.918,52.643,60.6],'cal/(mol*K)'),
        H298 = (-33.674,'kcal/mol'),
        S298 = (83.523,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methoxy-1-propene""",
    longDesc = 
u"""

""",
)

entry(
    index = 68,
    label = "C4H8Od",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,D} {13,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 O u0 p2 c0 {4,D}
13 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([25.498,30.164,35.064,39.809,48.113,54.419,62.61],'cal/(mol*K)'),
        H298 = (-49.472,'kcal/mol'),
        S298 = (82.135,'cal/(mol*K)'),
    ),
    shortDesc = u"""butyraldehyde""",
    longDesc = 
u"""

""",
)

entry(
    index = 69,
    label = "C4H8Oe",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,D} {13,S}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {2,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 O u0 p2 c0 {4,D}
13 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.694,29.434,34.957,39.622,46.673,52.346,60.224],'cal/(mol*K)'),
        H298 = (-51.575,'kcal/mol'),
        S298 = (75.042,'cal/(mol*K)'),
    ),
    shortDesc = u"""isobutyraldehyde""",
    longDesc = 
u"""

""",
)

entry(
    index = 70,
    label = "C4H8Of",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {4,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {3,S} {13,D}
5  H u0 p0 c0 {1,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.776,29.922,34.72,39.009,45.999,51.26,59.41],'cal/(mol*K)'),
        H298 = (-57.025,'kcal/mol'),
        S298 = (81.094,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl ethyl ketone""",
    longDesc = 
u"""

""",
)

entry(
    index = 71,
    label = "C4H8Og",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {5,S} {12,S} {13,S}
5  O u0 p2 c0 {3,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([18.435,25.494,32.13,37.754,46.071,52.084,60.973],'cal/(mol*K)'),
        H298 = (-44.017,'kcal/mol'),
        S298 = (71.157,'cal/(mol*K)'),
    ),
    shortDesc = u"""tetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 72,
    label = "C4H8O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {5,S} {13,D}
5  O u0 p2 c0 {4,S} {14,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.733,33.854,39.532,44.338,51.316,56.019,63.598],'cal/(mol*K)'),
        H298 = (-113.191,'kcal/mol'),
        S298 = (84.365,'cal/(mol*K)'),
    ),
    shortDesc = u"""butanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 73,
    label = "C4H8O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {5,S} {13,D}
5  O u0 p2 c0 {4,S} {14,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.969,32.036,38.502,43.705,50.993,56.558,64.209],'cal/(mol*K)'),
        H298 = (-114.242,'kcal/mol'),
        S298 = (86.595,'cal/(mol*K)'),
    ),
    shortDesc = u"""isobutanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 74,
    label = "C4H8O2c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,D} {14,S}
5  O u0 p2 c0 {2,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([26.355,33.046,39.235,44.241,51.239,56.6,65.157],'cal/(mol*K)'),
        H298 = (-97.416,'kcal/mol'),
        S298 = (88.053,'cal/(mol*K)'),
    ),
    shortDesc = u"""propyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 75,
    label = "C4H8O2d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,D} {14,S}
5  O u0 p2 c0 {1,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([25.904,31.696,37.061,41.475,47.677,52.153,60.038],'cal/(mol*K)'),
        H298 = (-101.527,'kcal/mol'),
        S298 = (85.168,'cal/(mol*K)'),
    ),
    shortDesc = u"""isopropyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 76,
    label = "C4H8O2e",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {4,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {3,S} {5,S} {14,D}
5  O u0 p2 c0 {1,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 O u0 p2 c0 {4,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.179,33.281,38.297,43.062,51.056,56.447,64.418],'cal/(mol*K)'),
        H298 = (-106.236,'kcal/mol'),
        S298 = (86.129,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 77,
    label = "C4H8O2f",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {5,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {5,S} {14,D}
5  O u0 p2 c0 {3,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 O u0 p2 c0 {4,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([26.763,34.117,40.244,44.873,51.17,56.335,63.548],'cal/(mol*K)'),
        H298 = (-102.173,'kcal/mol'),
        S298 = (86.05,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl propanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 78,
    label = "C4H8O2g",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {4,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {3,S} {5,S} {13,S} {14,S}
5  O u0 p2 c0 {1,S} {4,S}
6  O u0 p2 c0 {2,S} {3,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([22.172,29.791,36.804,42.769,51.707,58.086,67.447],'cal/(mol*K)'),
        H298 = (-75.298,'kcal/mol'),
        S298 = (71.807,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,4-dioxane""",
    longDesc = 
u"""

""",
)

entry(
    index = 79,
    label = "C4H8O2i",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {4,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {4,D} {11,S}
4  C u0 p0 c0 {2,S} {3,D} {12,S}
5  O u0 p2 c0 {2,S} {13,S}
6  O u0 p2 c0 {1,S} {14,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([26.443,32.488,38.041,42.898,50.465,55.683,62.812],'cal/(mol*K)'),
        H298 = (-71.699,'kcal/mol'),
        S298 = (92.615,'cal/(mol*K)'),
    ),
    shortDesc = u"""trans-2-butene-1,4-diol""",
    longDesc = 
u"""

""",
)

entry(
    index = 80,
    label = "C4H10Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {3,S} {15,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([25.95,32.949,39.297,44.645,52.715,58.779,68.246],'cal/(mol*K)'),
        H298 = (-65.628,'kcal/mol'),
        S298 = (86.434,'cal/(mol*K)'),
    ),
    shortDesc = u"""butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 81,
    label = "C4H10Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {2,S} {15,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([26.719,33.526,39.696,44.921,52.82,58.652,68.117],'cal/(mol*K)'),
        H298 = (-67.617,'kcal/mol'),
        S298 = (83.618,'cal/(mol*K)'),
    ),
    shortDesc = u"""isobutanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 82,
    label = "C4H10Oc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {1,S} {15,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.069,33.634,39.587,44.696,52.646,58.628,68.035],'cal/(mol*K)'),
        H298 = (-69.978,'kcal/mol'),
        S298 = (85.872,'cal/(mol*K)'),
    ),
    shortDesc = u"""sec-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 83,
    label = "C4H10Od",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {1,S} {15,S}
6  H u0 p0 c0 {2,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.29,34.171,40.246,45.371,53.229,59.097,68.313],'cal/(mol*K)'),
        H298 = (-74.663,'kcal/mol'),
        S298 = (78.097,'cal/(mol*K)'),
    ),
    shortDesc = u"""tert-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 84,
    label = "C4H10Oe",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {4,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {1,S} {2,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.657,34.293,39.62,44.48,52.591,58.719,68.298],'cal/(mol*K)'),
        H298 = (-59.94,'kcal/mol'),
        S298 = (81.863,'cal/(mol*K)'),
    ),
    shortDesc = u"""diethyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 85,
    label = "C4H10Of",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {2,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([26.967,32.955,38.762,43.963,52.3,58.468,67.264],'cal/(mol*K)'),
        H298 = (-56.857,'kcal/mol'),
        S298 = (84.269,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl propyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 86,
    label = "C4H10Og",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {1,S} {4,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.347,33.013,38.643,43.894,52.734,59.271,68.187],'cal/(mol*K)'),
        H298 = (-60.227,'kcal/mol'),
        S298 = (81.784,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl isopropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 88,
    label = "C4H10O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {1,S} {6,S}
6  O u0 p2 c0 {5,S} {16,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.824,39.055,45.314,50.552,58.577,64.491,72.963],'cal/(mol*K)'),
        H298 = (-58.076,'kcal/mol'),
        S298 = (87.139,'cal/(mol*K)'),
    ),
    shortDesc = u"""t-butyl hydroperoxide""",
    longDesc = 
u"""

""",
)

entry(
    index = 89,
    label = "C4H10O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {5,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {6,S} {14,S} {15,S} {16,S}
5  O u0 p2 c0 {1,S} {3,S}
6  O u0 p2 c0 {2,S} {4,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.356,36.443,42.814,48.321,57.004,63.332,71.653],'cal/(mol*K)'),
        H298 = (-82.693,'kcal/mol'),
        S298 = (92.159,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2-dimethoxyethane""",
    longDesc = 
u"""

""",
)

entry(
    index = 90,
    label = "C4H10O2c",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {9,S} {10,S}
2  C u0 p0 c0 {4,S} {5,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {1,S} {2,S}
6  O u0 p2 c0 {3,S} {16,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.054,36.441,42.764,48.195,56.802,62.854,71.15],'cal/(mol*K)'),
        H298 = (-95.599,'kcal/mol'),
        S298 = (95.237,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethoxyethanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 91,
    label = "C4H10O2d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {1,S} {15,S}
6  O u0 p2 c0 {3,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.556,36.32,42.901,48.516,56.824,62.995,72.038],'cal/(mol*K)'),
        H298 = (-106.355,'kcal/mol'),
        S298 = (89.047,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 92,
    label = "C4H10O2e",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {1,S} {15,S}
6  O u0 p2 c0 {3,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([30.235,37.018,43.483,48.876,56.709,62.687,71.685],'cal/(mol*K)'),
        H298 = (-108.028,'kcal/mol'),
        S298 = (82.161,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,3-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 93,
    label = "C4H10O2f",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {5,S} {13,S} {14,S}
5  O u0 p2 c0 {4,S} {15,S}
6  O u0 p2 c0 {3,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.431,36.344,42.924,48.38,56.285,62.424,71.385],'cal/(mol*K)'),
        H298 = (-102.292,'kcal/mol'),
        S298 = (90.202,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,4-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 94,
    label = "C4H10O2i",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {1,S} {16,S}
6  O u0 p2 c0 {2,S} {15,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {6,S}
16 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.542,36.899,43.874,49.548,57.376,63.217,72.292],'cal/(mol*K)'),
        H298 = (-110.896,'kcal/mol'),
        S298 = (69.584,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1,2-propanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 96,
    label = "C4H10O2l",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {1,S} {4,S}
6  O u0 p2 c0 {2,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.882,37.062,43.611,49.106,57.331,63.501,72.346],'cal/(mol*K)'),
        H298 = (-95.599,'kcal/mol'),
        S298 = (95.236,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methoxy-1-propanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 97,
    label = "C4H10O2m",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {2,S} {4,S}
6  O u0 p2 c0 {1,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.882,37.062,43.611,49.106,57.331,63.501,72.346],'cal/(mol*K)'),
        H298 = (-95.599,'kcal/mol'),
        S298 = (95.236,'cal/(mol*K)'),
    ),
    shortDesc = u"""propylene glycol monomethyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 98,
    label = "C4H10O2q",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {5,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {2,S} {15,S}
6  O u0 p2 c0 {1,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.506,36.341,43.001,48.672,57.003,63.124,72.185],'cal/(mol*K)'),
        H298 = (-108.527,'kcal/mol'),
        S298 = (89.663,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 101,
    label = "C4H10O2t",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {2,S} {4,S}
6  O u0 p2 c0 {2,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.882,37.062,43.611,49.106,57.331,63.501,72.346],'cal/(mol*K)'),
        H298 = (-95.599,'kcal/mol'),
        S298 = (95.239,'cal/(mol*K)'),
    ),
    shortDesc = u"""methoxypropanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 103,
    label = "C4H10O2w",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  O u0 p2 c0 {2,S} {15,S}
6  O u0 p2 c0 {3,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.366,36.235,42.806,48.371,56.587,62.706,71.64],'cal/(mol*K)'),
        H298 = (-108.527,'kcal/mol'),
        S298 = (89.664,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1,3-propanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 104,
    label = "C4H10O2x",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
5  O u0 p2 c0 {2,S} {4,S}
6  O u0 p2 c0 {3,S} {16,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.882,37.062,43.611,49.106,57.331,63.501,72.346],'cal/(mol*K)'),
        H298 = (-95.599,'kcal/mol'),
        S298 = (95.234,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methoxy-1-propanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 105,
    label = "C4H10O3",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {10,S} {11,S}
3  O u0 p2 c0 {2,S} {4,S}
4  C u0 p0 c0 {3,S} {5,S} {12,S} {13,S}
5  C u0 p0 c0 {4,S} {6,S} {14,S} {15,S}
6  O u0 p2 c0 {5,S} {16,S}
7  O u0 p2 c0 {1,S} {17,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.437,39.838,46.401,52.046,60.871,67.177,76.003],'cal/(mol*K)'),
        H298 = (-136.517,'kcal/mol'),
        S298 = (105.162,'cal/(mol*K)'),
    ),
    shortDesc = u"""diethylene glycol""",
    longDesc = 
u"""

""",
)

entry(
    index = 106,
    label = "C5H4O2",
    molecule = 
"""
1  O u0 p2 c0 {2,S} {10,S}
2  C u0 p0 c0 {1,S} {3,S} {6,D}
3  C u0 p0 c0 {2,S} {4,S} {5,D}
4  H u0 p0 c0 {3,S}
5  O u0 p2 c0 {3,D}
6  C u0 p0 c0 {2,D} {7,S} {8,S}
7  H u0 p0 c0 {6,S}
8  C u0 p0 c0 {6,S} {9,S} {10,D}
9  H u0 p0 c0 {8,S}
10 C u0 p0 c0 {1,S} {8,D} {11,S}
11 H u0 p0 c0 {10,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.56,29.836,35.399,39.755,45.416,49.228,54.963],'cal/(mol*K)'),
        H298 = (-36.098,'kcal/mol'),
        S298 = (79.732,'cal/(mol*K)'),
    ),
    shortDesc = u"""furfural""",
    longDesc = 
u"""

""",
)

entry(
    index = 107,
    label = "C5H6Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {3,D} {6,S}
3  C u0 p0 c0 {2,D} {4,S} {10,S}
4  C u0 p0 c0 {3,S} {5,D} {11,S}
5  C u0 p0 c0 {4,D} {6,S} {12,S}
6  O u0 p2 c0 {2,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([21.549,27.943,33.642,38.342,45.148,49.988,57.13],'cal/(mol*K)'),
        H298 = (-15.844,'kcal/mol'),
        S298 = (73.84,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methylfuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 108,
    label = "C5H6Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {4,D}
3  C u0 p0 c0 {2,S} {5,D} {10,S}
4  C u0 p0 c0 {2,D} {6,S} {11,S}
5  C u0 p0 c0 {3,D} {6,S} {12,S}
6  O u0 p2 c0 {4,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([21.674,28.094,33.803,38.496,45.268,50.081,57.182],'cal/(mol*K)'),
        H298 = (-16.059,'kcal/mol'),
        S298 = (74.161,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methylfuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 109,
    label = "C5H6O2",
    molecule = 
"""
1  O u0 p2 c0 {2,S} {7,S}
2  C u0 p0 c0 {1,S} {3,D} {9,S}
3  C u0 p0 c0 {2,D} {4,S} {5,S}
4  H u0 p0 c0 {3,S}
5  C u0 p0 c0 {3,S} {6,S} {7,D}
6  H u0 p0 c0 {5,S}
7  C u0 p0 c0 {1,S} {5,D} {8,S}
8  H u0 p0 c0 {7,S}
9  C u0 p0 c0 {2,S} {10,S} {11,S} {12,S}
10 H u0 p0 c0 {9,S}
11 H u0 p0 c0 {9,S}
12 O u0 p2 c0 {9,S} {13,S}
13 H u0 p0 c0 {12,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.647,35.307,41.005,45.617,52.151,56.594,64.029],'cal/(mol*K)'),
        H298 = (-52.317,'kcal/mol'),
        S298 = (97.551,'cal/(mol*K)'),
    ),
    shortDesc = u"""furfuryl alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 110,
    label = "C5H6O3",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {6,S} {8,D}
2  O u0 p2 c0 {1,S} {3,S}
3  C u0 p0 c0 {2,S} {4,S} {7,D}
4  C u0 p0 c0 {3,S} {5,S} {9,S} {10,S}
5  C u0 p0 c0 {4,S} {6,S} {11,S} {12,S}
6  C u0 p0 c0 {1,S} {5,S} {13,S} {14,S}
7  O u0 p2 c0 {3,D}
8  O u0 p2 c0 {1,D}
9  H u0 p0 c0 {4,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {6,S}
14 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.48,36.499,44.928,52.082,62.819,70.585,79.858],'cal/(mol*K)'),
        H298 = (-83.411,'kcal/mol'),
        S298 = (84.311,'cal/(mol*K)'),
    ),
    shortDesc = u"""glutaric anhydride""",
    longDesc = 
u"""

""",
)

entry(
    index = 111,
    label = "C5H6O4a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {8,S} {9,S} {10,S}
2  C u0 p0 c0 {1,S} {3,D} {4,S}
3  C u0 p0 c0 {2,D} {5,S} {11,S}
4  C u0 p0 c0 {2,S} {7,S} {13,D}
5  C u0 p0 c0 {3,S} {6,S} {12,D}
6  O u0 p2 c0 {5,S} {14,S}
7  O u0 p2 c0 {4,S} {15,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 O u0 p2 c0 {5,D}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {6,S}
15 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.587,44.72,51.223,56.127,62.86,68.2,77.16],'cal/(mol*K)'),
        H298 = (-176.863,'kcal/mol'),
        S298 = (104.013,'cal/(mol*K)'),
    ),
    shortDesc = u"""citraconic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 112,
    label = "C5H6O4b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {4,S} {5,D}
3  C u0 p0 c0 {1,S} {6,S} {10,D}
4  C u0 p0 c0 {2,S} {7,S} {11,D}
5  C u0 p0 c0 {2,D} {12,S} {13,S}
6  O u0 p2 c0 {3,S} {14,S}
7  O u0 p2 c0 {4,S} {15,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 O u0 p2 c0 {3,D}
11 O u0 p2 c0 {4,D}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {6,S}
15 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.883,42.801,49.309,54.357,61.332,66.471,75.204],'cal/(mol*K)'),
        H298 = (-174.234,'kcal/mol'),
        S298 = (104.816,'cal/(mol*K)'),
    ),
    shortDesc = u"""itaconic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 113,
    label = "C5H8Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {5,S} {12,S} {13,S}
5  C u0 p0 c0 {3,S} {4,S} {14,D}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([22.927,30.616,37.598,43.459,52.137,58.368,67.543],'cal/(mol*K)'),
        H298 = (-45.91,'kcal/mol'),
        S298 = (74.932,'cal/(mol*K)'),
    ),
    shortDesc = u"""cyclopentanone""",
    longDesc = 
u"""

""",
)

entry(
    index = 114,
    label = "C5H8Ob",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {4,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {4,S} {5,D}
4  C u0 p0 c0 {2,S} {3,S} {12,D}
5  C u0 p0 c0 {3,D} {13,S} {14,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 O u0 p2 c0 {4,D}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([25.037,31.641,37.621,42.716,50.513,56.135,63.51],'cal/(mol*K)'),
        H298 = (-43.019,'kcal/mol'),
        S298 = (86.153,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl isopropenyl ketone""",
    longDesc = 
u"""

""",
)

entry(
    index = 115,
    label = "C5H8O2a",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {4,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {5,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {2,S} {14,D}
5  C u0 p0 c0 {1,S} {3,S} {15,D}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 O u0 p2 c0 {4,D}
15 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.491,34.439,40.723,46.153,54.76,61.175,69.212],'cal/(mol*K)'),
        H298 = (-90.82,'kcal/mol'),
        S298 = (96.64,'cal/(mol*K)'),
    ),
    shortDesc = u"""acetylacetone""",
    longDesc = 
u"""

""",
)

entry(
    index = 116,
    label = "C5H8O2b",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {4,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {5,D} {12,S}
4  C u0 p0 c0 {2,S} {6,S} {13,D}
5  C u0 p0 c0 {3,D} {14,S} {15,S}
6  O u0 p2 c0 {1,S} {4,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.362,36.196,43.32,49.124,57.38,63.411,70.798],'cal/(mol*K)'),
        H298 = (-79.826,'kcal/mol'),
        S298 = (96.639,'cal/(mol*K)'),
    ),
    shortDesc = u"""allyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 117,
    label = "C5H8O2c",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {10,S} {11,S} {12,S}
2  C u0 p0 c0 {4,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,D} {6,S}
4  C u0 p0 c0 {2,S} {6,S} {13,D}
5  C u0 p0 c0 {3,D} {14,S} {15,S}
6  O u0 p2 c0 {3,S} {4,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.362,36.196,43.32,49.124,57.38,63.411,70.798],'cal/(mol*K)'),
        H298 = (-82.35,'kcal/mol'),
        S298 = (95.547,'cal/(mol*K)'),
    ),
    shortDesc = u"""isopropenyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 118,
    label = "C5H8O2d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {6,S} {12,D}
4  C u0 p0 c0 {5,D} {6,S} {13,S}
5  C u0 p0 c0 {4,D} {14,S} {15,S}
6  O u0 p2 c0 {3,S} {4,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 O u0 p2 c0 {3,D}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.663,35.833,42.289,47.722,55.697,61.077,69.238],'cal/(mol*K)'),
        H298 = (-83.019,'kcal/mol'),
        S298 = (92.15,'cal/(mol*K)'),
    ),
    shortDesc = u"""vinyl propanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 119,
    label = "C5H8O2f",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {6,S} {10,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {4,D} {13,S}
4  C u0 p0 c0 {3,D} {5,S} {14,S}
5  C u0 p0 c0 {4,S} {6,S} {15,D}
6  O u0 p2 c0 {2,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.362,36.196,43.32,49.124,57.38,63.411,70.798],'cal/(mol*K)'),
        H298 = (-82.35,'kcal/mol'),
        S298 = (95.547,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl trans-2-butenoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 120,
    label = "C5H8O2g",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {6,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {4,S} {5,D} {12,S}
4  C u0 p0 c0 {3,S} {6,S} {13,D}
5  C u0 p0 c0 {3,D} {14,S} {15,S}
6  O u0 p2 c0 {1,S} {4,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.915,36.19,42.698,48.13,56.051,61.47,69.684],'cal/(mol*K)'),
        H298 = (-83.537,'kcal/mol'),
        S298 = (97.377,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl acrylate""",
    longDesc = 
u"""

""",
)

entry(
    index = 121,
    label = "C5H8O2h",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {6,S} {10,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {4,S} {5,D}
4  C u0 p0 c0 {3,S} {6,S} {13,D}
5  C u0 p0 c0 {3,D} {14,S} {15,S}
6  O u0 p2 c0 {2,S} {4,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.826,35.395,42.158,47.706,55.638,61.204,69.383],'cal/(mol*K)'),
        H298 = (-83.019,'kcal/mol'),
        S298 = (96.022,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl methacrylate""",
    longDesc = 
u"""

""",
)

entry(
    index = 122,
    label = "C5H8O2i",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {4,S} {5,D}
4  C u0 p0 c0 {3,S} {6,S} {12,D}
5  C u0 p0 c0 {3,D} {13,S} {14,S}
6  O u0 p2 c0 {4,S} {15,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 O u0 p2 c0 {4,D}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.793,35.902,42.515,47.931,55.652,61.539,70.324],'cal/(mol*K)'),
        H298 = (-93.999,'kcal/mol'),
        S298 = (83.949,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methylenebutanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 123,
    label = "C5H8O2j",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {4,S} {10,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {4,D} {5,S}
4  C u0 p0 c0 {2,S} {3,D} {13,S}
5  C u0 p0 c0 {3,S} {6,S} {14,D}
6  O u0 p2 c0 {5,S} {15,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {4,S}
14 O u0 p2 c0 {5,D}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.824,35.911,42.496,47.885,55.579,61.475,70.25],'cal/(mol*K)'),
        H298 = (-93.019,'kcal/mol'),
        S298 = (94.089,'cal/(mol*K)'),
    ),
    shortDesc = u"""trans-2-methyl-2-butenoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 124,
    label = "C5H8O2l",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {5,D} {11,S}
4  C u0 p0 c0 {1,S} {6,S} {12,D}
5  C u0 p0 c0 {3,D} {13,S} {14,S}
6  O u0 p2 c0 {4,S} {15,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 O u0 p2 c0 {4,D}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.667,36.674,43.249,48.707,56.498,62.163,71.037],'cal/(mol*K)'),
        H298 = (-86.566,'kcal/mol'),
        S298 = (104.727,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-3-butenoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 125,
    label = "C5H8O2m",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {3,S} {10,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {2,S} {4,D}
4  C u0 p0 c0 {3,D} {5,S} {13,S}
5  C u0 p0 c0 {4,S} {6,S} {14,D}
6  O u0 p2 c0 {5,S} {15,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {4,S}
14 O u0 p2 c0 {5,D}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.824,35.911,42.496,47.885,55.579,61.475,70.25],'cal/(mol*K)'),
        H298 = (-93.664,'kcal/mol'),
        S298 = (91.925,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-2-butenoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 126,
    label = "C5H8O2n",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {3,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {2,S} {5,D}
4  C u0 p0 c0 {1,S} {6,S} {12,D}
5  C u0 p0 c0 {3,D} {13,S} {14,S}
6  O u0 p2 c0 {4,S} {15,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 O u0 p2 c0 {4,D}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.748,36.661,43.131,48.505,56.246,61.97,70.816],'cal/(mol*K)'),
        H298 = (-92.206,'kcal/mol'),
        S298 = (90.706,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-3-butenoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 127,
    label = "C5H8O2o",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {4,D} {12,S}
4  C u0 p0 c0 {3,D} {5,S} {13,S}
5  C u0 p0 c0 {4,S} {6,S} {14,D}
6  O u0 p2 c0 {5,S} {15,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 O u0 p2 c0 {5,D}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.793,35.902,42.515,47.931,55.652,61.539,70.324],'cal/(mol*K)'),
        H298 = (-89.697,'kcal/mol'),
        S298 = (98.378,'cal/(mol*K)'),
    ),
    shortDesc = u"""trans-2-pentenoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 128,
    label = "C5H8O2q",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {7,S} {8,S}
2  C u0 p0 c0 {4,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {4,D} {12,S}
4  C u0 p0 c0 {2,S} {3,D} {13,S}
5  C u0 p0 c0 {1,S} {6,S} {14,D}
6  O u0 p2 c0 {5,S} {15,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 O u0 p2 c0 {5,D}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.793,35.902,42.515,47.931,55.652,61.539,70.324],'cal/(mol*K)'),
        H298 = (-88.215,'kcal/mol'),
        S298 = (103.348,'cal/(mol*K)'),
    ),
    shortDesc = u"""trans-3-pentenoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 129,
    label = "C5H8O2s",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {9,S} {10,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {5,D} {11,S}
4  C u0 p0 c0 {2,S} {6,S} {12,D}
5  C u0 p0 c0 {3,D} {13,S} {14,S}
6  O u0 p2 c0 {4,S} {15,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 O u0 p2 c0 {4,D}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.717,36.652,43.15,48.551,56.319,62.034,70.89],'cal/(mol*K)'),
        H298 = (-88.239,'kcal/mol'),
        S298 = (97.159,'cal/(mol*K)'),
    ),
    shortDesc = u"""4-pentenoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 130,
    label = "C5H8O2t",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {6,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {5,D} {12,S}
4  C u0 p0 c0 {1,S} {6,S} {13,D}
5  C u0 p0 c0 {3,D} {14,S} {15,S}
6  O u0 p2 c0 {2,S} {4,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.362,36.196,43.32,49.124,57.38,63.411,70.798],'cal/(mol*K)'),
        H298 = (-82.35,'kcal/mol'),
        S298 = (95.547,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 3-butenoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 131,
    label = "C5H8O3a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {6,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
3  C u0 p0 c0 {4,S} {5,D} {12,S}
4  C u0 p0 c0 {3,S} {6,S} {13,D}
5  C u0 p0 c0 {3,D} {14,S} {15,S}
6  O u0 p2 c0 {1,S} {4,S}
7  O u0 p2 c0 {2,S} {16,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 O u0 p2 c0 {4,D}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.162,43.319,49.975,55.097,62.335,68.126,77.076],'cal/(mol*K)'),
        H298 = (-117.828,'kcal/mol'),
        S298 = (107.525,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-hydroxyethyl acrylate""",
    longDesc = 
u"""

""",
)

entry(
    index = 132,
    label = "C5H8O3b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {9,S} {10,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {8,S}
3  C u0 p0 c0 {4,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {3,S} {14,D}
5  C u0 p0 c0 {2,S} {6,S} {15,D}
6  O u0 p2 c0 {5,S} {16,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 O u0 p2 c0 {4,D}
15 O u0 p2 c0 {5,D}
16 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.213,41.037,46.966,52.114,60.242,65.841,74.491],'cal/(mol*K)'),
        H298 = (-145.074,'kcal/mol'),
        S298 = (101.914,'cal/(mol*K)'),
    ),
    shortDesc = u"""levulinic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 133,
    label = "C5H8O3c",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {5,S} {7,S} {8,S}
2  C u0 p0 c0 {4,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {6,S} {12,S} {13,S} {14,S}
4  C u0 p0 c0 {1,S} {2,S} {15,D}
5  C u0 p0 c0 {1,S} {6,S} {16,D}
6  O u0 p2 c0 {3,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 O u0 p2 c0 {4,D}
16 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([30.654,38.627,45.586,51.267,59.627,65.872,74.526],'cal/(mol*K)'),
        H298 = (-140.772,'kcal/mol'),
        S298 = (105.924,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl acetoacetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 134,
    label = "C5H8O4",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {8,D} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {10,S} {11,S}
3  C u0 p0 c0 {2,S} {4,S} {12,S} {13,S}
4  C u0 p0 c0 {3,S} {5,S} {14,S} {15,S}
5  C u0 p0 c0 {4,S} {6,D} {7,S}
6  O u0 p2 c0 {5,D}
7  O u0 p2 c0 {5,S} {16,S}
8  O u0 p2 c0 {1,D}
9  O u0 p2 c0 {1,S} {17,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {7,S}
17 H u0 p0 c0 {9,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.689,45.375,51.835,57.195,65.358,71.258,80.62],'cal/(mol*K)'),
        H298 = (-201.384,'kcal/mol'),
        S298 = (107.51,'cal/(mol*K)'),
    ),
    shortDesc = u"""glutaric acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 135,
    label = "C5H10Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,D} {16,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 O u0 p2 c0 {5,D}
16 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([30.333,37.013,43.67,49.595,59.029,66.291,76.268],'cal/(mol*K)'),
        H298 = (-54.443,'kcal/mol'),
        S298 = (91.491,'cal/(mol*K)'),
    ),
    shortDesc = u"""pentanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 136,
    label = "C5H10Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,D} {16,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 O u0 p2 c0 {5,D}
16 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.868,36.794,43.569,49.372,57.943,64.197,73.86],'cal/(mol*K)'),
        H298 = (-56.212,'kcal/mol'),
        S298 = (87.755,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methylbutanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 137,
    label = "C5H10Oc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,D} {16,S}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 O u0 p2 c0 {5,D}
16 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.868,36.794,43.569,49.372,57.943,64.197,73.86],'cal/(mol*K)'),
        H298 = (-56.522,'kcal/mol'),
        S298 = (86.713,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methylbutanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 138,
    label = "C5H10Od",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,D} {16,S}
6  H u0 p0 c0 {2,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 O u0 p2 c0 {5,D}
16 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.853,37.374,44.542,50.405,58.496,64.419,74.115],'cal/(mol*K)'),
        H298 = (-59.653,'kcal/mol'),
        S298 = (71.979,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethylpropanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 140,
    label = "C5H10Of",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {4,S} {16,D}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([30.219,36.937,43.059,48.455,57.02,63.26,74.204],'cal/(mol*K)'),
        H298 = (-61.948,'kcal/mol'),
        S298 = (90.529,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl propyl ketone""",
    longDesc = 
u"""

""",
)

entry(
    index = 141,
    label = "C5H10Og",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {4,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {2,S} {16,D}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.164,37.575,43.389,48.612,57.239,63.709,74.731],'cal/(mol*K)'),
        H298 = (-61.637,'kcal/mol'),
        S298 = (88.445,'cal/(mol*K)'),
    ),
    shortDesc = u"""diethyl ketone""",
    longDesc = 
u"""

""",
)

entry(
    index = 142,
    label = "C5H10Oh",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {4,S} {16,D}
6  H u0 p0 c0 {1,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.021,34.562,41.808,47.98,57.056,63.48,72.035],'cal/(mol*K)'),
        H298 = (-62.76,'kcal/mol'),
        S298 = (88.687,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl isopropyl ketone""",
    longDesc = 
u"""

""",
)

entry(
    index = 143,
    label = "C5H10Oi",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {4,S} {10,S} {11,S}
4  C u0 p0 c0 {3,S} {6,S} {12,S} {13,S}
5  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
6  O u0 p2 c0 {1,S} {4,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.095,30.155,36.79,42.414,50.731,56.745,65.633],'cal/(mol*K)'),
        H298 = (-52.112,'kcal/mol'),
        S298 = (59.505,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 144,
    label = "C5H10Oj",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {6,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {6,S} {10,S} {11,S}
5  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
6  O u0 p2 c0 {3,S} {4,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([23.095,30.155,36.79,42.414,50.731,56.745,65.633],'cal/(mol*K)'),
        H298 = (-52.112,'kcal/mol'),
        S298 = (59.505,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 145,
    label = "C5H10O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {6,S} {16,D}
6  O u0 p2 c0 {5,S} {17,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.057,40.884,47.972,53.776,62.157,68.463,77.725],'cal/(mol*K)'),
        H298 = (-118.783,'kcal/mol'),
        S298 = (95.003,'cal/(mol*K)'),
    ),
    shortDesc = u"""pentanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 146,
    label = "C5H10O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {6,S} {16,D}
6  O u0 p2 c0 {5,S} {17,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([30.416,37.887,44.659,50.262,58.872,66.055,74.91],'cal/(mol*K)'),
        H298 = (-118.783,'kcal/mol'),
        S298 = (98.181,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methylbutanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 147,
    label = "C5H10O2c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {6,S} {16,D}
6  O u0 p2 c0 {5,S} {17,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.747,40.556,47.744,53.737,62.509,68.94,78.266],'cal/(mol*K)'),
        H298 = (-120.217,'kcal/mol'),
        S298 = (103.019,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methylbutanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 148,
    label = "C5H10O2d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {6,S} {16,D}
6  O u0 p2 c0 {5,S} {17,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([30.575,39.294,47.07,53.375,62.373,69.075,78.696],'cal/(mol*K)'),
        H298 = (-117.349,'kcal/mol'),
        S298 = (98.892,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethylpropanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 150,
    label = "C5H10O2f",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,D} {17,S}
6  O u0 p2 c0 {3,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.907,39.967,47.474,53.611,62.307,68.931,79.352],'cal/(mol*K)'),
        H298 = (-102.077,'kcal/mol'),
        S298 = (97.649,'cal/(mol*K)'),
    ),
    shortDesc = u"""butyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 151,
    label = "C5H10O2g",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,D} {17,S}
6  O u0 p2 c0 {2,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.809,40.01,47.664,53.912,62.689,69.299,79.776],'cal/(mol*K)'),
        H298 = (-104.275,'kcal/mol'),
        S298 = (97.328,'cal/(mol*K)'),
    ),
    shortDesc = u"""isobutyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 152,
    label = "C5H10O2h",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,D} {17,S}
6  O u0 p2 c0 {1,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.401,38.591,45.302,50.861,58.759,64.484,74.233],'cal/(mol*K)'),
        H298 = (-106.45,'kcal/mol'),
        S298 = (96.847,'cal/(mol*K)'),
    ),
    shortDesc = u"""sec-butyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 153,
    label = "C5H10O2i",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,D} {17,S}
6  O u0 p2 c0 {1,S} {5,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.386,39.17,46.274,51.894,59.311,64.706,74.488],'cal/(mol*K)'),
        H298 = (-111.159,'kcal/mol'),
        S298 = (88.991,'cal/(mol*K)'),
    ),
    shortDesc = u"""tert-butyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 154,
    label = "C5H10O2j",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {5,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {4,S} {6,S} {17,D}
6  O u0 p2 c0 {2,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.59,39.928,46.852,52.876,62.057,68.484,78.154],'cal/(mol*K)'),
        H298 = (-111.087,'kcal/mol'),
        S298 = (96.286,'cal/(mol*K)'),
    ),
    shortDesc = u"""propyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 155,
    label = "C5H10O2k",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {5,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {4,S} {6,S} {17,D}
6  O u0 p2 c0 {1,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.54,40.168,47.967,54.178,62.7,69.104,78.863],'cal/(mol*K)'),
        H298 = (-115.126,'kcal/mol'),
        S298 = (93.401,'cal/(mol*K)'),
    ),
    shortDesc = u"""isopropyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 156,
    label = "C5H10O2l",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {7,S} {8,S}
2  C u0 p0 c0 {4,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {1,S} {6,S} {17,D}
6  O u0 p2 c0 {2,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.439,40.08,46.902,52.768,61.956,68.602,77.386],'cal/(mol*K)'),
        H298 = (-110.8,'kcal/mol'),
        S298 = (96.367,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl propanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 157,
    label = "C5H10O2m",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {6,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {2,S} {6,S} {17,D}
6  O u0 p2 c0 {4,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.365,40.55,47.779,53.606,62.014,68.646,79.217],'cal/(mol*K)'),
        H298 = (-107.717,'kcal/mol'),
        S298 = (95.485,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl butanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 158,
    label = "C5H10O2n",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {6,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {1,S} {6,S} {17,D}
6  O u0 p2 c0 {4,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([30.968,38.918,46.584,53.434,64.303,72.15,83.26],'cal/(mol*K)'),
        H298 = (-107.717,'kcal/mol'),
        S298 = (95.485,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl isobutanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 159,
    label = "C5H10O2o",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {11,S} {12,S}
3  C u0 p0 c0 {2,S} {4,S} {9,S} {10,S}
4  C u0 p0 c0 {3,S} {6,S} {15,S} {16,S}
5  C u0 p0 c0 {1,S} {7,S} {13,S} {14,S}
6  O u0 p2 c0 {1,S} {4,S}
7  O u0 p2 c0 {5,S} {17,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.515,42.036,49.479,55.576,64.491,70.951,80.272],'cal/(mol*K)'),
        H298 = (-88.238,'kcal/mol'),
        S298 = (89.232,'cal/(mol*K)'),
    ),
    shortDesc = u"""tetrahydrofurfuryl alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 161,
    label = "C5H10O3",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,D} {6,S}
2  C u0 p0 c0 {1,S} {3,S} {4,S} {9,S}
3  O u0 p2 c0 {2,S} {10,S}
4  C u0 p0 c0 {2,S} {11,S} {12,S} {13,S}
5  O u0 p2 c0 {1,D}
6  O u0 p2 c0 {1,S} {7,S}
7  C u0 p0 c0 {6,S} {8,S} {14,S} {15,S}
8  C u0 p0 c0 {7,S} {16,S} {17,S} {18,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {7,S}
15 H u0 p0 c0 {7,S}
16 H u0 p0 c0 {8,S}
17 H u0 p0 c0 {8,S}
18 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.291,44.158,51.763,57.876,66.722,73.35,82.987],'cal/(mol*K)'),
        H298 = (-151.766,'kcal/mol'),
        S298 = (109.097,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl lactate""",
    longDesc = 
u"""

""",
)

entry(
    index = 162,
    label = "C5H12Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {9,S} {10,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {6,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {4,S} {18,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.096,39.921,47.365,53.822,63.746,71.001,81.408],'cal/(mol*K)'),
        H298 = (-71.737,'kcal/mol'),
        S298 = (98.185,'cal/(mol*K)'),
    ),
    shortDesc = u"""1-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 163,
    label = "C5H12Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {18,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.523,40.531,47.983,54.28,63.753,70.903,81.295],'cal/(mol*K)'),
        H298 = (-74.997,'kcal/mol'),
        S298 = (94.898,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 164,
    label = "C5H12Oc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {18,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.577,40.536,47.849,54.013,63.653,71.597,82.091],'cal/(mol*K)'),
        H298 = (-75.797,'kcal/mol'),
        S298 = (91.325,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 165,
    label = "C5H12Od",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {3,S} {18,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.492,39.784,47.505,53.956,63.494,70.72,81.085],'cal/(mol*K)'),
        H298 = (-72.197,'kcal/mol'),
        S298 = (94.206,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 166,
    label = "C5H12Of",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
5  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
6  O u0 p2 c0 {2,S} {18,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.822,38.638,45.485,51.945,62.787,70.448,80.796],'cal/(mol*K)'),
        H298 = (-74.582,'kcal/mol'),
        S298 = (93.528,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-2-butanol, ()""",
    longDesc = 
u"""

""",
)

entry(
    index = 167,
    label = "C5H12Og",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {3,S} {18,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.467,39.458,47.104,53.696,63.519,70.35,80.662],'cal/(mol*K)'),
        H298 = (-71.797,'kcal/mol'),
        S298 = (94.177,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-1-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 168,
    label = "C5H12Oh",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {18,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.648,40.903,48.534,54.904,64.372,71.619,82.116],'cal/(mol*K)'),
        H298 = (-78.697,'kcal/mol'),
        S298 = (87.616,'cal/(mol*K)'),
    ),
    shortDesc = u"""tert-pentyl-alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 170,
    label = "C5H12Oj",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {2,S} {18,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.889,40.521,48.579,55.257,64.798,71.677,82.183],'cal/(mol*K)'),
        H298 = (-76.256,'kcal/mol'),
        S298 = (95.869,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethyl-1-propanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 171,
    label = "C5H12Ok",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {3,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.492,39.841,46.977,53.336,63.389,70.694,81.328],'cal/(mol*K)'),
        H298 = (-61.684,'kcal/mol'),
        S298 = (93.383,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl butyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 172,
    label = "C5H12Ol",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {2,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.609,39.679,47.338,53.871,63.758,71.244,81.961],'cal/(mol*K)'),
        H298 = (-63.429,'kcal/mol'),
        S298 = (90.498,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl isobutyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 173,
    label = "C5H12Om",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {1,S} {5,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.735,40.653,48.122,54.507,64.262,71.717,82.505],'cal/(mol*K)'),
        H298 = (-64.648,'kcal/mol'),
        S298 = (91.219,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl sec-butyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 174,
    label = "C5H12On",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {1,S} {5,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.644,38.81,45.896,52.363,62.927,70.703,81.339],'cal/(mol*K)'),
        H298 = (-67.683,'kcal/mol'),
        S298 = (85.768,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl tert-butyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 175,
    label = "C5H12Oo",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {5,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {2,S} {3,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.28,39.923,47.258,53.682,63.743,71.304,82.03],'cal/(mol*K)'),
        H298 = (-65.054,'kcal/mol'),
        S298 = (92.902,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl propyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 176,
    label = "C5H12Op",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {6,S} {7,S}
2  C u0 p0 c0 {5,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {1,S} {2,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.442,39.863,47.076,53.492,63.568,70.822,81.476],'cal/(mol*K)'),
        H298 = (-68.305,'kcal/mol'),
        S298 = (90.978,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl isopropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 182,
    label = "C5H12O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
3  C u0 p0 c0 {4,S} {6,S} {12,S} {13,S}
4  C u0 p0 c0 {3,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {2,S} {3,S}
7  O u0 p2 c0 {4,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.469,43.444,51.064,57.529,67.784,75.322,85.264],'cal/(mol*K)'),
        H298 = (-100.618,'kcal/mol'),
        S298 = (104.593,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylene glycol monopropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 183,
    label = "C5H12O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {2,S} {18,S}
7  O u0 p2 c0 {3,S} {19,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.279,43.955,52.332,59.307,69.137,76.224,87.165],'cal/(mol*K)'),
        H298 = (-106.832,'kcal/mol'),
        S298 = (96.574,'cal/(mol*K)'),
    ),
    shortDesc = u"""neopentyl glycol""",
    longDesc = 
u"""

""",
)

entry(
    index = 184,
    label = "C5H12O2c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {7,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {18,S}
7  O u0 p2 c0 {4,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.052,43.202,51.142,57.909,67.906,75.326,86.138],'cal/(mol*K)'),
        H298 = (-111.373,'kcal/mol'),
        S298 = (98.066,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 185,
    label = "C5H12O2e",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {11,S} {12,S}
3  C u0 p0 c0 {2,S} {4,S} {9,S} {10,S}
4  C u0 p0 c0 {3,S} {7,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {18,S}
7  O u0 p2 c0 {4,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.052,43.202,51.142,57.909,67.906,75.326,86.138],'cal/(mol*K)'),
        H298 = (-110.417,'kcal/mol'),
        S298 = (101.272,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,3-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 187,
    label = "C5H12O2g",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {10,S} {11,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {6,S} {16,S} {17,S}
6  O u0 p2 c0 {5,S} {18,S}
7  O u0 p2 c0 {4,S} {19,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.788,42.98,50.869,57.503,67.225,74.636,85.349],'cal/(mol*K)'),
        H298 = (-107.31,'kcal/mol'),
        S298 = (103.789,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,5-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 188,
    label = "C5H12O2h",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {9,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {18,S}
7  O u0 p2 c0 {2,S} {19,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.052,43.202,51.142,57.909,67.906,75.326,86.138],'cal/(mol*K)'),
        H298 = (-112.344,'kcal/mol'),
        S298 = (93.576,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 189,
    label = "C5H12O2i",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {3,S} {5,S} {6,S} {9,S}
3  C u0 p0 c0 {1,S} {2,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {2,S} {18,S}
7  O u0 p2 c0 {1,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.118,44.654,52.7,59.307,68.701,75.923,87.249],'cal/(mol*K)'),
        H298 = (-112.345,'kcal/mol'),
        S298 = (93.576,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,4-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 190,
    label = "C5H12O2n",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {19,S}
7  O u0 p2 c0 {3,S} {18,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {7,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.037,43.782,52.114,58.942,68.458,75.548,86.392],'cal/(mol*K)'),
        H298 = (-114.72,'kcal/mol'),
        S298 = (82.61,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1,2-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 191,
    label = "C5H12O2o",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {9,S}
3  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {2,S} {19,S}
7  O u0 p2 c0 {3,S} {18,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {7,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.002,43.224,51.241,58.066,68.086,75.454,86.285],'cal/(mol*K)'),
        H298 = (-112.568,'kcal/mol'),
        S298 = (96.013,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1,3-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 192,
    label = "C5H12O2p",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {7,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {3,S} {18,S}
7  O u0 p2 c0 {4,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.002,43.224,51.241,58.066,68.086,75.454,86.285],'cal/(mol*K)'),
        H298 = (-108.983,'kcal/mol'),
        S298 = (108.038,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1,4-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 193,
    label = "C5H12O2q",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {19,S}
7  O u0 p2 c0 {2,S} {18,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {7,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.987,43.804,52.214,59.098,68.638,75.676,86.539],'cal/(mol*K)'),
        H298 = (-119.022,'kcal/mol'),
        S298 = (70.137,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-2,3-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 194,
    label = "C5H12O2r",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {6,S} {9,S}
3  C u0 p0 c0 {2,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {2,S} {19,S}
7  O u0 p2 c0 {3,S} {18,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {7,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.002,43.224,51.241,58.066,68.086,75.454,86.285],'cal/(mol*K)'),
        H298 = (-112.808,'kcal/mol'),
        S298 = (95.212,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-1,2-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 195,
    label = "C5H12O2s",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {1,S} {19,S}
7  O u0 p2 c0 {3,S} {18,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {7,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.737,42.49,50.506,56.736,65.034,71.821,82.131],'cal/(mol*K)'),
        H298 = (-114.719,'kcal/mol'),
        S298 = (42.577,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-1,3-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 196,
    label = "C5H12O2t",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {7,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  O u0 p2 c0 {3,S} {18,S}
7  O u0 p2 c0 {4,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.302,44.516,52.849,60.272,71.51,79.181,90.546],'cal/(mol*K)'),
        H298 = (-108.984,'kcal/mol'),
        S298 = (148.07,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethyl-1,3-propanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 197,
    label = "C5H12O2u",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
3  C u0 p0 c0 {5,S} {6,S} {9,S} {10,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {3,S} {13,S} {14,S} {15,S}
6  O u0 p2 c0 {2,S} {3,S}
7  O u0 p2 c0 {1,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.469,43.444,51.064,57.529,67.784,75.322,85.264],'cal/(mol*K)'),
        H298 = (-100.618,'kcal/mol'),
        S298 = (104.596,'cal/(mol*K)'),
    ),
    shortDesc = u"""1-ethoxy-2-propanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 198,
    label = "C5H12O2v",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {7,S} {11,S} {12,S}
3  C u0 p0 c0 {5,S} {6,S} {9,S} {10,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {3,S} {13,S} {14,S} {15,S}
6  O u0 p2 c0 {1,S} {3,S}
7  O u0 p2 c0 {2,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.469,43.444,51.064,57.529,67.784,75.322,85.264],'cal/(mol*K)'),
        H298 = (-100.618,'kcal/mol'),
        S298 = (104.594,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethoxy-1-propanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 199,
    label = "C5H12O2w",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {5,S} {6,S} {8,S}
2  C u0 p0 c0 {3,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {1,S} {2,S}
7  O u0 p2 c0 {3,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.469,43.444,51.064,57.529,67.784,75.322,85.264],'cal/(mol*K)'),
        H298 = (-100.618,'kcal/mol'),
        S298 = (104.594,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-isopropoxyethanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 200,
    label = "C5H12O2x",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {1,S} {5,S}
7  O u0 p2 c0 {3,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.469,43.444,51.064,57.529,67.784,75.322,85.264],'cal/(mol*K)'),
        H298 = (-100.618,'kcal/mol'),
        S298 = (104.592,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methoxy-1-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 201,
    label = "C5H12O2y",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {6,S} {12,S} {13,S}
3  C u0 p0 c0 {5,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {2,S} {3,S}
7  O u0 p2 c0 {4,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.469,43.444,51.064,57.529,67.784,75.322,85.264],'cal/(mol*K)'),
        H298 = (-100.618,'kcal/mol'),
        S298 = (104.594,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-ethoxy-1-propanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 202,
    label = "C5H12O2z",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {3,S} {5,S}
7  O u0 p2 c0 {1,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.469,43.444,51.064,57.529,67.784,75.322,85.264],'cal/(mol*K)'),
        H298 = (-100.618,'kcal/mol'),
        S298 = (104.595,'cal/(mol*K)'),
    ),
    shortDesc = u"""1-methoxy-2-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 203,
    label = "C5H12O2cc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {10,S}
3  C u0 p0 c0 {5,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  O u0 p2 c0 {2,S} {3,S}
7  O u0 p2 c0 {2,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.469,43.444,51.064,57.529,67.784,75.322,85.264],'cal/(mol*K)'),
        H298 = (-100.618,'kcal/mol'),
        S298 = (104.59,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl ether of propylene glycol""",
    longDesc = 
u"""

""",
)

entry(
    index = 204,
    label = "C5H12O3",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {9,S} {10,S} {11,S}
2  O u0 p2 c0 {1,S} {3,S}
3  C u0 p0 c0 {2,S} {4,S} {12,S} {13,S}
4  C u0 p0 c0 {3,S} {5,S} {14,S} {15,S}
5  O u0 p2 c0 {4,S} {6,S}
6  C u0 p0 c0 {5,S} {7,S} {16,S} {17,S}
7  C u0 p0 c0 {6,S} {8,S} {18,S} {19,S}
8  O u0 p2 c0 {7,S} {20,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {7,S}
19 H u0 p0 c0 {7,S}
20 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.402,46.65,54.813,61.668,72.127,79.839,90.328],'cal/(mol*K)'),
        H298 = (-126.669,'kcal/mol'),
        S298 = (137.123,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-(2-methoxyethoxy)ethanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 205,
    label = "C5H12O4",
    molecule = 
"""
1  O u0 p2 c0 {2,S} {10,S}
2  C u0 p0 c0 {1,S} {3,S} {11,S} {12,S}
3  C u0 p0 c0 {2,S} {4,S} {6,S} {8,S}
4  C u0 p0 c0 {3,S} {5,S} {13,S} {14,S}
5  O u0 p2 c0 {4,S} {15,S}
6  C u0 p0 c0 {3,S} {7,S} {16,S} {17,S}
7  O u0 p2 c0 {6,S} {18,S}
8  C u0 p0 c0 {3,S} {9,S} {19,S} {20,S}
9  O u0 p2 c0 {8,S} {21,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {7,S}
19 H u0 p0 c0 {8,S}
20 H u0 p0 c0 {8,S}
21 H u0 p0 c0 {9,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([41.53,51.304,59.816,66.883,77.339,84.669,95.792],'cal/(mol*K)'),
        H298 = (-185.632,'kcal/mol'),
        S298 = (104.682,'cal/(mol*K)'),
    ),
    shortDesc = u"""pentaerythritol""",
    longDesc = 
u"""

""",
)

entry(
    index = 206,
    label = "C6H6O",
    molecule = 
"""
1  C u0 p0 c0 {2,B} {6,B} {7,S}
2  C u0 p0 c0 {1,B} {3,B} {8,S}
3  C u0 p0 c0 {2,B} {4,B} {9,S}
4  C u0 p0 c0 {3,B} {5,B} {10,S}
5  C u0 p0 c0 {4,B} {6,B} {11,S}
6  C u0 p0 c0 {1,B} {5,B} {12,S}
7  O u0 p2 c0 {1,S} {13,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {6,S}
13 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([24.818,32.361,38.697,43.714,50.703,55.566,62.744],'cal/(mol*K)'),
        H298 = (-23.038,'kcal/mol'),
        S298 = (75.211,'cal/(mol*K)'),
    ),
    shortDesc = u"""phenol""",
    longDesc = 
u"""

""",
)

entry(
    index = 207,
    label = "C6H6O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,B} {3,B} {8,S}
2  C u0 p0 c0 {1,B} {4,B} {7,S}
3  C u0 p0 c0 {1,B} {5,B} {9,S}
4  C u0 p0 c0 {2,B} {6,B} {12,S}
5  C u0 p0 c0 {3,B} {6,B} {10,S}
6  C u0 p0 c0 {4,B} {5,B} {11,S}
7  O u0 p2 c0 {2,S} {13,S}
8  O u0 p2 c0 {1,S} {14,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {5,S}
11 H u0 p0 c0 {6,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {7,S}
14 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([28.866,37.113,43.953,49.366,56.864,61.807,68.678],'cal/(mol*K)'),
        H298 = (-65.008,'kcal/mol'),
        S298 = (79.684,'cal/(mol*K)'),
    ),
    shortDesc = u"""pyrocatechol""",
    longDesc = 
u"""

""",
)

entry(
    index = 208,
    label = "C6H6O2b",
    molecule = 
"""
1  C u0 p0 c0 {3,B} {5,B} {8,S}
2  C u0 p0 c0 {3,B} {4,B} {7,S}
3  C u0 p0 c0 {1,B} {2,B} {9,S}
4  C u0 p0 c0 {2,B} {6,B} {10,S}
5  C u0 p0 c0 {1,B} {6,B} {12,S}
6  C u0 p0 c0 {4,B} {5,B} {11,S}
7  O u0 p2 c0 {2,S} {13,S}
8  O u0 p2 c0 {1,S} {14,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {6,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {7,S}
14 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.726,37.625,44.422,49.672,56.381,61.047,71.608],'cal/(mol*K)'),
        H298 = (-65.701,'kcal/mol'),
        S298 = (82.329,'cal/(mol*K)'),
    ),
    shortDesc = u"""resorcinol""",
    longDesc = 
u"""

""",
)

entry(
    index = 209,
    label = "C6H6O2c",
    molecule = 
"""
1  C u0 p0 c0 {3,B} {4,B} {7,S}
2  C u0 p0 c0 {5,B} {6,B} {8,S}
3  C u0 p0 c0 {1,B} {6,B} {9,S}
4  C u0 p0 c0 {1,B} {5,B} {10,S}
5  C u0 p0 c0 {2,B} {4,B} {11,S}
6  C u0 p0 c0 {2,B} {3,B} {12,S}
7  O u0 p2 c0 {1,S} {13,S}
8  O u0 p2 c0 {2,S} {14,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {6,S}
13 H u0 p0 c0 {7,S}
14 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.698,37.488,43.8,48.74,55.645,60.428,67.545],'cal/(mol*K)'),
        H298 = (-62.549,'kcal/mol'),
        S298 = (82.241,'cal/(mol*K)'),
    ),
    shortDesc = u"""p-hydroquinone""",
    longDesc = 
u"""

""",
)

entry(
    index = 210,
    label = "C6H6O3",
    molecule = 
"""
1  C u0 p0 c0 {2,B} {6,B} {9,S}
2  C u0 p0 c0 {1,B} {3,B} {8,S}
3  C u0 p0 c0 {2,B} {4,B} {7,S}
4  C u0 p0 c0 {3,B} {5,B} {10,S}
5  C u0 p0 c0 {4,B} {6,B} {11,S}
6  C u0 p0 c0 {1,B} {5,B} {12,S}
7  O u0 p2 c0 {3,S} {13,S}
8  O u0 p2 c0 {2,S} {14,S}
9  O u0 p2 c0 {1,S} {15,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {6,S}
13 H u0 p0 c0 {7,S}
14 H u0 p0 c0 {8,S}
15 H u0 p0 c0 {9,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.435,42.536,49.315,54.571,61.387,65.714,74.347],'cal/(mol*K)'),
        H298 = (-106.595,'kcal/mol'),
        S298 = (91.291,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2,3-benzenetriol""",
    longDesc = 
u"""

""",
)

entry(
    index = 213,
    label = "C6H8Oc",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {11,S} {12,S} {13,S}
2  C u0 p0 c0 {4,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {4,D} {5,S}
4  C u0 p0 c0 {2,S} {3,D} {7,S}
5  C u0 p0 c0 {3,S} {6,D} {14,S}
6  C u0 p0 c0 {5,D} {7,S} {15,S}
7  O u0 p2 c0 {4,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {1,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.705,35.053,41.405,46.805,55.231,61.269,69.439],'cal/(mol*K)'),
        H298 = (-23.396,'kcal/mol'),
        S298 = (80.438,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-dimethylfuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 214,
    label = "C6H8Od",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {11,S} {12,S} {13,S}
2  C u0 p0 c0 {4,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {5,S} {6,D}
4  C u0 p0 c0 {2,S} {5,D} {7,S}
5  C u0 p0 c0 {3,S} {4,D} {14,S}
6  C u0 p0 c0 {3,D} {7,S} {15,S}
7  O u0 p2 c0 {4,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {1,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.705,35.053,41.405,46.805,55.231,61.269,69.439],'cal/(mol*K)'),
        H298 = (-23.396,'kcal/mol'),
        S298 = (80.438,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,4-dimethylfuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 215,
    label = "C6H8Oe",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {8,S} {9,S} {10,S}
2  C u0 p0 c0 {4,S} {11,S} {12,S} {13,S}
3  C u0 p0 c0 {1,S} {5,D} {7,S}
4  C u0 p0 c0 {2,S} {6,D} {7,S}
5  C u0 p0 c0 {3,D} {6,S} {14,S}
6  C u0 p0 c0 {4,D} {5,S} {15,S}
7  O u0 p2 c0 {3,S} {4,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.705,35.053,41.405,46.805,55.231,61.269,69.439],'cal/(mol*K)'),
        H298 = (-23.399,'kcal/mol'),
        S298 = (80.783,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,5-dimethylfuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 216,
    label = "C6H8Of",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {8,S} {9,S} {10,S}
2  C u0 p0 c0 {4,S} {11,S} {12,S} {13,S}
3  C u0 p0 c0 {1,S} {4,S} {5,D}
4  C u0 p0 c0 {2,S} {3,S} {6,D}
5  C u0 p0 c0 {3,D} {7,S} {14,S}
6  C u0 p0 c0 {4,D} {7,S} {15,S}
7  O u0 p2 c0 {5,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.705,35.053,41.405,46.805,55.231,61.269,69.439],'cal/(mol*K)'),
        H298 = (-23.396,'kcal/mol'),
        S298 = (80.438,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,4-dimethylfuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 217,
    label = "C6H8O4",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {8,D} {9,S}
2  C u0 p0 c0 {1,S} {3,D} {11,S}
3  C u0 p0 c0 {2,D} {4,S} {12,S}
4  C u0 p0 c0 {3,S} {5,D} {6,S}
5  O u0 p2 c0 {4,D}
6  O u0 p2 c0 {4,S} {7,S}
7  C u0 p0 c0 {6,S} {13,S} {14,S} {15,S}
8  O u0 p2 c0 {1,D}
9  O u0 p2 c0 {1,S} {10,S}
10 C u0 p0 c0 {9,S} {16,S} {17,S} {18,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {7,S}
14 H u0 p0 c0 {7,S}
15 H u0 p0 c0 {7,S}
16 H u0 p0 c0 {10,S}
17 H u0 p0 c0 {10,S}
18 H u0 p0 c0 {10,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.044,48.596,55.746,61.576,70.364,76.984,87.098],'cal/(mol*K)'),
        H298 = (-148.373,'kcal/mol'),
        S298 = (119.462,'cal/(mol*K)'),
    ),
    shortDesc = u"""dimethyl maleate""",
    longDesc = 
u"""

""",
)

entry(
    index = 218,
    label = "C6H8O6",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {13,S} {14,S}
2  O u0 p2 c0 {1,S} {15,S}
3  C u0 p0 c0 {1,S} {4,S} {5,S} {16,S}
4  O u0 p2 c0 {3,S} {17,S}
5  C u0 p0 c0 {3,S} {6,S} {10,S} {18,S}
6  O u0 p2 c0 {5,S} {7,S}
7  C u0 p0 c0 {6,S} {8,D} {12,S}
8  C u0 p0 c0 {7,D} {9,S} {10,S}
9  O u0 p2 c0 {8,S} {19,S}
10 C u0 p0 c0 {5,S} {8,S} {11,D}
11 O u0 p2 c0 {10,D}
12 O u0 p2 c0 {7,S} {20,S}
13 H u0 p0 c0 {1,S}
14 H u0 p0 c0 {1,S}
15 H u0 p0 c0 {2,S}
16 H u0 p0 c0 {3,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {9,S}
20 H u0 p0 c0 {12,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([49.812,59.778,67.685,73.753,82.11,88.179,99.764],'cal/(mol*K)'),
        H298 = (-227.293,'kcal/mol'),
        S298 = (103.878,'cal/(mol*K)'),
    ),
    shortDesc = u"""ascorbic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 219,
    label = "C6H8O7",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {12,D} {13,S}
2  C u0 p0 c0 {1,S} {3,S} {14,S} {15,S}
3  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
4  O u0 p2 c0 {3,S} {16,S}
5  C u0 p0 c0 {3,S} {6,D} {7,S}
6  O u0 p2 c0 {5,D}
7  O u0 p2 c0 {5,S} {17,S}
8  C u0 p0 c0 {3,S} {9,S} {18,S} {19,S}
9  C u0 p0 c0 {8,S} {10,D} {11,S}
10 O u0 p2 c0 {9,D}
11 O u0 p2 c0 {9,S} {20,S}
12 O u0 p2 c0 {1,D}
13 O u0 p2 c0 {1,S} {21,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {2,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {7,S}
18 H u0 p0 c0 {8,S}
19 H u0 p0 c0 {8,S}
20 H u0 p0 c0 {11,S}
21 H u0 p0 c0 {13,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([50.795,60.687,68.767,75.256,84.521,90.746,102.668],'cal/(mol*K)'),
        H298 = (-332.216,'kcal/mol'),
        S298 = (133.204,'cal/(mol*K)'),
    ),
    shortDesc = u"""citric acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 220,
    label = "C6H10Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {9,S} {10,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {6,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {6,S} {15,S} {16,S}
6  C u0 p0 c0 {4,S} {5,S} {17,D}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.101,38.356,46.938,54.087,64.405,71.955,84.403],'cal/(mol*K)'),
        H298 = (-53.941,'kcal/mol'),
        S298 = (79.957,'cal/(mol*K)'),
    ),
    shortDesc = u"""cyclohexanone""",
    longDesc = 
u"""

""",
)

entry(
    index = 221,
    label = "C6H10Ob",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {10,S} {11,S} {12,S}
2  C u0 p0 c0 {4,S} {13,S} {14,S} {15,S}
3  C u0 p0 c0 {5,S} {7,S} {8,S} {9,S}
4  C u0 p0 c0 {1,S} {2,S} {6,D}
5  C u0 p0 c0 {3,S} {6,S} {16,D}
6  C u0 p0 c0 {4,D} {5,S} {17,S}
7  H u0 p0 c0 {3,S}
8  H u0 p0 c0 {3,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {2,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.588,42.814,49.094,54.598,63.744,70.713,80.003],'cal/(mol*K)'),
        H298 = (-46.738,'kcal/mol'),
        S298 = (95.282,'cal/(mol*K)'),
    ),
    shortDesc = u"""mesityl oxide""",
    longDesc = 
u"""

""",
)

entry(
    index = 222,
    label = "C6H10O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {10,S} {11,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {6,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {7,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {7,S} {18,D}
7  O u0 p2 c0 {5,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([29.394,39.905,49.789,58.056,69.882,77.962,88.205],'cal/(mol*K)'),
        H298 = (-101.796,'kcal/mol'),
        S298 = (86.685,'cal/(mol*K)'),
    ),
    shortDesc = u"""epsiloN-caprolactone""",
    longDesc = 
u"""

""",
)

entry(
    index = 223,
    label = "C6H10O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
3  C u0 p0 c0 {4,S} {13,S} {14,S} {15,S}
4  C u0 p0 c0 {3,S} {5,S} {6,D}
5  C u0 p0 c0 {4,S} {7,S} {16,D}
6  C u0 p0 c0 {4,D} {17,S} {18,S}
7  O u0 p2 c0 {1,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([32.895,42.126,50.325,57.017,66.602,73.435,83.082],'cal/(mol*K)'),
        H298 = (-91.058,'kcal/mol'),
        S298 = (105.995,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl methacrylate""",
    longDesc = 
u"""

""",
)

entry(
    index = 224,
    label = "C6H10O2c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
4  C u0 p0 c0 {5,S} {6,D} {15,S}
5  C u0 p0 c0 {4,S} {7,S} {16,D}
6  C u0 p0 c0 {4,D} {17,S} {18,S}
7  O u0 p2 c0 {2,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""propyl acrylate""",
    longDesc = 
u"""

""",
)

entry(
    index = 225,
    label = "C6H10O2d",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
3  C u0 p0 c0 {6,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {5,D} {16,S}
5  C u0 p0 c0 {2,S} {4,D} {17,S}
6  C u0 p0 c0 {3,S} {7,S} {18,D}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {2,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-buteN-1-yl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 226,
    label = "C6H10O2e",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {8,S} {9,S}
2  C u0 p0 c0 {4,S} {7,S} {13,S} {14,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {6,D} {15,S}
5  C u0 p0 c0 {1,S} {7,S} {16,D}
6  C u0 p0 c0 {4,D} {17,S} {18,S}
7  O u0 p2 c0 {2,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""allyl propanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 227,
    label = "C6H10O2f",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {5,S} {8,S} {9,S}
2  C u0 p0 c0 {3,S} {7,S} {10,S} {11,S}
3  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
4  C u0 p0 c0 {1,S} {6,D} {15,S}
5  C u0 p0 c0 {1,S} {7,S} {16,D}
6  C u0 p0 c0 {4,D} {17,S} {18,S}
7  O u0 p2 c0 {2,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {4,S}
16 O u0 p2 c0 {5,D}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl 3-butenoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 228,
    label = "C6H10O2h",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
3  C u0 p0 c0 {4,S} {13,S} {14,S} {15,S}
4  C u0 p0 c0 {3,S} {5,D} {16,S}
5  C u0 p0 c0 {4,D} {6,S} {17,S}
6  C u0 p0 c0 {5,S} {7,S} {18,D}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl 2-butenoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 229,
    label = "C6H10O2j",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {4,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
4  C u0 p0 c0 {2,S} {7,S} {15,D}
5  C u0 p0 c0 {6,D} {7,S} {16,S}
6  C u0 p0 c0 {5,D} {17,S} {18,S}
7  O u0 p2 c0 {4,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 O u0 p2 c0 {4,D}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""vinyl butanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 230,
    label = "C6H10O2k",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
4  C u0 p0 c0 {1,S} {7,S} {15,D}
5  C u0 p0 c0 {6,D} {7,S} {16,S}
6  C u0 p0 c0 {5,D} {17,S} {18,S}
7  O u0 p2 c0 {4,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 O u0 p2 c0 {4,D}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""vinyl 2-methylpropanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 231,
    label = "C6H10O2l",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {8,S} {9,S} {10,S}
2  C u0 p0 c0 {5,S} {11,S} {12,S} {13,S}
3  C u0 p0 c0 {7,S} {14,S} {15,S} {16,S}
4  C u0 p0 c0 {1,S} {5,D} {6,S}
5  C u0 p0 c0 {2,S} {4,D} {17,S}
6  C u0 p0 c0 {4,S} {7,S} {18,D}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {3,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 2-methyl-2-butenoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 232,
    label = "C6H10O2m",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {8,S} {9,S} {10,S}
2  C u0 p0 c0 {4,S} {11,S} {12,S} {13,S}
3  C u0 p0 c0 {7,S} {14,S} {15,S} {16,S}
4  C u0 p0 c0 {1,S} {2,S} {5,D}
5  C u0 p0 c0 {4,D} {6,S} {17,S}
6  C u0 p0 c0 {5,S} {7,S} {18,D}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {3,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 3-methyl-2-butenoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 233,
    label = "C6H10O2n",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
3  C u0 p0 c0 {7,S} {13,S} {14,S} {15,S}
4  C u0 p0 c0 {1,S} {5,D} {16,S}
5  C u0 p0 c0 {4,D} {6,S} {17,S}
6  C u0 p0 c0 {5,S} {7,S} {18,D}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.673,46.786,54.488,60.579,69.339,76.181,86.361],'cal/(mol*K)'),
        H298 = (-86.996,'kcal/mol'),
        S298 = (106.794,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl trans-2-pentenoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 234,
    label = "C6H10O3a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
3  C u0 p0 c0 {5,S} {6,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {2,S} {3,S} {17,D}
6  C u0 p0 c0 {3,S} {7,S} {18,D}
7  O u0 p2 c0 {6,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 O u0 p2 c0 {5,D}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.628,45.315,53.833,60.764,70.778,78.097,88.357],'cal/(mol*K)'),
        H298 = (-133.84,'kcal/mol'),
        S298 = (116.08,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylacetoacetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 235,
    label = "C6H10O3b",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {8,S} {9,S}
2  C u0 p0 c0 {4,S} {6,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
4  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
5  C u0 p0 c0 {1,S} {7,S} {18,D}
6  C u0 p0 c0 {2,S} {7,S} {19,D}
7  O u0 p2 c0 {5,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 O u0 p2 c0 {5,D}
19 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.333,45.61,54.153,61.417,71.435,76.757,86.841],'cal/(mol*K)'),
        H298 = (-149.734,'kcal/mol'),
        S298 = (112.473,'cal/(mol*K)'),
    ),
    shortDesc = u"""propionic anhydride""",
    longDesc = 
u"""

""",
)

entry(
    index = 236,
    label = "C6H10O4a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {9,S} {10,S}
2  C u0 p0 c0 {1,S} {4,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {5,S} {13,S} {14,S}
4  C u0 p0 c0 {2,S} {6,S} {15,S} {16,S}
5  C u0 p0 c0 {3,S} {8,S} {18,D}
6  C u0 p0 c0 {4,S} {7,S} {17,D}
7  O u0 p2 c0 {6,S} {19,S}
8  O u0 p2 c0 {5,S} {20,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 O u0 p2 c0 {6,D}
18 O u0 p2 c0 {5,D}
19 H u0 p0 c0 {7,S}
20 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([41.137,50.561,58.797,65.686,75.855,82.716,93.583],'cal/(mol*K)'),
        H298 = (-206.747,'kcal/mol'),
        S298 = (119.295,'cal/(mol*K)'),
    ),
    shortDesc = u"""adipic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 237,
    label = "C6H10O4b",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {7,S} {9,S} {10,S}
2  C u0 p0 c0 {4,S} {8,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
4  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {6,S} {8,S} {20,D}
6  C u0 p0 c0 {5,S} {7,S} {19,D}
7  O u0 p2 c0 {1,S} {6,S}
8  O u0 p2 c0 {2,S} {5,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 O u0 p2 c0 {6,D}
20 O u0 p2 c0 {5,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([39.738,50.343,59.317,66.275,75.839,83.139,94.062],'cal/(mol*K)'),
        H298 = (-176.813,'kcal/mol'),
        S298 = (126.326,'cal/(mol*K)'),
    ),
    shortDesc = u"""diethyl oxalate""",
    longDesc = 
u"""

""",
)

entry(
    index = 238,
    label = "C6H10O4c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {8,S} {11,S} {12,S}
2  C u0 p0 c0 {1,S} {7,S} {13,S} {14,S}
3  C u0 p0 c0 {5,S} {15,S} {16,S} {17,S}
4  C u0 p0 c0 {6,S} {18,S} {19,S} {20,S}
5  C u0 p0 c0 {3,S} {9,S} {21,D}
6  C u0 p0 c0 {4,S} {10,S} {22,D}
7  O u0 p2 c0 {2,S} {23,S}
8  O u0 p2 c0 {1,S} {24,S}
9  O u0 p2 c0 {5,S} {25,S}
10 O u0 p2 c0 {6,S} {26,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {3,S}
17 H u0 p0 c0 {3,S}
18 H u0 p0 c0 {4,S}
19 H u0 p0 c0 {4,S}
20 H u0 p0 c0 {4,S}
21 O u0 p2 c0 {5,D}
22 O u0 p2 c0 {6,D}
23 H u0 p0 c0 {7,S}
24 H u0 p0 c0 {8,S}
25 H u0 p0 c0 {9,S}
26 H u0 p0 c0 {10,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([39.739,50.345,59.318,66.276,75.841,83.141,94.064],'cal/(mol*K)'),
        H298 = (-192.875,'kcal/mol'),
        S298 = (121.356,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylene glycol diacetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 239,
    label = "C6H10O4d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
3  C u0 p0 c0 {5,S} {13,S} {14,S} {15,S}
4  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {3,S} {7,S} {19,D}
6  C u0 p0 c0 {4,S} {8,S} {20,D}
7  O u0 p2 c0 {1,S} {5,S}
8  O u0 p2 c0 {1,S} {6,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 O u0 p2 c0 {5,D}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.884,49.208,58.792,65.998,75.313,82.444,93.275],'cal/(mol*K)'),
        H298 = (-194.069,'kcal/mol'),
        S298 = (118.15,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylidene diacetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 240,
    label = "C6H12Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {4,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {6,D} {7,S} {17,S}
6  C u0 p0 c0 {5,D} {18,S} {19,S}
7  O u0 p2 c0 {3,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.702,40.851,47.199,52.182,59.461,66.148,75.442],'cal/(mol*K)'),
        H298 = (-43.735,'kcal/mol'),
        S298 = (102.45,'cal/(mol*K)'),
    ),
    shortDesc = u"""butyl vinyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 241,
    label = "C6H12Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {6,D} {7,S} {17,S}
6  C u0 p0 c0 {5,D} {18,S} {19,S}
7  O u0 p2 c0 {1,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.702,40.851,47.199,52.182,59.461,66.148,75.442],'cal/(mol*K)'),
        H298 = (-43.735,'kcal/mol'),
        S298 = (102.451,'cal/(mol*K)'),
    ),
    shortDesc = u"""sec-butyl vinyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 242,
    label = "C6H12Oc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {6,D} {7,S} {17,S}
6  C u0 p0 c0 {5,D} {18,S} {19,S}
7  O u0 p2 c0 {1,S} {5,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.702,40.851,47.199,52.182,59.461,66.148,75.442],'cal/(mol*K)'),
        H298 = (-43.735,'kcal/mol'),
        S298 = (102.452,'cal/(mol*K)'),
    ),
    shortDesc = u"""tert-butyl vinyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 243,
    label = "C6H12Od",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {7,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {6,D} {7,S} {17,S}
6  C u0 p0 c0 {5,D} {18,S} {19,S}
7  O u0 p2 c0 {2,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.702,40.851,47.199,52.182,59.461,66.148,75.442],'cal/(mol*K)'),
        H298 = (-43.735,'kcal/mol'),
        S298 = (102.451,'cal/(mol*K)'),
    ),
    shortDesc = u"""isobutyl vinyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 244,
    label = "C6H12Oe",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {5,S} {7,S} {15,S} {16,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {6,D} {17,S}
6  C u0 p0 c0 {5,D} {18,S} {19,S}
7  O u0 p2 c0 {1,S} {2,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {2,S}
16 H u0 p0 c0 {2,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.702,40.851,47.199,52.182,59.461,66.148,75.442],'cal/(mol*K)'),
        H298 = (-43.735,'kcal/mol'),
        S298 = (102.451,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-(1-methylethoxy)-1-propene""",
    longDesc = 
u"""

""",
)

entry(
    index = 245,
    label = "C6H12Of",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
3  C u0 p0 c0 {5,S} {7,S} {15,S} {16,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {6,D} {17,S}
6  C u0 p0 c0 {5,D} {18,S} {19,S}
7  O u0 p2 c0 {2,S} {3,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {3,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([33.702,40.851,47.199,52.182,59.461,66.148,75.442],'cal/(mol*K)'),
        H298 = (-43.735,'kcal/mol'),
        S298 = (102.45,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-propoxy-1-propene""",
    longDesc = 
u"""

""",
)

entry(
    index = 246,
    label = "C6H12Og",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {17,S} {18,S}
4  C u0 p0 c0 {2,S} {5,S} {11,S} {12,S}
5  C u0 p0 c0 {4,S} {6,S} {13,S} {14,S}
6  C u0 p0 c0 {3,S} {5,S} {15,S} {16,S}
7  O u0 p2 c0 {1,S} {19,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {6,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {3,S}
18 H u0 p0 c0 {3,S}
19 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([31.898,42.068,51.726,59.983,72.115,80.621,94.569],'cal/(mol*K)'),
        H298 = (-68.543,'kcal/mol'),
        S298 = (84.335,'cal/(mol*K)'),
    ),
    shortDesc = u"""cyclohexanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 247,
    label = "C6H12Oh",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {9,S} {10,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {6,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,D} {19,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.722,44.026,51.577,58.625,70.213,78.591,90.419],'cal/(mol*K)'),
        H298 = (-59.414,'kcal/mol'),
        S298 = (100.845,'cal/(mol*K)'),
    ),
    shortDesc = u"""hexanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 248,
    label = "C6H12Oi",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,D} {19,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.364,43.677,51.81,58.766,69.026,76.528,88.046],'cal/(mol*K)'),
        H298 = (-61.183,'kcal/mol'),
        S298 = (96.934,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methylpentanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 249,
    label = "C6H12Oj",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,D} {19,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.364,43.677,51.81,58.766,69.026,76.528,88.046],'cal/(mol*K)'),
        H298 = (-60.585,'kcal/mol'),
        S298 = (98.938,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methylpentanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 250,
    label = "C6H12Ok",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,D} {19,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.364,43.677,51.81,58.766,69.026,76.528,88.046],'cal/(mol*K)'),
        H298 = (-61.183,'kcal/mol'),
        S298 = (96.934,'cal/(mol*K)'),
    ),
    shortDesc = u"""4-methylpentanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 251,
    label = "C6H12Ol",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,D} {19,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.364,43.677,51.81,58.766,69.026,76.528,88.046],'cal/(mol*K)'),
        H298 = (-63.573,'kcal/mol'),
        S298 = (88.917,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethylbutanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 252,
    label = "C6H12Om",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
5  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
6  C u0 p0 c0 {1,S} {18,D} {19,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.349,44.257,52.782,59.798,69.578,76.75,88.301],'cal/(mol*K)'),
        H298 = (-62.64,'kcal/mol'),
        S298 = (87.811,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethylbutanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 253,
    label = "C6H12On",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {8,S}
3  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
4  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
5  C u0 p0 c0 {2,S} {9,S} {10,S} {11,S}
6  C u0 p0 c0 {2,S} {18,D} {19,S}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {5,S}
10 H u0 p0 c0 {5,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.314,43.699,51.909,58.922,69.205,76.656,88.194],'cal/(mol*K)'),
        H298 = (-64.098,'kcal/mol'),
        S298 = (89.11,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-dimethylbutanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 254,
    label = "C6H12Oo",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,D} {19,S}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 O u0 p2 c0 {6,D}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.349,44.257,52.782,59.798,69.578,76.75,88.301],'cal/(mol*K)'),
        H298 = (-60.872,'kcal/mol'),
        S298 = (93.743,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,3-dimethylbutanal""",
    longDesc = 
u"""

""",
)

entry(
    index = 255,
    label = "C6H12Op",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {3,S} {5,S} {19,D}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.117,43.768,51.165,57.789,68.17,75.275,85.419],'cal/(mol*K)'),
        H298 = (-66.68,'kcal/mol'),
        S298 = (100.044,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-hexanone""",
    longDesc = 
u"""

""",
)

entry(
    index = 256,
    label = "C6H12Oq",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
3  C u0 p0 c0 {5,S} {6,S} {9,S} {10,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {3,S} {13,S} {14,S} {15,S}
6  C u0 p0 c0 {2,S} {3,S} {19,D}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.175,44.304,51.269,57.729,68.421,75.94,86.173],'cal/(mol*K)'),
        H298 = (-66.369,'kcal/mol'),
        S298 = (97.959,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-hexanone""",
    longDesc = 
u"""

""",
)

entry(
    index = 257,
    label = "C6H12Or",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {1,S} {5,S} {19,D}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.435,42.941,51.039,58.006,68.526,76.107,86.363],'cal/(mol*K)'),
        H298 = (-67.444,'kcal/mol'),
        S298 = (98.522,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-2-pentanone""",
    longDesc = 
u"""

""",
)

entry(
    index = 258,
    label = "C6H12Os",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {5,S} {19,D}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.165,43.564,51.438,58.152,68.36,76.007,86.25],'cal/(mol*K)'),
        H298 = (-68.448,'kcal/mol'),
        S298 = (98.842,'cal/(mol*K)'),
    ),
    shortDesc = u"""4-methyl-2-pentanone""",
    longDesc = 
u"""

""",
)

entry(
    index = 259,
    label = "C6H12Ot",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {6,S} {7,S}
2  C u0 p0 c0 {5,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {1,S} {2,S} {19,D}
7  H u0 p0 c0 {1,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.522,42.538,50.282,57.145,67.941,75.735,85.941],'cal/(mol*K)'),
        H298 = (-68.376,'kcal/mol'),
        S298 = (97.4,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl isopropyl ketone""",
    longDesc = 
u"""

""",
)

entry(
    index = 260,
    label = "C6H12Ou",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {1,S} {5,S} {19,D}
7  H u0 p0 c0 {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.42,43.521,52.012,59.038,69.078,76.329,86.615],'cal/(mol*K)'),
        H298 = (-69.428,'kcal/mol'),
        S298 = (92.029,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,3-dimethyl-2-butanone""",
    longDesc = 
u"""

""",
)

entry(
    index = 262,
    label = "C6H12Ow",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {6,S} {9,S} {10,S}
4  C u0 p0 c0 {2,S} {5,S} {13,S} {14,S}
5  C u0 p0 c0 {4,S} {7,S} {15,S} {16,S}
6  C u0 p0 c0 {3,S} {17,S} {18,S} {19,S}
7  O u0 p2 c0 {1,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.756,34.816,41.451,47.075,55.392,61.405,70.294],'cal/(mol*K)'),
        H298 = (-57.045,'kcal/mol'),
        S298 = (68.812,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 263,
    label = "C6H12Ox",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {6,S} {9,S} {10,S}
4  C u0 p0 c0 {1,S} {7,S} {15,S} {16,S}
5  C u0 p0 c0 {2,S} {7,S} {13,S} {14,S}
6  C u0 p0 c0 {3,S} {17,S} {18,S} {19,S}
7  O u0 p2 c0 {4,S} {5,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.756,34.816,41.451,47.075,55.392,61.405,70.294],'cal/(mol*K)'),
        H298 = (-57.045,'kcal/mol'),
        S298 = (68.812,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-ethyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 264,
    label = "C6H12Oy",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {4,S} {10,S} {11,S}
4  C u0 p0 c0 {3,S} {7,S} {12,S} {13,S}
5  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
6  C u0 p0 c0 {1,S} {17,S} {18,S} {19,S}
7  O u0 p2 c0 {1,S} {4,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.756,34.816,41.451,47.075,55.392,61.405,70.294],'cal/(mol*K)'),
        H298 = (-53.403,'kcal/mol'),
        S298 = (85.426,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 265,
    label = "C6H12Oz",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {4,S} {10,S} {11,S}
4  C u0 p0 c0 {3,S} {7,S} {12,S} {13,S}
5  C u0 p0 c0 {1,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
7  O u0 p2 c0 {2,S} {4,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {6,S}
15 H u0 p0 c0 {6,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.756,34.816,41.451,47.075,55.392,61.405,70.294],'cal/(mol*K)'),
        H298 = (-61.907,'kcal/mol'),
        S298 = (58.683,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-dimethyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 266,
    label = "C6H12Oaa",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {3,S} {6,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {2,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
5  C u0 p0 c0 {1,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
7  O u0 p2 c0 {2,S} {4,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {6,S}
15 H u0 p0 c0 {6,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.756,34.816,41.451,47.075,55.392,61.405,70.294],'cal/(mol*K)'),
        H298 = (-61.907,'kcal/mol'),
        S298 = (58.683,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,4-dimethyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 267,
    label = "C6H12Obb",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {7,S} {8,S}
2  C u0 p0 c0 {4,S} {6,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {4,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {3,S} {12,S} {13,S}
5  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
6  C u0 p0 c0 {2,S} {17,S} {18,S} {19,S}
7  O u0 p2 c0 {1,S} {2,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.756,34.816,41.451,47.075,55.392,61.405,70.294],'cal/(mol*K)'),
        H298 = (-61.907,'kcal/mol'),
        S298 = (58.683,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,5-dimethyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 268,
    label = "C6H12Occ",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {7,S} {10,S} {11,S}
5  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
6  C u0 p0 c0 {1,S} {17,S} {18,S} {19,S}
7  O u0 p2 c0 {3,S} {4,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.756,34.816,41.451,47.075,55.392,61.405,70.294],'cal/(mol*K)'),
        H298 = (-53.404,'kcal/mol'),
        S298 = (85.426,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,3-dimethyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 269,
    label = "C6H12Odd",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {6,S} {9,S}
3  C u0 p0 c0 {2,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
5  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
6  C u0 p0 c0 {2,S} {17,S} {18,S} {19,S}
7  O u0 p2 c0 {3,S} {4,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([27.756,34.816,41.451,47.075,55.392,61.405,70.294],'cal/(mol*K)'),
        H298 = (-61.908,'kcal/mol'),
        S298 = (58.683,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,4-dimethyltetrahydrofuran""",
    longDesc = 
u"""

""",
)

entry(
    index = 271,
    label = "C6H12O2a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {10,S} {11,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {6,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {4,S} {7,S} {19,D}
7  O u0 p2 c0 {6,S} {20,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([38.644,47.706,56.046,63.037,73.438,81.195,92.18],'cal/(mol*K)'),
        H298 = (-121.651,'kcal/mol'),
        S298 = (109.168,'cal/(mol*K)'),
    ),
    shortDesc = u"""hexanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 272,
    label = "C6H12O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {1,S} {7,S} {19,D}
7  O u0 p2 c0 {6,S} {20,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.99,45.845,54.958,62.436,73.169,81.24,92.231],'cal/(mol*K)'),
        H298 = (-123.563,'kcal/mol'),
        S298 = (101.153,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethylbutanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 273,
    label = "C6H12O2c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {7,S} {19,D}
7  O u0 p2 c0 {6,S} {20,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.306,42.733,50.371,56.69,66.402,74.504,84.492],'cal/(mol*K)'),
        H298 = (-122.606,'kcal/mol'),
        S298 = (105.162,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,3-dimethylbutanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 274,
    label = "C6H12O2d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {6,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
6  C u0 p0 c0 {1,S} {7,S} {19,D}
7  O u0 p2 c0 {6,S} {20,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.16,46.17,55.408,62.913,73.446,81.329,93.056],'cal/(mol*K)'),
        H298 = (-122.607,'kcal/mol'),
        S298 = (105.161,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethylbutanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 275,
    label = "C6H12O2e",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {9,S}
3  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {2,S} {10,S} {11,S} {12,S}
6  C u0 p0 c0 {2,S} {7,S} {19,D}
7  O u0 p2 c0 {6,S} {20,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {5,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([34.832,43.388,51.143,57.559,67.42,75.646,85.787],'cal/(mol*K)'),
        H298 = (-122.606,'kcal/mol'),
        S298 = (105.162,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-dimethylbutanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 276,
    label = "C6H12O2f",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {1,S} {7,S} {19,D}
7  O u0 p2 c0 {6,S} {20,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.052,44.908,52.935,59.576,69.782,78.297,88.792],'cal/(mol*K)'),
        H298 = (-122.606,'kcal/mol'),
        S298 = (105.161,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methylpentanoic acid, ()""",
    longDesc = 
u"""

""",
)

entry(
    index = 277,
    label = "C6H12O2g",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {3,S} {7,S} {19,D}
7  O u0 p2 c0 {6,S} {20,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.654,45.658,53.818,60.57,70.947,79.603,90.274],'cal/(mol*K)'),
        H298 = (-122.607,'kcal/mol'),
        S298 = (105.161,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methylpentanoic acid, ()""",
    longDesc = 
u"""

""",
)

entry(
    index = 278,
    label = "C6H12O2h",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {3,S} {7,S} {19,D}
7  O u0 p2 c0 {6,S} {20,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.613,46.853,55.227,62.156,72.803,81.687,92.637],'cal/(mol*K)'),
        H298 = (-122.607,'kcal/mol'),
        S298 = (105.16,'cal/(mol*K)'),
    ),
    shortDesc = u"""4-methylpentanoic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 279,
    label = "C6H12O2i",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {10,S} {11,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,D} {20,S}
7  O u0 p2 c0 {4,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.427,46.964,55.844,63.097,73.377,81.246,93.529],'cal/(mol*K)'),
        H298 = (-107.119,'kcal/mol'),
        S298 = (107.084,'cal/(mol*K)'),
    ),
    shortDesc = u"""pentyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 280,
    label = "C6H12O2j",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {3,S} {13,S} {14,S} {15,S}
6  C u0 p0 c0 {7,S} {19,D} {20,S}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.897,45.485,53.543,60.248,69.841,76.815,88.428],'cal/(mol*K)'),
        H298 = (-111.445,'kcal/mol'),
        S298 = (105.321,'cal/(mol*K)'),
    ),
    shortDesc = u"""1-methylbutyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 281,
    label = "C6H12O2k",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
6  C u0 p0 c0 {7,S} {19,D} {20,S}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.897,45.485,53.543,60.248,69.841,76.815,88.428],'cal/(mol*K)'),
        H298 = (-108.625,'kcal/mol'),
        S298 = (105.802,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methylbutyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 282,
    label = "C6H12O2l",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,D} {20,S}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.897,45.485,53.543,60.248,69.841,76.815,88.428],'cal/(mol*K)'),
        H298 = (-108.458,'kcal/mol'),
        S298 = (105.321,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methylbutyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 283,
    label = "C6H12O2m",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,D} {20,S}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.897,45.485,53.543,60.248,69.841,76.815,88.428],'cal/(mol*K)'),
        H298 = (-111.851,'kcal/mol'),
        S298 = (105.802,'cal/(mol*K)'),
    ),
    shortDesc = u"""1-ethylpropyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 284,
    label = "C6H12O2n",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {2,S} {10,S} {11,S} {12,S}
6  C u0 p0 c0 {7,S} {19,D} {20,S}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {5,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.883,46.065,54.515,61.28,70.393,77.037,88.683],'cal/(mol*K)'),
        H298 = (-115.508,'kcal/mol'),
        S298 = (98.587,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,1-dimethylpropyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 285,
    label = "C6H12O2o",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,D} {20,S}
7  O u0 p2 c0 {2,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.847,45.507,53.642,60.404,70.02,76.943,88.576],'cal/(mol*K)'),
        H298 = (-111.899,'kcal/mol'),
        S298 = (101.713,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2-dimethylpropyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 286,
    label = "C6H12O2p",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,D} {20,S}
7  O u0 p2 c0 {2,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.883,46.065,54.515,61.28,70.393,77.037,88.683],'cal/(mol*K)'),
        H298 = (-111.134,'kcal/mol'),
        S298 = (99.87,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethylpropyl formate""",
    longDesc = 
u"""

""",
)

entry(
    index = 287,
    label = "C6H12O2q",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {4,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {6,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {5,S} {7,S} {20,D}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([38.174,46.604,54.927,62.448,73.731,80.363,91.711],'cal/(mol*K)'),
        H298 = (-115.986,'kcal/mol'),
        S298 = (105.962,'cal/(mol*K)'),
    ),
    shortDesc = u"""butyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 288,
    label = "C6H12O2r",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {7,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {6,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {5,S} {7,S} {20,D}
7  O u0 p2 c0 {2,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.074,46.705,55.567,62.845,73.138,80.541,91.915],'cal/(mol*K)'),
        H298 = (-118.233,'kcal/mol'),
        S298 = (106.363,'cal/(mol*K)'),
    ),
    shortDesc = u"""isobutyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 289,
    label = "C6H12O2s",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {6,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {5,S} {7,S} {20,D}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.263,47.263,56.314,63.586,73.794,81.609,93.134],'cal/(mol*K)'),
        H298 = (-120.408,'kcal/mol'),
        S298 = (105.16,'cal/(mol*K)'),
    ),
    shortDesc = u"""sec-butyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 290,
    label = "C6H12O2t",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {6,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {5,S} {7,S} {20,D}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.337,47.606,56.826,64.109,74.075,81.745,93.288],'cal/(mol*K)'),
        H298 = (-124.997,'kcal/mol'),
        S298 = (97.224,'cal/(mol*K)'),
    ),
    shortDesc = u"""tert-butyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 291,
    label = "C6H12O2u",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {8,S} {9,S}
2  C u0 p0 c0 {5,S} {6,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {17,S} {18,S} {19,S}
5  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
6  C u0 p0 c0 {2,S} {7,S} {20,D}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {5,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 H u0 p0 c0 {4,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.642,47.446,55.939,62.813,72.96,80.793,91.137],'cal/(mol*K)'),
        H298 = (-115.46,'kcal/mol'),
        S298 = (105.802,'cal/(mol*K)'),
    ),
    shortDesc = u"""propyl propanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 292,
    label = "C6H12O2v",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {5,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
4  C u0 p0 c0 {1,S} {17,S} {18,S} {19,S}
5  C u0 p0 c0 {2,S} {11,S} {12,S} {13,S}
6  C u0 p0 c0 {2,S} {7,S} {20,D}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {5,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {3,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 H u0 p0 c0 {4,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([38.165,47.088,55.25,62.408,73.445,80.669,90.998],'cal/(mol*K)'),
        H298 = (-119.786,'kcal/mol'),
        S298 = (103.717,'cal/(mol*K)'),
    ),
    shortDesc = u"""isopropyl propanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 293,
    label = "C6H12O2w",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
3  C u0 p0 c0 {5,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {3,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {2,S} {7,S} {20,D}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.779,47.336,55.866,62.826,72.938,80.735,93.168],'cal/(mol*K)'),
        H298 = (-116.034,'kcal/mol'),
        S298 = (105.721,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl butanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 294,
    label = "C6H12O2x",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {6,S} {8,S}
2  C u0 p0 c0 {5,S} {7,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {2,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {1,S} {7,S} {20,D}
7  O u0 p2 c0 {2,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.209,45.578,54.963,62.502,72.954,80.781,93.221],'cal/(mol*K)'),
        H298 = (-119.404,'kcal/mol'),
        S298 = (103.879,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl isobutanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 295,
    label = "C6H12O2y",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {6,S} {7,S} {15,S}
2  C u0 p0 c0 {1,S} {3,S} {16,S} {17,S}
3  C u0 p0 c0 {2,S} {4,S} {18,S} {19,S}
4  C u0 p0 c0 {3,S} {5,S} {20,S} {21,S}
5  C u0 p0 c0 {4,S} {6,S} {22,S} {23,S}
6  C u0 p0 c0 {1,S} {5,S} {24,S} {25,S}
7  O u0 p2 c0 {1,S} {8,S}
8  O u0 p2 c0 {7,S} {9,S}
9  C u0 p0 c0 {8,S} {10,S} {14,S} {26,S}
10 C u0 p0 c0 {9,S} {11,S} {27,S} {28,S}
11 C u0 p0 c0 {10,S} {12,S} {29,S} {30,S}
12 C u0 p0 c0 {11,S} {13,S} {31,S} {32,S}
13 C u0 p0 c0 {12,S} {14,S} {33,S} {34,S}
14 C u0 p0 c0 {9,S} {13,S} {35,S} {36,S}
15 H u0 p0 c0 {1,S}
16 H u0 p0 c0 {2,S}
17 H u0 p0 c0 {2,S}
18 H u0 p0 c0 {3,S}
19 H u0 p0 c0 {3,S}
20 H u0 p0 c0 {4,S}
21 H u0 p0 c0 {4,S}
22 H u0 p0 c0 {5,S}
23 H u0 p0 c0 {5,S}
24 H u0 p0 c0 {6,S}
25 H u0 p0 c0 {6,S}
26 H u0 p0 c0 {9,S}
27 H u0 p0 c0 {10,S}
28 H u0 p0 c0 {10,S}
29 H u0 p0 c0 {11,S}
30 H u0 p0 c0 {11,S}
31 H u0 p0 c0 {12,S}
32 H u0 p0 c0 {12,S}
33 H u0 p0 c0 {13,S}
34 H u0 p0 c0 {13,S}
35 H u0 p0 c0 {14,S}
36 H u0 p0 c0 {14,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.373,46.267,56.406,65.005,77.641,86.25,97.581],'cal/(mol*K)'),
        H298 = (-52.578,'kcal/mol'),
        S298 = (90.973,'cal/(mol*K)'),
    ),
    shortDesc = u"""cyclohexyl peroxide""",
    longDesc = 
u"""

""",
)

entry(
    index = 296,
    label = "C6H12O2z",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {6,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {5,S} {19,D}
7  O u0 p2 c0 {1,S} {20,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([38.476,47.367,55.33,62.235,73.084,80.775,91.387],'cal/(mol*K)'),
        H298 = (-130.446,'kcal/mol'),
        S298 = (104.519,'cal/(mol*K)'),
    ),
    shortDesc = u"""diacetone alcohol""",
    longDesc = 
u"""

""",
)

entry(
    index = 297,
    label = "C6H12O2aa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {11,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {7,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {1,S} {7,S} {20,D}
7  O u0 p2 c0 {5,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([38.165,47.088,55.25,62.408,73.445,80.669,90.998],'cal/(mol*K)'),
        H298 = (-117.623,'kcal/mol'),
        S298 = (104.762,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl tert-pentanoate""",
    longDesc = 
u"""

""",
)

entry(
    index = 300,
    label = "C6H12O3a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {11,S} {12,S}
2  C u0 p0 c0 {1,S} {8,S} {9,S} {10,S}
3  C u0 p0 c0 {4,S} {7,S} {13,S} {14,S}
4  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
5  C u0 p0 c0 {6,S} {18,S} {19,S} {20,S}
6  C u0 p0 c0 {5,S} {8,S} {21,D}
7  O u0 p2 c0 {1,S} {3,S}
8  O u0 p2 c0 {2,S} {6,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 O u0 p2 c0 {6,D}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([39.531,50.016,59.26,66.826,77.731,85.457,96.684],'cal/(mol*K)'),
        H298 = (-146.029,'kcal/mol'),
        S298 = (117.651,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethoxyethyl acetate""",
    longDesc = 
u"""

""",
)

entry(
    index = 301,
    label = "C6H12O3b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {10,S} {11,S}
2  C u0 p0 c0 {1,S} {4,S} {12,S} {13,S}
3  C u0 p0 c0 {1,S} {6,S} {7,S} {9,S}
4  C u0 p0 c0 {2,S} {5,S} {14,S} {15,S}
5  C u0 p0 c0 {4,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {3,S} {8,S} {19,D}
7  O u0 p2 c0 {3,S} {20,S}
8  O u0 p2 c0 {6,S} {21,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 O u0 p2 c0 {6,D}
20 H u0 p0 c0 {7,S}
21 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([41.562,51.434,60.088,67.327,78.179,85.867,97.148],'cal/(mol*K)'),
        H298 = (-163.238,'kcal/mol'),
        S298 = (112.039,'cal/(mol*K)'),
    ),
    shortDesc = u"""hydroxycaproic acid""",
    longDesc = 
u"""

""",
)

entry(
    index = 302,
    label = "C6H12O3c",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {7,S} {9,S} {10,S}
2  C u0 p0 c0 {5,S} {7,S} {8,S} {11,S}
3  C u0 p0 c0 {6,S} {8,S} {9,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {3,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {2,S}
8  O u0 p2 c0 {2,S} {3,S}
9  O u0 p2 c0 {1,S} {3,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([35.798,48.399,59.374,67.645,77.965,85.451,96.677],'cal/(mol*K)'),
        H298 = (-154.226,'kcal/mol'),
        S298 = (80.842,'cal/(mol*K)'),
    ),
    shortDesc = u"""paraldehyde""",
    longDesc = 
u"""

""",
)

entry(
    index = 303,
    label = "C6H14Oa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {10,S} {11,S}
2  C u0 p0 c0 {1,S} {4,S} {12,S} {13,S}
3  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
4  C u0 p0 c0 {2,S} {6,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {7,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {5,S} {21,S}
8  H u0 p0 c0 {3,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.683,46.889,55.648,63.232,74.779,83.098,95.277],'cal/(mol*K)'),
        H298 = (-75.713,'kcal/mol'),
        S298 = (105.143,'cal/(mol*K)'),
    ),
    shortDesc = u"""1-hexanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 304,
    label = "C6H14Ob",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {4,S} {11,S} {12,S}
4  C u0 p0 c0 {3,S} {6,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.806,47.346,56.254,63.782,75.091,83.628,95.886],'cal/(mol*K)'),
        H298 = (-79.705,'kcal/mol'),
        S298 = (104.422,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-hexanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 305,
    label = "C6H14Oc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
4  C u0 p0 c0 {2,S} {6,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.449,46.768,55.581,63.152,74.678,83.194,95.388],'cal/(mol*K)'),
        H298 = (-79.227,'kcal/mol'),
        S298 = (97.544,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-hexanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 306,
    label = "C6H14Od",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {7,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.743,46.353,55.367,62.981,74.384,82.978,95.141],'cal/(mol*K)'),
        H298 = (-77.171,'kcal/mol'),
        S298 = (107.148,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 307,
    label = "C6H14Oe",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {7,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.449,46.768,55.581,63.152,74.678,83.194,95.388],'cal/(mol*K)'),
        H298 = (-77.171,'kcal/mol'),
        S298 = (104.438,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-1-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 308,
    label = "C6H14Of",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {4,S} {11,S} {12,S}
4  C u0 p0 c0 {3,S} {7,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.449,46.768,55.581,63.152,74.678,83.194,95.388],'cal/(mol*K)'),
        H298 = (-77.649,'kcal/mol'),
        S298 = (102.835,'cal/(mol*K)'),
    ),
    shortDesc = u"""4-methyl-1-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 309,
    label = "C6H14Og",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {3,S} {6,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {2,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
6  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
7  O u0 p2 c0 {2,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {6,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.737,47.362,56.32,63.834,74.987,83.376,95.596],'cal/(mol*K)'),
        H298 = (-81.067,'kcal/mol'),
        S298 = (104.238,'cal/(mol*K)'),
    ),
    shortDesc = u"""4-methyl-2-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 310,
    label = "C6H14Oh",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.434,47.348,56.553,64.184,75.23,83.416,95.642],'cal/(mol*K)'),
        H298 = (-83.409,'kcal/mol'),
        S298 = (79.283,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-2-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 311,
    label = "C6H14Oi",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {2,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.399,46.79,55.68,63.308,74.857,83.322,95.535],'cal/(mol*K)'),
        H298 = (-80.111,'kcal/mol'),
        S298 = (96.534,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-2-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 312,
    label = "C6H14Oj",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {7,S} {9,S}
3  C u0 p0 c0 {2,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {2,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.399,46.79,55.68,63.308,74.857,83.322,95.535],'cal/(mol*K)'),
        H298 = (-80.111,'kcal/mol'),
        S298 = (96.534,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-3-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 313,
    label = "C6H14Ok",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.434,47.348,56.553,64.184,75.23,83.416,95.642],'cal/(mol*K)'),
        H298 = (-82.214,'kcal/mol'),
        S298 = (83.291,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-3-pentanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 314,
    label = "C6H14Ol",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {7,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.989,46.725,55.769,63.314,74.498,83.063,95.238],'cal/(mol*K)'),
        H298 = (-76.693,'kcal/mol'),
        S298 = (106.434,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethyl-1-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 315,
    label = "C6H14Om",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
6  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
7  O u0 p2 c0 {3,S} {21,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {6,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.434,47.348,56.553,64.184,75.23,83.416,95.642],'cal/(mol*K)'),
        H298 = (-78.868,'kcal/mol'),
        S298 = (94.514,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethyl-1-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 316,
    label = "C6H14On",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {9,S}
3  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {3,S} {21,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.399,46.79,55.68,63.308,74.857,83.322,95.535],'cal/(mol*K)'),
        H298 = (-78.056,'kcal/mol'),
        S298 = (103.428,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-dimethyl-1-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 317,
    label = "C6H14Op",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {7,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {3,S} {21,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.434,47.348,56.553,64.184,75.23,83.416,95.642],'cal/(mol*K)'),
        H298 = (-80.063,'kcal/mol'),
        S298 = (90.506,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,3-dimethyl-1-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 318,
    label = "C6H14Oq",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.384,47.369,56.653,64.34,75.409,83.544,95.79],'cal/(mol*K)'),
        H298 = (-83.218,'kcal/mol'),
        S298 = (81.88,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-dimethyl-2-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 319,
    label = "C6H14Or",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {8,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
5  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
6  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
7  O u0 p2 c0 {2,S} {21,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {6,S}
13 H u0 p0 c0 {6,S}
14 H u0 p0 c0 {6,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.384,47.369,56.653,64.34,75.409,83.544,95.79],'cal/(mol*K)'),
        H298 = (-81.927,'kcal/mol'),
        S298 = (86.209,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,3-dimethyl-2-butanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 323,
    label = "C6H14Ox",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {8,S} {9,S}
2  C u0 p0 c0 {4,S} {6,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {3,S} {4,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([36.838,46.518,55.64,63.314,74.73,83.437,95.989],'cal/(mol*K)'),
        H298 = (-70.049,'kcal/mol'),
        S298 = (101.376,'cal/(mol*K)'),
    ),
    shortDesc = u"""dipropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 324,
    label = "C6H14Oy",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {5,S} {7,S} {8,S}
2  C u0 p0 c0 {3,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {3,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.939,46.765,55.317,62.874,74.65,83.153,95.661],'cal/(mol*K)'),
        H298 = (-73.18,'kcal/mol'),
        S298 = (98.41,'cal/(mol*K)'),
    ),
    shortDesc = u"""propyl isopropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 325,
    label = "C6H14Oz",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {5,S} {6,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {2,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([38.928,46.653,54.527,62.071,74.847,83.761,96.361],'cal/(mol*K)'),
        H298 = (-76.335,'kcal/mol'),
        S298 = (95.523,'cal/(mol*K)'),
    ),
    shortDesc = u"""diisopropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 326,
    label = "C6H14Oaa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {10,S} {11,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {5,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {4,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.989,46.744,55.217,62.717,74.471,83.024,95.513],'cal/(mol*K)'),
        H298 = (-66.703,'kcal/mol'),
        S298 = (102.818,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl pentyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 327,
    label = "C6H14Obb",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.939,46.765,55.317,62.874,74.65,83.153,95.661],'cal/(mol*K)'),
        H298 = (-69.906,'kcal/mol'),
        S298 = (100.654,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 1-methylbutyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 328,
    label = "C6H14Occ",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.939,46.765,55.317,62.874,74.65,83.153,95.661],'cal/(mol*K)'),
        H298 = (-67.922,'kcal/mol'),
        S298 = (101.776,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 2-methylbutyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 329,
    label = "C6H14Odd",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {3,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.939,46.765,55.317,62.874,74.65,83.153,95.661],'cal/(mol*K)'),
        H298 = (-68.543,'kcal/mol'),
        S298 = (100.574,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 3-methylbutyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 330,
    label = "C6H14Oee",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.939,46.765,55.317,62.874,74.65,83.153,95.661],'cal/(mol*K)'),
        H298 = (-69.284,'kcal/mol'),
        S298 = (98.41,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 1-ethylpropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 331,
    label = "C6H14Off",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
4  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
5  C u0 p0 c0 {2,S} {10,S} {11,S} {12,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {2,S} {6,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {5,S}
11 H u0 p0 c0 {5,S}
12 H u0 p0 c0 {5,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {4,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.889,46.787,55.416,63.03,74.83,83.282,95.809],'cal/(mol*K)'),
        H298 = (-70.216,'kcal/mol'),
        S298 = (99.131,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 1,2-dimethylpropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 332,
    label = "C6H14Ogg",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([38.392,47.862,56.786,64.363,75.759,84.355,97.044],'cal/(mol*K)'),
        H298 = (-74.566,'kcal/mol'),
        S298 = (97.447,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl tert-pentyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 333,
    label = "C6H14Ohh",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {2,S} {6,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.924,47.345,56.289,63.906,75.202,83.375,95.917],'cal/(mol*K)'),
        H298 = (-70.766,'kcal/mol'),
        S298 = (93.84,'cal/(mol*K)'),
    ),
    shortDesc = u"""methyl 2,2-dimethylpropyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 334,
    label = "C6H14Oii",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {6,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {4,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {3,S} {4,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.866,46.933,55.591,63.107,74.743,83.487,96.046],'cal/(mol*K)'),
        H298 = (-69.882,'kcal/mol'),
        S298 = (102.738,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl butyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 335,
    label = "C6H14Ojj",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {8,S}
2  C u0 p0 c0 {1,S} {7,S} {9,S} {10,S}
3  C u0 p0 c0 {6,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {3,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {2,S} {3,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.939,46.765,55.317,62.874,74.65,83.153,95.661],'cal/(mol*K)'),
        H298 = (-71.411,'kcal/mol'),
        S298 = (99.933,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl isobutyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 336,
    label = "C6H14Okk",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {7,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {6,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {3,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {3,S}
8  H u0 p0 c0 {1,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.939,46.765,55.317,62.874,74.65,83.153,95.661],'cal/(mol*K)'),
        H298 = (-72.798,'kcal/mol'),
        S298 = (100.574,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl sec-butyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 337,
    label = "C6H14Oll",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {6,S} {7,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {10,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {2,S}
8  H u0 p0 c0 {2,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([37.924,47.345,56.289,63.906,75.202,83.375,95.917],'cal/(mol*K)'),
        H298 = (-75.642,'kcal/mol'),
        S298 = (95.203,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethyl tert-butyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 340,
    label = "C6H14O2a",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {7,S} {8,S} {9,S}
2  C u0 p0 c0 {6,S} {7,S} {10,S} {11,S}
3  C u0 p0 c0 {5,S} {8,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {14,S} {15,S} {16,S}
5  C u0 p0 c0 {3,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {2,S} {20,S} {21,S} {22,S}
7  O u0 p2 c0 {1,S} {2,S}
8  O u0 p2 c0 {1,S} {3,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([38.829,49.365,58.823,66.74,78.597,87.207,98.664],'cal/(mol*K)'),
        H298 = (-108.385,'kcal/mol'),
        S298 = (108.737,'cal/(mol*K)'),
    ),
    shortDesc = u"""acetal""",
    longDesc = 
u"""

""",
)

entry(
    index = 341,
    label = "C6H14O2b",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {9,S} {10,S}
2  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
3  C u0 p0 c0 {1,S} {7,S} {13,S} {14,S}
4  C u0 p0 c0 {5,S} {7,S} {15,S} {16,S}
5  C u0 p0 c0 {4,S} {8,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {3,S} {4,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([39.882,50.368,59.301,66.886,78.897,87.696,99.271],'cal/(mol*K)'),
        H298 = (-105.397,'kcal/mol'),
        S298 = (114.749,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-butoxyethanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 342,
    label = "C6H14O2c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {11,S} {12,S}
2  C u0 p0 c0 {1,S} {4,S} {13,S} {14,S}
3  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
4  C u0 p0 c0 {2,S} {6,S} {15,S} {16,S}
5  C u0 p0 c0 {3,S} {8,S} {17,S} {18,S}
6  C u0 p0 c0 {4,S} {7,S} {19,S} {20,S}
7  O u0 p2 c0 {6,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([41.471,51.785,61.545,69.476,80.443,88.702,101.434],'cal/(mol*K)'),
        H298 = (-127.807,'kcal/mol'),
        S298 = (109.328,'cal/(mol*K)'),
    ),
    shortDesc = u"""hexylene glycol""",
    longDesc = 
u"""

""",
)

entry(
    index = 343,
    label = "C6H14O2d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {7,S} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {10,S} {11,S}
3  C u0 p0 c0 {2,S} {4,S} {12,S} {13,S}
4  C u0 p0 c0 {3,S} {6,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {8,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.548,50.085,59.383,67.303,78.988,87.656,100.239],'cal/(mol*K)'),
        H298 = (-115.364,'kcal/mol'),
        S298 = (110.531,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,2-hexanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 344,
    label = "C6H14O2e",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {9,S}
2  C u0 p0 c0 {1,S} {4,S} {12,S} {13,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {2,S} {6,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {8,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.548,50.085,59.383,67.303,78.988,87.656,100.239],'cal/(mol*K)'),
        H298 = (-115.364,'kcal/mol'),
        S298 = (110.531,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,3-hexanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 345,
    label = "C6H14O2f",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {7,S} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {12,S} {13,S}
3  C u0 p0 c0 {2,S} {5,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {6,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {8,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.548,50.085,59.383,67.303,78.988,87.656,100.239],'cal/(mol*K)'),
        H298 = (-115.364,'kcal/mol'),
        S298 = (110.531,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,4-hexanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 346,
    label = "C6H14O2g",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {6,S} {7,S} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {14,S} {15,S}
3  C u0 p0 c0 {2,S} {4,S} {12,S} {13,S}
4  C u0 p0 c0 {3,S} {5,S} {10,S} {11,S}
5  C u0 p0 c0 {4,S} {8,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {2,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.548,50.085,59.383,67.303,78.988,87.656,100.239],'cal/(mol*K)'),
        H298 = (-115.842,'kcal/mol'),
        S298 = (108.928,'cal/(mol*K)'),
    ),
    shortDesc = u"""1,5-hexanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 348,
    label = "C6H14O2i",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {7,S} {10,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {4,S} {11,S} {12,S}
4  C u0 p0 c0 {3,S} {6,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  O u0 p2 c0 {2,S} {22,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-118.304,'kcal/mol'),
        S298 = (102.627,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-hexanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 349,
    label = "C6H14O2j",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {7,S} {10,S}
2  C u0 p0 c0 {3,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {2,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {6,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {21,S}
8  O u0 p2 c0 {2,S} {22,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-116.912,'kcal/mol'),
        S298 = (105.934,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,4-hexanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 350,
    label = "C6H14O2k",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {8,S} {9,S}
2  C u0 p0 c0 {4,S} {6,S} {7,S} {10,S}
3  C u0 p0 c0 {1,S} {4,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {3,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {2,S} {21,S}
8  O u0 p2 c0 {1,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-119.499,'kcal/mol'),
        S298 = (98.619,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,5-hexanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 351,
    label = "C6H14O2l",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {8,S} {9,S}
2  C u0 p0 c0 {1,S} {4,S} {7,S} {10,S}
3  C u0 p0 c0 {1,S} {5,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {6,S} {13,S} {14,S}
5  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {4,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {2,S} {21,S}
8  O u0 p2 c0 {1,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-117.826,'kcal/mol'),
        S298 = (104.23,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,4-hexanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 352,
    label = "C6H14O2m",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {22,S}
8  O u0 p2 c0 {4,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.533,50.664,60.355,68.336,79.54,87.878,100.492],'cal/(mol*K)'),
        H298 = (-118.352,'kcal/mol'),
        S298 = (96.278,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1,2-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 353,
    label = "C6H14O2n",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {7,S} {10,S}
3  C u0 p0 c0 {2,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {2,S} {22,S}
8  O u0 p2 c0 {4,S} {21,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-115.771,'kcal/mol'),
        S298 = (111.124,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1,3-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 354,
    label = "C6H14O2o",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {6,S} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {10,S} {11,S}
3  C u0 p0 c0 {2,S} {5,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {8,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-113.309,'kcal/mol'),
        S298 = (119.381,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-1,5-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 355,
    label = "C6H14O2p",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {8,S} {9,S}
3  C u0 p0 c0 {2,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {22,S}
8  O u0 p2 c0 {2,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.483,50.686,60.454,68.492,79.72,88.007,100.64],'cal/(mol*K)'),
        H298 = (-120.933,'kcal/mol'),
        S298 = (89.576,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-2,3-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 356,
    label = "C6H14O2q",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {22,S}
8  O u0 p2 c0 {4,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.533,50.664,60.355,68.336,79.54,87.878,100.492],'cal/(mol*K)'),
        H298 = (-118.352,'kcal/mol'),
        S298 = (96.278,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-1,3-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 357,
    label = "C6H14O2r",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {6,S} {9,S}
2  C u0 p0 c0 {1,S} {4,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {5,S} {12,S} {13,S}
4  C u0 p0 c0 {2,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {3,S} {8,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.548,50.085,59.383,67.303,78.988,87.656,100.239],'cal/(mol*K)'),
        H298 = (-113.309,'kcal/mol'),
        S298 = (117.425,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-1,5-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 358,
    label = "C6H14O2s",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {22,S}
8  O u0 p2 c0 {2,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.483,50.686,60.454,68.492,79.72,88.007,100.64],'cal/(mol*K)'),
        H298 = (-120.216,'kcal/mol'),
        S298 = (91.981,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-2,3-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 359,
    label = "C6H14O2t",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {9,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {8,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {2,S} {21,S}
8  O u0 p2 c0 {3,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.447,50.128,59.581,67.616,79.347,87.913,100.533],'cal/(mol*K)'),
        H298 = (-118.949,'kcal/mol'),
        S298 = (102.418,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methyl-2,4-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 360,
    label = "C6H14O2u",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {4,S} {11,S} {12,S}
4  C u0 p0 c0 {3,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {22,S}
8  O u0 p2 c0 {4,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.533,50.664,60.355,68.336,79.54,87.878,100.492],'cal/(mol*K)'),
        H298 = (-119.547,'kcal/mol'),
        S298 = (92.27,'cal/(mol*K)'),
    ),
    shortDesc = u"""4-methyl-1,4-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 361,
    label = "C6H14O2x",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {7,S}
2  C u0 p0 c0 {1,S} {5,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {22,S}
8  O u0 p2 c0 {4,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.533,50.664,60.355,68.336,79.54,87.878,100.492],'cal/(mol*K)'),
        H298 = (-117.157,'kcal/mol'),
        S298 = (100.286,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethyl-1,2-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 362,
    label = "C6H14O2y",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {9,S}
2  C u0 p0 c0 {1,S} {5,S} {7,S} {10,S}
3  C u0 p0 c0 {1,S} {6,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
6  C u0 p0 c0 {3,S} {15,S} {16,S} {17,S}
7  O u0 p2 c0 {2,S} {22,S}
8  O u0 p2 c0 {4,S} {21,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {6,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-115.771,'kcal/mol'),
        S298 = (111.124,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethyl-1,3-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 363,
    label = "C6H14O2z",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {9,S}
2  C u0 p0 c0 {1,S} {5,S} {12,S} {13,S}
3  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {8,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-112.831,'kcal/mol'),
        S298 = (120.984,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-ethyl-1,4-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 364,
    label = "C6H14O2aa",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {7,S} {9,S}
3  C u0 p0 c0 {1,S} {8,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
6  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
7  O u0 p2 c0 {2,S} {22,S}
8  O u0 p2 c0 {3,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {6,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.483,50.686,60.454,68.492,79.72,88.007,100.64],'cal/(mol*K)'),
        H298 = (-116.87,'kcal/mol'),
        S298 = (103.204,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethyl-1,3-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 365,
    label = "C6H14O2bb",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {4,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {2,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {3,S} {21,S}
8  O u0 p2 c0 {4,S} {22,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.483,50.686,60.454,68.492,79.72,88.007,100.64],'cal/(mol*K)'),
        H298 = (-115.006,'kcal/mol'),
        S298 = (109.457,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,2-dimethyl-1,4-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 366,
    label = "C6H14O2cc",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {6,S} {9,S}
3  C u0 p0 c0 {2,S} {8,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
5  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
6  C u0 p0 c0 {2,S} {12,S} {13,S} {14,S}
7  O u0 p2 c0 {1,S} {22,S}
8  O u0 p2 c0 {3,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {6,S}
13 H u0 p0 c0 {6,S}
14 H u0 p0 c0 {6,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.483,50.686,60.454,68.492,79.72,88.007,100.64],'cal/(mol*K)'),
        H298 = (-118.161,'kcal/mol'),
        S298 = (98.875,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-dimethyl-1,2-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 368,
    label = "C6H14O2gg",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {8,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {7,S}
3  C u0 p0 c0 {1,S} {9,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {2,S} {21,S}
8  O u0 p2 c0 {1,S} {22,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.468,51.266,61.427,69.524,80.272,88.229,100.893],'cal/(mol*K)'),
        H298 = (-122.606,'kcal/mol'),
        S298 = (79.732,'cal/(mol*K)'),
    ),
    shortDesc = u"""2,3-dimethyl-2,3-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 369,
    label = "C6H14O2hh",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {6,S}
2  C u0 p0 c0 {1,S} {3,S} {7,S} {9,S}
3  C u0 p0 c0 {2,S} {8,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {1,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {2,S} {22,S}
8  O u0 p2 c0 {3,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.483,50.686,60.454,68.492,79.72,88.007,100.64],'cal/(mol*K)'),
        H298 = (-117.587,'kcal/mol'),
        S298 = (100.799,'cal/(mol*K)'),
    ),
    shortDesc = u"""3,3-dimethyl-1,2-butanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 370,
    label = "C6H14O2ii",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {9,S}
2  C u0 p0 c0 {1,S} {3,S} {10,S} {11,S}
3  C u0 p0 c0 {2,S} {6,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {7,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {8,S} {16,S} {17,S}
6  C u0 p0 c0 {3,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {21,S}
8  O u0 p2 c0 {5,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.548,50.085,59.383,67.303,78.988,87.656,100.239],'cal/(mol*K)'),
        H298 = (-112.831,'kcal/mol'),
        S298 = (119.028,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-propyl-1,3-propanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 371,
    label = "C6H14O2jj",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {10,S}
2  C u0 p0 c0 {1,S} {5,S} {6,S} {9,S}
3  C u0 p0 c0 {1,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {2,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {3,S} {21,S}
8  O u0 p2 c0 {4,S} {22,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-112.807,'kcal/mol'),
        S298 = (121.064,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-isopropyl-1,3-propanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 372,
    label = "C6H14O2kk",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {9,S} {10,S}
3  C u0 p0 c0 {1,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {8,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {3,S} {21,S}
8  O u0 p2 c0 {4,S} {22,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.533,50.664,60.355,68.336,79.54,87.878,100.492],'cal/(mol*K)'),
        H298 = (-113.811,'kcal/mol'),
        S298 = (111.509,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-methyl-2-ethyl-1,3-propanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 373,
    label = "C6H14O2ll",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {5,S} {7,S} {9,S}
2  C u0 p0 c0 {3,S} {6,S} {8,S} {10,S}
3  C u0 p0 c0 {2,S} {7,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {3,S}
8  O u0 p2 c0 {2,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.862,51.427,61.031,68.869,80.123,88.683,101.345],'cal/(mol*K)'),
        H298 = (-105.398,'kcal/mol'),
        S298 = (114.748,'cal/(mol*K)'),
    ),
    shortDesc = u"""1-(1-methylethoxy)-2-propanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 374,
    label = "C6H14O2mm",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {6,S} {9,S}
2  C u0 p0 c0 {1,S} {7,S} {10,S} {11,S}
3  C u0 p0 c0 {4,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {3,S} {8,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {1,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {2,S} {3,S}
8  O u0 p2 c0 {4,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.862,51.427,61.031,68.869,80.123,88.683,101.345],'cal/(mol*K)'),
        H298 = (-105.398,'kcal/mol'),
        S298 = (114.751,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-(2-methylpropoxy)ethanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 375,
    label = "C6H14O2nn",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {5,S} {8,S} {9,S}
2  C u0 p0 c0 {4,S} {6,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {7,S} {14,S} {15,S}
4  C u0 p0 c0 {2,S} {7,S} {12,S} {13,S}
5  C u0 p0 c0 {1,S} {19,S} {20,S} {21,S}
6  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
7  O u0 p2 c0 {3,S} {4,S}
8  O u0 p2 c0 {1,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {6,S}
17 H u0 p0 c0 {6,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 H u0 p0 c0 {5,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.367,50.724,60.169,68.001,79.508,88.169,100.71],'cal/(mol*K)'),
        H298 = (-105.398,'kcal/mol'),
        S298 = (114.748,'cal/(mol*K)'),
    ),
    shortDesc = u"""1-propoxy-2-propanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 376,
    label = "C6H14O2oo",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {11,S} {12,S}
2  C u0 p0 c0 {1,S} {8,S} {13,S} {14,S}
3  C u0 p0 c0 {5,S} {7,S} {9,S} {10,S}
4  C u0 p0 c0 {6,S} {8,S} {15,S} {16,S}
5  C u0 p0 c0 {3,S} {17,S} {18,S} {19,S}
6  C u0 p0 c0 {4,S} {20,S} {21,S} {22,S}
7  O u0 p2 c0 {1,S} {3,S}
8  O u0 p2 c0 {2,S} {4,S}
9  H u0 p0 c0 {3,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([39.169,50.086,59.406,67.227,79.276,87.978,99.904],'cal/(mol*K)'),
        H298 = (-105.397,'kcal/mol'),
        S298 = (114.75,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylene glycol diethyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 378,
    label = "C6H14O2rr",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {1,S} {3,S} {9,S} {10,S}
3  C u0 p0 c0 {2,S} {8,S} {11,S} {12,S}
4  C u0 p0 c0 {1,S} {13,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {7,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {6,S}
8  O u0 p2 c0 {3,S} {22,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([41.189,51.703,60.397,67.674,79.619,89.334,101.125],'cal/(mol*K)'),
        H298 = (-105.398,'kcal/mol'),
        S298 = (114.749,'cal/(mol*K)'),
    ),
    shortDesc = u"""3-methoxy-3-methylbutanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 379,
    label = "C6H14O2ss",
    molecule = 
"""
1  C u0 p0 c0 {3,S} {4,S} {5,S} {7,S}
2  C u0 p0 c0 {3,S} {6,S} {8,S} {9,S}
3  C u0 p0 c0 {1,S} {2,S} {10,S} {11,S}
4  C u0 p0 c0 {1,S} {12,S} {13,S} {14,S}
5  C u0 p0 c0 {1,S} {15,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {1,S} {22,S}
8  O u0 p2 c0 {2,S} {21,S}
9  H u0 p0 c0 {2,S}
10 H u0 p0 c0 {3,S}
11 H u0 p0 c0 {3,S}
12 H u0 p0 c0 {4,S}
13 H u0 p0 c0 {4,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {5,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {7,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([40.497,50.106,59.482,67.46,79.168,87.785,100.386],'cal/(mol*K)'),
        H298 = (-116.912,'kcal/mol'),
        S298 = (105.934,'cal/(mol*K)'),
    ),
    shortDesc = u"""(R)-(-)-2-methyl-2,4-pentanediol""",
    longDesc = 
u"""

""",
)

entry(
    index = 380,
    label = "C6H14O2tt",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {5,S} {7,S} {9,S}
2  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
3  C u0 p0 c0 {4,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {3,S} {8,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {2,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {3,S}
8  O u0 p2 c0 {4,S} {22,S}
9  H u0 p0 c0 {1,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([41.189,51.703,60.397,67.674,79.619,89.334,101.125],'cal/(mol*K)'),
        H298 = (-105.398,'kcal/mol'),
        S298 = (114.743,'cal/(mol*K)'),
    ),
    shortDesc = u"""ethylene glycol mono-sec-butyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 381,
    label = "C6H14O3a",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {8,S} {10,S} {11,S}
2  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
3  C u0 p0 c0 {4,S} {7,S} {14,S} {15,S}
4  C u0 p0 c0 {3,S} {9,S} {16,S} {17,S}
5  C u0 p0 c0 {8,S} {18,S} {19,S} {20,S}
6  C u0 p0 c0 {9,S} {21,S} {22,S} {23,S}
7  O u0 p2 c0 {2,S} {3,S}
8  O u0 p2 c0 {1,S} {5,S}
9  O u0 p2 c0 {4,S} {6,S}
10 H u0 p0 c0 {1,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {2,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {3,S}
15 H u0 p0 c0 {3,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {4,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {5,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {6,S}
23 H u0 p0 c0 {6,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([42.792,53.611,63.177,71.201,83.513,92.778,104.967],'cal/(mol*K)'),
        H298 = (-122.128,'kcal/mol'),
        S298 = (120.425,'cal/(mol*K)'),
    ),
    shortDesc = u"""diethylene glycol dimethyl ether""",
    longDesc = 
u"""

""",
)

entry(
    index = 382,
    label = "C6H14O3b",
    molecule = 
"""
1  C u0 p0 c0 {4,S} {6,S} {7,S} {11,S}
2  C u0 p0 c0 {3,S} {5,S} {8,S} {10,S}
3  C u0 p0 c0 {2,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {9,S} {14,S} {15,S}
5  C u0 p0 c0 {2,S} {16,S} {17,S} {18,S}
6  C u0 p0 c0 {1,S} {19,S} {20,S} {21,S}
7  O u0 p2 c0 {1,S} {3,S}
8  O u0 p2 c0 {2,S} {23,S}
9  O u0 p2 c0 {4,S} {22,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {9,S}
23 H u0 p0 c0 {8,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([43.897,55.022,64.712,72.637,84.257,92.768,104.956],'cal/(mol*K)'),
        H298 = (-150.092,'kcal/mol'),
        S298 = (122.429,'cal/(mol*K)'),
    ),
    shortDesc = u"""dipropylene glycol""",
    longDesc = 
u"""

""",
)

entry(
    index = 383,
    label = "C6H14O3c",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {7,S} {12,S} {13,S}
2  C u0 p0 c0 {1,S} {8,S} {14,S} {15,S}
3  C u0 p0 c0 {5,S} {8,S} {16,S} {17,S}
4  C u0 p0 c0 {6,S} {7,S} {10,S} {11,S}
5  C u0 p0 c0 {3,S} {9,S} {18,S} {19,S}
6  C u0 p0 c0 {4,S} {20,S} {21,S} {22,S}
7  O u0 p2 c0 {1,S} {4,S}
8  O u0 p2 c0 {2,S} {3,S}
9  O u0 p2 c0 {5,S} {23,S}
10 H u0 p0 c0 {4,S}
11 H u0 p0 c0 {4,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {1,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {2,S}
16 H u0 p0 c0 {3,S}
17 H u0 p0 c0 {3,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {5,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {6,S}
22 H u0 p0 c0 {6,S}
23 H u0 p0 c0 {9,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([42.567,53.415,63.064,71.163,83.368,92.179,104.289],'cal/(mol*K)'),
        H298 = (-135.034,'kcal/mol'),
        S298 = (124.033,'cal/(mol*K)'),
    ),
    shortDesc = u"""2-(2-ethoxyethoxy)ethanol""",
    longDesc = 
u"""

""",
)

entry(
    index = 384,
    label = "C6H14O3d",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {4,S} {5,S}
2  C u0 p0 c0 {1,S} {6,S} {10,S} {11,S}
3  C u0 p0 c0 {1,S} {7,S} {12,S} {13,S}
4  C u0 p0 c0 {1,S} {8,S} {14,S} {15,S}
5  C u0 p0 c0 {1,S} {9,S} {16,S} {17,S}
6  C u0 p0 c0 {2,S} {18,S} {19,S} {20,S}
7  O u0 p2 c0 {3,S} {21,S}
8  O u0 p2 c0 {4,S} {22,S}
9  O u0 p2 c0 {5,S} {23,S}
10 H u0 p0 c0 {2,S}
11 H u0 p0 c0 {2,S}
12 H u0 p0 c0 {3,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {4,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {5,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {6,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {7,S}
22 H u0 p0 c0 {8,S}
23 H u0 p0 c0 {9,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([43.732,54.611,64.182,72.141,83.999,92.527,104.683],'cal/(mol*K)'),
        H298 = (-153.005,'kcal/mol'),
        S298 = (116.914,'cal/(mol*K)'),
    ),
    shortDesc = u"""trimethylolpropane""",
    longDesc = 
u"""

""",
)

entry(
    index = 385,
    label = "C6H14O4",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {10,S} {11,S} {12,S}
2  C u0 p0 c0 {1,S} {3,S} {13,S} {14,S}
3  O u0 p2 c0 {2,S} {4,S}
4  C u0 p0 c0 {3,S} {5,S} {15,S} {16,S}
5  C u0 p0 c0 {4,S} {6,S} {17,S} {18,S}
6  O u0 p2 c0 {5,S} {7,S}
7  C u0 p0 c0 {6,S} {8,S} {19,S} {20,S}
8  C u0 p0 c0 {7,S} {9,S} {21,S} {22,S}
9  O u0 p2 c0 {8,S} {23,S}
10 O u0 p2 c0 {1,S} {24,S}
11 H u0 p0 c0 {1,S}
12 H u0 p0 c0 {1,S}
13 H u0 p0 c0 {2,S}
14 H u0 p0 c0 {2,S}
15 H u0 p0 c0 {4,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {7,S}
20 H u0 p0 c0 {7,S}
21 H u0 p0 c0 {8,S}
22 H u0 p0 c0 {8,S}
23 H u0 p0 c0 {9,S}
24 H u0 p0 c0 {10,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([46.108,57.064,66.734,74.909,87.396,96.356,109.015],'cal/(mol*K)'),
        H298 = (-173.297,'kcal/mol'),
        S298 = (133.661,'cal/(mol*K)'),
    ),
    shortDesc = u"""triethylene glycol""",
    longDesc = 
u"""

""",
)

entry(
    index = 386,
    label = "C6H14O6",
    molecule = 
"""
1  C u0 p0 c0 {2,S} {3,S} {9,S} {14,S}
2  C u0 p0 c0 {1,S} {4,S} {8,S} {15,S}
3  C u0 p0 c0 {1,S} {5,S} {10,S} {13,S}
4  C u0 p0 c0 {2,S} {6,S} {7,S} {16,S}
5  C u0 p0 c0 {3,S} {12,S} {17,S} {18,S}
6  C u0 p0 c0 {4,S} {11,S} {19,S} {20,S}
7  O u0 p2 c0 {4,S} {22,S}
8  O u0 p2 c0 {2,S} {23,S}
9  O u0 p2 c0 {1,S} {24,S}
10 O u0 p2 c0 {3,S} {25,S}
11 O u0 p2 c0 {6,S} {21,S}
12 O u0 p2 c0 {5,S} {26,S}
13 H u0 p0 c0 {3,S}
14 H u0 p0 c0 {1,S}
15 H u0 p0 c0 {2,S}
16 H u0 p0 c0 {4,S}
17 H u0 p0 c0 {5,S}
18 H u0 p0 c0 {5,S}
19 H u0 p0 c0 {6,S}
20 H u0 p0 c0 {6,S}
21 H u0 p0 c0 {11,S}
22 H u0 p0 c0 {7,S}
23 H u0 p0 c0 {8,S}
24 H u0 p0 c0 {9,S}
25 H u0 p0 c0 {10,S}
26 H u0 p0 c0 {12,S}
""",
    thermo = ThermoData(
        Tdata = ([300,400,500,600,800,1000,1500],'K'),
        Cpdata = ([54.724,67.214,77.64,85.864,97.308,105.41,119.258],'cal/(mol*K)'),
        H298 = (-272.463,'kcal/mol'),
        S298 = (154.287,'cal/(mol*K)'),
    ),
    shortDesc = u"""sorbitol""",
    longDesc = 
u"""

""",
)

